/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_dphg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dp|hg) integrals */

void d1hrr_order_dphg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][5][11] = int_stack + 0;
 Libderiv->deriv_classes[2][6][11] = int_stack + 126;
 Libderiv->deriv_classes[2][7][11] = int_stack + 294;
 Libderiv->deriv_classes[2][8][11] = int_stack + 510;
 Libderiv->deriv_classes[2][9][11] = int_stack + 780;
 Libderiv->deriv_classes[3][5][11] = int_stack + 1110;
 Libderiv->deriv_classes[3][6][11] = int_stack + 1320;
 Libderiv->deriv_classes[3][7][11] = int_stack + 1600;
 Libderiv->deriv_classes[3][8][11] = int_stack + 1960;
 Libderiv->deriv_classes[3][9][11] = int_stack + 2410;
 Libderiv->deriv_classes[2][5][10] = int_stack + 2960;
 Libderiv->deriv_classes[2][6][10] = int_stack + 3086;
 Libderiv->deriv_classes[2][7][10] = int_stack + 3254;
 Libderiv->deriv_classes[2][8][10] = int_stack + 3470;
 Libderiv->deriv_classes[2][9][10] = int_stack + 3740;
 Libderiv->deriv_classes[3][5][10] = int_stack + 4070;
 Libderiv->deriv_classes[3][6][10] = int_stack + 4280;
 Libderiv->deriv_classes[3][7][10] = int_stack + 4560;
 Libderiv->deriv_classes[3][8][10] = int_stack + 4920;
 Libderiv->deriv_classes[3][9][10] = int_stack + 5370;
 Libderiv->deriv_classes[2][5][9] = int_stack + 5920;
 Libderiv->deriv_classes[2][6][9] = int_stack + 6046;
 Libderiv->deriv_classes[2][7][9] = int_stack + 6214;
 Libderiv->deriv_classes[2][8][9] = int_stack + 6430;
 Libderiv->deriv_classes[2][9][9] = int_stack + 6700;
 Libderiv->deriv_classes[3][5][9] = int_stack + 7030;
 Libderiv->deriv_classes[3][6][9] = int_stack + 7240;
 Libderiv->deriv_classes[3][7][9] = int_stack + 7520;
 Libderiv->deriv_classes[3][8][9] = int_stack + 7880;
 Libderiv->deriv_classes[3][9][9] = int_stack + 8330;
 Libderiv->deriv_classes[2][5][8] = int_stack + 8880;
 Libderiv->deriv_classes[2][6][8] = int_stack + 9006;
 Libderiv->deriv_classes[2][7][8] = int_stack + 9174;
 Libderiv->deriv_classes[2][8][8] = int_stack + 9390;
 Libderiv->deriv_classes[2][9][8] = int_stack + 9660;
 Libderiv->deriv_classes[3][5][8] = int_stack + 9990;
 Libderiv->deriv_classes[3][6][8] = int_stack + 10200;
 Libderiv->deriv_classes[3][7][8] = int_stack + 10480;
 Libderiv->deriv_classes[3][8][8] = int_stack + 10840;
 Libderiv->deriv_classes[3][9][8] = int_stack + 11290;
 Libderiv->deriv_classes[2][5][7] = int_stack + 11840;
 Libderiv->deriv_classes[2][6][7] = int_stack + 11966;
 Libderiv->deriv_classes[2][7][7] = int_stack + 12134;
 Libderiv->deriv_classes[2][8][7] = int_stack + 12350;
 Libderiv->deriv_classes[2][9][7] = int_stack + 12620;
 Libderiv->deriv_classes[3][5][7] = int_stack + 12950;
 Libderiv->deriv_classes[3][6][7] = int_stack + 13160;
 Libderiv->deriv_classes[3][7][7] = int_stack + 13440;
 Libderiv->deriv_classes[3][8][7] = int_stack + 13800;
 Libderiv->deriv_classes[3][9][7] = int_stack + 14250;
 Libderiv->deriv_classes[2][5][6] = int_stack + 14800;
 Libderiv->deriv_classes[2][6][6] = int_stack + 14926;
 Libderiv->deriv_classes[2][7][6] = int_stack + 15094;
 Libderiv->deriv_classes[2][8][6] = int_stack + 15310;
 Libderiv->deriv_classes[2][9][6] = int_stack + 15580;
 Libderiv->dvrr_classes[3][5] = int_stack + 15910;
 Libderiv->deriv_classes[3][5][6] = int_stack + 16120;
 Libderiv->dvrr_classes[3][6] = int_stack + 16330;
 Libderiv->deriv_classes[3][6][6] = int_stack + 16610;
 Libderiv->dvrr_classes[3][7] = int_stack + 16890;
 Libderiv->deriv_classes[3][7][6] = int_stack + 17250;
 Libderiv->dvrr_classes[3][8] = int_stack + 17610;
 Libderiv->deriv_classes[3][8][6] = int_stack + 18060;
 Libderiv->deriv_classes[3][9][6] = int_stack + 18510;
 Libderiv->deriv_classes[2][5][2] = int_stack + 19060;
 Libderiv->deriv_classes[2][6][2] = int_stack + 19186;
 Libderiv->deriv_classes[2][7][2] = int_stack + 19354;
 Libderiv->deriv_classes[2][8][2] = int_stack + 19570;
 Libderiv->deriv_classes[2][9][2] = int_stack + 19840;
 Libderiv->deriv_classes[3][5][2] = int_stack + 20170;
 Libderiv->deriv_classes[3][6][2] = int_stack + 20380;
 Libderiv->deriv_classes[3][7][2] = int_stack + 20660;
 Libderiv->deriv_classes[3][8][2] = int_stack + 21020;
 Libderiv->deriv_classes[3][9][2] = int_stack + 21470;
 Libderiv->deriv_classes[2][5][1] = int_stack + 22020;
 Libderiv->deriv_classes[2][6][1] = int_stack + 22146;
 Libderiv->deriv_classes[2][7][1] = int_stack + 22314;
 Libderiv->deriv_classes[2][8][1] = int_stack + 22530;
 Libderiv->deriv_classes[2][9][1] = int_stack + 22800;
 Libderiv->deriv_classes[3][5][1] = int_stack + 23130;
 Libderiv->deriv_classes[3][6][1] = int_stack + 23340;
 Libderiv->deriv_classes[3][7][1] = int_stack + 23620;
 Libderiv->deriv_classes[3][8][1] = int_stack + 23980;
 Libderiv->deriv_classes[3][9][1] = int_stack + 24430;
 Libderiv->dvrr_classes[2][5] = int_stack + 24980;
 Libderiv->dvrr_classes[2][6] = int_stack + 25106;
 Libderiv->dvrr_classes[2][7] = int_stack + 25274;
 Libderiv->dvrr_classes[2][8] = int_stack + 25490;
 Libderiv->dvrr_classes[2][9] = int_stack + 25760;
 Libderiv->deriv_classes[2][5][0] = int_stack + 26090;
 Libderiv->deriv_classes[2][6][0] = int_stack + 26216;
 Libderiv->deriv_classes[2][7][0] = int_stack + 26384;
 Libderiv->deriv_classes[2][8][0] = int_stack + 26600;
 Libderiv->deriv_classes[2][9][0] = int_stack + 26870;
 Libderiv->deriv_classes[3][5][0] = int_stack + 27200;
 Libderiv->deriv_classes[3][6][0] = int_stack + 27410;
 Libderiv->deriv_classes[3][7][0] = int_stack + 27690;
 Libderiv->deriv_classes[3][8][0] = int_stack + 28050;
 Libderiv->deriv_classes[3][9][0] = int_stack + 28500;
 memset(int_stack,0,232400);

 Libderiv->dvrr_stack = int_stack + 77008;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_dphg(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29050,int_stack+25106,int_stack+24980,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29428,int_stack+25274,int_stack+25106,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+29932,int_stack+29428,int_stack+29050,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+30688,int_stack+25490,int_stack+25274,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+31336,int_stack+30688,int_stack+29428,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+32344,int_stack+31336,int_stack+29932,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33604,int_stack+126,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24980,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33982,int_stack+294,int_stack+126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25106,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34486,int_stack+33982,int_stack+33604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29050,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+35242,int_stack+510,int_stack+294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25274,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35890,int_stack+35242,int_stack+33982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29428,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36898,int_stack+35890,int_stack+34486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29932,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+33604,int_stack+780,int_stack+510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25490,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38158,int_stack+33604,int_stack+35242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30688,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+33604,int_stack+38158,int_stack+35890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31336,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+38158,int_stack+33604,int_stack+36898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32344,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+33604,int_stack+16330,int_stack+15910,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+34234,int_stack+16890,int_stack+16330,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+35074,int_stack+34234,int_stack+33604,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36334,int_stack+17610,int_stack+16890,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40048,int_stack+36334,int_stack+34234,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+41728,int_stack+40048,int_stack+35074,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37414,int_stack+1320,int_stack+1110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15910,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+1600,int_stack+1320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+43828,int_stack+0,int_stack+37414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33604,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45088,int_stack+1960,int_stack+1600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16890,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46168,int_stack+45088,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34234,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+47848,int_stack+46168,int_stack+43828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35074,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+2410,int_stack+1960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49948,int_stack+0,int_stack+45088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36334,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+49948,int_stack+46168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40048,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+43828,int_stack+0,int_stack+47848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41728,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+3086,int_stack+2960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24980, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+378,int_stack+3254,int_stack+3086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25106, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+882,int_stack+378,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29050, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1638,int_stack+3470,int_stack+3254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25274, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2286,int_stack+1638,int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29428, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+2286,int_stack+882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29932, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3740,int_stack+3470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25490, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+48238,int_stack+0,int_stack+1638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30688, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+48238,int_stack+2286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31336, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+48238,int_stack+0,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32344, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+4280,int_stack+4070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15910, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4560,int_stack+4280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+840,int_stack+0,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33604, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+4920,int_stack+4560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16890, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2100,int_stack+46978,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34234, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+50128,int_stack+2100,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35074, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+5370,int_stack+4920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+52228,int_stack+0,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36334, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+54388,int_stack+52228,int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40048, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+54388,int_stack+50128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41728, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50128,int_stack+6046,int_stack+5920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24980, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50506,int_stack+6214,int_stack+6046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25106, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51010,int_stack+50506,int_stack+50128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29050, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+51766,int_stack+6430,int_stack+6214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25274, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+52414,int_stack+51766,int_stack+50506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29428, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+52414,int_stack+51010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29932, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+6700,int_stack+6430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25490, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53422,int_stack+50128,int_stack+51766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30688, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+53422,int_stack+52414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31336, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+51808,int_stack+50128,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32344, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+7240,int_stack+7030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+7520,int_stack+7240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+53698,int_stack+50128,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33604, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+7880,int_stack+7520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16890, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+54958,int_stack+46978,int_stack+50128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34234, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3150,int_stack+54958,int_stack+53698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35074, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+8330,int_stack+7880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5250,int_stack+50128,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36334, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+56638,int_stack+5250,int_stack+54958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40048, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5250,int_stack+56638,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41728, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+9006,int_stack+8880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3528,int_stack+9174,int_stack+9006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4032,int_stack+3528,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8400,int_stack+9390,int_stack+9174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46978,int_stack+8400,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+50128,int_stack+46978,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3150,int_stack+9660,int_stack+9390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53698,int_stack+3150,int_stack+8400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3150,int_stack+53698,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+53698,int_stack+3150,int_stack+50128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50128,int_stack+10200,int_stack+9990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50758,int_stack+10480,int_stack+10200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46978,int_stack+50758,int_stack+50128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3150,int_stack+10840,int_stack+10480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+55588,int_stack+3150,int_stack+50758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+57268,int_stack+55588,int_stack+46978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+11290,int_stack+10840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8400,int_stack+50128,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59368,int_stack+8400,int_stack+55588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8400,int_stack+59368,int_stack+57268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55588,int_stack+11966,int_stack+11840, 0.0, zero_stack, 1.0, int_stack+24980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+55966,int_stack+12134,int_stack+11966, 0.0, zero_stack, 1.0, int_stack+25106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+56470,int_stack+55966,int_stack+55588, 0.0, zero_stack, 1.0, int_stack+29050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+57226,int_stack+12350,int_stack+12134, 0.0, zero_stack, 1.0, int_stack+25274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+57874,int_stack+57226,int_stack+55966, 0.0, zero_stack, 1.0, int_stack+29428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+57874,int_stack+56470, 0.0, zero_stack, 1.0, int_stack+29932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+55588,int_stack+12620,int_stack+12350, 0.0, zero_stack, 1.0, int_stack+25490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+58882,int_stack+55588,int_stack+57226, 0.0, zero_stack, 1.0, int_stack+30688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+58882,int_stack+57874, 0.0, zero_stack, 1.0, int_stack+31336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+55588,int_stack+50128,int_stack+46978, 0.0, zero_stack, 1.0, int_stack+32344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+13160,int_stack+12950, 0.0, zero_stack, 1.0, int_stack+15910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+13440,int_stack+13160, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+57478,int_stack+50128,int_stack+46978, 0.0, zero_stack, 1.0, int_stack+33604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+13800,int_stack+13440, 0.0, zero_stack, 1.0, int_stack+16890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+58738,int_stack+46978,int_stack+50128, 0.0, zero_stack, 1.0, int_stack+34234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3150,int_stack+58738,int_stack+57478, 0.0, zero_stack, 1.0, int_stack+35074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+14250,int_stack+13800, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+60418,int_stack+50128,int_stack+46978, 0.0, zero_stack, 1.0, int_stack+36334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11550,int_stack+60418,int_stack+58738, 0.0, zero_stack, 1.0, int_stack+40048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+57478,int_stack+11550,int_stack+3150, 0.0, zero_stack, 1.0, int_stack+41728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+14926,int_stack+14800, 1.0, int_stack+24980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3528,int_stack+15094,int_stack+14926, 1.0, int_stack+25106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4032,int_stack+3528,int_stack+3150, 1.0, int_stack+29050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11550,int_stack+15310,int_stack+15094, 1.0, int_stack+25274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12198,int_stack+11550,int_stack+3528, 1.0, int_stack+29428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+12198,int_stack+4032, 1.0, int_stack+29932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+29050,int_stack+15580,int_stack+15310, 1.0, int_stack+25490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3150,int_stack+29050,int_stack+11550, 1.0, int_stack+30688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+3150,int_stack+12198, 1.0, int_stack+31336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3150,int_stack+50128,int_stack+46978, 1.0, int_stack+32344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+16610,int_stack+16120, 1.0, int_stack+15910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+17250,int_stack+16610, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11550,int_stack+50128,int_stack+46978, 1.0, int_stack+33604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+18060,int_stack+17250, 1.0, int_stack+16890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12810,int_stack+46978,int_stack+50128, 1.0, int_stack+34234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+14490,int_stack+12810,int_stack+11550, 1.0, int_stack+35074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+18510,int_stack+18060, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33604,int_stack+50128,int_stack+46978, 1.0, int_stack+36334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+60628,int_stack+33604,int_stack+12810, 1.0, int_stack+40048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+33604,int_stack+60628,int_stack+14490, 1.0, int_stack+41728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+60628,int_stack+25760,int_stack+25490,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+61438,int_stack+60628,int_stack+30688,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+61438,int_stack+31336,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+60628,int_stack+50128,int_stack+32344,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+50128,int_stack+19186,int_stack+19060,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50506,int_stack+19354,int_stack+19186,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51010,int_stack+50506,int_stack+50128,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+62518,int_stack+19570,int_stack+19354,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40048,int_stack+62518,int_stack+50506,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+40048,int_stack+51010,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+19840,int_stack+19570,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+41056,int_stack+50128,int_stack+62518,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+41056,int_stack+40048,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+40048,int_stack+50128,int_stack+46978,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+20380,int_stack+20170,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+20660,int_stack+20380,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+41938,int_stack+50128,int_stack+46978,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+21020,int_stack+20660,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+11550,int_stack+46978,int_stack+50128,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13230,int_stack+11550,int_stack+41938,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41938,int_stack+21470,int_stack+21020,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15330,int_stack+41938,int_stack+46978,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+17490,int_stack+15330,int_stack+11550,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+29050,int_stack+17490,int_stack+13230,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+11550,int_stack+22146,int_stack+22020,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+11928,int_stack+22314,int_stack+22146,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+12432,int_stack+11928,int_stack+11550,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13188,int_stack+22530,int_stack+22314,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13836,int_stack+13188,int_stack+11928,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+13836,int_stack+12432,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+11550,int_stack+22800,int_stack+22530,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+14844,int_stack+11550,int_stack+13188,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+14844,int_stack+13836,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+41938,int_stack+50128,int_stack+46978,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+23340,int_stack+23130,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+23620,int_stack+23340,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11550,int_stack+50128,int_stack+46978,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+23980,int_stack+23620,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+12810,int_stack+46978,int_stack+50128,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+14490,int_stack+12810,int_stack+11550,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+24430,int_stack+23980,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+16590,int_stack+50128,int_stack+46978,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+18750,int_stack+16590,int_stack+12810,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+21550,int_stack+18750,int_stack+14490,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+26216,int_stack+26090,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+47356,int_stack+26384,int_stack+26216,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+50128,int_stack+47356,int_stack+46978,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+50884,int_stack+26600,int_stack+26384,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+11550,int_stack+50884,int_stack+47356,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+46978,int_stack+11550,int_stack+50128,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+12558,int_stack+26870,int_stack+26600,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13368,int_stack+12558,int_stack+50884,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+50128,int_stack+13368,int_stack+11550,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+11550,int_stack+50128,int_stack+46978,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46978,int_stack+27410,int_stack+27200,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50128,int_stack+27690,int_stack+27410,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13440,int_stack+50128,int_stack+46978,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46978,int_stack+28050,int_stack+27690,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14700,int_stack+46978,int_stack+50128,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+16380,int_stack+14700,int_stack+13440,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+50128,int_stack+28500,int_stack+28050,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+18480,int_stack+50128,int_stack+46978,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+24700,int_stack+18480,int_stack+14700,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+62518,int_stack+24700,int_stack+16380,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+13440,int_stack+43828,int_stack+38158,315);
     Libderiv->ABCD[11] = int_stack + 13440;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+65668,int_stack+0,int_stack+48238,315);
     Libderiv->ABCD[10] = int_stack + 65668;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+43828,int_stack+5250,int_stack+51808,315);
     Libderiv->ABCD[9] = int_stack + 43828;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+71338,int_stack+8400,int_stack+53698,315);
     Libderiv->ABCD[8] = int_stack + 71338;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+49498,int_stack+57478,int_stack+55588,315);
     Libderiv->ABCD[7] = int_stack + 49498;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+5040,int_stack+33604,int_stack+3150,315);
     Libderiv->ABCD[6] = int_stack + 5040;
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+32200,int_stack+29050,int_stack+40048, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 32200;
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+24700,int_stack+21550,int_stack+41938, 0.0, zero_stack, 1.0, int_stack+60628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 24700;
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+37870,int_stack+62518,int_stack+11550, 1.0, int_stack+60628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 37870;

}
