/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_dpig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dp|ig) integrals */

void d1hrr_order_dpig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][6][11] = int_stack + 0;
 Libderiv->deriv_classes[2][7][11] = int_stack + 168;
 Libderiv->deriv_classes[2][8][11] = int_stack + 384;
 Libderiv->deriv_classes[2][9][11] = int_stack + 654;
 Libderiv->deriv_classes[2][10][11] = int_stack + 984;
 Libderiv->deriv_classes[3][6][11] = int_stack + 1380;
 Libderiv->deriv_classes[3][7][11] = int_stack + 1660;
 Libderiv->deriv_classes[3][8][11] = int_stack + 2020;
 Libderiv->deriv_classes[3][9][11] = int_stack + 2470;
 Libderiv->deriv_classes[3][10][11] = int_stack + 3020;
 Libderiv->deriv_classes[2][6][10] = int_stack + 3680;
 Libderiv->deriv_classes[2][7][10] = int_stack + 3848;
 Libderiv->deriv_classes[2][8][10] = int_stack + 4064;
 Libderiv->deriv_classes[2][9][10] = int_stack + 4334;
 Libderiv->deriv_classes[2][10][10] = int_stack + 4664;
 Libderiv->deriv_classes[3][6][10] = int_stack + 5060;
 Libderiv->deriv_classes[3][7][10] = int_stack + 5340;
 Libderiv->deriv_classes[3][8][10] = int_stack + 5700;
 Libderiv->deriv_classes[3][9][10] = int_stack + 6150;
 Libderiv->deriv_classes[3][10][10] = int_stack + 6700;
 Libderiv->deriv_classes[2][6][9] = int_stack + 7360;
 Libderiv->deriv_classes[2][7][9] = int_stack + 7528;
 Libderiv->deriv_classes[2][8][9] = int_stack + 7744;
 Libderiv->deriv_classes[2][9][9] = int_stack + 8014;
 Libderiv->deriv_classes[2][10][9] = int_stack + 8344;
 Libderiv->deriv_classes[3][6][9] = int_stack + 8740;
 Libderiv->deriv_classes[3][7][9] = int_stack + 9020;
 Libderiv->deriv_classes[3][8][9] = int_stack + 9380;
 Libderiv->deriv_classes[3][9][9] = int_stack + 9830;
 Libderiv->deriv_classes[3][10][9] = int_stack + 10380;
 Libderiv->deriv_classes[2][6][8] = int_stack + 11040;
 Libderiv->deriv_classes[2][7][8] = int_stack + 11208;
 Libderiv->deriv_classes[2][8][8] = int_stack + 11424;
 Libderiv->deriv_classes[2][9][8] = int_stack + 11694;
 Libderiv->deriv_classes[2][10][8] = int_stack + 12024;
 Libderiv->deriv_classes[3][6][8] = int_stack + 12420;
 Libderiv->deriv_classes[3][7][8] = int_stack + 12700;
 Libderiv->deriv_classes[3][8][8] = int_stack + 13060;
 Libderiv->deriv_classes[3][9][8] = int_stack + 13510;
 Libderiv->deriv_classes[3][10][8] = int_stack + 14060;
 Libderiv->deriv_classes[2][6][7] = int_stack + 14720;
 Libderiv->deriv_classes[2][7][7] = int_stack + 14888;
 Libderiv->deriv_classes[2][8][7] = int_stack + 15104;
 Libderiv->deriv_classes[2][9][7] = int_stack + 15374;
 Libderiv->deriv_classes[2][10][7] = int_stack + 15704;
 Libderiv->deriv_classes[3][6][7] = int_stack + 16100;
 Libderiv->deriv_classes[3][7][7] = int_stack + 16380;
 Libderiv->deriv_classes[3][8][7] = int_stack + 16740;
 Libderiv->deriv_classes[3][9][7] = int_stack + 17190;
 Libderiv->deriv_classes[3][10][7] = int_stack + 17740;
 Libderiv->deriv_classes[2][6][6] = int_stack + 18400;
 Libderiv->deriv_classes[2][7][6] = int_stack + 18568;
 Libderiv->deriv_classes[2][8][6] = int_stack + 18784;
 Libderiv->deriv_classes[2][9][6] = int_stack + 19054;
 Libderiv->deriv_classes[2][10][6] = int_stack + 19384;
 Libderiv->dvrr_classes[3][6] = int_stack + 19780;
 Libderiv->deriv_classes[3][6][6] = int_stack + 20060;
 Libderiv->dvrr_classes[3][7] = int_stack + 20340;
 Libderiv->deriv_classes[3][7][6] = int_stack + 20700;
 Libderiv->dvrr_classes[3][8] = int_stack + 21060;
 Libderiv->deriv_classes[3][8][6] = int_stack + 21510;
 Libderiv->dvrr_classes[3][9] = int_stack + 21960;
 Libderiv->deriv_classes[3][9][6] = int_stack + 22510;
 Libderiv->deriv_classes[3][10][6] = int_stack + 23060;
 Libderiv->deriv_classes[2][6][2] = int_stack + 23720;
 Libderiv->deriv_classes[2][7][2] = int_stack + 23888;
 Libderiv->deriv_classes[2][8][2] = int_stack + 24104;
 Libderiv->deriv_classes[2][9][2] = int_stack + 24374;
 Libderiv->deriv_classes[2][10][2] = int_stack + 24704;
 Libderiv->deriv_classes[3][6][2] = int_stack + 25100;
 Libderiv->deriv_classes[3][7][2] = int_stack + 25380;
 Libderiv->deriv_classes[3][8][2] = int_stack + 25740;
 Libderiv->deriv_classes[3][9][2] = int_stack + 26190;
 Libderiv->deriv_classes[3][10][2] = int_stack + 26740;
 Libderiv->deriv_classes[2][6][1] = int_stack + 27400;
 Libderiv->deriv_classes[2][7][1] = int_stack + 27568;
 Libderiv->deriv_classes[2][8][1] = int_stack + 27784;
 Libderiv->deriv_classes[2][9][1] = int_stack + 28054;
 Libderiv->deriv_classes[2][10][1] = int_stack + 28384;
 Libderiv->deriv_classes[3][6][1] = int_stack + 28780;
 Libderiv->deriv_classes[3][7][1] = int_stack + 29060;
 Libderiv->deriv_classes[3][8][1] = int_stack + 29420;
 Libderiv->deriv_classes[3][9][1] = int_stack + 29870;
 Libderiv->deriv_classes[3][10][1] = int_stack + 30420;
 Libderiv->dvrr_classes[2][6] = int_stack + 31080;
 Libderiv->dvrr_classes[2][7] = int_stack + 31248;
 Libderiv->dvrr_classes[2][8] = int_stack + 31464;
 Libderiv->dvrr_classes[2][9] = int_stack + 31734;
 Libderiv->dvrr_classes[2][10] = int_stack + 32064;
 Libderiv->deriv_classes[2][6][0] = int_stack + 32460;
 Libderiv->deriv_classes[2][7][0] = int_stack + 32628;
 Libderiv->deriv_classes[2][8][0] = int_stack + 32844;
 Libderiv->deriv_classes[2][9][0] = int_stack + 33114;
 Libderiv->deriv_classes[2][10][0] = int_stack + 33444;
 Libderiv->deriv_classes[3][6][0] = int_stack + 33840;
 Libderiv->deriv_classes[3][7][0] = int_stack + 34120;
 Libderiv->deriv_classes[3][8][0] = int_stack + 34480;
 Libderiv->deriv_classes[3][9][0] = int_stack + 34930;
 Libderiv->deriv_classes[3][10][0] = int_stack + 35480;
 memset(int_stack,0,289120);

 Libderiv->dvrr_stack = int_stack + 103752;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_dpig(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+36140,int_stack+31248,int_stack+31080,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36644,int_stack+31464,int_stack+31248,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37292,int_stack+36644,int_stack+36140,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+38300,int_stack+31734,int_stack+31464,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+39110,int_stack+38300,int_stack+36644,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+40406,int_stack+39110,int_stack+37292,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42086,int_stack+168,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31080,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+42590,int_stack+384,int_stack+168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31248,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43238,int_stack+42590,int_stack+42086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36140,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+44246,int_stack+654,int_stack+384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31464,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45056,int_stack+44246,int_stack+42590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36644,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+46352,int_stack+45056,int_stack+43238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37292,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+42086,int_stack+984,int_stack+654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31734,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+48032,int_stack+42086,int_stack+44246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38300,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+42086,int_stack+48032,int_stack+45056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39110,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+48032,int_stack+42086,int_stack+46352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40406,6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+42086,int_stack+20340,int_stack+19780,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+42926,int_stack+21060,int_stack+20340,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+44006,int_stack+42926,int_stack+42086,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+45686,int_stack+21960,int_stack+21060,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+50552,int_stack+45686,int_stack+42926,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+52712,int_stack+50552,int_stack+44006,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+47036,int_stack+1660,int_stack+1380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19780,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+2020,int_stack+1660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20340,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+55512,int_stack+0,int_stack+47036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42086,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+57192,int_stack+2470,int_stack+2020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21060,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+58542,int_stack+57192,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42926,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+60702,int_stack+58542,int_stack+55512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44006,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+55512,int_stack+3020,int_stack+2470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21960,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+55512,int_stack+57192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45686,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+63502,int_stack+0,int_stack+58542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50552,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+55512,int_stack+63502,int_stack+60702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52712,10);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+3848,int_stack+3680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31080, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+504,int_stack+4064,int_stack+3848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31248, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1152,int_stack+504,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36140, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2160,int_stack+4334,int_stack+4064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31464, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2970,int_stack+2160,int_stack+504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36644, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+2970,int_stack+1152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37292, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+4664,int_stack+4334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31734, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+61392,int_stack+0,int_stack+2160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38300, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+61392,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39110, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+61392,int_stack+0,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40406, 0.0, zero_stack,6);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+5340,int_stack+5060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19780, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+5700,int_stack+5340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20340, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1080,int_stack+0,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42086, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+6150,int_stack+5700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21060, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2760,int_stack+59712,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42926, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+63912,int_stack+2760,int_stack+1080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44006, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+6700,int_stack+6150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21960, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+66712,int_stack+0,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45686, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+69412,int_stack+66712,int_stack+2760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+69412,int_stack+63912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52712, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+63912,int_stack+7528,int_stack+7360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31080, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+64416,int_stack+7744,int_stack+7528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31248, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+65064,int_stack+64416,int_stack+63912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36140, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+66072,int_stack+8014,int_stack+7744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31464, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+66882,int_stack+66072,int_stack+64416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36644, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+66882,int_stack+65064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37292, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+63912,int_stack+8344,int_stack+8014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31734, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+68178,int_stack+63912,int_stack+66072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38300, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+68178,int_stack+66882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39110, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+66072,int_stack+63912,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40406, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+9020,int_stack+8740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19780, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+9380,int_stack+9020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20340, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+68592,int_stack+63912,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42086, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+9830,int_stack+9380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21060, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+70272,int_stack+59712,int_stack+63912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42926, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4200,int_stack+70272,int_stack+68592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44006, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+68592,int_stack+10380,int_stack+9830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21960, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7000,int_stack+68592,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45686, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+72432,int_stack+7000,int_stack+70272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+76032,int_stack+72432,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52712, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4200,int_stack+11208,int_stack+11040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4704,int_stack+11424,int_stack+11208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5352,int_stack+4704,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6360,int_stack+11694,int_stack+11424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7170,int_stack+6360,int_stack+4704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+7170,int_stack+5352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4200,int_stack+12024,int_stack+11694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8466,int_stack+4200,int_stack+6360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+8466,int_stack+7170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4200,int_stack+63912,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+12700,int_stack+12420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+13060,int_stack+12700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6720,int_stack+63912,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+13510,int_stack+13060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8400,int_stack+59712,int_stack+63912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10560,int_stack+8400,int_stack+6720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6720,int_stack+14060,int_stack+13510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+68592,int_stack+6720,int_stack+59712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+71292,int_stack+68592,int_stack+8400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+80232,int_stack+71292,int_stack+10560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+68592,int_stack+14888,int_stack+14720, 0.0, zero_stack, 1.0, int_stack+31080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+69096,int_stack+15104,int_stack+14888, 0.0, zero_stack, 1.0, int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+69744,int_stack+69096,int_stack+68592, 0.0, zero_stack, 1.0, int_stack+36140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+70752,int_stack+15374,int_stack+15104, 0.0, zero_stack, 1.0, int_stack+31464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+71562,int_stack+70752,int_stack+69096, 0.0, zero_stack, 1.0, int_stack+36644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+71562,int_stack+69744, 0.0, zero_stack, 1.0, int_stack+37292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+68592,int_stack+15704,int_stack+15374, 0.0, zero_stack, 1.0, int_stack+31734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+72858,int_stack+68592,int_stack+70752, 0.0, zero_stack, 1.0, int_stack+38300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+72858,int_stack+71562, 0.0, zero_stack, 1.0, int_stack+39110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+68592,int_stack+63912,int_stack+59712, 0.0, zero_stack, 1.0, int_stack+40406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+16380,int_stack+16100, 0.0, zero_stack, 1.0, int_stack+19780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+16740,int_stack+16380, 0.0, zero_stack, 1.0, int_stack+20340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+71112,int_stack+63912,int_stack+59712, 0.0, zero_stack, 1.0, int_stack+42086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+17190,int_stack+16740, 0.0, zero_stack, 1.0, int_stack+21060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+72792,int_stack+59712,int_stack+63912, 0.0, zero_stack, 1.0, int_stack+42926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6720,int_stack+72792,int_stack+71112, 0.0, zero_stack, 1.0, int_stack+44006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+71112,int_stack+17740,int_stack+17190, 0.0, zero_stack, 1.0, int_stack+21960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9520,int_stack+71112,int_stack+59712, 0.0, zero_stack, 1.0, int_stack+45686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12220,int_stack+9520,int_stack+72792, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+71112,int_stack+12220,int_stack+6720, 0.0, zero_stack, 1.0, int_stack+52712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6720,int_stack+18568,int_stack+18400, 1.0, int_stack+31080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7224,int_stack+18784,int_stack+18568, 1.0, int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7872,int_stack+7224,int_stack+6720, 1.0, int_stack+36140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8880,int_stack+19054,int_stack+18784, 1.0, int_stack+31464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9690,int_stack+8880,int_stack+7224, 1.0, int_stack+36644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+9690,int_stack+7872, 1.0, int_stack+37292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+36140,int_stack+19384,int_stack+19054, 1.0, int_stack+31734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6720,int_stack+36140,int_stack+8880, 1.0, int_stack+38300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+36140,int_stack+6720,int_stack+9690, 1.0, int_stack+39110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6720,int_stack+36140,int_stack+59712, 1.0, int_stack+40406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+20700,int_stack+20060, 1.0, int_stack+19780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+36140,int_stack+21510,int_stack+20700, 1.0, int_stack+20340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9240,int_stack+36140,int_stack+59712, 1.0, int_stack+42086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+22510,int_stack+21510, 1.0, int_stack+21060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+63912,int_stack+59712,int_stack+36140, 1.0, int_stack+42926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10920,int_stack+63912,int_stack+9240, 1.0, int_stack+44006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9240,int_stack+23060,int_stack+22510, 1.0, int_stack+21960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+42086,int_stack+9240,int_stack+59712, 1.0, int_stack+45686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13720,int_stack+42086,int_stack+63912, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42086,int_stack+13720,int_stack+10920, 1.0, int_stack+52712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+50552,int_stack+32064,int_stack+31734,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+51542,int_stack+50552,int_stack+38300,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+51542,int_stack+39110,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+50552,int_stack+63912,int_stack+40406,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+63912,int_stack+23888,int_stack+23720,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+64416,int_stack+24104,int_stack+23888,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65064,int_stack+64416,int_stack+63912,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+53072,int_stack+24374,int_stack+24104,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+53882,int_stack+53072,int_stack+64416,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+53882,int_stack+65064,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+63912,int_stack+24704,int_stack+24374,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+46286,int_stack+63912,int_stack+53072,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+46286,int_stack+53882,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9240,int_stack+63912,int_stack+59712,6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+25380,int_stack+25100,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+25740,int_stack+25380,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+46286,int_stack+63912,int_stack+59712,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+26190,int_stack+25740,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+53072,int_stack+59712,int_stack+63912,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+11760,int_stack+53072,int_stack+46286,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+46286,int_stack+26740,int_stack+26190,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+14560,int_stack+46286,int_stack+59712,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+17260,int_stack+14560,int_stack+53072,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+20860,int_stack+17260,int_stack+11760,10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+11760,int_stack+27568,int_stack+27400,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+12264,int_stack+27784,int_stack+27568,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+12912,int_stack+12264,int_stack+11760,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13920,int_stack+28054,int_stack+27784,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+14730,int_stack+13920,int_stack+12264,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+14730,int_stack+12912,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+11760,int_stack+28384,int_stack+28054,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+16026,int_stack+11760,int_stack+13920,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+16026,int_stack+14730,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+11760,int_stack+63912,int_stack+59712,6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+29060,int_stack+28780,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+29420,int_stack+29060,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14280,int_stack+63912,int_stack+59712,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+29870,int_stack+29420,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15960,int_stack+59712,int_stack+63912,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+25060,int_stack+15960,int_stack+14280,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+14280,int_stack+30420,int_stack+29870,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+18120,int_stack+14280,int_stack+59712,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+27860,int_stack+18120,int_stack+15960,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+14280,int_stack+27860,int_stack+25060,10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+25060,int_stack+32628,int_stack+32460,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+25564,int_stack+32844,int_stack+32628,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+26212,int_stack+25564,int_stack+25060,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+27220,int_stack+33114,int_stack+32844,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+28030,int_stack+27220,int_stack+25564,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+59712,int_stack+28030,int_stack+26212,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+25060,int_stack+33444,int_stack+33114,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+29326,int_stack+25060,int_stack+27220,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+63912,int_stack+29326,int_stack+28030,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+25060,int_stack+63912,int_stack+59712,6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+59712,int_stack+34120,int_stack+33840,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63912,int_stack+34480,int_stack+34120,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+27580,int_stack+63912,int_stack+59712,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+59712,int_stack+34930,int_stack+34480,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+29260,int_stack+59712,int_stack+63912,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+31420,int_stack+29260,int_stack+27580,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+27580,int_stack+35480,int_stack+34930,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+34220,int_stack+27580,int_stack+59712,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+36920,int_stack+34220,int_stack+29260,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+84432,int_stack+36920,int_stack+31420,10);
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+27580,int_stack+55512,int_stack+48032,420);
     Libderiv->ABCD[11] = int_stack + 27580;
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+53072,int_stack+0,int_stack+61392,420);
     Libderiv->ABCD[10] = int_stack + 53072;
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+88632,int_stack+76032,int_stack+66072,420);
     Libderiv->ABCD[9] = int_stack + 88632;
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+60632,int_stack+80232,int_stack+4200,420);
     Libderiv->ABCD[8] = int_stack + 60632;
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+75312,int_stack+71112,int_stack+68592,420);
     Libderiv->ABCD[7] = int_stack + 75312;
 /*--- compute (dp|ig) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+96192,int_stack+42086,int_stack+6720,420);
     Libderiv->ABCD[6] = int_stack + 96192;
 /*--- compute (dp|ig) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+0,int_stack+20860,int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 0;
 /*--- compute (dp|ig) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+35140,int_stack+14280,int_stack+11760, 0.0, zero_stack, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 35140;
 /*--- compute (dp|ig) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+7560,int_stack+84432,int_stack+25060, 1.0, int_stack+50552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 7560;

}
