/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fdih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|ih) integrals */

void d1hrr_order_fdih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][11] = int_stack + 280;
 Libderiv->deriv_classes[3][8][11] = int_stack + 640;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1090;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1640;
 Libderiv->deriv_classes[3][11][11] = int_stack + 2300;
 Libderiv->deriv_classes[4][6][11] = int_stack + 3080;
 Libderiv->deriv_classes[4][7][11] = int_stack + 3500;
 Libderiv->deriv_classes[4][8][11] = int_stack + 4040;
 Libderiv->deriv_classes[4][9][11] = int_stack + 4715;
 Libderiv->deriv_classes[4][10][11] = int_stack + 5540;
 Libderiv->deriv_classes[4][11][11] = int_stack + 6530;
 Libderiv->deriv_classes[5][6][11] = int_stack + 7700;
 Libderiv->deriv_classes[5][7][11] = int_stack + 8288;
 Libderiv->deriv_classes[5][8][11] = int_stack + 9044;
 Libderiv->deriv_classes[5][9][11] = int_stack + 9989;
 Libderiv->deriv_classes[5][10][11] = int_stack + 11144;
 Libderiv->deriv_classes[5][11][11] = int_stack + 12530;
 Libderiv->deriv_classes[3][6][10] = int_stack + 14168;
 Libderiv->deriv_classes[3][7][10] = int_stack + 14448;
 Libderiv->deriv_classes[3][8][10] = int_stack + 14808;
 Libderiv->deriv_classes[3][9][10] = int_stack + 15258;
 Libderiv->deriv_classes[3][10][10] = int_stack + 15808;
 Libderiv->deriv_classes[3][11][10] = int_stack + 16468;
 Libderiv->deriv_classes[4][6][10] = int_stack + 17248;
 Libderiv->deriv_classes[4][7][10] = int_stack + 17668;
 Libderiv->deriv_classes[4][8][10] = int_stack + 18208;
 Libderiv->deriv_classes[4][9][10] = int_stack + 18883;
 Libderiv->deriv_classes[4][10][10] = int_stack + 19708;
 Libderiv->deriv_classes[4][11][10] = int_stack + 20698;
 Libderiv->deriv_classes[5][6][10] = int_stack + 21868;
 Libderiv->deriv_classes[5][7][10] = int_stack + 22456;
 Libderiv->deriv_classes[5][8][10] = int_stack + 23212;
 Libderiv->deriv_classes[5][9][10] = int_stack + 24157;
 Libderiv->deriv_classes[5][10][10] = int_stack + 25312;
 Libderiv->deriv_classes[5][11][10] = int_stack + 26698;
 Libderiv->deriv_classes[3][6][9] = int_stack + 28336;
 Libderiv->deriv_classes[3][7][9] = int_stack + 28616;
 Libderiv->deriv_classes[3][8][9] = int_stack + 28976;
 Libderiv->deriv_classes[3][9][9] = int_stack + 29426;
 Libderiv->deriv_classes[3][10][9] = int_stack + 29976;
 Libderiv->deriv_classes[3][11][9] = int_stack + 30636;
 Libderiv->deriv_classes[4][6][9] = int_stack + 31416;
 Libderiv->deriv_classes[4][7][9] = int_stack + 31836;
 Libderiv->deriv_classes[4][8][9] = int_stack + 32376;
 Libderiv->deriv_classes[4][9][9] = int_stack + 33051;
 Libderiv->deriv_classes[4][10][9] = int_stack + 33876;
 Libderiv->deriv_classes[4][11][9] = int_stack + 34866;
 Libderiv->deriv_classes[5][6][9] = int_stack + 36036;
 Libderiv->deriv_classes[5][7][9] = int_stack + 36624;
 Libderiv->deriv_classes[5][8][9] = int_stack + 37380;
 Libderiv->deriv_classes[5][9][9] = int_stack + 38325;
 Libderiv->deriv_classes[5][10][9] = int_stack + 39480;
 Libderiv->deriv_classes[5][11][9] = int_stack + 40866;
 Libderiv->deriv_classes[3][6][8] = int_stack + 42504;
 Libderiv->deriv_classes[3][7][8] = int_stack + 42784;
 Libderiv->deriv_classes[3][8][8] = int_stack + 43144;
 Libderiv->deriv_classes[3][9][8] = int_stack + 43594;
 Libderiv->deriv_classes[3][10][8] = int_stack + 44144;
 Libderiv->deriv_classes[3][11][8] = int_stack + 44804;
 Libderiv->deriv_classes[4][6][8] = int_stack + 45584;
 Libderiv->deriv_classes[4][7][8] = int_stack + 46004;
 Libderiv->deriv_classes[4][8][8] = int_stack + 46544;
 Libderiv->deriv_classes[4][9][8] = int_stack + 47219;
 Libderiv->deriv_classes[4][10][8] = int_stack + 48044;
 Libderiv->deriv_classes[4][11][8] = int_stack + 49034;
 Libderiv->deriv_classes[5][6][8] = int_stack + 50204;
 Libderiv->deriv_classes[5][7][8] = int_stack + 50792;
 Libderiv->deriv_classes[5][8][8] = int_stack + 51548;
 Libderiv->deriv_classes[5][9][8] = int_stack + 52493;
 Libderiv->deriv_classes[5][10][8] = int_stack + 53648;
 Libderiv->deriv_classes[5][11][8] = int_stack + 55034;
 Libderiv->deriv_classes[3][6][7] = int_stack + 56672;
 Libderiv->deriv_classes[3][7][7] = int_stack + 56952;
 Libderiv->deriv_classes[3][8][7] = int_stack + 57312;
 Libderiv->deriv_classes[3][9][7] = int_stack + 57762;
 Libderiv->deriv_classes[3][10][7] = int_stack + 58312;
 Libderiv->deriv_classes[3][11][7] = int_stack + 58972;
 Libderiv->deriv_classes[4][6][7] = int_stack + 59752;
 Libderiv->deriv_classes[4][7][7] = int_stack + 60172;
 Libderiv->deriv_classes[4][8][7] = int_stack + 60712;
 Libderiv->deriv_classes[4][9][7] = int_stack + 61387;
 Libderiv->deriv_classes[4][10][7] = int_stack + 62212;
 Libderiv->deriv_classes[4][11][7] = int_stack + 63202;
 Libderiv->deriv_classes[5][6][7] = int_stack + 64372;
 Libderiv->deriv_classes[5][7][7] = int_stack + 64960;
 Libderiv->deriv_classes[5][8][7] = int_stack + 65716;
 Libderiv->deriv_classes[5][9][7] = int_stack + 66661;
 Libderiv->deriv_classes[5][10][7] = int_stack + 67816;
 Libderiv->deriv_classes[5][11][7] = int_stack + 69202;
 Libderiv->deriv_classes[3][6][6] = int_stack + 70840;
 Libderiv->deriv_classes[3][7][6] = int_stack + 71120;
 Libderiv->deriv_classes[3][8][6] = int_stack + 71480;
 Libderiv->deriv_classes[3][9][6] = int_stack + 71930;
 Libderiv->deriv_classes[3][10][6] = int_stack + 72480;
 Libderiv->deriv_classes[3][11][6] = int_stack + 73140;
 Libderiv->deriv_classes[4][6][6] = int_stack + 73920;
 Libderiv->deriv_classes[4][7][6] = int_stack + 74340;
 Libderiv->deriv_classes[4][8][6] = int_stack + 74880;
 Libderiv->deriv_classes[4][9][6] = int_stack + 75555;
 Libderiv->deriv_classes[4][10][6] = int_stack + 76380;
 Libderiv->deriv_classes[4][11][6] = int_stack + 77370;
 Libderiv->dvrr_classes[5][6] = int_stack + 78540;
 Libderiv->deriv_classes[5][6][6] = int_stack + 79128;
 Libderiv->dvrr_classes[5][7] = int_stack + 79716;
 Libderiv->deriv_classes[5][7][6] = int_stack + 80472;
 Libderiv->dvrr_classes[5][8] = int_stack + 81228;
 Libderiv->deriv_classes[5][8][6] = int_stack + 82173;
 Libderiv->dvrr_classes[5][9] = int_stack + 83118;
 Libderiv->deriv_classes[5][9][6] = int_stack + 84273;
 Libderiv->dvrr_classes[5][10] = int_stack + 85428;
 Libderiv->deriv_classes[5][10][6] = int_stack + 86814;
 Libderiv->deriv_classes[5][11][6] = int_stack + 88200;
 Libderiv->deriv_classes[3][6][2] = int_stack + 89838;
 Libderiv->deriv_classes[3][7][2] = int_stack + 90118;
 Libderiv->deriv_classes[3][8][2] = int_stack + 90478;
 Libderiv->deriv_classes[3][9][2] = int_stack + 90928;
 Libderiv->deriv_classes[3][10][2] = int_stack + 91478;
 Libderiv->deriv_classes[3][11][2] = int_stack + 92138;
 Libderiv->deriv_classes[4][6][2] = int_stack + 92918;
 Libderiv->deriv_classes[4][7][2] = int_stack + 93338;
 Libderiv->deriv_classes[4][8][2] = int_stack + 93878;
 Libderiv->deriv_classes[4][9][2] = int_stack + 94553;
 Libderiv->deriv_classes[4][10][2] = int_stack + 95378;
 Libderiv->deriv_classes[4][11][2] = int_stack + 96368;
 Libderiv->deriv_classes[5][6][2] = int_stack + 97538;
 Libderiv->deriv_classes[5][7][2] = int_stack + 98126;
 Libderiv->deriv_classes[5][8][2] = int_stack + 98882;
 Libderiv->deriv_classes[5][9][2] = int_stack + 99827;
 Libderiv->deriv_classes[5][10][2] = int_stack + 100982;
 Libderiv->deriv_classes[5][11][2] = int_stack + 102368;
 Libderiv->deriv_classes[3][6][1] = int_stack + 104006;
 Libderiv->deriv_classes[3][7][1] = int_stack + 104286;
 Libderiv->deriv_classes[3][8][1] = int_stack + 104646;
 Libderiv->deriv_classes[3][9][1] = int_stack + 105096;
 Libderiv->deriv_classes[3][10][1] = int_stack + 105646;
 Libderiv->deriv_classes[3][11][1] = int_stack + 106306;
 Libderiv->deriv_classes[4][6][1] = int_stack + 107086;
 Libderiv->deriv_classes[4][7][1] = int_stack + 107506;
 Libderiv->deriv_classes[4][8][1] = int_stack + 108046;
 Libderiv->deriv_classes[4][9][1] = int_stack + 108721;
 Libderiv->deriv_classes[4][10][1] = int_stack + 109546;
 Libderiv->deriv_classes[4][11][1] = int_stack + 110536;
 Libderiv->deriv_classes[5][6][1] = int_stack + 111706;
 Libderiv->deriv_classes[5][7][1] = int_stack + 112294;
 Libderiv->deriv_classes[5][8][1] = int_stack + 113050;
 Libderiv->deriv_classes[5][9][1] = int_stack + 113995;
 Libderiv->deriv_classes[5][10][1] = int_stack + 115150;
 Libderiv->deriv_classes[5][11][1] = int_stack + 116536;
 Libderiv->dvrr_classes[3][6] = int_stack + 118174;
 Libderiv->dvrr_classes[3][7] = int_stack + 118454;
 Libderiv->dvrr_classes[3][8] = int_stack + 118814;
 Libderiv->dvrr_classes[3][9] = int_stack + 119264;
 Libderiv->dvrr_classes[3][10] = int_stack + 119814;
 Libderiv->dvrr_classes[3][11] = int_stack + 120474;
 Libderiv->deriv_classes[3][6][0] = int_stack + 121254;
 Libderiv->deriv_classes[3][7][0] = int_stack + 121534;
 Libderiv->deriv_classes[3][8][0] = int_stack + 121894;
 Libderiv->deriv_classes[3][9][0] = int_stack + 122344;
 Libderiv->deriv_classes[3][10][0] = int_stack + 122894;
 Libderiv->deriv_classes[3][11][0] = int_stack + 123554;
 Libderiv->dvrr_classes[4][6] = int_stack + 124334;
 Libderiv->dvrr_classes[4][7] = int_stack + 124754;
 Libderiv->dvrr_classes[4][8] = int_stack + 125294;
 Libderiv->dvrr_classes[4][9] = int_stack + 125969;
 Libderiv->dvrr_classes[4][10] = int_stack + 126794;
 Libderiv->dvrr_classes[4][11] = int_stack + 127784;
 Libderiv->deriv_classes[4][6][0] = int_stack + 128954;
 Libderiv->deriv_classes[4][7][0] = int_stack + 129374;
 Libderiv->deriv_classes[4][8][0] = int_stack + 129914;
 Libderiv->deriv_classes[4][9][0] = int_stack + 130589;
 Libderiv->deriv_classes[4][10][0] = int_stack + 131414;
 Libderiv->deriv_classes[4][11][0] = int_stack + 132404;
 Libderiv->deriv_classes[5][6][0] = int_stack + 133574;
 Libderiv->deriv_classes[5][7][0] = int_stack + 134162;
 Libderiv->deriv_classes[5][8][0] = int_stack + 134918;
 Libderiv->deriv_classes[5][9][0] = int_stack + 135863;
 Libderiv->deriv_classes[5][10][0] = int_stack + 137018;
 Libderiv->deriv_classes[5][11][0] = int_stack + 138404;
 memset(int_stack,0,1120336);

 Libderiv->dvrr_stack = int_stack + 595821;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fdih(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+140042,int_stack+118454,int_stack+118174,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+140882,int_stack+118814,int_stack+118454,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+141962,int_stack+140882,int_stack+140042,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143642,int_stack+119264,int_stack+118814,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+144992,int_stack+143642,int_stack+140882,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+147152,int_stack+144992,int_stack+141962,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+149952,int_stack+119814,int_stack+119264,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+151602,int_stack+149952,int_stack+143642,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+154302,int_stack+151602,int_stack+144992,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+157902,int_stack+154302,int_stack+147152,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+162102,int_stack+280,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118174,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162942,int_stack+640,int_stack+280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118454,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164022,int_stack+162942,int_stack+162102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140042,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+165702,int_stack+1090,int_stack+640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118814,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+167052,int_stack+165702,int_stack+162942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140882,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+169212,int_stack+167052,int_stack+164022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141962,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+162102,int_stack+1640,int_stack+1090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119264,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+172012,int_stack+162102,int_stack+165702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143642,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+174712,int_stack+172012,int_stack+167052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144992,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+163752,int_stack+174712,int_stack+169212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147152,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+167952,int_stack+2300,int_stack+1640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119814,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+178312,int_stack+167952,int_stack+162102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149952,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+181612,int_stack+178312,int_stack+172012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151602,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+167952,int_stack+181612,int_stack+174712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154302,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+173352,int_stack+167952,int_stack+163752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157902,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+162102,int_stack+124754,int_stack+124334,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+163362,int_stack+125294,int_stack+124754,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+164982,int_stack+163362,int_stack+162102,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+167502,int_stack+125969,int_stack+125294,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+169527,int_stack+167502,int_stack+163362,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+179232,int_stack+169527,int_stack+164982,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+183432,int_stack+126794,int_stack+125969,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+185907,int_stack+183432,int_stack+167502,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+189957,int_stack+185907,int_stack+169527,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+195357,int_stack+189957,int_stack+179232,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+3500,int_stack+3080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124334,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+4040,int_stack+3500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124754,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+201657,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162102,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204177,int_stack+4715,int_stack+4040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125294,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206202,int_stack+204177,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163362,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+206202,int_stack+201657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164982,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+201657,int_stack+5540,int_stack+4715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125969,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+209442,int_stack+201657,int_stack+204177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167502,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+213492,int_stack+209442,int_stack+206202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169527,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+218892,int_stack+213492,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179232,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+6530,int_stack+5540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126794,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+204132,int_stack+0,int_stack+201657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183432,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+204132,int_stack+209442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185907,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+201657,int_stack+0,int_stack+213492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189957,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+209757,int_stack+201657,int_stack+218892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195357,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+218577,int_stack+209757,int_stack+173352,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+201657,int_stack+79716,int_stack+78540,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+203421,int_stack+81228,int_stack+79716,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+205689,int_stack+203421,int_stack+201657,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+83118,int_stack+81228,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2835,int_stack+0,int_stack+203421,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+172767,int_stack+2835,int_stack+205689,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+236217,int_stack+85428,int_stack+83118,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+239682,int_stack+236217,int_stack+0,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+245352,int_stack+239682,int_stack+2835,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+252912,int_stack+245352,int_stack+172767,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261732,int_stack+8288,int_stack+7700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78540,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263496,int_stack+9044,int_stack+8288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79716,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265764,int_stack+263496,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201657,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+269292,int_stack+9989,int_stack+9044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81228,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272127,int_stack+269292,int_stack+263496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203421,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+276663,int_stack+272127,int_stack+265764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205689,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+261732,int_stack+11144,int_stack+9989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83118,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+282543,int_stack+261732,int_stack+269292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+288213,int_stack+282543,int_stack+272127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+265197,int_stack+288213,int_stack+276663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172767,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+274017,int_stack+12530,int_stack+11144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85428,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+295773,int_stack+274017,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236217,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+302703,int_stack+295773,int_stack+282543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239682,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+274017,int_stack+302703,int_stack+288213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245352,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+285357,int_stack+274017,int_stack+265197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252912,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+297705,int_stack+285357,int_stack+209757,588);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261732,int_stack+14448,int_stack+14168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118174, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262572,int_stack+14808,int_stack+14448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118454, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+263652,int_stack+262572,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+265332,int_stack+15258,int_stack+14808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118814, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+266682,int_stack+265332,int_stack+262572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140882, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+268842,int_stack+266682,int_stack+263652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141962, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+261732,int_stack+15808,int_stack+15258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119264, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+271642,int_stack+261732,int_stack+265332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143642, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+274342,int_stack+271642,int_stack+266682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144992, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+263382,int_stack+274342,int_stack+268842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147152, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+267582,int_stack+16468,int_stack+15808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119814, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+277942,int_stack+267582,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149952, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+281242,int_stack+277942,int_stack+271642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151602, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+267582,int_stack+281242,int_stack+274342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154302, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+272982,int_stack+267582,int_stack+263382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157902, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261732,int_stack+17668,int_stack+17248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124334, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262992,int_stack+18208,int_stack+17668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124754, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+264612,int_stack+262992,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162102, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+267132,int_stack+18883,int_stack+18208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125294, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+269157,int_stack+267132,int_stack+262992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163362, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+278862,int_stack+269157,int_stack+264612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164982, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+261732,int_stack+19708,int_stack+18883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125969, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+283062,int_stack+261732,int_stack+267132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167502, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+287112,int_stack+283062,int_stack+269157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169527, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+264207,int_stack+287112,int_stack+278862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179232, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+278862,int_stack+20698,int_stack+19708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126794, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+292512,int_stack+278862,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183432, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+209217,int_stack+292512,int_stack+283062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185907, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+278862,int_stack+209217,int_stack+287112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189957, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+209217,int_stack+278862,int_stack+264207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195357, 0.0, zero_stack,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+278862,int_stack+209217,int_stack+272982,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261732,int_stack+22456,int_stack+21868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78540, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263496,int_stack+23212,int_stack+22456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79716, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265764,int_stack+263496,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201657, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+269292,int_stack+24157,int_stack+23212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81228, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272127,int_stack+269292,int_stack+263496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203421, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7371,int_stack+272127,int_stack+265764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205689, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+261732,int_stack+25312,int_stack+24157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83118, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13251,int_stack+261732,int_stack+269292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+324165,int_stack+13251,int_stack+272127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+265197,int_stack+324165,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172767, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+7371,int_stack+26698,int_stack+25312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85428, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+18921,int_stack+7371,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236217, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+331725,int_stack+18921,int_stack+13251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239682, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+7371,int_stack+331725,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245352, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+324165,int_stack+7371,int_stack+265197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252912, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+336513,int_stack+324165,int_stack+209217,588);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+209217,int_stack+28616,int_stack+28336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118174, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+210057,int_stack+28976,int_stack+28616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118454, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+211137,int_stack+210057,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+212817,int_stack+29426,int_stack+28976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118814, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+214167,int_stack+212817,int_stack+210057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140882, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+324165,int_stack+214167,int_stack+211137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141962, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209217,int_stack+29976,int_stack+29426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119264, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+326965,int_stack+209217,int_stack+212817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143642, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+329665,int_stack+326965,int_stack+214167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144992, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+210867,int_stack+329665,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147152, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+324165,int_stack+30636,int_stack+29976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119814, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+215067,int_stack+324165,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149952, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+7371,int_stack+215067,int_stack+326965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151602, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+7371,int_stack+329665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154302, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+7371,int_stack+324165,int_stack+210867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157902, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+324165,int_stack+31836,int_stack+31416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124334, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+325425,int_stack+32376,int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124754, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+327045,int_stack+325425,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162102, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329565,int_stack+33051,int_stack+32376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125294, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331590,int_stack+329565,int_stack+325425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163362, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13251,int_stack+331590,int_stack+327045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164982, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+324165,int_stack+33876,int_stack+33051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125969, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+17451,int_stack+324165,int_stack+329565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167502, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+21501,int_stack+17451,int_stack+331590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169527, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+326640,int_stack+21501,int_stack+13251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179232, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+13251,int_stack+34866,int_stack+33876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126794, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+26901,int_stack+13251,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183432, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+209217,int_stack+26901,int_stack+17451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185907, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+26901,int_stack+209217,int_stack+21501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189957, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+209217,int_stack+26901,int_stack+326640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195357, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+13251,int_stack+209217,int_stack+7371,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7371,int_stack+36624,int_stack+36036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78540, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9135,int_stack+37380,int_stack+36624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79716, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+324165,int_stack+9135,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201657, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327693,int_stack+38325,int_stack+37380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81228, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330528,int_stack+327693,int_stack+9135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203421, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7371,int_stack+330528,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205689, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+324165,int_stack+39480,int_stack+38325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83118, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+30891,int_stack+324165,int_stack+327693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+261732,int_stack+30891,int_stack+330528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+327630,int_stack+261732,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172767, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+7371,int_stack+40866,int_stack+39480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85428, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+269292,int_stack+7371,int_stack+324165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236217, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+362973,int_stack+269292,int_stack+30891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239682, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+30891,int_stack+362973,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245352, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+261732,int_stack+30891,int_stack+327630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252912, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+362973,int_stack+261732,int_stack+209217,588);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+209217,int_stack+42784,int_stack+42504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+210057,int_stack+43144,int_stack+42784, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+211137,int_stack+210057,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+212817,int_stack+43594,int_stack+43144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+214167,int_stack+212817,int_stack+210057, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+261732,int_stack+214167,int_stack+211137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209217,int_stack+44144,int_stack+43594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+264532,int_stack+209217,int_stack+212817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+267232,int_stack+264532,int_stack+214167, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+210867,int_stack+267232,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+261732,int_stack+44804,int_stack+44144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+215067,int_stack+261732,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+270832,int_stack+215067,int_stack+264532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+261732,int_stack+270832,int_stack+267232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+7371,int_stack+261732,int_stack+210867, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261732,int_stack+46004,int_stack+45584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262992,int_stack+46544,int_stack+46004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+264612,int_stack+262992,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+267132,int_stack+47219,int_stack+46544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+269157,int_stack+267132,int_stack+262992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+272397,int_stack+269157,int_stack+264612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+261732,int_stack+48044,int_stack+47219, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+209217,int_stack+261732,int_stack+267132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30891,int_stack+209217,int_stack+269157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+264207,int_stack+30891,int_stack+272397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+270507,int_stack+49034,int_stack+48044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+273477,int_stack+270507,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+36291,int_stack+273477,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+209217,int_stack+36291,int_stack+30891, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+30891,int_stack+209217,int_stack+264207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+389433,int_stack+30891,int_stack+7371,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7371,int_stack+50792,int_stack+50204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9135,int_stack+51548,int_stack+50792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+209217,int_stack+9135,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+212745,int_stack+52493,int_stack+51548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+39711,int_stack+212745,int_stack+9135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7371,int_stack+39711,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209217,int_stack+53648,int_stack+52493, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+44247,int_stack+209217,int_stack+212745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+261732,int_stack+44247,int_stack+39711, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+269292,int_stack+261732,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+7371,int_stack+55034,int_stack+53648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+324165,int_stack+7371,int_stack+209217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+407073,int_stack+324165,int_stack+44247, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+407073,int_stack+261732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39711,int_stack+324165,int_stack+269292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+407073,int_stack+39711,int_stack+30891,588);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30891,int_stack+56952,int_stack+56672, 0.0, zero_stack, 1.0, int_stack+118174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31731,int_stack+57312,int_stack+56952, 0.0, zero_stack, 1.0, int_stack+118454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32811,int_stack+31731,int_stack+30891, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+34491,int_stack+57762,int_stack+57312, 0.0, zero_stack, 1.0, int_stack+118814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35841,int_stack+34491,int_stack+31731, 0.0, zero_stack, 1.0, int_stack+140882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38001,int_stack+35841,int_stack+32811, 0.0, zero_stack, 1.0, int_stack+141962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30891,int_stack+58312,int_stack+57762, 0.0, zero_stack, 1.0, int_stack+119264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+40801,int_stack+30891,int_stack+34491, 0.0, zero_stack, 1.0, int_stack+143642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+43501,int_stack+40801,int_stack+35841, 0.0, zero_stack, 1.0, int_stack+144992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+32541,int_stack+43501,int_stack+38001, 0.0, zero_stack, 1.0, int_stack+147152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+36741,int_stack+58972,int_stack+58312, 0.0, zero_stack, 1.0, int_stack+119814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47101,int_stack+36741,int_stack+30891, 0.0, zero_stack, 1.0, int_stack+149952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+50401,int_stack+47101,int_stack+40801, 0.0, zero_stack, 1.0, int_stack+151602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+36741,int_stack+50401,int_stack+43501, 0.0, zero_stack, 1.0, int_stack+154302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+7371,int_stack+36741,int_stack+32541, 0.0, zero_stack, 1.0, int_stack+157902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30891,int_stack+60172,int_stack+59752, 0.0, zero_stack, 1.0, int_stack+124334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32151,int_stack+60712,int_stack+60172, 0.0, zero_stack, 1.0, int_stack+124754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+33771,int_stack+32151,int_stack+30891, 0.0, zero_stack, 1.0, int_stack+162102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36291,int_stack+61387,int_stack+60712, 0.0, zero_stack, 1.0, int_stack+125294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38316,int_stack+36291,int_stack+32151, 0.0, zero_stack, 1.0, int_stack+163362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+41556,int_stack+38316,int_stack+33771, 0.0, zero_stack, 1.0, int_stack+164982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30891,int_stack+62212,int_stack+61387, 0.0, zero_stack, 1.0, int_stack+125969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+45756,int_stack+30891,int_stack+36291, 0.0, zero_stack, 1.0, int_stack+167502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49806,int_stack+45756,int_stack+38316, 0.0, zero_stack, 1.0, int_stack+169527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+33366,int_stack+49806,int_stack+41556, 0.0, zero_stack, 1.0, int_stack+179232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39666,int_stack+63202,int_stack+62212, 0.0, zero_stack, 1.0, int_stack+126794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+55206,int_stack+39666,int_stack+30891, 0.0, zero_stack, 1.0, int_stack+183432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+324165,int_stack+55206,int_stack+45756, 0.0, zero_stack, 1.0, int_stack+185907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+55206,int_stack+324165,int_stack+49806, 0.0, zero_stack, 1.0, int_stack+189957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+324165,int_stack+55206,int_stack+33366, 0.0, zero_stack, 1.0, int_stack+195357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+30891,int_stack+324165,int_stack+7371,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7371,int_stack+64960,int_stack+64372, 0.0, zero_stack, 1.0, int_stack+78540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9135,int_stack+65716,int_stack+64960, 0.0, zero_stack, 1.0, int_stack+79716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+332985,int_stack+9135,int_stack+7371, 0.0, zero_stack, 1.0, int_stack+201657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+48531,int_stack+66661,int_stack+65716, 0.0, zero_stack, 1.0, int_stack+81228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51366,int_stack+48531,int_stack+9135, 0.0, zero_stack, 1.0, int_stack+203421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7371,int_stack+51366,int_stack+332985, 0.0, zero_stack, 1.0, int_stack+205689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+332985,int_stack+67816,int_stack+66661, 0.0, zero_stack, 1.0, int_stack+83118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+55902,int_stack+332985,int_stack+48531, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+261732,int_stack+55902,int_stack+51366, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+269292,int_stack+261732,int_stack+7371, 0.0, zero_stack, 1.0, int_stack+172767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+7371,int_stack+69202,int_stack+67816, 0.0, zero_stack, 1.0, int_stack+85428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+48531,int_stack+7371,int_stack+332985, 0.0, zero_stack, 1.0, int_stack+236217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+433533,int_stack+48531,int_stack+55902, 0.0, zero_stack, 1.0, int_stack+239682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+48531,int_stack+433533,int_stack+261732, 0.0, zero_stack, 1.0, int_stack+245352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+433533,int_stack+48531,int_stack+269292, 0.0, zero_stack, 1.0, int_stack+252912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+445881,int_stack+433533,int_stack+324165,588);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+324165,int_stack+71120,int_stack+70840, 1.0, int_stack+118174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+325005,int_stack+71480,int_stack+71120, 1.0, int_stack+118454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+326085,int_stack+325005,int_stack+324165, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327765,int_stack+71930,int_stack+71480, 1.0, int_stack+118814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+329115,int_stack+327765,int_stack+325005, 1.0, int_stack+140882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+331275,int_stack+329115,int_stack+326085, 1.0, int_stack+141962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+140042,int_stack+72480,int_stack+71930, 1.0, int_stack+119264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+324165,int_stack+140042,int_stack+327765, 1.0, int_stack+143642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+433533,int_stack+324165,int_stack+329115, 1.0, int_stack+144992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+141692,int_stack+433533,int_stack+331275, 1.0, int_stack+147152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+145892,int_stack+73140,int_stack+72480, 1.0, int_stack+119814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+326865,int_stack+145892,int_stack+140042, 1.0, int_stack+149952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+330165,int_stack+326865,int_stack+324165, 1.0, int_stack+151602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+330165,int_stack+433533, 1.0, int_stack+154302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+7371,int_stack+324165,int_stack+141692, 1.0, int_stack+157902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+324165,int_stack+74340,int_stack+73920, 1.0, int_stack+124334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+325425,int_stack+74880,int_stack+74340, 1.0, int_stack+124754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+327045,int_stack+325425,int_stack+324165, 1.0, int_stack+162102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329565,int_stack+75555,int_stack+74880, 1.0, int_stack+125294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331590,int_stack+329565,int_stack+325425, 1.0, int_stack+163362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+433533,int_stack+331590,int_stack+327045, 1.0, int_stack+164982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+162102,int_stack+76380,int_stack+75555, 1.0, int_stack+125969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+324165,int_stack+162102,int_stack+329565, 1.0, int_stack+167502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+437733,int_stack+324165,int_stack+331590, 1.0, int_stack+169527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+164577,int_stack+437733,int_stack+433533, 1.0, int_stack+179232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+433533,int_stack+77370,int_stack+76380, 1.0, int_stack+126794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+328215,int_stack+433533,int_stack+162102, 1.0, int_stack+183432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+140042,int_stack+328215,int_stack+324165, 1.0, int_stack+185907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+140042,int_stack+437733, 1.0, int_stack+189957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+140042,int_stack+324165,int_stack+164577, 1.0, int_stack+195357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+48531,int_stack+140042,int_stack+7371,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7371,int_stack+80472,int_stack+79128, 1.0, int_stack+78540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9135,int_stack+82173,int_stack+80472, 1.0, int_stack+79716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+324165,int_stack+9135,int_stack+7371, 1.0, int_stack+201657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327693,int_stack+84273,int_stack+82173, 1.0, int_stack+81228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330528,int_stack+327693,int_stack+9135, 1.0, int_stack+203421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7371,int_stack+330528,int_stack+324165, 1.0, int_stack+205689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+324165,int_stack+86814,int_stack+84273, 1.0, int_stack+83118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+201657,int_stack+324165,int_stack+327693, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+207327,int_stack+201657,int_stack+330528, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+327630,int_stack+207327,int_stack+7371, 1.0, int_stack+172767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+88200,int_stack+86814, 1.0, int_stack+85428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+4158,int_stack+0,int_stack+324165, 1.0, int_stack+236217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+162102,int_stack+4158,int_stack+201657, 1.0, int_stack+239682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+162102,int_stack+207327, 1.0, int_stack+245352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+433533,int_stack+0,int_stack+327630, 1.0, int_stack+252912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+236217,int_stack+433533,int_stack+140042,588);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+140042,int_stack+120474,int_stack+119814,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+142022,int_stack+140042,int_stack+149952,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+145322,int_stack+142022,int_stack+151602,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+433533,int_stack+145322,int_stack+154302,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+140042,int_stack+433533,int_stack+157902,10);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+433533,int_stack+127784,int_stack+126794,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+436503,int_stack+433533,int_stack+183432,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+145922,int_stack+436503,int_stack+185907,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+433533,int_stack+145922,int_stack+189957,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+145922,int_stack+433533,int_stack+195357,15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+154742,int_stack+145922,int_stack+140042,588);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433533,int_stack+90118,int_stack+89838,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+434373,int_stack+90478,int_stack+90118,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+435453,int_stack+434373,int_stack+433533,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+437133,int_stack+90928,int_stack+90478,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+438483,int_stack+437133,int_stack+434373,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+440643,int_stack+438483,int_stack+435453,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+433533,int_stack+91478,int_stack+90928,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+172382,int_stack+433533,int_stack+437133,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+175082,int_stack+172382,int_stack+438483,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+435183,int_stack+175082,int_stack+440643,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+439383,int_stack+92138,int_stack+91478,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+441363,int_stack+439383,int_stack+433533,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+178682,int_stack+441363,int_stack+172382,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+439383,int_stack+178682,int_stack+175082,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+172382,int_stack+439383,int_stack+435183,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+178262,int_stack+93338,int_stack+92918,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+179522,int_stack+93878,int_stack+93338,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+181142,int_stack+179522,int_stack+178262,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+183662,int_stack+94553,int_stack+93878,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+185687,int_stack+183662,int_stack+179522,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+188927,int_stack+185687,int_stack+181142,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+178262,int_stack+95378,int_stack+94553,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+193127,int_stack+178262,int_stack+183662,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+197177,int_stack+193127,int_stack+185687,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+180737,int_stack+197177,int_stack+188927,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+187037,int_stack+96368,int_stack+95378,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+202577,int_stack+187037,int_stack+178262,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+207527,int_stack+202577,int_stack+193127,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+187037,int_stack+207527,int_stack+197177,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+195137,int_stack+187037,int_stack+180737,15);
 /*--- compute (fp|ih) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+66171,int_stack+195137,int_stack+172382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+172382,int_stack+98126,int_stack+97538,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+174146,int_stack+98882,int_stack+98126,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+176414,int_stack+174146,int_stack+172382,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+179942,int_stack+99827,int_stack+98882,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+182777,int_stack+179942,int_stack+174146,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+187313,int_stack+182777,int_stack+176414,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+172382,int_stack+100982,int_stack+99827,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+203957,int_stack+172382,int_stack+179942,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+209627,int_stack+203957,int_stack+182777,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+175847,int_stack+209627,int_stack+187313,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+184667,int_stack+102368,int_stack+100982,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+433533,int_stack+184667,int_stack+172382,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+184667,int_stack+433533,int_stack+203957,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+433533,int_stack+184667,int_stack+209627,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+324165,int_stack+433533,int_stack+175847,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+472341,int_stack+324165,int_stack+195137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+324165,int_stack+104286,int_stack+104006,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+325005,int_stack+104646,int_stack+104286,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+326085,int_stack+325005,int_stack+324165,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+327765,int_stack+105096,int_stack+104646,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+329115,int_stack+327765,int_stack+325005,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+331275,int_stack+329115,int_stack+326085,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+324165,int_stack+105646,int_stack+105096,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+433533,int_stack+324165,int_stack+327765,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+436233,int_stack+433533,int_stack+329115,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+325815,int_stack+436233,int_stack+331275,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+330015,int_stack+106306,int_stack+105646,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+331995,int_stack+330015,int_stack+324165,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+439833,int_stack+331995,int_stack+433533,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+330015,int_stack+439833,int_stack+436233,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+433533,int_stack+330015,int_stack+325815,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+439413,int_stack+107506,int_stack+107086,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+440673,int_stack+108046,int_stack+107506,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+442293,int_stack+440673,int_stack+439413,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+324165,int_stack+108721,int_stack+108046,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+326190,int_stack+324165,int_stack+440673,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+329430,int_stack+326190,int_stack+442293,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+439413,int_stack+109546,int_stack+108721,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+172382,int_stack+439413,int_stack+324165,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+176432,int_stack+172382,int_stack+326190,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+181832,int_stack+176432,int_stack+329430,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+324165,int_stack+110536,int_stack+109546,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+327135,int_stack+324165,int_stack+439413,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+188132,int_stack+327135,int_stack+172382,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+188132,int_stack+176432,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+188132,int_stack+324165,int_stack+181832,15);
 /*--- compute (fp|ih) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+196952,int_stack+188132,int_stack+433533, 0.0, zero_stack, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433533,int_stack+112294,int_stack+111706,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+435297,int_stack+113050,int_stack+112294,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+437565,int_stack+435297,int_stack+433533,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+441093,int_stack+113995,int_stack+113050,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+324165,int_stack+441093,int_stack+435297,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+328701,int_stack+324165,int_stack+437565,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+433533,int_stack+115150,int_stack+113995,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+172382,int_stack+433533,int_stack+441093,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+436998,int_stack+172382,int_stack+324165,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+178052,int_stack+436998,int_stack+328701,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+324165,int_stack+116536,int_stack+115150,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+328323,int_stack+324165,int_stack+433533,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+328323,int_stack+172382,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+324165,int_stack+0,int_stack+436998,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+433533,int_stack+324165,int_stack+178052,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+83811,int_stack+433533,int_stack+188132, 0.0, zero_stack, 1.0, int_stack+145922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433533,int_stack+121534,int_stack+121254,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+434373,int_stack+121894,int_stack+121534,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+435453,int_stack+434373,int_stack+433533,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+437133,int_stack+122344,int_stack+121894,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+438483,int_stack+437133,int_stack+434373,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+440643,int_stack+438483,int_stack+435453,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+433533,int_stack+122894,int_stack+122344,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+324165,int_stack+433533,int_stack+437133,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+326865,int_stack+324165,int_stack+438483,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+435183,int_stack+326865,int_stack+440643,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+439383,int_stack+123554,int_stack+122894,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+441363,int_stack+439383,int_stack+433533,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+330465,int_stack+441363,int_stack+324165,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+439383,int_stack+330465,int_stack+326865,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+324165,int_stack+439383,int_stack+435183,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+330045,int_stack+129374,int_stack+128954,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+331305,int_stack+129914,int_stack+129374,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+332925,int_stack+331305,int_stack+330045,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+433533,int_stack+130589,int_stack+129914,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+435558,int_stack+433533,int_stack+331305,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+438798,int_stack+435558,int_stack+332925,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+330045,int_stack+131414,int_stack+130589,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+330045,int_stack+433533,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4050,int_stack+0,int_stack+435558,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+172382,int_stack+4050,int_stack+438798,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+433533,int_stack+132404,int_stack+131414,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+436503,int_stack+433533,int_stack+330045,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+178682,int_stack+436503,int_stack+0,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+433533,int_stack+178682,int_stack+4050,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+178682,int_stack+433533,int_stack+172382,15);
 /*--- compute (fp|ih) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+110271,int_stack+178682,int_stack+324165, 1.0, int_stack+140042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+140042,int_stack+134162,int_stack+133574,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+141806,int_stack+134918,int_stack+134162,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+324165,int_stack+141806,int_stack+140042,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+327693,int_stack+135863,int_stack+134918,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+330528,int_stack+327693,int_stack+141806,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+140042,int_stack+330528,int_stack+324165,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+324165,int_stack+137018,int_stack+135863,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+172382,int_stack+324165,int_stack+327693,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+433533,int_stack+172382,int_stack+330528,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+327630,int_stack+433533,int_stack+140042,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+140042,int_stack+138404,int_stack+137018,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+187502,int_stack+140042,int_stack+324165,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+187502,int_stack+172382,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+262677,int_stack+0,int_stack+433533,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+433533,int_stack+262677,int_stack+327630,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+498801,int_stack+433533,int_stack+178682, 1.0, int_stack+145922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+525261,int_stack+297705,int_stack+218577,588);
     Libderiv->ABCD[11] = int_stack + 525261;
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+296502,int_stack+336513,int_stack+278862,588);
     Libderiv->ABCD[10] = int_stack + 296502;
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+560541,int_stack+362973,int_stack+13251,588);
     Libderiv->ABCD[9] = int_stack + 560541;
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+331782,int_stack+407073,int_stack+389433,588);
     Libderiv->ABCD[8] = int_stack + 331782;
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+367062,int_stack+445881,int_stack+30891,588);
     Libderiv->ABCD[7] = int_stack + 367062;
 /*--- compute (fd|ih) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+0,int_stack+236217,int_stack+48531,588);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (fd|ih) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+214592,int_stack+472341,int_stack+66171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 214592;
 /*--- compute (fd|ih) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+35280,int_stack+83811,int_stack+196952, 0.0, zero_stack, 1.0, int_stack+154742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 35280;
 /*--- compute (fd|ih) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+70560,int_stack+498801,int_stack+110271, 1.0, int_stack+154742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 70560;

}
