/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ffhd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ff|hd) integrals */

void d1hrr_order_ffhd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[4][5][11] = int_stack + 850;
 Libderiv->deriv_classes[4][6][11] = int_stack + 1165;
 Libderiv->deriv_classes[4][7][11] = int_stack + 1585;
 Libderiv->deriv_classes[5][5][11] = int_stack + 2125;
 Libderiv->deriv_classes[5][6][11] = int_stack + 2566;
 Libderiv->deriv_classes[5][7][11] = int_stack + 3154;
 Libderiv->deriv_classes[6][5][11] = int_stack + 3910;
 Libderiv->deriv_classes[6][6][11] = int_stack + 4498;
 Libderiv->deriv_classes[6][7][11] = int_stack + 5282;
 Libderiv->deriv_classes[3][5][10] = int_stack + 6290;
 Libderiv->deriv_classes[3][6][10] = int_stack + 6500;
 Libderiv->deriv_classes[3][7][10] = int_stack + 6780;
 Libderiv->deriv_classes[4][5][10] = int_stack + 7140;
 Libderiv->deriv_classes[4][6][10] = int_stack + 7455;
 Libderiv->deriv_classes[4][7][10] = int_stack + 7875;
 Libderiv->deriv_classes[5][5][10] = int_stack + 8415;
 Libderiv->deriv_classes[5][6][10] = int_stack + 8856;
 Libderiv->deriv_classes[5][7][10] = int_stack + 9444;
 Libderiv->deriv_classes[6][5][10] = int_stack + 10200;
 Libderiv->deriv_classes[6][6][10] = int_stack + 10788;
 Libderiv->deriv_classes[6][7][10] = int_stack + 11572;
 Libderiv->deriv_classes[3][5][9] = int_stack + 12580;
 Libderiv->deriv_classes[3][6][9] = int_stack + 12790;
 Libderiv->deriv_classes[3][7][9] = int_stack + 13070;
 Libderiv->deriv_classes[4][5][9] = int_stack + 13430;
 Libderiv->deriv_classes[4][6][9] = int_stack + 13745;
 Libderiv->deriv_classes[4][7][9] = int_stack + 14165;
 Libderiv->deriv_classes[5][5][9] = int_stack + 14705;
 Libderiv->deriv_classes[5][6][9] = int_stack + 15146;
 Libderiv->deriv_classes[5][7][9] = int_stack + 15734;
 Libderiv->deriv_classes[6][5][9] = int_stack + 16490;
 Libderiv->deriv_classes[6][6][9] = int_stack + 17078;
 Libderiv->deriv_classes[6][7][9] = int_stack + 17862;
 Libderiv->deriv_classes[3][5][8] = int_stack + 18870;
 Libderiv->deriv_classes[3][6][8] = int_stack + 19080;
 Libderiv->deriv_classes[3][7][8] = int_stack + 19360;
 Libderiv->deriv_classes[4][5][8] = int_stack + 19720;
 Libderiv->deriv_classes[4][6][8] = int_stack + 20035;
 Libderiv->deriv_classes[4][7][8] = int_stack + 20455;
 Libderiv->deriv_classes[5][5][8] = int_stack + 20995;
 Libderiv->deriv_classes[5][6][8] = int_stack + 21436;
 Libderiv->deriv_classes[5][7][8] = int_stack + 22024;
 Libderiv->deriv_classes[6][5][8] = int_stack + 22780;
 Libderiv->deriv_classes[6][6][8] = int_stack + 23368;
 Libderiv->deriv_classes[6][7][8] = int_stack + 24152;
 Libderiv->deriv_classes[3][5][7] = int_stack + 25160;
 Libderiv->deriv_classes[3][6][7] = int_stack + 25370;
 Libderiv->deriv_classes[3][7][7] = int_stack + 25650;
 Libderiv->deriv_classes[4][5][7] = int_stack + 26010;
 Libderiv->deriv_classes[4][6][7] = int_stack + 26325;
 Libderiv->deriv_classes[4][7][7] = int_stack + 26745;
 Libderiv->deriv_classes[5][5][7] = int_stack + 27285;
 Libderiv->deriv_classes[5][6][7] = int_stack + 27726;
 Libderiv->deriv_classes[5][7][7] = int_stack + 28314;
 Libderiv->deriv_classes[6][5][7] = int_stack + 29070;
 Libderiv->deriv_classes[6][6][7] = int_stack + 29658;
 Libderiv->deriv_classes[6][7][7] = int_stack + 30442;
 Libderiv->deriv_classes[3][5][6] = int_stack + 31450;
 Libderiv->deriv_classes[3][6][6] = int_stack + 31660;
 Libderiv->deriv_classes[3][7][6] = int_stack + 31940;
 Libderiv->deriv_classes[4][5][6] = int_stack + 32300;
 Libderiv->deriv_classes[4][6][6] = int_stack + 32615;
 Libderiv->deriv_classes[4][7][6] = int_stack + 33035;
 Libderiv->deriv_classes[5][5][6] = int_stack + 33575;
 Libderiv->deriv_classes[5][6][6] = int_stack + 34016;
 Libderiv->deriv_classes[5][7][6] = int_stack + 34604;
 Libderiv->dvrr_classes[6][5] = int_stack + 35360;
 Libderiv->deriv_classes[6][5][6] = int_stack + 35948;
 Libderiv->dvrr_classes[6][6] = int_stack + 36536;
 Libderiv->deriv_classes[6][6][6] = int_stack + 37320;
 Libderiv->deriv_classes[6][7][6] = int_stack + 38104;
 Libderiv->deriv_classes[3][5][2] = int_stack + 39112;
 Libderiv->deriv_classes[3][6][2] = int_stack + 39322;
 Libderiv->deriv_classes[3][7][2] = int_stack + 39602;
 Libderiv->deriv_classes[4][5][2] = int_stack + 39962;
 Libderiv->deriv_classes[4][6][2] = int_stack + 40277;
 Libderiv->deriv_classes[4][7][2] = int_stack + 40697;
 Libderiv->deriv_classes[5][5][2] = int_stack + 41237;
 Libderiv->deriv_classes[5][6][2] = int_stack + 41678;
 Libderiv->deriv_classes[5][7][2] = int_stack + 42266;
 Libderiv->deriv_classes[6][5][2] = int_stack + 43022;
 Libderiv->deriv_classes[6][6][2] = int_stack + 43610;
 Libderiv->deriv_classes[6][7][2] = int_stack + 44394;
 Libderiv->deriv_classes[3][5][1] = int_stack + 45402;
 Libderiv->deriv_classes[3][6][1] = int_stack + 45612;
 Libderiv->deriv_classes[3][7][1] = int_stack + 45892;
 Libderiv->deriv_classes[4][5][1] = int_stack + 46252;
 Libderiv->deriv_classes[4][6][1] = int_stack + 46567;
 Libderiv->deriv_classes[4][7][1] = int_stack + 46987;
 Libderiv->deriv_classes[5][5][1] = int_stack + 47527;
 Libderiv->deriv_classes[5][6][1] = int_stack + 47968;
 Libderiv->deriv_classes[5][7][1] = int_stack + 48556;
 Libderiv->deriv_classes[6][5][1] = int_stack + 49312;
 Libderiv->deriv_classes[6][6][1] = int_stack + 49900;
 Libderiv->deriv_classes[6][7][1] = int_stack + 50684;
 Libderiv->dvrr_classes[3][5] = int_stack + 51692;
 Libderiv->dvrr_classes[3][6] = int_stack + 51902;
 Libderiv->dvrr_classes[3][7] = int_stack + 52182;
 Libderiv->deriv_classes[3][5][0] = int_stack + 52542;
 Libderiv->deriv_classes[3][6][0] = int_stack + 52752;
 Libderiv->deriv_classes[3][7][0] = int_stack + 53032;
 Libderiv->dvrr_classes[4][5] = int_stack + 53392;
 Libderiv->dvrr_classes[4][6] = int_stack + 53707;
 Libderiv->dvrr_classes[4][7] = int_stack + 54127;
 Libderiv->deriv_classes[4][5][0] = int_stack + 54667;
 Libderiv->deriv_classes[4][6][0] = int_stack + 54982;
 Libderiv->deriv_classes[4][7][0] = int_stack + 55402;
 Libderiv->dvrr_classes[5][5] = int_stack + 55942;
 Libderiv->dvrr_classes[5][6] = int_stack + 56383;
 Libderiv->dvrr_classes[5][7] = int_stack + 56971;
 Libderiv->deriv_classes[5][5][0] = int_stack + 57727;
 Libderiv->deriv_classes[5][6][0] = int_stack + 58168;
 Libderiv->deriv_classes[5][7][0] = int_stack + 58756;
 Libderiv->deriv_classes[6][5][0] = int_stack + 59512;
 Libderiv->deriv_classes[6][6][0] = int_stack + 60100;
 Libderiv->deriv_classes[6][7][0] = int_stack + 60884;
 memset(int_stack,0,495136);

 Libderiv->dvrr_stack = int_stack + 233525;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ffhd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61892,int_stack+51902,int_stack+51692,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+62522,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51692,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+63152,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51902,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63992,int_stack+63152,int_stack+62522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61892,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+62522,int_stack+53707,int_stack+53392,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65252,int_stack+1165,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53392,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66197,int_stack+1585,int_stack+1165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53707,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+66197,int_stack+65252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62522,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+65252,int_stack+0,int_stack+63992,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+63467,int_stack+56383,int_stack+55942,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69032,int_stack+2566,int_stack+2125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55942,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70355,int_stack+3154,int_stack+2566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56383,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72119,int_stack+70355,int_stack+69032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63467,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+74765,int_stack+72119,int_stack+0,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+80435,int_stack+74765,int_stack+65252,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+36536,int_stack+35360,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1764,int_stack+4498,int_stack+3910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35360,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64790,int_stack+5282,int_stack+4498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36536,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+67142,int_stack+64790,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+87995,int_stack+67142,int_stack+72119,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+95933,int_stack+87995,int_stack+74765,126);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87995,int_stack+6500,int_stack+6290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51692, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88625,int_stack+6780,int_stack+6500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51902, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+89465,int_stack+88625,int_stack+87995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61892, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87995,int_stack+7455,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53392, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+90725,int_stack+7875,int_stack+7455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53707, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+91985,int_stack+90725,int_stack+87995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62522, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+1764,int_stack+91985,int_stack+89465,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87995,int_stack+8856,int_stack+8415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55942, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+89318,int_stack+9444,int_stack+8856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56383, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5544,int_stack+89318,int_stack+87995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63467, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+64790,int_stack+5544,int_stack+91985,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+87995,int_stack+64790,int_stack+1764,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1764,int_stack+10788,int_stack+10200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35360, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8190,int_stack+11572,int_stack+10788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36536, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+70460,int_stack+8190,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+107273,int_stack+70460,int_stack+5544,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+115211,int_stack+107273,int_stack+64790,126);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64790,int_stack+12790,int_stack+12580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51692, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65420,int_stack+13070,int_stack+12790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51902, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66260,int_stack+65420,int_stack+64790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61892, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64790,int_stack+13745,int_stack+13430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53392, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67520,int_stack+14165,int_stack+13745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53707, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+68780,int_stack+67520,int_stack+64790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62522, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+70670,int_stack+68780,int_stack+66260,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64790,int_stack+15146,int_stack+14705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55942, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66113,int_stack+15734,int_stack+15146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56383, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+74450,int_stack+66113,int_stack+64790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63467, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+107273,int_stack+74450,int_stack+68780,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+1764,int_stack+107273,int_stack+70670,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64790,int_stack+17078,int_stack+16490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35360, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66554,int_stack+17862,int_stack+17078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36536, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+68906,int_stack+66554,int_stack+64790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+9324,int_stack+68906,int_stack+74450,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+64790,int_stack+9324,int_stack+107273,126);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+107273,int_stack+19080,int_stack+18870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+107903,int_stack+19360,int_stack+19080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+108743,int_stack+107903,int_stack+107273, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+107273,int_stack+20035,int_stack+19720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+110003,int_stack+20455,int_stack+20035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111263,int_stack+110003,int_stack+107273, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+9324,int_stack+111263,int_stack+108743,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+107273,int_stack+21436,int_stack+20995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108596,int_stack+22024,int_stack+21436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13104,int_stack+108596,int_stack+107273, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+15750,int_stack+13104,int_stack+111263,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+107273,int_stack+15750,int_stack+9324,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9324,int_stack+23368,int_stack+22780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76130,int_stack+24152,int_stack+23368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21420,int_stack+76130,int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+126551,int_stack+21420,int_stack+13104,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+134489,int_stack+126551,int_stack+15750,126);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+126551,int_stack+25370,int_stack+25160, 0.0, zero_stack, 1.0, int_stack+51692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+127181,int_stack+25650,int_stack+25370, 0.0, zero_stack, 1.0, int_stack+51902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+128021,int_stack+127181,int_stack+126551, 0.0, zero_stack, 1.0, int_stack+61892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+126551,int_stack+26325,int_stack+26010, 0.0, zero_stack, 1.0, int_stack+53392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+129281,int_stack+26745,int_stack+26325, 0.0, zero_stack, 1.0, int_stack+53707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+130541,int_stack+129281,int_stack+126551, 0.0, zero_stack, 1.0, int_stack+62522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+9324,int_stack+130541,int_stack+128021,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+126551,int_stack+27726,int_stack+27285, 0.0, zero_stack, 1.0, int_stack+55942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+127874,int_stack+28314,int_stack+27726, 0.0, zero_stack, 1.0, int_stack+56383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13104,int_stack+127874,int_stack+126551, 0.0, zero_stack, 1.0, int_stack+63467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+15750,int_stack+13104,int_stack+130541,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+126551,int_stack+15750,int_stack+9324,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9324,int_stack+29658,int_stack+29070, 0.0, zero_stack, 1.0, int_stack+35360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21420,int_stack+30442,int_stack+29658, 0.0, zero_stack, 1.0, int_stack+36536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23772,int_stack+21420,int_stack+9324, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+145829,int_stack+23772,int_stack+13104,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+153767,int_stack+145829,int_stack+15750,126);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145829,int_stack+31660,int_stack+31450, 1.0, int_stack+51692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146459,int_stack+31940,int_stack+31660, 1.0, int_stack+51902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+147299,int_stack+146459,int_stack+145829, 1.0, int_stack+61892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145829,int_stack+32615,int_stack+32300, 1.0, int_stack+53392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+148559,int_stack+33035,int_stack+32615, 1.0, int_stack+53707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+149819,int_stack+148559,int_stack+145829, 1.0, int_stack+62522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+9324,int_stack+149819,int_stack+147299,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145829,int_stack+34016,int_stack+33575, 1.0, int_stack+55942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147152,int_stack+34604,int_stack+34016, 1.0, int_stack+56383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13104,int_stack+147152,int_stack+145829, 1.0, int_stack+63467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+15750,int_stack+13104,int_stack+149819,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+145829,int_stack+15750,int_stack+9324,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9324,int_stack+37320,int_stack+35948, 1.0, int_stack+35360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21420,int_stack+38104,int_stack+37320, 1.0, int_stack+36536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23772,int_stack+21420,int_stack+9324, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+27300,int_stack+23772,int_stack+13104,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+165107,int_stack+27300,int_stack+15750,126);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+52182,int_stack+51902,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9324,int_stack+0,int_stack+61892,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+54127,int_stack+53707,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10584,int_stack+0,int_stack+62522,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+12474,int_stack+10584,int_stack+9324,126);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+56971,int_stack+56383,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+16254,int_stack+0,int_stack+63467,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+18900,int_stack+16254,int_stack+10584,126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+24570,int_stack+18900,int_stack+12474,126);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+39322,int_stack+39112,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+39602,int_stack+39322,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+61892,int_stack+630,int_stack+0,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+40277,int_stack+39962,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+63152,int_stack+40697,int_stack+40277,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+32130,int_stack+63152,int_stack+0,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+34020,int_stack+32130,int_stack+61892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61892,int_stack+41678,int_stack+41237,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+42266,int_stack+41678,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+37800,int_stack+0,int_stack+61892,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+176447,int_stack+37800,int_stack+32130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (fd|hd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+182117,int_stack+176447,int_stack+34020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+43610,int_stack+43022,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+32130,int_stack+44394,int_stack+43610,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40446,int_stack+32130,int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+189677,int_stack+40446,int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+32130,int_stack+189677,int_stack+176447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+176447,int_stack+45612,int_stack+45402,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+177077,int_stack+45892,int_stack+45612,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+177917,int_stack+177077,int_stack+176447,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+176447,int_stack+46567,int_stack+46252,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+179177,int_stack+46987,int_stack+46567,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+189677,int_stack+179177,int_stack+176447,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+191567,int_stack+189677,int_stack+177917, 0.0, zero_stack, 1.0, int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+176447,int_stack+47968,int_stack+47527,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+48556,int_stack+47968,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+177770,int_stack+0,int_stack+176447,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+43470,int_stack+177770,int_stack+189677, 0.0, zero_stack, 1.0, int_stack+10584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (fd|hd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+195347,int_stack+43470,int_stack+191567, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+49900,int_stack+49312,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+189677,int_stack+50684,int_stack+49900,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76130,int_stack+189677,int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+202907,int_stack+76130,int_stack+177770, 0.0, zero_stack, 1.0, int_stack+16254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+210845,int_stack+202907,int_stack+43470, 0.0, zero_stack, 1.0, int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43470,int_stack+52752,int_stack+52542,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+44100,int_stack+53032,int_stack+52752,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+44940,int_stack+44100,int_stack+43470,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43470,int_stack+54982,int_stack+54667,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+46200,int_stack+55402,int_stack+54982,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+47460,int_stack+46200,int_stack+43470,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+49350,int_stack+47460,int_stack+44940, 1.0, int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43470,int_stack+58168,int_stack+57727,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+58756,int_stack+58168,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+44793,int_stack+0,int_stack+43470,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+189677,int_stack+44793,int_stack+47460, 1.0, int_stack+10584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (fd|hd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+202907,int_stack+189677,int_stack+49350, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+60100,int_stack+59512,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9324,int_stack+60884,int_stack+60100,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11676,int_stack+9324,int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+47439,int_stack+11676,int_stack+44793, 1.0, int_stack+16254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+222185,int_stack+47439,int_stack+189677, 1.0, int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+9324,int_stack+95933,int_stack+80435,126);
     Libderiv->ABCD[11] = int_stack + 9324;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+43470,int_stack+115211,int_stack+87995,126);
     Libderiv->ABCD[10] = int_stack + 43470;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+76130,int_stack+64790,int_stack+1764,126);
     Libderiv->ABCD[9] = int_stack + 76130;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+56070,int_stack+134489,int_stack+107273,126);
     Libderiv->ABCD[8] = int_stack + 56070;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+88730,int_stack+153767,int_stack+126551,126);
     Libderiv->ABCD[7] = int_stack + 88730;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+101330,int_stack+165107,int_stack+145829,126);
     Libderiv->ABCD[6] = int_stack + 101330;
 /*--- compute (ff|hd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+113930,int_stack+32130,int_stack+182117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 113930;
 /*--- compute (ff|hd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+126530,int_stack+210845,int_stack+195347, 0.0, zero_stack, 1.0, int_stack+24570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 126530;
 /*--- compute (ff|hd) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+139130,int_stack+222185,int_stack+202907, 1.0, int_stack+24570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 139130;

}
