/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_g0hh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (g0|hh) integrals */

void d1hrr_order_g0hh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1950;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2775;
 Libderiv->deriv_classes[4][5][10] = int_stack + 3765;
 Libderiv->deriv_classes[4][6][10] = int_stack + 4080;
 Libderiv->deriv_classes[4][7][10] = int_stack + 4500;
 Libderiv->deriv_classes[4][8][10] = int_stack + 5040;
 Libderiv->deriv_classes[4][9][10] = int_stack + 5715;
 Libderiv->deriv_classes[4][10][10] = int_stack + 6540;
 Libderiv->deriv_classes[4][5][9] = int_stack + 7530;
 Libderiv->deriv_classes[4][6][9] = int_stack + 7845;
 Libderiv->deriv_classes[4][7][9] = int_stack + 8265;
 Libderiv->deriv_classes[4][8][9] = int_stack + 8805;
 Libderiv->deriv_classes[4][9][9] = int_stack + 9480;
 Libderiv->deriv_classes[4][10][9] = int_stack + 10305;
 Libderiv->deriv_classes[4][5][8] = int_stack + 11295;
 Libderiv->deriv_classes[4][6][8] = int_stack + 11610;
 Libderiv->deriv_classes[4][7][8] = int_stack + 12030;
 Libderiv->deriv_classes[4][8][8] = int_stack + 12570;
 Libderiv->deriv_classes[4][9][8] = int_stack + 13245;
 Libderiv->deriv_classes[4][10][8] = int_stack + 14070;
 Libderiv->deriv_classes[4][5][7] = int_stack + 15060;
 Libderiv->deriv_classes[4][6][7] = int_stack + 15375;
 Libderiv->deriv_classes[4][7][7] = int_stack + 15795;
 Libderiv->deriv_classes[4][8][7] = int_stack + 16335;
 Libderiv->deriv_classes[4][9][7] = int_stack + 17010;
 Libderiv->deriv_classes[4][10][7] = int_stack + 17835;
 Libderiv->dvrr_classes[4][5] = int_stack + 18825;
 Libderiv->deriv_classes[4][5][6] = int_stack + 19140;
 Libderiv->dvrr_classes[4][6] = int_stack + 19455;
 Libderiv->deriv_classes[4][6][6] = int_stack + 19875;
 Libderiv->dvrr_classes[4][7] = int_stack + 20295;
 Libderiv->deriv_classes[4][7][6] = int_stack + 20835;
 Libderiv->dvrr_classes[4][8] = int_stack + 21375;
 Libderiv->deriv_classes[4][8][6] = int_stack + 22050;
 Libderiv->dvrr_classes[4][9] = int_stack + 22725;
 Libderiv->deriv_classes[4][9][6] = int_stack + 23550;
 Libderiv->deriv_classes[4][10][6] = int_stack + 24375;
 Libderiv->deriv_classes[4][5][2] = int_stack + 25365;
 Libderiv->deriv_classes[4][6][2] = int_stack + 25680;
 Libderiv->deriv_classes[4][7][2] = int_stack + 26100;
 Libderiv->deriv_classes[4][8][2] = int_stack + 26640;
 Libderiv->deriv_classes[4][9][2] = int_stack + 27315;
 Libderiv->deriv_classes[4][10][2] = int_stack + 28140;
 Libderiv->deriv_classes[4][5][1] = int_stack + 29130;
 Libderiv->deriv_classes[4][6][1] = int_stack + 29445;
 Libderiv->deriv_classes[4][7][1] = int_stack + 29865;
 Libderiv->deriv_classes[4][8][1] = int_stack + 30405;
 Libderiv->deriv_classes[4][9][1] = int_stack + 31080;
 Libderiv->deriv_classes[4][10][1] = int_stack + 31905;
 Libderiv->deriv_classes[4][5][0] = int_stack + 32895;
 Libderiv->deriv_classes[4][6][0] = int_stack + 33210;
 Libderiv->deriv_classes[4][7][0] = int_stack + 33630;
 Libderiv->deriv_classes[4][8][0] = int_stack + 34170;
 Libderiv->deriv_classes[4][9][0] = int_stack + 34845;
 Libderiv->deriv_classes[4][10][0] = int_stack + 35670;
 memset(int_stack,0,293280);

 Libderiv->dvrr_stack = int_stack + 134910;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_g0hh(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+36660,int_stack+19455,int_stack+18825,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37605,int_stack+20295,int_stack+19455,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+38865,int_stack+37605,int_stack+36660,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+40755,int_stack+21375,int_stack+20295,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+42375,int_stack+40755,int_stack+37605,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+44895,int_stack+42375,int_stack+38865,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+48045,int_stack+22725,int_stack+21375,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+50070,int_stack+48045,int_stack+40755,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+53310,int_stack+50070,int_stack+42375,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+57510,int_stack+53310,int_stack+44895,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+62235,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18825,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+63180,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19455,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+64440,int_stack+63180,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36660,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+66330,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20295,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+67950,int_stack+66330,int_stack+63180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37605,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+70470,int_stack+67950,int_stack+64440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38865,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+1950,int_stack+1275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21375,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+73620,int_stack+62235,int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40755,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+76860,int_stack+73620,int_stack+67950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42375,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+64260,int_stack+76860,int_stack+70470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44895,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+68985,int_stack+2775,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22725,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+81060,int_stack+68985,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48045,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+85110,int_stack+81060,int_stack+73620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50070,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+68985,int_stack+85110,int_stack+76860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53310,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+62235,int_stack+4080,int_stack+3765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18825, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75285,int_stack+4500,int_stack+4080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19455, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76545,int_stack+75285,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36660, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62235,int_stack+5040,int_stack+4500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20295, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+78435,int_stack+62235,int_stack+75285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37605, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+80955,int_stack+78435,int_stack+76545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38865, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+75285,int_stack+5715,int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21375, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+84105,int_stack+75285,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40755, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+84105,int_stack+78435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42375, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+87345,int_stack+0,int_stack+80955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44895, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+77310,int_stack+6540,int_stack+5715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22725, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+79785,int_stack+77310,int_stack+75285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48045, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+92070,int_stack+79785,int_stack+84105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50070, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+75285,int_stack+92070,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53310, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+7845,int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18825, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+8265,int_stack+7845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19455, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36660, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4095,int_stack+8805,int_stack+8265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20295, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5715,int_stack+4095,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37605, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+92070,int_stack+5715,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38865, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+9480,int_stack+8805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+81585,int_stack+0,int_stack+5715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3240,int_stack+81585,int_stack+92070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44895, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+92070,int_stack+10305,int_stack+9480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22725, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+94545,int_stack+92070,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48045, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+98595,int_stack+94545,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50070, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+92070,int_stack+98595,int_stack+81585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53310, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+81585,int_stack+11610,int_stack+11295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+82530,int_stack+12030,int_stack+11610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83790,int_stack+82530,int_stack+81585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+85680,int_stack+12570,int_stack+12030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+85680,int_stack+82530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+0,int_stack+83790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+13245,int_stack+12570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+81585,int_stack+62235,int_stack+85680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+81585,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+101520,int_stack+7965,int_stack+98370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+14070,int_stack+13245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+106245,int_stack+98370,int_stack+62235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+110295,int_stack+106245,int_stack+81585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+115695,int_stack+110295,int_stack+7965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7965,int_stack+15375,int_stack+15060, 0.0, zero_stack, 1.0, int_stack+18825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8910,int_stack+15795,int_stack+15375, 0.0, zero_stack, 1.0, int_stack+19455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10170,int_stack+8910,int_stack+7965, 0.0, zero_stack, 1.0, int_stack+36660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12060,int_stack+16335,int_stack+15795, 0.0, zero_stack, 1.0, int_stack+20295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13680,int_stack+12060,int_stack+8910, 0.0, zero_stack, 1.0, int_stack+37605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+13680,int_stack+10170, 0.0, zero_stack, 1.0, int_stack+38865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+17010,int_stack+16335, 0.0, zero_stack, 1.0, int_stack+21375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+12060, 0.0, zero_stack, 1.0, int_stack+40755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+0,int_stack+13680, 0.0, zero_stack, 1.0, int_stack+42375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12165,int_stack+7965,int_stack+98370, 0.0, zero_stack, 1.0, int_stack+44895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+17835,int_stack+17010, 0.0, zero_stack, 1.0, int_stack+22725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+81585,int_stack+98370,int_stack+62235, 0.0, zero_stack, 1.0, int_stack+48045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+106245,int_stack+81585,int_stack+0, 0.0, zero_stack, 1.0, int_stack+50070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+121995,int_stack+106245,int_stack+7965, 0.0, zero_stack, 1.0, int_stack+53310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7965,int_stack+19875,int_stack+19140, 1.0, int_stack+18825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8910,int_stack+20835,int_stack+19875, 1.0, int_stack+19455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10170,int_stack+8910,int_stack+7965, 1.0, int_stack+36660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+106245,int_stack+22050,int_stack+20835, 1.0, int_stack+20295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+107865,int_stack+106245,int_stack+8910, 1.0, int_stack+37605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+107865,int_stack+10170, 1.0, int_stack+38865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+23550,int_stack+22050, 1.0, int_stack+21375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+106245, 1.0, int_stack+40755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+0,int_stack+107865, 1.0, int_stack+42375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+106245,int_stack+7965,int_stack+98370, 1.0, int_stack+44895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+24375,int_stack+23550, 1.0, int_stack+22725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+110970,int_stack+98370,int_stack+62235, 1.0, int_stack+48045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+36660,int_stack+110970,int_stack+0, 1.0, int_stack+50070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42060,int_stack+36660,int_stack+7965, 1.0, int_stack+53310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7965,int_stack+25680,int_stack+25365,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8910,int_stack+26100,int_stack+25680,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10170,int_stack+8910,int_stack+7965,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36660,int_stack+26640,int_stack+26100,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+38280,int_stack+36660,int_stack+8910,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+38280,int_stack+10170,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+27315,int_stack+26640,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+36660,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+0,int_stack+38280,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+110970,int_stack+7965,int_stack+98370,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+28140,int_stack+27315,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+36660,int_stack+98370,int_stack+62235,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+48360,int_stack+36660,int_stack+0,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+16890,int_stack+48360,int_stack+7965,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7965,int_stack+29445,int_stack+29130,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8910,int_stack+29865,int_stack+29445,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10170,int_stack+8910,int_stack+7965,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+48360,int_stack+30405,int_stack+29865,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+49980,int_stack+48360,int_stack+8910,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+49980,int_stack+10170,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+31080,int_stack+30405,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+48360,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+0,int_stack+49980,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+48360,int_stack+7965,int_stack+98370,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+31905,int_stack+31080,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+53085,int_stack+98370,int_stack+62235,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+36660,int_stack+53085,int_stack+0,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+23190,int_stack+36660,int_stack+7965,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7965,int_stack+33210,int_stack+32895,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8910,int_stack+33630,int_stack+33210,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10170,int_stack+8910,int_stack+7965,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36660,int_stack+34170,int_stack+33630,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+38280,int_stack+36660,int_stack+8910,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98370,int_stack+38280,int_stack+10170,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+62235,int_stack+34845,int_stack+34170,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+62235,int_stack+36660,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7965,int_stack+0,int_stack+38280,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+36660,int_stack+7965,int_stack+98370,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+98370,int_stack+35670,int_stack+34845,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+53085,int_stack+98370,int_stack+62235,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+81585,int_stack+53085,int_stack+0,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+29490,int_stack+81585,int_stack+7965,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+128295,int_stack+68985,int_stack+64260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57510,15);
     Libderiv->ABCD[11] = int_stack + 128295;
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+62235,int_stack+75285,int_stack+87345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57510, 0.0, zero_stack,15);
     Libderiv->ABCD[10] = int_stack + 62235;
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+68850,int_stack+92070,int_stack+3240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57510, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[9] = int_stack + 68850;
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+115695,int_stack+101520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+75465,int_stack+121995,int_stack+12165, 0.0, zero_stack, 1.0, int_stack+57510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[7] = int_stack + 75465;
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+115695,int_stack+42060,int_stack+106245, 1.0, int_stack+57510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[6] = int_stack + 115695;
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6615,int_stack+16890,int_stack+110970,15);
     Libderiv->ABCD[2] = int_stack + 6615;
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13230,int_stack+23190,int_stack+48360,15);
     Libderiv->ABCD[1] = int_stack + 13230;
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+19845,int_stack+29490,int_stack+36660,15);
     Libderiv->ABCD[0] = int_stack + 19845;

}
