/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfip(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|ip) integrals */

void d1hrr_order_gfip(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[5][6][11] = int_stack + 960;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1548;
 Libderiv->deriv_classes[6][6][11] = int_stack + 2304;
 Libderiv->deriv_classes[6][7][11] = int_stack + 3088;
 Libderiv->deriv_classes[7][6][11] = int_stack + 4096;
 Libderiv->deriv_classes[7][7][11] = int_stack + 5104;
 Libderiv->deriv_classes[4][6][10] = int_stack + 6400;
 Libderiv->deriv_classes[4][7][10] = int_stack + 6820;
 Libderiv->deriv_classes[5][6][10] = int_stack + 7360;
 Libderiv->deriv_classes[5][7][10] = int_stack + 7948;
 Libderiv->deriv_classes[6][6][10] = int_stack + 8704;
 Libderiv->deriv_classes[6][7][10] = int_stack + 9488;
 Libderiv->deriv_classes[7][6][10] = int_stack + 10496;
 Libderiv->deriv_classes[7][7][10] = int_stack + 11504;
 Libderiv->deriv_classes[4][6][9] = int_stack + 12800;
 Libderiv->deriv_classes[4][7][9] = int_stack + 13220;
 Libderiv->deriv_classes[5][6][9] = int_stack + 13760;
 Libderiv->deriv_classes[5][7][9] = int_stack + 14348;
 Libderiv->deriv_classes[6][6][9] = int_stack + 15104;
 Libderiv->deriv_classes[6][7][9] = int_stack + 15888;
 Libderiv->deriv_classes[7][6][9] = int_stack + 16896;
 Libderiv->deriv_classes[7][7][9] = int_stack + 17904;
 Libderiv->deriv_classes[4][6][8] = int_stack + 19200;
 Libderiv->deriv_classes[4][7][8] = int_stack + 19620;
 Libderiv->deriv_classes[5][6][8] = int_stack + 20160;
 Libderiv->deriv_classes[5][7][8] = int_stack + 20748;
 Libderiv->deriv_classes[6][6][8] = int_stack + 21504;
 Libderiv->deriv_classes[6][7][8] = int_stack + 22288;
 Libderiv->deriv_classes[7][6][8] = int_stack + 23296;
 Libderiv->deriv_classes[7][7][8] = int_stack + 24304;
 Libderiv->deriv_classes[4][6][7] = int_stack + 25600;
 Libderiv->deriv_classes[4][7][7] = int_stack + 26020;
 Libderiv->deriv_classes[5][6][7] = int_stack + 26560;
 Libderiv->deriv_classes[5][7][7] = int_stack + 27148;
 Libderiv->deriv_classes[6][6][7] = int_stack + 27904;
 Libderiv->deriv_classes[6][7][7] = int_stack + 28688;
 Libderiv->deriv_classes[7][6][7] = int_stack + 29696;
 Libderiv->deriv_classes[7][7][7] = int_stack + 30704;
 Libderiv->deriv_classes[4][6][6] = int_stack + 32000;
 Libderiv->deriv_classes[4][7][6] = int_stack + 32420;
 Libderiv->deriv_classes[5][6][6] = int_stack + 32960;
 Libderiv->deriv_classes[5][7][6] = int_stack + 33548;
 Libderiv->deriv_classes[6][6][6] = int_stack + 34304;
 Libderiv->deriv_classes[6][7][6] = int_stack + 35088;
 Libderiv->dvrr_classes[7][6] = int_stack + 36096;
 Libderiv->deriv_classes[7][6][6] = int_stack + 37104;
 Libderiv->deriv_classes[7][7][6] = int_stack + 38112;
 Libderiv->deriv_classes[4][6][2] = int_stack + 39408;
 Libderiv->deriv_classes[4][7][2] = int_stack + 39828;
 Libderiv->deriv_classes[5][6][2] = int_stack + 40368;
 Libderiv->deriv_classes[5][7][2] = int_stack + 40956;
 Libderiv->deriv_classes[6][6][2] = int_stack + 41712;
 Libderiv->deriv_classes[6][7][2] = int_stack + 42496;
 Libderiv->deriv_classes[7][6][2] = int_stack + 43504;
 Libderiv->deriv_classes[7][7][2] = int_stack + 44512;
 Libderiv->deriv_classes[4][6][1] = int_stack + 45808;
 Libderiv->deriv_classes[4][7][1] = int_stack + 46228;
 Libderiv->deriv_classes[5][6][1] = int_stack + 46768;
 Libderiv->deriv_classes[5][7][1] = int_stack + 47356;
 Libderiv->deriv_classes[6][6][1] = int_stack + 48112;
 Libderiv->deriv_classes[6][7][1] = int_stack + 48896;
 Libderiv->deriv_classes[7][6][1] = int_stack + 49904;
 Libderiv->deriv_classes[7][7][1] = int_stack + 50912;
 Libderiv->dvrr_classes[4][6] = int_stack + 52208;
 Libderiv->dvrr_classes[4][7] = int_stack + 52628;
 Libderiv->deriv_classes[4][6][0] = int_stack + 53168;
 Libderiv->deriv_classes[4][7][0] = int_stack + 53588;
 Libderiv->dvrr_classes[5][6] = int_stack + 54128;
 Libderiv->dvrr_classes[5][7] = int_stack + 54716;
 Libderiv->deriv_classes[5][6][0] = int_stack + 55472;
 Libderiv->deriv_classes[5][7][0] = int_stack + 56060;
 Libderiv->dvrr_classes[6][6] = int_stack + 56816;
 Libderiv->dvrr_classes[6][7] = int_stack + 57600;
 Libderiv->deriv_classes[6][6][0] = int_stack + 58608;
 Libderiv->deriv_classes[6][7][0] = int_stack + 59392;
 Libderiv->deriv_classes[7][6][0] = int_stack + 60400;
 Libderiv->deriv_classes[7][7][0] = int_stack + 61408;
 memset(int_stack,0,501632);

 Libderiv->dvrr_stack = int_stack + 210208;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfip(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52208,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+63964,int_stack+1548,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54128,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+65728,int_stack+63964,int_stack+62704,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+69508,int_stack+3088,int_stack+2304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56816,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+71860,int_stack+69508,int_stack+63964,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+77152,int_stack+71860,int_stack+65728,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+5104,int_stack+4096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36096,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+84712,int_stack+62704,int_stack+69508,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+91768,int_stack+84712,int_stack+71860,84);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+6820,int_stack+6400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52208, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+85972,int_stack+7948,int_stack+7360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54128, 0.0, zero_stack,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+87736,int_stack+85972,int_stack+84712,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+9488,int_stack+8704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56816, 0.0, zero_stack,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+85972,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+65056,int_stack+87736,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+11504,int_stack+10496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36096, 0.0, zero_stack,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+102352,int_stack+84712,int_stack+62704,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+109408,int_stack+102352,int_stack+65056,84);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+13220,int_stack+12800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52208, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+103612,int_stack+14348,int_stack+13760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54128, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+105376,int_stack+103612,int_stack+102352,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+15888,int_stack+15104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56816, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+103612,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+7560,int_stack+65056,int_stack+105376,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+17904,int_stack+16896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36096, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+84712,int_stack+102352,int_stack+62704,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+119992,int_stack+84712,int_stack+65056,84);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+19620,int_stack+19200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+85972,int_stack+20748,int_stack+20160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+87736,int_stack+85972,int_stack+84712,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+22288,int_stack+21504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+85972,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+15120,int_stack+65056,int_stack+87736,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+24304,int_stack+23296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+102352,int_stack+84712,int_stack+62704,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+130576,int_stack+102352,int_stack+65056,84);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+26020,int_stack+25600, 0.0, zero_stack, 1.0, int_stack+52208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+103612,int_stack+27148,int_stack+26560, 0.0, zero_stack, 1.0, int_stack+54128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+105376,int_stack+103612,int_stack+102352,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+28688,int_stack+27904, 0.0, zero_stack, 1.0, int_stack+56816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+103612,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+141160,int_stack+65056,int_stack+105376,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+30704,int_stack+29696, 0.0, zero_stack, 1.0, int_stack+36096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+84712,int_stack+102352,int_stack+62704,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+148720,int_stack+84712,int_stack+65056,84);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+32420,int_stack+32000, 1.0, int_stack+52208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+85972,int_stack+33548,int_stack+32960, 1.0, int_stack+54128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+87736,int_stack+85972,int_stack+84712,84);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+35088,int_stack+34304, 1.0, int_stack+56816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+85972,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+22680,int_stack+65056,int_stack+87736,84);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+38112,int_stack+37104, 1.0, int_stack+36096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ip) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+102352,int_stack+84712,int_stack+62704,84);
 /*--- compute (hd|ip) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+159304,int_stack+102352,int_stack+65056,84);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+52628,int_stack+52208,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+103612,int_stack+54716,int_stack+54128,21);
 /*--- compute (gp|ip) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+105376,int_stack+103612,int_stack+102352,84);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+62704,int_stack+57600,int_stack+56816,28);
 /*--- compute (hp|ip) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+65056,int_stack+62704,int_stack+103612,84);
 /*--- compute (gd|ip) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+30240,int_stack+65056,int_stack+105376,84);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56816,int_stack+39828,int_stack+39408,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+70348,int_stack+40956,int_stack+40368,21);
 /*--- compute (gp|ip) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+72112,int_stack+70348,int_stack+56816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+42496,int_stack+41712,28);
 /*--- compute (hp|ip) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+37800,int_stack+84712,int_stack+70348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (gd|ip) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+169888,int_stack+37800,int_stack+72112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+70348,int_stack+44512,int_stack+43504,36);
 /*--- compute (ip|ip) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+177448,int_stack+70348,int_stack+84712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (hd|ip) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+184504,int_stack+177448,int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37800,int_stack+46228,int_stack+45808,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+39060,int_stack+47356,int_stack+46768,21);
 /*--- compute (gp|ip) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+40824,int_stack+39060,int_stack+37800, 0.0, zero_stack, 1.0, int_stack+102352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+44604,int_stack+48896,int_stack+48112,28);
 /*--- compute (hp|ip) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+177448,int_stack+44604,int_stack+39060, 0.0, zero_stack, 1.0, int_stack+103612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (gd|ip) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+195088,int_stack+177448,int_stack+40824, 0.0, zero_stack, 1.0, int_stack+105376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37800,int_stack+50912,int_stack+49904,36);
 /*--- compute (ip|ip) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+84712,int_stack+37800,int_stack+44604, 0.0, zero_stack, 1.0, int_stack+62704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (hd|ip) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+37800,int_stack+84712,int_stack+177448, 0.0, zero_stack, 1.0, int_stack+65056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+177448,int_stack+53588,int_stack+53168,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+178708,int_stack+56060,int_stack+55472,21);
 /*--- compute (gp|ip) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+180472,int_stack+178708,int_stack+177448, 1.0, int_stack+102352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+84712,int_stack+59392,int_stack+58608,28);
 /*--- compute (hp|ip) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+48384,int_stack+84712,int_stack+178708, 1.0, int_stack+103612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (gd|ip) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+202648,int_stack+48384,int_stack+180472, 1.0, int_stack+105376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+102352,int_stack+61408,int_stack+60400,36);
 /*--- compute (ip|ip) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+177448,int_stack+102352,int_stack+84712, 1.0, int_stack+62704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (hd|ip) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+53676,int_stack+177448,int_stack+48384, 1.0, int_stack+65056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+64260,int_stack+91768,int_stack+77152,84);
     Libderiv->ABCD[11] = int_stack + 64260;
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+76860,int_stack+109408,int_stack+0,84);
     Libderiv->ABCD[10] = int_stack + 76860;
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+89460,int_stack+119992,int_stack+7560,84);
     Libderiv->ABCD[9] = int_stack + 89460;
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+0,int_stack+130576,int_stack+15120,84);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+102060,int_stack+148720,int_stack+141160,84);
     Libderiv->ABCD[7] = int_stack + 102060;
 /*--- compute (gf|ip) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+114660,int_stack+159304,int_stack+22680,84);
     Libderiv->ABCD[6] = int_stack + 114660;
 /*--- compute (gf|ip) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+12600,int_stack+184504,int_stack+169888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
     Libderiv->ABCD[2] = int_stack + 12600;
 /*--- compute (gf|ip) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+127260,int_stack+37800,int_stack+195088, 0.0, zero_stack, 1.0, int_stack+30240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
     Libderiv->ABCD[1] = int_stack + 127260;
 /*--- compute (gf|ip) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+37800,int_stack+53676,int_stack+202648, 1.0, int_stack+30240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,84);
     Libderiv->ABCD[0] = int_stack + 37800;

}
