/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ggig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|ig) integrals */

void d1hrr_order_ggig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[5][6][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4038;
 Libderiv->deriv_classes[5][8][11] = int_stack + 4794;
 Libderiv->deriv_classes[5][9][11] = int_stack + 5739;
 Libderiv->deriv_classes[5][10][11] = int_stack + 6894;
 Libderiv->deriv_classes[6][6][11] = int_stack + 8280;
 Libderiv->deriv_classes[6][7][11] = int_stack + 9064;
 Libderiv->deriv_classes[6][8][11] = int_stack + 10072;
 Libderiv->deriv_classes[6][9][11] = int_stack + 11332;
 Libderiv->deriv_classes[6][10][11] = int_stack + 12872;
 Libderiv->deriv_classes[7][6][11] = int_stack + 14720;
 Libderiv->deriv_classes[7][7][11] = int_stack + 15728;
 Libderiv->deriv_classes[7][8][11] = int_stack + 17024;
 Libderiv->deriv_classes[7][9][11] = int_stack + 18644;
 Libderiv->deriv_classes[7][10][11] = int_stack + 20624;
 Libderiv->deriv_classes[8][6][11] = int_stack + 23000;
 Libderiv->deriv_classes[8][7][11] = int_stack + 24260;
 Libderiv->deriv_classes[8][8][11] = int_stack + 25880;
 Libderiv->deriv_classes[8][9][11] = int_stack + 27905;
 Libderiv->deriv_classes[8][10][11] = int_stack + 30380;
 Libderiv->deriv_classes[4][6][10] = int_stack + 33350;
 Libderiv->deriv_classes[4][7][10] = int_stack + 33770;
 Libderiv->deriv_classes[4][8][10] = int_stack + 34310;
 Libderiv->deriv_classes[4][9][10] = int_stack + 34985;
 Libderiv->deriv_classes[4][10][10] = int_stack + 35810;
 Libderiv->deriv_classes[5][6][10] = int_stack + 36800;
 Libderiv->deriv_classes[5][7][10] = int_stack + 37388;
 Libderiv->deriv_classes[5][8][10] = int_stack + 38144;
 Libderiv->deriv_classes[5][9][10] = int_stack + 39089;
 Libderiv->deriv_classes[5][10][10] = int_stack + 40244;
 Libderiv->deriv_classes[6][6][10] = int_stack + 41630;
 Libderiv->deriv_classes[6][7][10] = int_stack + 42414;
 Libderiv->deriv_classes[6][8][10] = int_stack + 43422;
 Libderiv->deriv_classes[6][9][10] = int_stack + 44682;
 Libderiv->deriv_classes[6][10][10] = int_stack + 46222;
 Libderiv->deriv_classes[7][6][10] = int_stack + 48070;
 Libderiv->deriv_classes[7][7][10] = int_stack + 49078;
 Libderiv->deriv_classes[7][8][10] = int_stack + 50374;
 Libderiv->deriv_classes[7][9][10] = int_stack + 51994;
 Libderiv->deriv_classes[7][10][10] = int_stack + 53974;
 Libderiv->deriv_classes[8][6][10] = int_stack + 56350;
 Libderiv->deriv_classes[8][7][10] = int_stack + 57610;
 Libderiv->deriv_classes[8][8][10] = int_stack + 59230;
 Libderiv->deriv_classes[8][9][10] = int_stack + 61255;
 Libderiv->deriv_classes[8][10][10] = int_stack + 63730;
 Libderiv->deriv_classes[4][6][9] = int_stack + 66700;
 Libderiv->deriv_classes[4][7][9] = int_stack + 67120;
 Libderiv->deriv_classes[4][8][9] = int_stack + 67660;
 Libderiv->deriv_classes[4][9][9] = int_stack + 68335;
 Libderiv->deriv_classes[4][10][9] = int_stack + 69160;
 Libderiv->deriv_classes[5][6][9] = int_stack + 70150;
 Libderiv->deriv_classes[5][7][9] = int_stack + 70738;
 Libderiv->deriv_classes[5][8][9] = int_stack + 71494;
 Libderiv->deriv_classes[5][9][9] = int_stack + 72439;
 Libderiv->deriv_classes[5][10][9] = int_stack + 73594;
 Libderiv->deriv_classes[6][6][9] = int_stack + 74980;
 Libderiv->deriv_classes[6][7][9] = int_stack + 75764;
 Libderiv->deriv_classes[6][8][9] = int_stack + 76772;
 Libderiv->deriv_classes[6][9][9] = int_stack + 78032;
 Libderiv->deriv_classes[6][10][9] = int_stack + 79572;
 Libderiv->deriv_classes[7][6][9] = int_stack + 81420;
 Libderiv->deriv_classes[7][7][9] = int_stack + 82428;
 Libderiv->deriv_classes[7][8][9] = int_stack + 83724;
 Libderiv->deriv_classes[7][9][9] = int_stack + 85344;
 Libderiv->deriv_classes[7][10][9] = int_stack + 87324;
 Libderiv->deriv_classes[8][6][9] = int_stack + 89700;
 Libderiv->deriv_classes[8][7][9] = int_stack + 90960;
 Libderiv->deriv_classes[8][8][9] = int_stack + 92580;
 Libderiv->deriv_classes[8][9][9] = int_stack + 94605;
 Libderiv->deriv_classes[8][10][9] = int_stack + 97080;
 Libderiv->deriv_classes[4][6][8] = int_stack + 100050;
 Libderiv->deriv_classes[4][7][8] = int_stack + 100470;
 Libderiv->deriv_classes[4][8][8] = int_stack + 101010;
 Libderiv->deriv_classes[4][9][8] = int_stack + 101685;
 Libderiv->deriv_classes[4][10][8] = int_stack + 102510;
 Libderiv->deriv_classes[5][6][8] = int_stack + 103500;
 Libderiv->deriv_classes[5][7][8] = int_stack + 104088;
 Libderiv->deriv_classes[5][8][8] = int_stack + 104844;
 Libderiv->deriv_classes[5][9][8] = int_stack + 105789;
 Libderiv->deriv_classes[5][10][8] = int_stack + 106944;
 Libderiv->deriv_classes[6][6][8] = int_stack + 108330;
 Libderiv->deriv_classes[6][7][8] = int_stack + 109114;
 Libderiv->deriv_classes[6][8][8] = int_stack + 110122;
 Libderiv->deriv_classes[6][9][8] = int_stack + 111382;
 Libderiv->deriv_classes[6][10][8] = int_stack + 112922;
 Libderiv->deriv_classes[7][6][8] = int_stack + 114770;
 Libderiv->deriv_classes[7][7][8] = int_stack + 115778;
 Libderiv->deriv_classes[7][8][8] = int_stack + 117074;
 Libderiv->deriv_classes[7][9][8] = int_stack + 118694;
 Libderiv->deriv_classes[7][10][8] = int_stack + 120674;
 Libderiv->deriv_classes[8][6][8] = int_stack + 123050;
 Libderiv->deriv_classes[8][7][8] = int_stack + 124310;
 Libderiv->deriv_classes[8][8][8] = int_stack + 125930;
 Libderiv->deriv_classes[8][9][8] = int_stack + 127955;
 Libderiv->deriv_classes[8][10][8] = int_stack + 130430;
 Libderiv->deriv_classes[4][6][7] = int_stack + 133400;
 Libderiv->deriv_classes[4][7][7] = int_stack + 133820;
 Libderiv->deriv_classes[4][8][7] = int_stack + 134360;
 Libderiv->deriv_classes[4][9][7] = int_stack + 135035;
 Libderiv->deriv_classes[4][10][7] = int_stack + 135860;
 Libderiv->deriv_classes[5][6][7] = int_stack + 136850;
 Libderiv->deriv_classes[5][7][7] = int_stack + 137438;
 Libderiv->deriv_classes[5][8][7] = int_stack + 138194;
 Libderiv->deriv_classes[5][9][7] = int_stack + 139139;
 Libderiv->deriv_classes[5][10][7] = int_stack + 140294;
 Libderiv->deriv_classes[6][6][7] = int_stack + 141680;
 Libderiv->deriv_classes[6][7][7] = int_stack + 142464;
 Libderiv->deriv_classes[6][8][7] = int_stack + 143472;
 Libderiv->deriv_classes[6][9][7] = int_stack + 144732;
 Libderiv->deriv_classes[6][10][7] = int_stack + 146272;
 Libderiv->deriv_classes[7][6][7] = int_stack + 148120;
 Libderiv->deriv_classes[7][7][7] = int_stack + 149128;
 Libderiv->deriv_classes[7][8][7] = int_stack + 150424;
 Libderiv->deriv_classes[7][9][7] = int_stack + 152044;
 Libderiv->deriv_classes[7][10][7] = int_stack + 154024;
 Libderiv->deriv_classes[8][6][7] = int_stack + 156400;
 Libderiv->deriv_classes[8][7][7] = int_stack + 157660;
 Libderiv->deriv_classes[8][8][7] = int_stack + 159280;
 Libderiv->deriv_classes[8][9][7] = int_stack + 161305;
 Libderiv->deriv_classes[8][10][7] = int_stack + 163780;
 Libderiv->deriv_classes[4][6][6] = int_stack + 166750;
 Libderiv->deriv_classes[4][7][6] = int_stack + 167170;
 Libderiv->deriv_classes[4][8][6] = int_stack + 167710;
 Libderiv->deriv_classes[4][9][6] = int_stack + 168385;
 Libderiv->deriv_classes[4][10][6] = int_stack + 169210;
 Libderiv->deriv_classes[5][6][6] = int_stack + 170200;
 Libderiv->deriv_classes[5][7][6] = int_stack + 170788;
 Libderiv->deriv_classes[5][8][6] = int_stack + 171544;
 Libderiv->deriv_classes[5][9][6] = int_stack + 172489;
 Libderiv->deriv_classes[5][10][6] = int_stack + 173644;
 Libderiv->deriv_classes[6][6][6] = int_stack + 175030;
 Libderiv->deriv_classes[6][7][6] = int_stack + 175814;
 Libderiv->deriv_classes[6][8][6] = int_stack + 176822;
 Libderiv->deriv_classes[6][9][6] = int_stack + 178082;
 Libderiv->deriv_classes[6][10][6] = int_stack + 179622;
 Libderiv->deriv_classes[7][6][6] = int_stack + 181470;
 Libderiv->deriv_classes[7][7][6] = int_stack + 182478;
 Libderiv->deriv_classes[7][8][6] = int_stack + 183774;
 Libderiv->deriv_classes[7][9][6] = int_stack + 185394;
 Libderiv->deriv_classes[7][10][6] = int_stack + 187374;
 Libderiv->dvrr_classes[8][6] = int_stack + 189750;
 Libderiv->deriv_classes[8][6][6] = int_stack + 191010;
 Libderiv->dvrr_classes[8][7] = int_stack + 192270;
 Libderiv->deriv_classes[8][7][6] = int_stack + 193890;
 Libderiv->dvrr_classes[8][8] = int_stack + 195510;
 Libderiv->deriv_classes[8][8][6] = int_stack + 197535;
 Libderiv->dvrr_classes[8][9] = int_stack + 199560;
 Libderiv->deriv_classes[8][9][6] = int_stack + 202035;
 Libderiv->deriv_classes[8][10][6] = int_stack + 204510;
 Libderiv->deriv_classes[4][6][2] = int_stack + 207480;
 Libderiv->deriv_classes[4][7][2] = int_stack + 207900;
 Libderiv->deriv_classes[4][8][2] = int_stack + 208440;
 Libderiv->deriv_classes[4][9][2] = int_stack + 209115;
 Libderiv->deriv_classes[4][10][2] = int_stack + 209940;
 Libderiv->deriv_classes[5][6][2] = int_stack + 210930;
 Libderiv->deriv_classes[5][7][2] = int_stack + 211518;
 Libderiv->deriv_classes[5][8][2] = int_stack + 212274;
 Libderiv->deriv_classes[5][9][2] = int_stack + 213219;
 Libderiv->deriv_classes[5][10][2] = int_stack + 214374;
 Libderiv->deriv_classes[6][6][2] = int_stack + 215760;
 Libderiv->deriv_classes[6][7][2] = int_stack + 216544;
 Libderiv->deriv_classes[6][8][2] = int_stack + 217552;
 Libderiv->deriv_classes[6][9][2] = int_stack + 218812;
 Libderiv->deriv_classes[6][10][2] = int_stack + 220352;
 Libderiv->deriv_classes[7][6][2] = int_stack + 222200;
 Libderiv->deriv_classes[7][7][2] = int_stack + 223208;
 Libderiv->deriv_classes[7][8][2] = int_stack + 224504;
 Libderiv->deriv_classes[7][9][2] = int_stack + 226124;
 Libderiv->deriv_classes[7][10][2] = int_stack + 228104;
 Libderiv->deriv_classes[8][6][2] = int_stack + 230480;
 Libderiv->deriv_classes[8][7][2] = int_stack + 231740;
 Libderiv->deriv_classes[8][8][2] = int_stack + 233360;
 Libderiv->deriv_classes[8][9][2] = int_stack + 235385;
 Libderiv->deriv_classes[8][10][2] = int_stack + 237860;
 Libderiv->deriv_classes[4][6][1] = int_stack + 240830;
 Libderiv->deriv_classes[4][7][1] = int_stack + 241250;
 Libderiv->deriv_classes[4][8][1] = int_stack + 241790;
 Libderiv->deriv_classes[4][9][1] = int_stack + 242465;
 Libderiv->deriv_classes[4][10][1] = int_stack + 243290;
 Libderiv->deriv_classes[5][6][1] = int_stack + 244280;
 Libderiv->deriv_classes[5][7][1] = int_stack + 244868;
 Libderiv->deriv_classes[5][8][1] = int_stack + 245624;
 Libderiv->deriv_classes[5][9][1] = int_stack + 246569;
 Libderiv->deriv_classes[5][10][1] = int_stack + 247724;
 Libderiv->deriv_classes[6][6][1] = int_stack + 249110;
 Libderiv->deriv_classes[6][7][1] = int_stack + 249894;
 Libderiv->deriv_classes[6][8][1] = int_stack + 250902;
 Libderiv->deriv_classes[6][9][1] = int_stack + 252162;
 Libderiv->deriv_classes[6][10][1] = int_stack + 253702;
 Libderiv->deriv_classes[7][6][1] = int_stack + 255550;
 Libderiv->deriv_classes[7][7][1] = int_stack + 256558;
 Libderiv->deriv_classes[7][8][1] = int_stack + 257854;
 Libderiv->deriv_classes[7][9][1] = int_stack + 259474;
 Libderiv->deriv_classes[7][10][1] = int_stack + 261454;
 Libderiv->deriv_classes[8][6][1] = int_stack + 263830;
 Libderiv->deriv_classes[8][7][1] = int_stack + 265090;
 Libderiv->deriv_classes[8][8][1] = int_stack + 266710;
 Libderiv->deriv_classes[8][9][1] = int_stack + 268735;
 Libderiv->deriv_classes[8][10][1] = int_stack + 271210;
 Libderiv->dvrr_classes[4][6] = int_stack + 274180;
 Libderiv->dvrr_classes[4][7] = int_stack + 274600;
 Libderiv->dvrr_classes[4][8] = int_stack + 275140;
 Libderiv->dvrr_classes[4][9] = int_stack + 275815;
 Libderiv->dvrr_classes[4][10] = int_stack + 276640;
 Libderiv->deriv_classes[4][6][0] = int_stack + 277630;
 Libderiv->deriv_classes[4][7][0] = int_stack + 278050;
 Libderiv->deriv_classes[4][8][0] = int_stack + 278590;
 Libderiv->deriv_classes[4][9][0] = int_stack + 279265;
 Libderiv->deriv_classes[4][10][0] = int_stack + 280090;
 Libderiv->dvrr_classes[5][6] = int_stack + 281080;
 Libderiv->dvrr_classes[5][7] = int_stack + 281668;
 Libderiv->dvrr_classes[5][8] = int_stack + 282424;
 Libderiv->dvrr_classes[5][9] = int_stack + 283369;
 Libderiv->dvrr_classes[5][10] = int_stack + 284524;
 Libderiv->deriv_classes[5][6][0] = int_stack + 285910;
 Libderiv->deriv_classes[5][7][0] = int_stack + 286498;
 Libderiv->deriv_classes[5][8][0] = int_stack + 287254;
 Libderiv->deriv_classes[5][9][0] = int_stack + 288199;
 Libderiv->deriv_classes[5][10][0] = int_stack + 289354;
 Libderiv->dvrr_classes[6][6] = int_stack + 290740;
 Libderiv->dvrr_classes[6][7] = int_stack + 291524;
 Libderiv->dvrr_classes[6][8] = int_stack + 292532;
 Libderiv->dvrr_classes[6][9] = int_stack + 293792;
 Libderiv->dvrr_classes[6][10] = int_stack + 295332;
 Libderiv->deriv_classes[6][6][0] = int_stack + 297180;
 Libderiv->deriv_classes[6][7][0] = int_stack + 297964;
 Libderiv->deriv_classes[6][8][0] = int_stack + 298972;
 Libderiv->deriv_classes[6][9][0] = int_stack + 300232;
 Libderiv->deriv_classes[6][10][0] = int_stack + 301772;
 Libderiv->dvrr_classes[7][6] = int_stack + 303620;
 Libderiv->dvrr_classes[7][7] = int_stack + 304628;
 Libderiv->dvrr_classes[7][8] = int_stack + 305924;
 Libderiv->dvrr_classes[7][9] = int_stack + 307544;
 Libderiv->dvrr_classes[7][10] = int_stack + 309524;
 Libderiv->deriv_classes[7][6][0] = int_stack + 311900;
 Libderiv->deriv_classes[7][7][0] = int_stack + 312908;
 Libderiv->deriv_classes[7][8][0] = int_stack + 314204;
 Libderiv->deriv_classes[7][9][0] = int_stack + 315824;
 Libderiv->deriv_classes[7][10][0] = int_stack + 317804;
 Libderiv->deriv_classes[8][6][0] = int_stack + 320180;
 Libderiv->deriv_classes[8][7][0] = int_stack + 321440;
 Libderiv->deriv_classes[8][8][0] = int_stack + 323060;
 Libderiv->deriv_classes[8][9][0] = int_stack + 325085;
 Libderiv->deriv_classes[8][10][0] = int_stack + 327560;
 memset(int_stack,0,2644240);

 Libderiv->dvrr_stack = int_stack + 1907995;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ggig(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+330530,int_stack+274600,int_stack+274180,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+331790,int_stack+275140,int_stack+274600,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+333410,int_stack+331790,int_stack+330530,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+335930,int_stack+275815,int_stack+275140,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+337955,int_stack+335930,int_stack+331790,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+341195,int_stack+337955,int_stack+333410,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+345395,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274180,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+346655,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274600,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+348275,int_stack+346655,int_stack+345395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330530,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+350795,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275140,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+352820,int_stack+350795,int_stack+346655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331790,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+356060,int_stack+352820,int_stack+348275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333410,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+345395,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275815,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+360260,int_stack+345395,int_stack+350795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335930,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+345395,int_stack+360260,int_stack+352820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337955,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+360260,int_stack+345395,int_stack+356060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341195,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+345395,int_stack+281668,int_stack+281080,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+347159,int_stack+282424,int_stack+281668,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+349427,int_stack+347159,int_stack+345395,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+352955,int_stack+283369,int_stack+282424,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+366560,int_stack+352955,int_stack+347159,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+371096,int_stack+366560,int_stack+349427,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+355790,int_stack+4038,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281080,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+357554,int_stack+4794,int_stack+4038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281668,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+357554,int_stack+355790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345395,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+376976,int_stack+5739,int_stack+4794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282424,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+379811,int_stack+376976,int_stack+357554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347159,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+384347,int_stack+379811,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349427,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+6894,int_stack+5739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283369,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+390227,int_stack+0,int_stack+376976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352955,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+390227,int_stack+379811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366560,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+390227,int_stack+0,int_stack+384347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371096,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+399047,int_stack+390227,int_stack+360260,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+291524,int_stack+290740,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+292532,int_stack+291524,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+376976,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+381680,int_stack+293792,int_stack+292532,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+355790,int_stack+381680,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+417947,int_stack+355790,int_stack+376976,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+9064,int_stack+8280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290740,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+385460,int_stack+10072,int_stack+9064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291524,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+361838,int_stack+385460,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5376,int_stack+11332,int_stack+10072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292532,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+425787,int_stack+5376,int_stack+385460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+431835,int_stack+425787,int_stack+361838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376976,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+361838,int_stack+12872,int_stack+11332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293792,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+439675,int_stack+361838,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381680,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+447235,int_stack+439675,int_stack+425787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355790,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+457315,int_stack+447235,int_stack+431835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417947,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+425787,int_stack+457315,int_stack+390227,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+469075,int_stack+425787,int_stack+399047,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+452247,int_stack+304628,int_stack+303620,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5376,int_stack+305924,int_stack+304628,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+385460,int_stack+5376,int_stack+452247,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9264,int_stack+307544,int_stack+305924,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+391508,int_stack+9264,int_stack+5376,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+399284,int_stack+391508,int_stack+385460,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+361838,int_stack+15728,int_stack+14720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303620,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+409364,int_stack+17024,int_stack+15728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304628,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+506875,int_stack+409364,int_stack+361838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452247,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+512923,int_stack+18644,int_stack+17024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305924,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+517783,int_stack+512923,int_stack+409364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+525559,int_stack+517783,int_stack+506875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385460,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+506875,int_stack+20624,int_stack+18644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307544,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+535639,int_stack+506875,int_stack+512923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+545359,int_stack+535639,int_stack+517783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391508,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+506875,int_stack+545359,int_stack+525559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399284,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+521995,int_stack+506875,int_stack+457315,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+557275,int_stack+521995,int_stack+425787,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+610195,int_stack+557275,int_stack+469075,420);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+425787,int_stack+192270,int_stack+189750,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+429567,int_stack+195510,int_stack+192270,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+434427,int_stack+429567,int_stack+425787,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+441987,int_stack+199560,int_stack+195510,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+455271,int_stack+441987,int_stack+429567,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+464991,int_stack+455271,int_stack+434427,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+448062,int_stack+24260,int_stack+23000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189750,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+409364,int_stack+25880,int_stack+24260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192270,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477591,int_stack+409364,int_stack+448062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425787,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+485151,int_stack+27905,int_stack+25880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195510,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+491226,int_stack+485151,int_stack+409364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429567,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14124,int_stack+491226,int_stack+477591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434427,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+477591,int_stack+30380,int_stack+27905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199560,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+673195,int_stack+477591,int_stack+485151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441987,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+685345,int_stack+673195,int_stack+491226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455271,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+477591,int_stack+685345,int_stack+14124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464991,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+673195,int_stack+477591,int_stack+506875,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+718555,int_stack+673195,int_stack+521995,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+789115,int_stack+718555,int_stack+557275,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+673195,int_stack+33770,int_stack+33350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274180, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+674455,int_stack+34310,int_stack+33770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274600, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+676075,int_stack+674455,int_stack+673195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+678595,int_stack+34985,int_stack+34310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275140, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+680620,int_stack+678595,int_stack+674455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331790, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+683860,int_stack+680620,int_stack+676075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333410, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+673195,int_stack+35810,int_stack+34985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275815, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+688060,int_stack+673195,int_stack+678595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335930, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+673195,int_stack+688060,int_stack+680620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337955, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+688060,int_stack+673195,int_stack+683860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341195, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+673195,int_stack+37388,int_stack+36800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281080, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+674959,int_stack+38144,int_stack+37388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281668, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+677227,int_stack+674959,int_stack+673195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345395, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+680755,int_stack+39089,int_stack+38144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282424, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+694360,int_stack+680755,int_stack+674959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347159, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+698896,int_stack+694360,int_stack+677227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349427, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+673195,int_stack+40244,int_stack+39089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283369, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+704776,int_stack+673195,int_stack+680755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352955, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+673195,int_stack+704776,int_stack+694360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366560, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+704776,int_stack+673195,int_stack+698896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371096, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+713596,int_stack+704776,int_stack+688060,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+673195,int_stack+42414,int_stack+41630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290740, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+675547,int_stack+43422,int_stack+42414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291524, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+678571,int_stack+675547,int_stack+673195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+683275,int_stack+44682,int_stack+43422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292532, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+687055,int_stack+683275,int_stack+675547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+693103,int_stack+687055,int_stack+678571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376976, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+673195,int_stack+46222,int_stack+44682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293792, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+732496,int_stack+673195,int_stack+683275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381680, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+673195,int_stack+732496,int_stack+687055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355790, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+732496,int_stack+673195,int_stack+693103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417947, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+673195,int_stack+732496,int_stack+704776,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+744256,int_stack+673195,int_stack+713596,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+699655,int_stack+49078,int_stack+48070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303620, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+702679,int_stack+50374,int_stack+49078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304628, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+706567,int_stack+702679,int_stack+699655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452247, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+712615,int_stack+51994,int_stack+50374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305924, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+717475,int_stack+712615,int_stack+702679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477591,int_stack+717475,int_stack+706567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385460, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+699655,int_stack+53974,int_stack+51994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307544, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+487671,int_stack+699655,int_stack+712615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+699655,int_stack+487671,int_stack+717475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391508, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+487671,int_stack+699655,int_stack+477591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399284, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+502791,int_stack+487671,int_stack+732496,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+538071,int_stack+502791,int_stack+673195,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+673195,int_stack+538071,int_stack+744256,420);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+736195,int_stack+57610,int_stack+56350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189750, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+739975,int_stack+59230,int_stack+57610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192270, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+744835,int_stack+739975,int_stack+736195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425787, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+752395,int_stack+61255,int_stack+59230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195510, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+758470,int_stack+752395,int_stack+739975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429567, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+768190,int_stack+758470,int_stack+744835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434427, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+736195,int_stack+63730,int_stack+61255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199560, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+590991,int_stack+736195,int_stack+752395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441987, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+590991,int_stack+758470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455271, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+590991,int_stack+736195,int_stack+768190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464991, 0.0, zero_stack,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+736195,int_stack+590991,int_stack+487671,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+877315,int_stack+736195,int_stack+502791,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+947875,int_stack+877315,int_stack+538071,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+67120,int_stack+66700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274180, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+878575,int_stack+67660,int_stack+67120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274600, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+880195,int_stack+878575,int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+882715,int_stack+68335,int_stack+67660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275140, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+884740,int_stack+882715,int_stack+878575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331790, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+887980,int_stack+884740,int_stack+880195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333410, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+877315,int_stack+69160,int_stack+68335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275815, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+892180,int_stack+877315,int_stack+882715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335930, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+877315,int_stack+892180,int_stack+884740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337955, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+892180,int_stack+877315,int_stack+887980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+70738,int_stack+70150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281080, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+879079,int_stack+71494,int_stack+70738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281668, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+881347,int_stack+879079,int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345395, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+884875,int_stack+72439,int_stack+71494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282424, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+898480,int_stack+884875,int_stack+879079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347159, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+903016,int_stack+898480,int_stack+881347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349427, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+877315,int_stack+73594,int_stack+72439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283369, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+908896,int_stack+877315,int_stack+884875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352955, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+877315,int_stack+908896,int_stack+898480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366560, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+908896,int_stack+877315,int_stack+903016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371096, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+917716,int_stack+908896,int_stack+892180,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+75764,int_stack+74980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290740, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+879667,int_stack+76772,int_stack+75764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291524, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+882691,int_stack+879667,int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+887395,int_stack+78032,int_stack+76772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292532, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+891175,int_stack+887395,int_stack+879667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+897223,int_stack+891175,int_stack+882691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376976, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+877315,int_stack+79572,int_stack+78032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293792, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+936616,int_stack+877315,int_stack+887395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381680, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+877315,int_stack+936616,int_stack+891175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355790, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+736195,int_stack+877315,int_stack+897223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417947, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+877315,int_stack+736195,int_stack+908896,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+747955,int_stack+877315,int_stack+917716,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+903775,int_stack+82428,int_stack+81420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303620, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+906799,int_stack+83724,int_stack+82428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304628, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+910687,int_stack+906799,int_stack+903775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452247, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+916735,int_stack+85344,int_stack+83724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305924, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+921595,int_stack+916735,int_stack+906799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+929371,int_stack+921595,int_stack+910687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385460, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+903775,int_stack+87324,int_stack+85344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307544, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+477591,int_stack+903775,int_stack+916735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+903775,int_stack+477591,int_stack+921595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391508, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+477591,int_stack+903775,int_stack+929371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399284, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+903775,int_stack+477591,int_stack+736195,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+492711,int_stack+903775,int_stack+877315,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+545631,int_stack+492711,int_stack+747955,420);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+90960,int_stack+89700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189750, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+881095,int_stack+92580,int_stack+90960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192270, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+885955,int_stack+881095,int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425787, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+893515,int_stack+94605,int_stack+92580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195510, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+736195,int_stack+893515,int_stack+881095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429567, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745915,int_stack+736195,int_stack+885955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434427, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+877315,int_stack+97080,int_stack+94605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199560, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+758515,int_stack+877315,int_stack+893515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441987, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+877315,int_stack+758515,int_stack+736195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455271, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+758515,int_stack+877315,int_stack+745915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464991, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+14124,int_stack+758515,int_stack+477591,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1036075,int_stack+14124,int_stack+903775,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1106635,int_stack+1036075,int_stack+492711,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1036075,int_stack+100470,int_stack+100050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1037335,int_stack+101010,int_stack+100470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1038955,int_stack+1037335,int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1041475,int_stack+101685,int_stack+101010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1043500,int_stack+1041475,int_stack+1037335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1046740,int_stack+1043500,int_stack+1038955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1036075,int_stack+102510,int_stack+101685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1050940,int_stack+1036075,int_stack+1041475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1036075,int_stack+1050940,int_stack+1043500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1050940,int_stack+1036075,int_stack+1046740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1036075,int_stack+104088,int_stack+103500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1037839,int_stack+104844,int_stack+104088, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1040107,int_stack+1037839,int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1043635,int_stack+105789,int_stack+104844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1057240,int_stack+1043635,int_stack+1037839, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1061776,int_stack+1057240,int_stack+1040107, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1036075,int_stack+106944,int_stack+105789, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1067656,int_stack+1036075,int_stack+1043635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1036075,int_stack+1067656,int_stack+1057240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1067656,int_stack+1036075,int_stack+1061776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1076476,int_stack+1067656,int_stack+1050940,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1036075,int_stack+109114,int_stack+108330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1038427,int_stack+110122,int_stack+109114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1041451,int_stack+1038427,int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1046155,int_stack+111382,int_stack+110122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1049935,int_stack+1046155,int_stack+1038427, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1055983,int_stack+1049935,int_stack+1041451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1036075,int_stack+112922,int_stack+111382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1095376,int_stack+1036075,int_stack+1046155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1036075,int_stack+1095376,int_stack+1049935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14124,int_stack+1036075,int_stack+1055983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1036075,int_stack+14124,int_stack+1067656,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+25884,int_stack+1036075,int_stack+1076476,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1062535,int_stack+115778,int_stack+114770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1065559,int_stack+117074,int_stack+115778, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1069447,int_stack+1065559,int_stack+1062535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1075495,int_stack+118694,int_stack+117074, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1080355,int_stack+1075495,int_stack+1065559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1088131,int_stack+1080355,int_stack+1069447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1062535,int_stack+120674,int_stack+118694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+63684,int_stack+1062535,int_stack+1075495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1062535,int_stack+63684,int_stack+1080355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+63684,int_stack+1062535,int_stack+1088131, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1062535,int_stack+63684,int_stack+14124,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+736195,int_stack+1062535,int_stack+1036075,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+477591,int_stack+736195,int_stack+25884,420);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1036075,int_stack+124310,int_stack+123050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1039855,int_stack+125930,int_stack+124310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1044715,int_stack+1039855,int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1052275,int_stack+127955,int_stack+125930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14124,int_stack+1052275,int_stack+1039855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23844,int_stack+14124,int_stack+1044715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1036075,int_stack+130430,int_stack+127955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+36444,int_stack+1036075,int_stack+1052275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1036075,int_stack+36444,int_stack+14124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+36444,int_stack+1036075,int_stack+23844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+78804,int_stack+36444,int_stack+63684,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+877315,int_stack+78804,int_stack+1062535,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+14124,int_stack+877315,int_stack+736195,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+736195,int_stack+133820,int_stack+133400, 0.0, zero_stack, 1.0, int_stack+274180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+737455,int_stack+134360,int_stack+133820, 0.0, zero_stack, 1.0, int_stack+274600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+739075,int_stack+737455,int_stack+736195, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+741595,int_stack+135035,int_stack+134360, 0.0, zero_stack, 1.0, int_stack+275140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+743620,int_stack+741595,int_stack+737455, 0.0, zero_stack, 1.0, int_stack+331790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+746860,int_stack+743620,int_stack+739075, 0.0, zero_stack, 1.0, int_stack+333410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+736195,int_stack+135860,int_stack+135035, 0.0, zero_stack, 1.0, int_stack+275815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+751060,int_stack+736195,int_stack+741595, 0.0, zero_stack, 1.0, int_stack+335930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+751060,int_stack+743620, 0.0, zero_stack, 1.0, int_stack+337955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+751060,int_stack+736195,int_stack+746860, 0.0, zero_stack, 1.0, int_stack+341195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+736195,int_stack+137438,int_stack+136850, 0.0, zero_stack, 1.0, int_stack+281080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+737959,int_stack+138194,int_stack+137438, 0.0, zero_stack, 1.0, int_stack+281668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+740227,int_stack+737959,int_stack+736195, 0.0, zero_stack, 1.0, int_stack+345395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+743755,int_stack+139139,int_stack+138194, 0.0, zero_stack, 1.0, int_stack+282424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+757360,int_stack+743755,int_stack+737959, 0.0, zero_stack, 1.0, int_stack+347159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+761896,int_stack+757360,int_stack+740227, 0.0, zero_stack, 1.0, int_stack+349427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+736195,int_stack+140294,int_stack+139139, 0.0, zero_stack, 1.0, int_stack+283369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+767776,int_stack+736195,int_stack+743755, 0.0, zero_stack, 1.0, int_stack+352955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+767776,int_stack+757360, 0.0, zero_stack, 1.0, int_stack+366560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+767776,int_stack+736195,int_stack+761896, 0.0, zero_stack, 1.0, int_stack+371096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+877315,int_stack+767776,int_stack+751060,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+736195,int_stack+142464,int_stack+141680, 0.0, zero_stack, 1.0, int_stack+290740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+738547,int_stack+143472,int_stack+142464, 0.0, zero_stack, 1.0, int_stack+291524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+741571,int_stack+738547,int_stack+736195, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+746275,int_stack+144732,int_stack+143472, 0.0, zero_stack, 1.0, int_stack+292532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+750055,int_stack+746275,int_stack+738547, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+756103,int_stack+750055,int_stack+741571, 0.0, zero_stack, 1.0, int_stack+376976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+736195,int_stack+146272,int_stack+144732, 0.0, zero_stack, 1.0, int_stack+293792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+776596,int_stack+736195,int_stack+746275, 0.0, zero_stack, 1.0, int_stack+381680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+776596,int_stack+750055, 0.0, zero_stack, 1.0, int_stack+355790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+776596,int_stack+736195,int_stack+756103, 0.0, zero_stack, 1.0, int_stack+417947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+736195,int_stack+776596,int_stack+767776,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+896215,int_stack+736195,int_stack+877315,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+149128,int_stack+148120, 0.0, zero_stack, 1.0, int_stack+303620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+880339,int_stack+150424,int_stack+149128, 0.0, zero_stack, 1.0, int_stack+304628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+884227,int_stack+880339,int_stack+877315, 0.0, zero_stack, 1.0, int_stack+452247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+890275,int_stack+152044,int_stack+150424, 0.0, zero_stack, 1.0, int_stack+305924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+762655,int_stack+890275,int_stack+880339, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+934015,int_stack+762655,int_stack+884227, 0.0, zero_stack, 1.0, int_stack+385460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+877315,int_stack+154024,int_stack+152044, 0.0, zero_stack, 1.0, int_stack+307544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1036075,int_stack+877315,int_stack+890275, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+877315,int_stack+1036075,int_stack+762655, 0.0, zero_stack, 1.0, int_stack+391508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1036075,int_stack+877315,int_stack+934015, 0.0, zero_stack, 1.0, int_stack+399284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1051195,int_stack+1036075,int_stack+776596,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+102324,int_stack+1051195,int_stack+736195,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1194835,int_stack+102324,int_stack+896215,420);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+736195,int_stack+157660,int_stack+156400, 0.0, zero_stack, 1.0, int_stack+189750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+739975,int_stack+159280,int_stack+157660, 0.0, zero_stack, 1.0, int_stack+192270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+744835,int_stack+739975,int_stack+736195, 0.0, zero_stack, 1.0, int_stack+425787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+752395,int_stack+161305,int_stack+159280, 0.0, zero_stack, 1.0, int_stack+195510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+758470,int_stack+752395,int_stack+739975, 0.0, zero_stack, 1.0, int_stack+429567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+768190,int_stack+758470,int_stack+744835, 0.0, zero_stack, 1.0, int_stack+434427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+736195,int_stack+163780,int_stack+161305, 0.0, zero_stack, 1.0, int_stack+199560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+877315,int_stack+736195,int_stack+752395, 0.0, zero_stack, 1.0, int_stack+441987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+877315,int_stack+758470, 0.0, zero_stack, 1.0, int_stack+455271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+877315,int_stack+736195,int_stack+768190, 0.0, zero_stack, 1.0, int_stack+464991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+736195,int_stack+877315,int_stack+1036075,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+877315,int_stack+736195,int_stack+1051195,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1257835,int_stack+877315,int_stack+102324,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102324,int_stack+167170,int_stack+166750, 1.0, int_stack+274180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+103584,int_stack+167710,int_stack+167170, 1.0, int_stack+274600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+105204,int_stack+103584,int_stack+102324, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+107724,int_stack+168385,int_stack+167710, 1.0, int_stack+275140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109749,int_stack+107724,int_stack+103584, 1.0, int_stack+331790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+112989,int_stack+109749,int_stack+105204, 1.0, int_stack+333410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+330530,int_stack+169210,int_stack+168385, 1.0, int_stack+275815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+102324,int_stack+330530,int_stack+107724, 1.0, int_stack+335930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+330530,int_stack+102324,int_stack+109749, 1.0, int_stack+337955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+102324,int_stack+330530,int_stack+112989, 1.0, int_stack+341195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+330530,int_stack+170788,int_stack+170200, 1.0, int_stack+281080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+332294,int_stack+171544,int_stack+170788, 1.0, int_stack+281668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108624,int_stack+332294,int_stack+330530, 1.0, int_stack+345395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+112152,int_stack+172489,int_stack+171544, 1.0, int_stack+282424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+114987,int_stack+112152,int_stack+332294, 1.0, int_stack+347159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+119523,int_stack+114987,int_stack+108624, 1.0, int_stack+349427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+108624,int_stack+173644,int_stack+172489, 1.0, int_stack+283369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+345395,int_stack+108624,int_stack+112152, 1.0, int_stack+352955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+125403,int_stack+345395,int_stack+114987, 1.0, int_stack+366560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+108624,int_stack+125403,int_stack+119523, 1.0, int_stack+371096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+117444,int_stack+108624,int_stack+102324,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102324,int_stack+175814,int_stack+175030, 1.0, int_stack+290740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+104676,int_stack+176822,int_stack+175814, 1.0, int_stack+291524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+345395,int_stack+104676,int_stack+102324, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+136344,int_stack+178082,int_stack+176822, 1.0, int_stack+292532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+140124,int_stack+136344,int_stack+104676, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+146172,int_stack+140124,int_stack+345395, 1.0, int_stack+376976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+376976,int_stack+179622,int_stack+178082, 1.0, int_stack+293792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+345395,int_stack+376976,int_stack+136344, 1.0, int_stack+381680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+154012,int_stack+345395,int_stack+140124, 1.0, int_stack+355790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+164092,int_stack+154012,int_stack+146172, 1.0, int_stack+417947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+136344,int_stack+164092,int_stack+108624,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+877315,int_stack+136344,int_stack+117444,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+345395,int_stack+182478,int_stack+181470, 1.0, int_stack+303620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+348419,int_stack+183774,int_stack+182478, 1.0, int_stack+304628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+102324,int_stack+348419,int_stack+345395, 1.0, int_stack+452247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+185394,int_stack+183774, 1.0, int_stack+305924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+108372,int_stack+0,int_stack+348419, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+116148,int_stack+108372,int_stack+102324, 1.0, int_stack+385460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+385460,int_stack+187374,int_stack+185394, 1.0, int_stack+307544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+126228,int_stack+385460,int_stack+0, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+175852,int_stack+126228,int_stack+108372, 1.0, int_stack+391508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+915115,int_stack+175852,int_stack+116148, 1.0, int_stack+399284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+736195,int_stack+915115,int_stack+164092,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1036075,int_stack+736195,int_stack+136344,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+102324,int_stack+1036075,int_stack+877315,420);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+877315,int_stack+193890,int_stack+191010, 1.0, int_stack+189750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+881095,int_stack+197535,int_stack+193890, 1.0, int_stack+192270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+345395,int_stack+881095,int_stack+877315, 1.0, int_stack+425787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+885955,int_stack+202035,int_stack+197535, 1.0, int_stack+195510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+892030,int_stack+885955,int_stack+881095, 1.0, int_stack+429567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+901750,int_stack+892030,int_stack+345395, 1.0, int_stack+434427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+345395,int_stack+204510,int_stack+202035, 1.0, int_stack+199560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+425787,int_stack+345395,int_stack+885955, 1.0, int_stack+441987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+437937,int_stack+425787,int_stack+892030, 1.0, int_stack+455271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+877315,int_stack+437937,int_stack+901750, 1.0, int_stack+464991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ig) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+425787,int_stack+877315,int_stack+915115,420);
 /*--- compute (id|ig) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+877315,int_stack+425787,int_stack+736195,420);
 /*--- compute (hf|ig) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1346035,int_stack+877315,int_stack+1036075,420);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1036075,int_stack+276640,int_stack+275815,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1038550,int_stack+1036075,int_stack+335930,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1042600,int_stack+1038550,int_stack+337955,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1036075,int_stack+1042600,int_stack+341195,15);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1042375,int_stack+284524,int_stack+283369,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1045840,int_stack+1042375,int_stack+352955,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1051510,int_stack+1045840,int_stack+366560,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1042375,int_stack+1051510,int_stack+371096,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1051195,int_stack+1042375,int_stack+1036075,420);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1070095,int_stack+295332,int_stack+293792,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1074715,int_stack+1070095,int_stack+381680,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1082275,int_stack+1074715,int_stack+355790,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1070095,int_stack+1082275,int_stack+417947,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+877315,int_stack+1070095,int_stack+1042375,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+903775,int_stack+877315,int_stack+1051195,420);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1081855,int_stack+309524,int_stack+307544,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1087795,int_stack+1081855,int_stack+9264,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+736195,int_stack+1087795,int_stack+391508,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1081855,int_stack+736195,int_stack+399284,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+736195,int_stack+1081855,int_stack+1070095,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+330530,int_stack+736195,int_stack+877315,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+383450,int_stack+330530,int_stack+903775,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+771475,int_stack+207900,int_stack+207480,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+772735,int_stack+208440,int_stack+207900,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+774355,int_stack+772735,int_stack+771475,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+776875,int_stack+209115,int_stack+208440,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+778900,int_stack+776875,int_stack+772735,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+782140,int_stack+778900,int_stack+774355,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+771475,int_stack+209940,int_stack+209115,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1096975,int_stack+771475,int_stack+776875,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+771475,int_stack+1096975,int_stack+778900,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+941575,int_stack+771475,int_stack+782140,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+771475,int_stack+211518,int_stack+210930,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+773239,int_stack+212274,int_stack+211518,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+775507,int_stack+773239,int_stack+771475,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+779035,int_stack+213219,int_stack+212274,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+781870,int_stack+779035,int_stack+773239,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1096975,int_stack+781870,int_stack+775507,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+771475,int_stack+214374,int_stack+213219,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+771475,int_stack+779035,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+771475,int_stack+0,int_stack+781870,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+771475,int_stack+1096975,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+165324,int_stack+0,int_stack+941575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+941575,int_stack+216544,int_stack+215760,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+943927,int_stack+217552,int_stack+216544,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1096975,int_stack+943927,int_stack+941575,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1101679,int_stack+218812,int_stack+217552,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+771475,int_stack+1101679,int_stack+943927,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+777523,int_stack+771475,int_stack+1096975,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1096975,int_stack+220352,int_stack+218812,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+184224,int_stack+1096975,int_stack+1101679,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+191784,int_stack+184224,int_stack+771475,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+201864,int_stack+191784,int_stack+777523,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+446450,int_stack+201864,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1434235,int_stack+446450,int_stack+165324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1051195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+165324,int_stack+223208,int_stack+222200,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+168348,int_stack+224504,int_stack+223208,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+172236,int_stack+168348,int_stack+165324,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+178284,int_stack+226124,int_stack+224504,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+183144,int_stack+178284,int_stack+168348,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+190920,int_stack+183144,int_stack+172236,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+165324,int_stack+228104,int_stack+226124,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+165324,int_stack+178284,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+165324,int_stack+0,int_stack+183144,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+771475,int_stack+165324,int_stack+190920,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+165324,int_stack+771475,int_stack+201864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1472035,int_stack+165324,int_stack+446450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1524955,int_stack+1472035,int_stack+1434235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+903775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1434235,int_stack+231740,int_stack+230480,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1438015,int_stack+233360,int_stack+231740,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1442875,int_stack+1438015,int_stack+1434235,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1450435,int_stack+235385,int_stack+233360,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1456510,int_stack+1450435,int_stack+1438015,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+446450,int_stack+1456510,int_stack+1442875,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1434235,int_stack+237860,int_stack+235385,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+459050,int_stack+1434235,int_stack+1450435,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1434235,int_stack+459050,int_stack+1456510,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1450435,int_stack+1434235,int_stack+446450,45);
 /*--- compute (kp|ig) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1587955,int_stack+1450435,int_stack+771475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (id|ig) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1633315,int_stack+1587955,int_stack+165324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+736195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hf|ig) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1703875,int_stack+1633315,int_stack+1472035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+165324,int_stack+241250,int_stack+240830,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+166584,int_stack+241790,int_stack+241250,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+168204,int_stack+166584,int_stack+165324,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+170724,int_stack+242465,int_stack+241790,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+172749,int_stack+170724,int_stack+166584,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+175989,int_stack+172749,int_stack+168204,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+165324,int_stack+243290,int_stack+242465,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+180189,int_stack+165324,int_stack+170724,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+165324,int_stack+180189,int_stack+172749,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+941575,int_stack+165324,int_stack+175989,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+165324,int_stack+244868,int_stack+244280,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+167088,int_stack+245624,int_stack+244868,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+169356,int_stack+167088,int_stack+165324,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+172884,int_stack+246569,int_stack+245624,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+175719,int_stack+172884,int_stack+167088,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+180255,int_stack+175719,int_stack+169356,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+165324,int_stack+247724,int_stack+246569,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+186135,int_stack+165324,int_stack+172884,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+165324,int_stack+186135,int_stack+175719,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+186135,int_stack+165324,int_stack+180255,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+165324,int_stack+186135,int_stack+941575, 0.0, zero_stack, 1.0, int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+941575,int_stack+249894,int_stack+249110,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+943927,int_stack+250902,int_stack+249894,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+194955,int_stack+943927,int_stack+941575,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+199659,int_stack+252162,int_stack+250902,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+203439,int_stack+199659,int_stack+943927,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+209487,int_stack+203439,int_stack+194955,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+194955,int_stack+253702,int_stack+252162,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+217327,int_stack+194955,int_stack+199659,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+224887,int_stack+217327,int_stack+203439,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+194955,int_stack+224887,int_stack+209487,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+206715,int_stack+194955,int_stack+186135, 0.0, zero_stack, 1.0, int_stack+1042375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1587955,int_stack+206715,int_stack+165324, 0.0, zero_stack, 1.0, int_stack+1051195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+165324,int_stack+256558,int_stack+255550,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+168348,int_stack+257854,int_stack+256558,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+172236,int_stack+168348,int_stack+165324,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+178284,int_stack+259474,int_stack+257854,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+183144,int_stack+178284,int_stack+168348,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+233175,int_stack+183144,int_stack+172236,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+165324,int_stack+261454,int_stack+259474,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+243255,int_stack+165324,int_stack+178284,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+165324,int_stack+243255,int_stack+183144,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+243255,int_stack+165324,int_stack+233175,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1625755,int_stack+243255,int_stack+194955, 0.0, zero_stack, 1.0, int_stack+1070095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1434235,int_stack+1625755,int_stack+206715, 0.0, zero_stack, 1.0, int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+165324,int_stack+1434235,int_stack+1587955, 0.0, zero_stack, 1.0, int_stack+903775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1587955,int_stack+265090,int_stack+263830,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1591735,int_stack+266710,int_stack+265090,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1596595,int_stack+1591735,int_stack+1587955,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1604155,int_stack+268735,int_stack+266710,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1610230,int_stack+1604155,int_stack+1591735,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+228324,int_stack+1610230,int_stack+1596595,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1587955,int_stack+271210,int_stack+268735,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+258375,int_stack+1587955,int_stack+1604155,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1587955,int_stack+258375,int_stack+1610230,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+258375,int_stack+1587955,int_stack+228324,45);
 /*--- compute (kp|ig) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1792075,int_stack+258375,int_stack+243255, 0.0, zero_stack, 1.0, int_stack+1081855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (id|ig) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1837435,int_stack+1792075,int_stack+1625755, 0.0, zero_stack, 1.0, int_stack+736195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hf|ig) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1587955,int_stack+1837435,int_stack+1434235, 0.0, zero_stack, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1434235,int_stack+278050,int_stack+277630,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1435495,int_stack+278590,int_stack+278050,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1437115,int_stack+1435495,int_stack+1434235,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1439635,int_stack+279265,int_stack+278590,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1441660,int_stack+1439635,int_stack+1435495,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1444900,int_stack+1441660,int_stack+1437115,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1434235,int_stack+280090,int_stack+279265,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1449100,int_stack+1434235,int_stack+1439635,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1434235,int_stack+1449100,int_stack+1441660,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+941575,int_stack+1434235,int_stack+1444900,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1434235,int_stack+286498,int_stack+285910,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1435999,int_stack+287254,int_stack+286498,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1438267,int_stack+1435999,int_stack+1434235,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1441795,int_stack+288199,int_stack+287254,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1444630,int_stack+1441795,int_stack+1435999,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1449166,int_stack+1444630,int_stack+1438267,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1434235,int_stack+289354,int_stack+288199,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1455046,int_stack+1434235,int_stack+1441795,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1434235,int_stack+1455046,int_stack+1444630,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1455046,int_stack+1434235,int_stack+1449166,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1434235,int_stack+1455046,int_stack+941575, 1.0, int_stack+1036075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1036075,int_stack+297964,int_stack+297180,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1038427,int_stack+298972,int_stack+297964,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+941575,int_stack+1038427,int_stack+1036075,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1463866,int_stack+300232,int_stack+298972,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1467646,int_stack+1463866,int_stack+1038427,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1473694,int_stack+1467646,int_stack+941575,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+941575,int_stack+301772,int_stack+300232,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1481534,int_stack+941575,int_stack+1463866,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1489094,int_stack+1481534,int_stack+1467646,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1499174,int_stack+1489094,int_stack+1473694,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1463866,int_stack+1499174,int_stack+1455046, 1.0, int_stack+1042375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1792075,int_stack+1463866,int_stack+1434235, 1.0, int_stack+1051195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1434235,int_stack+312908,int_stack+311900,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1437259,int_stack+314204,int_stack+312908,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1441147,int_stack+1437259,int_stack+1434235,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1447195,int_stack+315824,int_stack+314204,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1452055,int_stack+1447195,int_stack+1437259,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1036075,int_stack+1452055,int_stack+1441147,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1434235,int_stack+317804,int_stack+315824,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1046155,int_stack+1434235,int_stack+1447195,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1434235,int_stack+1046155,int_stack+1452055,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1046155,int_stack+1434235,int_stack+1036075,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1829875,int_stack+1046155,int_stack+1499174, 1.0, int_stack+1070095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+228324,int_stack+1829875,int_stack+1463866, 1.0, int_stack+877315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1434235,int_stack+228324,int_stack+1792075, 1.0, int_stack+903775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1792075,int_stack+321440,int_stack+320180,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1795855,int_stack+323060,int_stack+321440,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1800715,int_stack+1795855,int_stack+1792075,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1808275,int_stack+325085,int_stack+323060,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1814350,int_stack+1808275,int_stack+1795855,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+877315,int_stack+1814350,int_stack+1800715,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1792075,int_stack+327560,int_stack+325085,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+889915,int_stack+1792075,int_stack+1808275,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1792075,int_stack+889915,int_stack+1814350,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889915,int_stack+1792075,int_stack+877315,45);
 /*--- compute (kp|ig) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+281244,int_stack+889915,int_stack+1046155, 1.0, int_stack+1081855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (id|ig) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+877315,int_stack+281244,int_stack+1829875, 1.0, int_stack+736195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hf|ig) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1792075,int_stack+877315,int_stack+228324, 1.0, int_stack+330530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+228324,int_stack+789115,int_stack+610195,420);
     Libderiv->ABCD[11] = int_stack + 228324;
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+736195,int_stack+947875,int_stack+673195,420);
     Libderiv->ABCD[10] = int_stack + 736195;
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+830695,int_stack+1106635,int_stack+545631,420);
     Libderiv->ABCD[9] = int_stack + 830695;
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+925195,int_stack+14124,int_stack+477591,420);
     Libderiv->ABCD[8] = int_stack + 925195;
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1019695,int_stack+1257835,int_stack+1194835,420);
     Libderiv->ABCD[7] = int_stack + 1019695;
 /*--- compute (gg|ig) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1114195,int_stack+1346035,int_stack+102324,420);
     Libderiv->ABCD[6] = int_stack + 1114195;
 /*--- compute (gg|ig) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1208695,int_stack+1703875,int_stack+1524955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 1208695;
 /*--- compute (gg|ig) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1303195,int_stack+1587955,int_stack+165324, 0.0, zero_stack, 1.0, int_stack+383450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 1303195;
 /*--- compute (gg|ig) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1497235,int_stack+1792075,int_stack+1434235, 1.0, int_stack+383450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 1497235;

}
