/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_idif(Libderiv_t *, prim_data *);

  /* Computes derivatives of (id|if) integrals */

void d1hrr_order_idif(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[7][6][11] = int_stack + 4592;
 Libderiv->deriv_classes[7][7][11] = int_stack + 5600;
 Libderiv->deriv_classes[7][8][11] = int_stack + 6896;
 Libderiv->deriv_classes[7][9][11] = int_stack + 8516;
 Libderiv->deriv_classes[8][6][11] = int_stack + 10496;
 Libderiv->deriv_classes[8][7][11] = int_stack + 11756;
 Libderiv->deriv_classes[8][8][11] = int_stack + 13376;
 Libderiv->deriv_classes[8][9][11] = int_stack + 15401;
 Libderiv->deriv_classes[6][6][10] = int_stack + 17876;
 Libderiv->deriv_classes[6][7][10] = int_stack + 18660;
 Libderiv->deriv_classes[6][8][10] = int_stack + 19668;
 Libderiv->deriv_classes[6][9][10] = int_stack + 20928;
 Libderiv->deriv_classes[7][6][10] = int_stack + 22468;
 Libderiv->deriv_classes[7][7][10] = int_stack + 23476;
 Libderiv->deriv_classes[7][8][10] = int_stack + 24772;
 Libderiv->deriv_classes[7][9][10] = int_stack + 26392;
 Libderiv->deriv_classes[8][6][10] = int_stack + 28372;
 Libderiv->deriv_classes[8][7][10] = int_stack + 29632;
 Libderiv->deriv_classes[8][8][10] = int_stack + 31252;
 Libderiv->deriv_classes[8][9][10] = int_stack + 33277;
 Libderiv->deriv_classes[6][6][9] = int_stack + 35752;
 Libderiv->deriv_classes[6][7][9] = int_stack + 36536;
 Libderiv->deriv_classes[6][8][9] = int_stack + 37544;
 Libderiv->deriv_classes[6][9][9] = int_stack + 38804;
 Libderiv->deriv_classes[7][6][9] = int_stack + 40344;
 Libderiv->deriv_classes[7][7][9] = int_stack + 41352;
 Libderiv->deriv_classes[7][8][9] = int_stack + 42648;
 Libderiv->deriv_classes[7][9][9] = int_stack + 44268;
 Libderiv->deriv_classes[8][6][9] = int_stack + 46248;
 Libderiv->deriv_classes[8][7][9] = int_stack + 47508;
 Libderiv->deriv_classes[8][8][9] = int_stack + 49128;
 Libderiv->deriv_classes[8][9][9] = int_stack + 51153;
 Libderiv->deriv_classes[6][6][8] = int_stack + 53628;
 Libderiv->deriv_classes[6][7][8] = int_stack + 54412;
 Libderiv->deriv_classes[6][8][8] = int_stack + 55420;
 Libderiv->deriv_classes[6][9][8] = int_stack + 56680;
 Libderiv->deriv_classes[7][6][8] = int_stack + 58220;
 Libderiv->deriv_classes[7][7][8] = int_stack + 59228;
 Libderiv->deriv_classes[7][8][8] = int_stack + 60524;
 Libderiv->deriv_classes[7][9][8] = int_stack + 62144;
 Libderiv->deriv_classes[8][6][8] = int_stack + 64124;
 Libderiv->deriv_classes[8][7][8] = int_stack + 65384;
 Libderiv->deriv_classes[8][8][8] = int_stack + 67004;
 Libderiv->deriv_classes[8][9][8] = int_stack + 69029;
 Libderiv->deriv_classes[6][6][7] = int_stack + 71504;
 Libderiv->deriv_classes[6][7][7] = int_stack + 72288;
 Libderiv->deriv_classes[6][8][7] = int_stack + 73296;
 Libderiv->deriv_classes[6][9][7] = int_stack + 74556;
 Libderiv->deriv_classes[7][6][7] = int_stack + 76096;
 Libderiv->deriv_classes[7][7][7] = int_stack + 77104;
 Libderiv->deriv_classes[7][8][7] = int_stack + 78400;
 Libderiv->deriv_classes[7][9][7] = int_stack + 80020;
 Libderiv->deriv_classes[8][6][7] = int_stack + 82000;
 Libderiv->deriv_classes[8][7][7] = int_stack + 83260;
 Libderiv->deriv_classes[8][8][7] = int_stack + 84880;
 Libderiv->deriv_classes[8][9][7] = int_stack + 86905;
 Libderiv->deriv_classes[6][6][6] = int_stack + 89380;
 Libderiv->deriv_classes[6][7][6] = int_stack + 90164;
 Libderiv->deriv_classes[6][8][6] = int_stack + 91172;
 Libderiv->deriv_classes[6][9][6] = int_stack + 92432;
 Libderiv->deriv_classes[7][6][6] = int_stack + 93972;
 Libderiv->deriv_classes[7][7][6] = int_stack + 94980;
 Libderiv->deriv_classes[7][8][6] = int_stack + 96276;
 Libderiv->deriv_classes[7][9][6] = int_stack + 97896;
 Libderiv->dvrr_classes[8][6] = int_stack + 99876;
 Libderiv->deriv_classes[8][6][6] = int_stack + 101136;
 Libderiv->dvrr_classes[8][7] = int_stack + 102396;
 Libderiv->deriv_classes[8][7][6] = int_stack + 104016;
 Libderiv->dvrr_classes[8][8] = int_stack + 105636;
 Libderiv->deriv_classes[8][8][6] = int_stack + 107661;
 Libderiv->deriv_classes[8][9][6] = int_stack + 109686;
 Libderiv->deriv_classes[6][6][2] = int_stack + 112161;
 Libderiv->deriv_classes[6][7][2] = int_stack + 112945;
 Libderiv->deriv_classes[6][8][2] = int_stack + 113953;
 Libderiv->deriv_classes[6][9][2] = int_stack + 115213;
 Libderiv->deriv_classes[7][6][2] = int_stack + 116753;
 Libderiv->deriv_classes[7][7][2] = int_stack + 117761;
 Libderiv->deriv_classes[7][8][2] = int_stack + 119057;
 Libderiv->deriv_classes[7][9][2] = int_stack + 120677;
 Libderiv->deriv_classes[8][6][2] = int_stack + 122657;
 Libderiv->deriv_classes[8][7][2] = int_stack + 123917;
 Libderiv->deriv_classes[8][8][2] = int_stack + 125537;
 Libderiv->deriv_classes[8][9][2] = int_stack + 127562;
 Libderiv->deriv_classes[6][6][1] = int_stack + 130037;
 Libderiv->deriv_classes[6][7][1] = int_stack + 130821;
 Libderiv->deriv_classes[6][8][1] = int_stack + 131829;
 Libderiv->deriv_classes[6][9][1] = int_stack + 133089;
 Libderiv->deriv_classes[7][6][1] = int_stack + 134629;
 Libderiv->deriv_classes[7][7][1] = int_stack + 135637;
 Libderiv->deriv_classes[7][8][1] = int_stack + 136933;
 Libderiv->deriv_classes[7][9][1] = int_stack + 138553;
 Libderiv->deriv_classes[8][6][1] = int_stack + 140533;
 Libderiv->deriv_classes[8][7][1] = int_stack + 141793;
 Libderiv->deriv_classes[8][8][1] = int_stack + 143413;
 Libderiv->deriv_classes[8][9][1] = int_stack + 145438;
 Libderiv->dvrr_classes[6][6] = int_stack + 147913;
 Libderiv->dvrr_classes[6][7] = int_stack + 148697;
 Libderiv->dvrr_classes[6][8] = int_stack + 149705;
 Libderiv->dvrr_classes[6][9] = int_stack + 150965;
 Libderiv->deriv_classes[6][6][0] = int_stack + 152505;
 Libderiv->deriv_classes[6][7][0] = int_stack + 153289;
 Libderiv->deriv_classes[6][8][0] = int_stack + 154297;
 Libderiv->deriv_classes[6][9][0] = int_stack + 155557;
 Libderiv->dvrr_classes[7][6] = int_stack + 157097;
 Libderiv->dvrr_classes[7][7] = int_stack + 158105;
 Libderiv->dvrr_classes[7][8] = int_stack + 159401;
 Libderiv->dvrr_classes[7][9] = int_stack + 161021;
 Libderiv->deriv_classes[7][6][0] = int_stack + 163001;
 Libderiv->deriv_classes[7][7][0] = int_stack + 164009;
 Libderiv->deriv_classes[7][8][0] = int_stack + 165305;
 Libderiv->deriv_classes[7][9][0] = int_stack + 166925;
 Libderiv->deriv_classes[8][6][0] = int_stack + 168905;
 Libderiv->deriv_classes[8][7][0] = int_stack + 170165;
 Libderiv->deriv_classes[8][8][0] = int_stack + 171785;
 Libderiv->deriv_classes[8][9][0] = int_stack + 173810;
 memset(int_stack,0,1410280);

 Libderiv->dvrr_stack = int_stack + 654144;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_idif(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+176285,int_stack+148697,int_stack+147913,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+178637,int_stack+149705,int_stack+148697,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+181661,int_stack+178637,int_stack+176285,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+186365,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147913,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+188717,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148697,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+191741,int_stack+188717,int_stack+186365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176285,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+196445,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149705,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+200225,int_stack+196445,int_stack+188717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178637,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206273,int_stack+200225,int_stack+191741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181661,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+186365,int_stack+158105,int_stack+157097,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+189389,int_stack+159401,int_stack+158105,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+193277,int_stack+189389,int_stack+186365,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199325,int_stack+5600,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157097,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202349,int_stack+6896,int_stack+5600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158105,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+202349,int_stack+199325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186365,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+214113,int_stack+8516,int_stack+6896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159401,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+218973,int_stack+214113,int_stack+202349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189389,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+226749,int_stack+218973,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193277,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+236829,int_stack+226749,int_stack+206273,280);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+102396,int_stack+99876,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+105636,int_stack+102396,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+199325,int_stack+3780,int_stack+0,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+206885,int_stack+11756,int_stack+10496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99876,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+210665,int_stack+13376,int_stack+11756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102396,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+215525,int_stack+210665,int_stack+206885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+260349,int_stack+15401,int_stack+13376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105636,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+266424,int_stack+260349,int_stack+210665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+276144,int_stack+266424,int_stack+215525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199325,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+288744,int_stack+276144,int_stack+226749,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+18660,int_stack+17876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147913, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262701,int_stack+19668,int_stack+18660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148697, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265725,int_stack+262701,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+270429,int_stack+20928,int_stack+19668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149705, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+274209,int_stack+270429,int_stack+262701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178637, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+280257,int_stack+274209,int_stack+265725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181661, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+23476,int_stack+22468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157097, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263373,int_stack+24772,int_stack+23476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158105, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+267261,int_stack+263373,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186365, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+273309,int_stack+26392,int_stack+24772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159401, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206885,int_stack+273309,int_stack+263373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189389, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+214661,int_stack+206885,int_stack+267261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193277, 0.0, zero_stack,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+318984,int_stack+214661,int_stack+280257,280);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+206885,int_stack+29632,int_stack+28372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99876, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+260349,int_stack+31252,int_stack+29632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102396, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265209,int_stack+260349,int_stack+206885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+206885,int_stack+33277,int_stack+31252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105636, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272769,int_stack+206885,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8640,int_stack+272769,int_stack+265209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199325, 0.0, zero_stack,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+342504,int_stack+8640,int_stack+214661,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8640,int_stack+36536,int_stack+35752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147913, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10992,int_stack+37544,int_stack+36536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148697, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14016,int_stack+10992,int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+18720,int_stack+38804,int_stack+37544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149705, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+22500,int_stack+18720,int_stack+10992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178637, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+28548,int_stack+22500,int_stack+14016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181661, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8640,int_stack+41352,int_stack+40344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157097, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11664,int_stack+42648,int_stack+41352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158105, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15552,int_stack+11664,int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186365, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+21600,int_stack+44268,int_stack+42648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159401, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+36388,int_stack+21600,int_stack+11664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189389, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+260349,int_stack+36388,int_stack+15552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193277, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+206885,int_stack+260349,int_stack+28548,280);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8640,int_stack+47508,int_stack+46248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99876, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12420,int_stack+49128,int_stack+47508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102396, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17280,int_stack+12420,int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24840,int_stack+51153,int_stack+49128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105636, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30915,int_stack+24840,int_stack+12420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+40635,int_stack+30915,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8640,int_stack+40635,int_stack+260349,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+54412,int_stack+53628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262701,int_stack+55420,int_stack+54412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265725,int_stack+262701,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+270429,int_stack+56680,int_stack+55420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+274209,int_stack+270429,int_stack+262701, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+280257,int_stack+274209,int_stack+265725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+59228,int_stack+58220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263373,int_stack+60524,int_stack+59228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+267261,int_stack+263373,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+273309,int_stack+62144,int_stack+60524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38880,int_stack+273309,int_stack+263373, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+46656,int_stack+38880,int_stack+267261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+372744,int_stack+46656,int_stack+280257,280);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38880,int_stack+65384,int_stack+64124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+260349,int_stack+67004,int_stack+65384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265209,int_stack+260349,int_stack+38880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+69029,int_stack+67004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272769,int_stack+38880,int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+56736,int_stack+272769,int_stack+265209, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+396264,int_stack+56736,int_stack+46656,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+72288,int_stack+71504, 0.0, zero_stack, 1.0, int_stack+147913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+262701,int_stack+73296,int_stack+72288, 0.0, zero_stack, 1.0, int_stack+148697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265725,int_stack+262701,int_stack+260349, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+270429,int_stack+74556,int_stack+73296, 0.0, zero_stack, 1.0, int_stack+149705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+274209,int_stack+270429,int_stack+262701, 0.0, zero_stack, 1.0, int_stack+178637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+280257,int_stack+274209,int_stack+265725, 0.0, zero_stack, 1.0, int_stack+181661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+77104,int_stack+76096, 0.0, zero_stack, 1.0, int_stack+157097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263373,int_stack+78400,int_stack+77104, 0.0, zero_stack, 1.0, int_stack+158105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+267261,int_stack+263373,int_stack+260349, 0.0, zero_stack, 1.0, int_stack+186365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+273309,int_stack+80020,int_stack+78400, 0.0, zero_stack, 1.0, int_stack+159401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38880,int_stack+273309,int_stack+263373, 0.0, zero_stack, 1.0, int_stack+189389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+46656,int_stack+38880,int_stack+267261, 0.0, zero_stack, 1.0, int_stack+193277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+56736,int_stack+46656,int_stack+280257,280);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38880,int_stack+83260,int_stack+82000, 0.0, zero_stack, 1.0, int_stack+99876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+260349,int_stack+84880,int_stack+83260, 0.0, zero_stack, 1.0, int_stack+102396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+265209,int_stack+260349,int_stack+38880, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+86905,int_stack+84880, 0.0, zero_stack, 1.0, int_stack+105636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272769,int_stack+38880,int_stack+260349, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+272769,int_stack+265209, 0.0, zero_stack, 1.0, int_stack+199325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+439104,int_stack+426504,int_stack+46656,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+426504,int_stack+90164,int_stack+89380, 1.0, int_stack+147913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+428856,int_stack+91172,int_stack+90164, 1.0, int_stack+148697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+431880,int_stack+428856,int_stack+426504, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+260349,int_stack+92432,int_stack+91172, 1.0, int_stack+149705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+264129,int_stack+260349,int_stack+428856, 1.0, int_stack+178637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+270177,int_stack+264129,int_stack+431880, 1.0, int_stack+181661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+260349,int_stack+94980,int_stack+93972, 1.0, int_stack+157097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263373,int_stack+96276,int_stack+94980, 1.0, int_stack+158105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+426504,int_stack+263373,int_stack+260349, 1.0, int_stack+186365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+432552,int_stack+97896,int_stack+96276, 1.0, int_stack+159401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+278017,int_stack+432552,int_stack+263373, 1.0, int_stack+189389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38880,int_stack+278017,int_stack+426504, 1.0, int_stack+193277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+469344,int_stack+38880,int_stack+270177,280);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+426504,int_stack+104016,int_stack+101136, 1.0, int_stack+99876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+430284,int_stack+107661,int_stack+104016, 1.0, int_stack+102396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+260349,int_stack+430284,int_stack+426504, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+267909,int_stack+109686,int_stack+107661, 1.0, int_stack+105636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+273984,int_stack+267909,int_stack+430284, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+273984,int_stack+260349, 1.0, int_stack+199325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|if) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+80256,int_stack+426504,int_stack+38880,280);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+150965,int_stack+149705,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+42660,int_stack+38880,int_stack+178637,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+48708,int_stack+42660,int_stack+181661,28);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+161021,int_stack+159401,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+426504,int_stack+38880,int_stack+189389,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+260349,int_stack+426504,int_stack+193277,36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+176285,int_stack+260349,int_stack+48708,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+426504,int_stack+112945,int_stack+112161,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+428856,int_stack+113953,int_stack+112945,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+431880,int_stack+428856,int_stack+426504,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+115213,int_stack+113953,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+42660,int_stack+38880,int_stack+428856,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+270429,int_stack+42660,int_stack+431880,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38880,int_stack+117761,int_stack+116753,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+41904,int_stack+119057,int_stack+117761,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+426504,int_stack+41904,int_stack+38880,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+432552,int_stack+120677,int_stack+119057,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+278269,int_stack+432552,int_stack+41904,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+110496,int_stack+278269,int_stack+426504,36);
 /*--- compute (ip|if) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+492864,int_stack+110496,int_stack+270429, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+270429,int_stack+123917,int_stack+122657,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+274209,int_stack+125537,int_stack+123917,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+279069,int_stack+274209,int_stack+270429,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+426504,int_stack+127562,int_stack+125537,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+38880,int_stack+426504,int_stack+274209,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+38880,int_stack+279069,45);
 /*--- compute (kp|if) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+516384,int_stack+426504,int_stack+110496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+110496,int_stack+130821,int_stack+130037,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+112848,int_stack+131829,int_stack+130821,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+115872,int_stack+112848,int_stack+110496,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+120576,int_stack+133089,int_stack+131829,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+124356,int_stack+120576,int_stack+112848,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+124356,int_stack+115872,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+110496,int_stack+135637,int_stack+134629,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+113520,int_stack+136933,int_stack+135637,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+117408,int_stack+113520,int_stack+110496,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+123456,int_stack+138553,int_stack+136933,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+128316,int_stack+123456,int_stack+113520,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+270429,int_stack+128316,int_stack+117408,36);
 /*--- compute (ip|if) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+110496,int_stack+270429,int_stack+426504, 0.0, zero_stack, 1.0, int_stack+48708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+426504,int_stack+141793,int_stack+140533,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+430284,int_stack+143413,int_stack+141793,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+134016,int_stack+430284,int_stack+426504,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+38880,int_stack+145438,int_stack+143413,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+141576,int_stack+38880,int_stack+430284,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+141576,int_stack+134016,45);
 /*--- compute (kp|if) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+546624,int_stack+426504,int_stack+270429, 0.0, zero_stack, 1.0, int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+270429,int_stack+153289,int_stack+152505,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+272781,int_stack+154297,int_stack+153289,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+275805,int_stack+272781,int_stack+270429,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+280509,int_stack+155557,int_stack+154297,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+426504,int_stack+280509,int_stack+272781,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+280509,int_stack+426504,int_stack+275805,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+426504,int_stack+164009,int_stack+163001,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+429528,int_stack+165305,int_stack+164009,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+270429,int_stack+429528,int_stack+426504,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+433416,int_stack+166925,int_stack+165305,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+134016,int_stack+433416,int_stack+429528,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+426504,int_stack+134016,int_stack+270429,36);
 /*--- compute (ip|if) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+134016,int_stack+426504,int_stack+280509, 1.0, int_stack+48708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+270429,int_stack+170165,int_stack+168905,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+274209,int_stack+171785,int_stack+170165,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+279069,int_stack+274209,int_stack+270429,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+157536,int_stack+173810,int_stack+171785,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+163611,int_stack+157536,int_stack+274209,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+38880,int_stack+163611,int_stack+279069,45);
 /*--- compute (kp|if) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+576864,int_stack+38880,int_stack+426504, 1.0, int_stack+260349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+607104,int_stack+288744,int_stack+236829,280);
     Libderiv->ABCD[11] = int_stack + 607104;
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+230405,int_stack+342504,int_stack+318984,280);
     Libderiv->ABCD[10] = int_stack + 230405;
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+277445,int_stack+8640,int_stack+206885,280);
     Libderiv->ABCD[9] = int_stack + 277445;
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+0,int_stack+396264,int_stack+372744,280);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+324485,int_stack+439104,int_stack+56736,280);
     Libderiv->ABCD[7] = int_stack + 324485;
 /*--- compute (id|if) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+371525,int_stack+80256,int_stack+469344,280);
     Libderiv->ABCD[6] = int_stack + 371525;
 /*--- compute (id|if) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+47040,int_stack+516384,int_stack+492864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[2] = int_stack + 47040;
 /*--- compute (id|if) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+418565,int_stack+546624,int_stack+110496, 0.0, zero_stack, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[1] = int_stack + 418565;
 /*--- compute (id|if) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+465605,int_stack+576864,int_stack+134016, 1.0, int_stack+176285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[0] = int_stack + 465605;

}
