/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ppif(Libderiv_t *, prim_data *);

  /* Computes derivatives of (pp|if) integrals */

void d1hrr_order_ppif(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][6][11] = int_stack + 0;
 Libderiv->deriv_classes[1][7][11] = int_stack + 84;
 Libderiv->deriv_classes[1][8][11] = int_stack + 192;
 Libderiv->deriv_classes[1][9][11] = int_stack + 327;
 Libderiv->deriv_classes[2][6][11] = int_stack + 492;
 Libderiv->deriv_classes[2][7][11] = int_stack + 660;
 Libderiv->deriv_classes[2][8][11] = int_stack + 876;
 Libderiv->deriv_classes[2][9][11] = int_stack + 1146;
 Libderiv->deriv_classes[1][6][10] = int_stack + 1476;
 Libderiv->deriv_classes[1][7][10] = int_stack + 1560;
 Libderiv->deriv_classes[1][8][10] = int_stack + 1668;
 Libderiv->deriv_classes[1][9][10] = int_stack + 1803;
 Libderiv->deriv_classes[2][6][10] = int_stack + 1968;
 Libderiv->deriv_classes[2][7][10] = int_stack + 2136;
 Libderiv->deriv_classes[2][8][10] = int_stack + 2352;
 Libderiv->deriv_classes[2][9][10] = int_stack + 2622;
 Libderiv->deriv_classes[1][6][9] = int_stack + 2952;
 Libderiv->deriv_classes[1][7][9] = int_stack + 3036;
 Libderiv->deriv_classes[1][8][9] = int_stack + 3144;
 Libderiv->deriv_classes[1][9][9] = int_stack + 3279;
 Libderiv->deriv_classes[2][6][9] = int_stack + 3444;
 Libderiv->deriv_classes[2][7][9] = int_stack + 3612;
 Libderiv->deriv_classes[2][8][9] = int_stack + 3828;
 Libderiv->deriv_classes[2][9][9] = int_stack + 4098;
 Libderiv->deriv_classes[1][6][8] = int_stack + 4428;
 Libderiv->deriv_classes[1][7][8] = int_stack + 4512;
 Libderiv->deriv_classes[1][8][8] = int_stack + 4620;
 Libderiv->deriv_classes[1][9][8] = int_stack + 4755;
 Libderiv->deriv_classes[2][6][8] = int_stack + 4920;
 Libderiv->deriv_classes[2][7][8] = int_stack + 5088;
 Libderiv->deriv_classes[2][8][8] = int_stack + 5304;
 Libderiv->deriv_classes[2][9][8] = int_stack + 5574;
 Libderiv->deriv_classes[1][6][7] = int_stack + 5904;
 Libderiv->deriv_classes[1][7][7] = int_stack + 5988;
 Libderiv->deriv_classes[1][8][7] = int_stack + 6096;
 Libderiv->deriv_classes[1][9][7] = int_stack + 6231;
 Libderiv->deriv_classes[2][6][7] = int_stack + 6396;
 Libderiv->deriv_classes[2][7][7] = int_stack + 6564;
 Libderiv->deriv_classes[2][8][7] = int_stack + 6780;
 Libderiv->deriv_classes[2][9][7] = int_stack + 7050;
 Libderiv->deriv_classes[1][6][6] = int_stack + 7380;
 Libderiv->deriv_classes[1][7][6] = int_stack + 7464;
 Libderiv->deriv_classes[1][8][6] = int_stack + 7572;
 Libderiv->deriv_classes[1][9][6] = int_stack + 7707;
 Libderiv->dvrr_classes[2][6] = int_stack + 7872;
 Libderiv->deriv_classes[2][6][6] = int_stack + 8040;
 Libderiv->dvrr_classes[2][7] = int_stack + 8208;
 Libderiv->deriv_classes[2][7][6] = int_stack + 8424;
 Libderiv->dvrr_classes[2][8] = int_stack + 8640;
 Libderiv->deriv_classes[2][8][6] = int_stack + 8910;
 Libderiv->deriv_classes[2][9][6] = int_stack + 9180;
 Libderiv->deriv_classes[1][6][2] = int_stack + 9510;
 Libderiv->deriv_classes[1][7][2] = int_stack + 9594;
 Libderiv->deriv_classes[1][8][2] = int_stack + 9702;
 Libderiv->deriv_classes[1][9][2] = int_stack + 9837;
 Libderiv->deriv_classes[2][6][2] = int_stack + 10002;
 Libderiv->deriv_classes[2][7][2] = int_stack + 10170;
 Libderiv->deriv_classes[2][8][2] = int_stack + 10386;
 Libderiv->deriv_classes[2][9][2] = int_stack + 10656;
 Libderiv->deriv_classes[1][6][1] = int_stack + 10986;
 Libderiv->deriv_classes[1][7][1] = int_stack + 11070;
 Libderiv->deriv_classes[1][8][1] = int_stack + 11178;
 Libderiv->deriv_classes[1][9][1] = int_stack + 11313;
 Libderiv->deriv_classes[2][6][1] = int_stack + 11478;
 Libderiv->deriv_classes[2][7][1] = int_stack + 11646;
 Libderiv->deriv_classes[2][8][1] = int_stack + 11862;
 Libderiv->deriv_classes[2][9][1] = int_stack + 12132;
 Libderiv->dvrr_classes[1][6] = int_stack + 12462;
 Libderiv->dvrr_classes[1][7] = int_stack + 12546;
 Libderiv->dvrr_classes[1][8] = int_stack + 12654;
 Libderiv->dvrr_classes[1][9] = int_stack + 12789;
 Libderiv->deriv_classes[1][6][0] = int_stack + 12954;
 Libderiv->deriv_classes[1][7][0] = int_stack + 13038;
 Libderiv->deriv_classes[1][8][0] = int_stack + 13146;
 Libderiv->deriv_classes[1][9][0] = int_stack + 13281;
 Libderiv->deriv_classes[2][6][0] = int_stack + 13446;
 Libderiv->deriv_classes[2][7][0] = int_stack + 13614;
 Libderiv->deriv_classes[2][8][0] = int_stack + 13830;
 Libderiv->deriv_classes[2][9][0] = int_stack + 14100;
 memset(int_stack,0,115440);

 Libderiv->dvrr_stack = int_stack + 35235;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ppif(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+14430,int_stack+12546,int_stack+12462,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+14682,int_stack+12654,int_stack+12546,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+15006,int_stack+14682,int_stack+14430,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15510,int_stack+84,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12462,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15762,int_stack+192,int_stack+84, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12546,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16086,int_stack+15762,int_stack+15510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14430,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16590,int_stack+327,int_stack+192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12654,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16995,int_stack+16590,int_stack+15762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14682,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17643,int_stack+16995,int_stack+16086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15006,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+15510,int_stack+8208,int_stack+7872,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16014,int_stack+8640,int_stack+8208,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+18483,int_stack+16014,int_stack+15510,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16662,int_stack+660,int_stack+492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7872,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+876,int_stack+660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8208,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19491,int_stack+0,int_stack+16662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15510,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16662,int_stack+1146,int_stack+876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20499,int_stack+16662,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16014,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21795,int_stack+20499,int_stack+19491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18483,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19491,int_stack+1560,int_stack+1476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12462, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+19743,int_stack+1668,int_stack+1560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12546, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20067,int_stack+19743,int_stack+19491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14430, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+20571,int_stack+1803,int_stack+1668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12654, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20976,int_stack+20571,int_stack+19743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14682, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+20976,int_stack+20067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15006, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19491,int_stack+2136,int_stack+1968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7872, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+19995,int_stack+2352,int_stack+2136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8208, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20643,int_stack+19995,int_stack+19491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15510, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+840,int_stack+2622,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1650,int_stack+840,int_stack+19995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16014, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23475,int_stack+1650,int_stack+20643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840,int_stack+3036,int_stack+2952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12462, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1092,int_stack+3144,int_stack+3036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12546, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1416,int_stack+1092,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14430, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1920,int_stack+3279,int_stack+3144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12654, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2325,int_stack+1920,int_stack+1092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14682, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19491,int_stack+2325,int_stack+1416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15006, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840,int_stack+3612,int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7872, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1344,int_stack+3828,int_stack+3612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8208, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1992,int_stack+1344,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15510, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3000,int_stack+4098,int_stack+3828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20331,int_stack+3000,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16014, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+25155,int_stack+20331,int_stack+1992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20331,int_stack+4512,int_stack+4428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20583,int_stack+4620,int_stack+4512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20907,int_stack+20583,int_stack+20331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+840,int_stack+4755,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1245,int_stack+840,int_stack+20583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1893,int_stack+1245,int_stack+20907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840,int_stack+5088,int_stack+4920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20331,int_stack+5304,int_stack+5088, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2733,int_stack+20331,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+840,int_stack+5574,int_stack+5304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3741,int_stack+840,int_stack+20331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26835,int_stack+3741,int_stack+2733, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2733,int_stack+5988,int_stack+5904, 0.0, zero_stack, 1.0, int_stack+12462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2985,int_stack+6096,int_stack+5988, 0.0, zero_stack, 1.0, int_stack+12546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3309,int_stack+2985,int_stack+2733, 0.0, zero_stack, 1.0, int_stack+14430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3813,int_stack+6231,int_stack+6096, 0.0, zero_stack, 1.0, int_stack+12654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4218,int_stack+3813,int_stack+2985, 0.0, zero_stack, 1.0, int_stack+14682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4866,int_stack+4218,int_stack+3309, 0.0, zero_stack, 1.0, int_stack+15006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2733,int_stack+6564,int_stack+6396, 0.0, zero_stack, 1.0, int_stack+7872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3237,int_stack+6780,int_stack+6564, 0.0, zero_stack, 1.0, int_stack+8208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5706,int_stack+3237,int_stack+2733, 0.0, zero_stack, 1.0, int_stack+15510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3885,int_stack+7050,int_stack+6780, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20331,int_stack+3885,int_stack+3237, 0.0, zero_stack, 1.0, int_stack+16014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2733,int_stack+20331,int_stack+5706, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5706,int_stack+7464,int_stack+7380, 1.0, int_stack+12462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5958,int_stack+7572,int_stack+7464, 1.0, int_stack+12546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6282,int_stack+5958,int_stack+5706, 1.0, int_stack+14430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6786,int_stack+7707,int_stack+7572, 1.0, int_stack+12654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7191,int_stack+6786,int_stack+5958, 1.0, int_stack+14682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+20331,int_stack+7191,int_stack+6282, 1.0, int_stack+15006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5706,int_stack+8424,int_stack+8040, 1.0, int_stack+7872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6210,int_stack+8910,int_stack+8424, 1.0, int_stack+8208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6858,int_stack+6210,int_stack+5706, 1.0, int_stack+15510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+840,int_stack+9180,int_stack+8910, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7866,int_stack+840,int_stack+6210, 1.0, int_stack+16014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15510,int_stack+7866,int_stack+6858, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+18483,int_stack+12789,int_stack+12654,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+840,int_stack+18483,int_stack+14682,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+18483,int_stack+840,int_stack+15006,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+840,int_stack+9594,int_stack+9510,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1092,int_stack+9702,int_stack+9594,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5706,int_stack+1092,int_stack+840,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1416,int_stack+9837,int_stack+9702,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6210,int_stack+1416,int_stack+1092,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+840,int_stack+6210,int_stack+5706,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5706,int_stack+10170,int_stack+10002,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6210,int_stack+10386,int_stack+10170,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6858,int_stack+6210,int_stack+5706,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7866,int_stack+10656,int_stack+10386,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8676,int_stack+7866,int_stack+6210,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+28515,int_stack+8676,int_stack+6858,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5706,int_stack+11070,int_stack+10986,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5958,int_stack+11178,int_stack+11070,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6282,int_stack+5958,int_stack+5706,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6786,int_stack+11313,int_stack+11178,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7191,int_stack+6786,int_stack+5958,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7839,int_stack+7191,int_stack+6282,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5706,int_stack+11646,int_stack+11478,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6210,int_stack+11862,int_stack+11646,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8679,int_stack+6210,int_stack+5706,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6858,int_stack+12132,int_stack+11862,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9687,int_stack+6858,int_stack+6210,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5706,int_stack+9687,int_stack+8679,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8679,int_stack+13038,int_stack+12954,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8931,int_stack+13146,int_stack+13038,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9255,int_stack+8931,int_stack+8679,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9759,int_stack+13281,int_stack+13146,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10164,int_stack+9759,int_stack+8931,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+10812,int_stack+10164,int_stack+9255,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8679,int_stack+13614,int_stack+13446,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9183,int_stack+13830,int_stack+13614,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+11652,int_stack+9183,int_stack+8679,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9831,int_stack+14100,int_stack+13830,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+12660,int_stack+9831,int_stack+9183,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8679,int_stack+12660,int_stack+11652,6);
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+11652,int_stack+21795,int_stack+17643,280);
     Libderiv->ABCD[11] = int_stack + 11652;
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+30195,int_stack+23475,int_stack+0,280);
     Libderiv->ABCD[10] = int_stack + 30195;
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+21171,int_stack+25155,int_stack+19491,280);
     Libderiv->ABCD[9] = int_stack + 21171;
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+23691,int_stack+26835,int_stack+1893,280);
     Libderiv->ABCD[8] = int_stack + 23691;
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+32715,int_stack+2733,int_stack+4866,280);
     Libderiv->ABCD[7] = int_stack + 32715;
 /*--- compute (pp|if) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+1680,int_stack+15510,int_stack+20331,280);
     Libderiv->ABCD[6] = int_stack + 1680;
 /*--- compute (pp|if) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+14172,int_stack+28515,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[2] = int_stack + 14172;
 /*--- compute (pp|if) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+26211,int_stack+5706,int_stack+7839, 0.0, zero_stack, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[1] = int_stack + 26211;
 /*--- compute (pp|if) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+4200,int_stack+8679,int_stack+10812, 1.0, int_stack+18483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[0] = int_stack + 4200;

}
