/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ppih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (pp|ih) integrals */

void d1hrr_order_ppih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][6][11] = int_stack + 0;
 Libderiv->deriv_classes[1][7][11] = int_stack + 84;
 Libderiv->deriv_classes[1][8][11] = int_stack + 192;
 Libderiv->deriv_classes[1][9][11] = int_stack + 327;
 Libderiv->deriv_classes[1][10][11] = int_stack + 492;
 Libderiv->deriv_classes[1][11][11] = int_stack + 690;
 Libderiv->deriv_classes[2][6][11] = int_stack + 924;
 Libderiv->deriv_classes[2][7][11] = int_stack + 1092;
 Libderiv->deriv_classes[2][8][11] = int_stack + 1308;
 Libderiv->deriv_classes[2][9][11] = int_stack + 1578;
 Libderiv->deriv_classes[2][10][11] = int_stack + 1908;
 Libderiv->deriv_classes[2][11][11] = int_stack + 2304;
 Libderiv->deriv_classes[1][6][10] = int_stack + 2772;
 Libderiv->deriv_classes[1][7][10] = int_stack + 2856;
 Libderiv->deriv_classes[1][8][10] = int_stack + 2964;
 Libderiv->deriv_classes[1][9][10] = int_stack + 3099;
 Libderiv->deriv_classes[1][10][10] = int_stack + 3264;
 Libderiv->deriv_classes[1][11][10] = int_stack + 3462;
 Libderiv->deriv_classes[2][6][10] = int_stack + 3696;
 Libderiv->deriv_classes[2][7][10] = int_stack + 3864;
 Libderiv->deriv_classes[2][8][10] = int_stack + 4080;
 Libderiv->deriv_classes[2][9][10] = int_stack + 4350;
 Libderiv->deriv_classes[2][10][10] = int_stack + 4680;
 Libderiv->deriv_classes[2][11][10] = int_stack + 5076;
 Libderiv->deriv_classes[1][6][9] = int_stack + 5544;
 Libderiv->deriv_classes[1][7][9] = int_stack + 5628;
 Libderiv->deriv_classes[1][8][9] = int_stack + 5736;
 Libderiv->deriv_classes[1][9][9] = int_stack + 5871;
 Libderiv->deriv_classes[1][10][9] = int_stack + 6036;
 Libderiv->deriv_classes[1][11][9] = int_stack + 6234;
 Libderiv->deriv_classes[2][6][9] = int_stack + 6468;
 Libderiv->deriv_classes[2][7][9] = int_stack + 6636;
 Libderiv->deriv_classes[2][8][9] = int_stack + 6852;
 Libderiv->deriv_classes[2][9][9] = int_stack + 7122;
 Libderiv->deriv_classes[2][10][9] = int_stack + 7452;
 Libderiv->deriv_classes[2][11][9] = int_stack + 7848;
 Libderiv->deriv_classes[1][6][8] = int_stack + 8316;
 Libderiv->deriv_classes[1][7][8] = int_stack + 8400;
 Libderiv->deriv_classes[1][8][8] = int_stack + 8508;
 Libderiv->deriv_classes[1][9][8] = int_stack + 8643;
 Libderiv->deriv_classes[1][10][8] = int_stack + 8808;
 Libderiv->deriv_classes[1][11][8] = int_stack + 9006;
 Libderiv->deriv_classes[2][6][8] = int_stack + 9240;
 Libderiv->deriv_classes[2][7][8] = int_stack + 9408;
 Libderiv->deriv_classes[2][8][8] = int_stack + 9624;
 Libderiv->deriv_classes[2][9][8] = int_stack + 9894;
 Libderiv->deriv_classes[2][10][8] = int_stack + 10224;
 Libderiv->deriv_classes[2][11][8] = int_stack + 10620;
 Libderiv->deriv_classes[1][6][7] = int_stack + 11088;
 Libderiv->deriv_classes[1][7][7] = int_stack + 11172;
 Libderiv->deriv_classes[1][8][7] = int_stack + 11280;
 Libderiv->deriv_classes[1][9][7] = int_stack + 11415;
 Libderiv->deriv_classes[1][10][7] = int_stack + 11580;
 Libderiv->deriv_classes[1][11][7] = int_stack + 11778;
 Libderiv->deriv_classes[2][6][7] = int_stack + 12012;
 Libderiv->deriv_classes[2][7][7] = int_stack + 12180;
 Libderiv->deriv_classes[2][8][7] = int_stack + 12396;
 Libderiv->deriv_classes[2][9][7] = int_stack + 12666;
 Libderiv->deriv_classes[2][10][7] = int_stack + 12996;
 Libderiv->deriv_classes[2][11][7] = int_stack + 13392;
 Libderiv->deriv_classes[1][6][6] = int_stack + 13860;
 Libderiv->deriv_classes[1][7][6] = int_stack + 13944;
 Libderiv->deriv_classes[1][8][6] = int_stack + 14052;
 Libderiv->deriv_classes[1][9][6] = int_stack + 14187;
 Libderiv->deriv_classes[1][10][6] = int_stack + 14352;
 Libderiv->deriv_classes[1][11][6] = int_stack + 14550;
 Libderiv->dvrr_classes[2][6] = int_stack + 14784;
 Libderiv->deriv_classes[2][6][6] = int_stack + 14952;
 Libderiv->dvrr_classes[2][7] = int_stack + 15120;
 Libderiv->deriv_classes[2][7][6] = int_stack + 15336;
 Libderiv->dvrr_classes[2][8] = int_stack + 15552;
 Libderiv->deriv_classes[2][8][6] = int_stack + 15822;
 Libderiv->dvrr_classes[2][9] = int_stack + 16092;
 Libderiv->deriv_classes[2][9][6] = int_stack + 16422;
 Libderiv->dvrr_classes[2][10] = int_stack + 16752;
 Libderiv->deriv_classes[2][10][6] = int_stack + 17148;
 Libderiv->deriv_classes[2][11][6] = int_stack + 17544;
 Libderiv->deriv_classes[1][6][2] = int_stack + 18012;
 Libderiv->deriv_classes[1][7][2] = int_stack + 18096;
 Libderiv->deriv_classes[1][8][2] = int_stack + 18204;
 Libderiv->deriv_classes[1][9][2] = int_stack + 18339;
 Libderiv->deriv_classes[1][10][2] = int_stack + 18504;
 Libderiv->deriv_classes[1][11][2] = int_stack + 18702;
 Libderiv->deriv_classes[2][6][2] = int_stack + 18936;
 Libderiv->deriv_classes[2][7][2] = int_stack + 19104;
 Libderiv->deriv_classes[2][8][2] = int_stack + 19320;
 Libderiv->deriv_classes[2][9][2] = int_stack + 19590;
 Libderiv->deriv_classes[2][10][2] = int_stack + 19920;
 Libderiv->deriv_classes[2][11][2] = int_stack + 20316;
 Libderiv->deriv_classes[1][6][1] = int_stack + 20784;
 Libderiv->deriv_classes[1][7][1] = int_stack + 20868;
 Libderiv->deriv_classes[1][8][1] = int_stack + 20976;
 Libderiv->deriv_classes[1][9][1] = int_stack + 21111;
 Libderiv->deriv_classes[1][10][1] = int_stack + 21276;
 Libderiv->deriv_classes[1][11][1] = int_stack + 21474;
 Libderiv->deriv_classes[2][6][1] = int_stack + 21708;
 Libderiv->deriv_classes[2][7][1] = int_stack + 21876;
 Libderiv->deriv_classes[2][8][1] = int_stack + 22092;
 Libderiv->deriv_classes[2][9][1] = int_stack + 22362;
 Libderiv->deriv_classes[2][10][1] = int_stack + 22692;
 Libderiv->deriv_classes[2][11][1] = int_stack + 23088;
 Libderiv->dvrr_classes[1][6] = int_stack + 23556;
 Libderiv->dvrr_classes[1][7] = int_stack + 23640;
 Libderiv->dvrr_classes[1][8] = int_stack + 23748;
 Libderiv->dvrr_classes[1][9] = int_stack + 23883;
 Libderiv->dvrr_classes[1][10] = int_stack + 24048;
 Libderiv->dvrr_classes[1][11] = int_stack + 24246;
 Libderiv->deriv_classes[1][6][0] = int_stack + 24480;
 Libderiv->deriv_classes[1][7][0] = int_stack + 24564;
 Libderiv->deriv_classes[1][8][0] = int_stack + 24672;
 Libderiv->deriv_classes[1][9][0] = int_stack + 24807;
 Libderiv->deriv_classes[1][10][0] = int_stack + 24972;
 Libderiv->deriv_classes[1][11][0] = int_stack + 25170;
 Libderiv->deriv_classes[2][6][0] = int_stack + 25404;
 Libderiv->deriv_classes[2][7][0] = int_stack + 25572;
 Libderiv->deriv_classes[2][8][0] = int_stack + 25788;
 Libderiv->deriv_classes[2][9][0] = int_stack + 26058;
 Libderiv->deriv_classes[2][10][0] = int_stack + 26388;
 Libderiv->deriv_classes[2][11][0] = int_stack + 26784;
 memset(int_stack,0,218016);

 Libderiv->dvrr_stack = int_stack + 77829;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ppih(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+27252,int_stack+23640,int_stack+23556,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+27504,int_stack+23748,int_stack+23640,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+27828,int_stack+27504,int_stack+27252,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+28332,int_stack+23883,int_stack+23748,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+28737,int_stack+28332,int_stack+27504,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+29385,int_stack+28737,int_stack+27828,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+30225,int_stack+24048,int_stack+23883,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+30720,int_stack+30225,int_stack+28332,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+31530,int_stack+30720,int_stack+28737,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+32610,int_stack+31530,int_stack+29385,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33870,int_stack+84,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23556,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+34122,int_stack+192,int_stack+84, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23640,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34446,int_stack+34122,int_stack+33870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27252,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+34950,int_stack+327,int_stack+192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23748,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35355,int_stack+34950,int_stack+34122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27504,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+36003,int_stack+35355,int_stack+34446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27828,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+33870,int_stack+492,int_stack+327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23883,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+36843,int_stack+33870,int_stack+34950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28332,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+37653,int_stack+36843,int_stack+35355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28737,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+34365,int_stack+37653,int_stack+36003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29385,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+35625,int_stack+690,int_stack+492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24048,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+38733,int_stack+35625,int_stack+33870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30225,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+39723,int_stack+38733,int_stack+36843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30720,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+35625,int_stack+39723,int_stack+37653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31530,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+37245,int_stack+35625,int_stack+34365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32610,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+33870,int_stack+15120,int_stack+14784,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34374,int_stack+15552,int_stack+15120,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+35022,int_stack+34374,int_stack+33870,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+36030,int_stack+16092,int_stack+15552,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+39009,int_stack+36030,int_stack+34374,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+40305,int_stack+39009,int_stack+35022,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+41985,int_stack+16752,int_stack+16092,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+42975,int_stack+41985,int_stack+36030,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+44595,int_stack+42975,int_stack+39009,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+46755,int_stack+44595,int_stack+40305,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49275,int_stack+1092,int_stack+924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14784,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+1308,int_stack+1092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+49779,int_stack+0,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33870,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50787,int_stack+1578,int_stack+1308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15552,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51597,int_stack+50787,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34374,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+52893,int_stack+51597,int_stack+49779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35022,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+1908,int_stack+1578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16092,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+54573,int_stack+0,int_stack+50787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36030,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49275,int_stack+54573,int_stack+51597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39009,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+56193,int_stack+49275,int_stack+52893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40305,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+51435,int_stack+2304,int_stack+1908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16752,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+58713,int_stack+51435,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41985,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+58713,int_stack+54573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42975,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+51435,int_stack+0,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44595,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+58713,int_stack+51435,int_stack+56193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46755,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49275,int_stack+2856,int_stack+2772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23556, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+49527,int_stack+2964,int_stack+2856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23640, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+49851,int_stack+49527,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27252, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36840,int_stack+3099,int_stack+2964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23748, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+50355,int_stack+36840,int_stack+49527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27504, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+51003,int_stack+50355,int_stack+49851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27828, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+49275,int_stack+3264,int_stack+3099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23883, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51843,int_stack+49275,int_stack+36840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28332, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+52653,int_stack+51843,int_stack+50355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28737, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+53733,int_stack+52653,int_stack+51003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29385, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+49770,int_stack+3462,int_stack+3264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24048, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+50364,int_stack+49770,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30225, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+54993,int_stack+50364,int_stack+51843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30720, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+49275,int_stack+54993,int_stack+52653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31530, 0.0, zero_stack,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+54993,int_stack+49275,int_stack+53733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32610, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49275,int_stack+3864,int_stack+3696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14784, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+49779,int_stack+4080,int_stack+3864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50427,int_stack+49779,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33870, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+51435,int_stack+4350,int_stack+4080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15552, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+52245,int_stack+51435,int_stack+49779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34374, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+56757,int_stack+52245,int_stack+50427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35022, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+49275,int_stack+4680,int_stack+4350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16092, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+49275,int_stack+51435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36030, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1620,int_stack+0,int_stack+52245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39009, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+50265,int_stack+1620,int_stack+56757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40305, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+56757,int_stack+5076,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16752, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+52785,int_stack+56757,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41985, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+62241,int_stack+52785,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42975, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+64941,int_stack+62241,int_stack+1620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44595, 0.0, zero_stack,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+0,int_stack+64941,int_stack+50265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46755, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62241,int_stack+5628,int_stack+5544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23556, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62493,int_stack+5736,int_stack+5628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23640, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+62817,int_stack+62493,int_stack+62241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27252, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36840,int_stack+5871,int_stack+5736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23748, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+63321,int_stack+36840,int_stack+62493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27504, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+63969,int_stack+63321,int_stack+62817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27828, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+62241,int_stack+6036,int_stack+5871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23883, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+64809,int_stack+62241,int_stack+36840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28332, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65619,int_stack+64809,int_stack+63321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28737, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+66699,int_stack+65619,int_stack+63969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29385, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+62736,int_stack+6234,int_stack+6036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24048, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+63330,int_stack+62736,int_stack+62241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30225, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3528,int_stack+63330,int_stack+64809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30720, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+62241,int_stack+3528,int_stack+65619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31530, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3528,int_stack+62241,int_stack+66699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32610, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62241,int_stack+6636,int_stack+6468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14784, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62745,int_stack+6852,int_stack+6636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+63393,int_stack+62745,int_stack+62241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33870, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+64401,int_stack+7122,int_stack+6852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15552, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65211,int_stack+64401,int_stack+62745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34374, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+66507,int_stack+65211,int_stack+63393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35022, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+62241,int_stack+7452,int_stack+7122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16092, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5292,int_stack+62241,int_stack+64401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36030, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49275,int_stack+5292,int_stack+65211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39009, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+63231,int_stack+49275,int_stack+66507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40305, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+65751,int_stack+7848,int_stack+7452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16752, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+66939,int_stack+65751,int_stack+62241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41985, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+51435,int_stack+66939,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42975, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+65751,int_stack+51435,int_stack+49275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44595, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+49275,int_stack+65751,int_stack+63231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46755, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52803,int_stack+8400,int_stack+8316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+53055,int_stack+8508,int_stack+8400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+53379,int_stack+53055,int_stack+52803, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36840,int_stack+8643,int_stack+8508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53883,int_stack+36840,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5292,int_stack+53883,int_stack+53379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+52803,int_stack+8808,int_stack+8643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6132,int_stack+52803,int_stack+36840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6942,int_stack+6132,int_stack+53883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+53298,int_stack+6942,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+5292,int_stack+9006,int_stack+8808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+8022,int_stack+5292,int_stack+52803, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+62241,int_stack+8022,int_stack+6132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+5292,int_stack+62241,int_stack+6942, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+62241,int_stack+5292,int_stack+53298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+9408,int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+9624,int_stack+9408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6444,int_stack+5796,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7452,int_stack+9894,int_stack+9624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8262,int_stack+7452,int_stack+5796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+64005,int_stack+8262,int_stack+6444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5292,int_stack+10224,int_stack+9894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+65685,int_stack+5292,int_stack+7452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+52803,int_stack+65685,int_stack+8262, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6282,int_stack+52803,int_stack+64005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+64005,int_stack+10620,int_stack+10224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+8802,int_stack+64005,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+67305,int_stack+8802,int_stack+65685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+64005,int_stack+67305,int_stack+52803, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+67245,int_stack+64005,int_stack+6282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64005,int_stack+11172,int_stack+11088, 0.0, zero_stack, 1.0, int_stack+23556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+64257,int_stack+11280,int_stack+11172, 0.0, zero_stack, 1.0, int_stack+23640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+64581,int_stack+64257,int_stack+64005, 0.0, zero_stack, 1.0, int_stack+27252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36840,int_stack+11415,int_stack+11280, 0.0, zero_stack, 1.0, int_stack+23748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65085,int_stack+36840,int_stack+64257, 0.0, zero_stack, 1.0, int_stack+27504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+65733,int_stack+65085,int_stack+64581, 0.0, zero_stack, 1.0, int_stack+27828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+64005,int_stack+11580,int_stack+11415, 0.0, zero_stack, 1.0, int_stack+23883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+52803,int_stack+64005,int_stack+36840, 0.0, zero_stack, 1.0, int_stack+28332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+53613,int_stack+52803,int_stack+65085, 0.0, zero_stack, 1.0, int_stack+28737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5292,int_stack+53613,int_stack+65733, 0.0, zero_stack, 1.0, int_stack+29385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+64500,int_stack+11778,int_stack+11580, 0.0, zero_stack, 1.0, int_stack+24048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+65094,int_stack+64500,int_stack+64005, 0.0, zero_stack, 1.0, int_stack+30225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+6552,int_stack+65094,int_stack+52803, 0.0, zero_stack, 1.0, int_stack+30720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+64005,int_stack+6552,int_stack+53613, 0.0, zero_stack, 1.0, int_stack+31530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+6552,int_stack+64005,int_stack+5292, 0.0, zero_stack, 1.0, int_stack+32610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+12180,int_stack+12012, 0.0, zero_stack, 1.0, int_stack+14784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+12396,int_stack+12180, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+64005,int_stack+5796,int_stack+5292, 0.0, zero_stack, 1.0, int_stack+33870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+65013,int_stack+12666,int_stack+12396, 0.0, zero_stack, 1.0, int_stack+15552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65823,int_stack+65013,int_stack+5796, 0.0, zero_stack, 1.0, int_stack+34374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8316,int_stack+65823,int_stack+64005, 0.0, zero_stack, 1.0, int_stack+35022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+64005,int_stack+12996,int_stack+12666, 0.0, zero_stack, 1.0, int_stack+16092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9996,int_stack+64005,int_stack+65013, 0.0, zero_stack, 1.0, int_stack+36030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+52803,int_stack+9996,int_stack+65823, 0.0, zero_stack, 1.0, int_stack+39009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+70773,int_stack+52803,int_stack+8316, 0.0, zero_stack, 1.0, int_stack+40305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+8316,int_stack+13392,int_stack+12996, 0.0, zero_stack, 1.0, int_stack+16752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+64995,int_stack+8316,int_stack+64005, 0.0, zero_stack, 1.0, int_stack+41985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+73293,int_stack+64995,int_stack+9996, 0.0, zero_stack, 1.0, int_stack+42975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+64005,int_stack+73293,int_stack+52803, 0.0, zero_stack, 1.0, int_stack+44595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+8316,int_stack+64005,int_stack+70773, 0.0, zero_stack, 1.0, int_stack+46755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70773,int_stack+13944,int_stack+13860, 1.0, int_stack+23556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+71025,int_stack+14052,int_stack+13944, 1.0, int_stack+23640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+71349,int_stack+71025,int_stack+70773, 1.0, int_stack+27252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36840,int_stack+14187,int_stack+14052, 1.0, int_stack+23748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+71853,int_stack+36840,int_stack+71025, 1.0, int_stack+27504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+72501,int_stack+71853,int_stack+71349, 1.0, int_stack+27828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+27252,int_stack+14352,int_stack+14187, 1.0, int_stack+23883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+70773,int_stack+27252,int_stack+36840, 1.0, int_stack+28332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+73341,int_stack+70773,int_stack+71853, 1.0, int_stack+28737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5292,int_stack+73341,int_stack+72501, 1.0, int_stack+29385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+27747,int_stack+14550,int_stack+14352, 1.0, int_stack+24048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+28341,int_stack+27747,int_stack+27252, 1.0, int_stack+30225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+71583,int_stack+28341,int_stack+70773, 1.0, int_stack+30720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+27252,int_stack+71583,int_stack+73341, 1.0, int_stack+31530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+70773,int_stack+27252,int_stack+5292, 1.0, int_stack+32610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+15336,int_stack+14952, 1.0, int_stack+14784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+15822,int_stack+15336, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27252,int_stack+5796,int_stack+5292, 1.0, int_stack+33870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28260,int_stack+16422,int_stack+15822, 1.0, int_stack+15552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+72537,int_stack+28260,int_stack+5796, 1.0, int_stack+34374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+73833,int_stack+72537,int_stack+27252, 1.0, int_stack+35022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+27252,int_stack+17148,int_stack+16422, 1.0, int_stack+16092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+33870,int_stack+27252,int_stack+28260, 1.0, int_stack+36030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+64005,int_stack+33870,int_stack+72537, 1.0, int_stack+39009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11844,int_stack+64005,int_stack+73833, 1.0, int_stack+40305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39009,int_stack+17544,int_stack+17148, 1.0, int_stack+16752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+72537,int_stack+39009,int_stack+27252, 1.0, int_stack+41985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+27252,int_stack+72537,int_stack+33870, 1.0, int_stack+42975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+33870,int_stack+27252,int_stack+64005, 1.0, int_stack+44595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39009,int_stack+33870,int_stack+11844, 1.0, int_stack+46755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+11844,int_stack+24246,int_stack+24048,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+12438,int_stack+11844,int_stack+30225,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+13428,int_stack+12438,int_stack+30720,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+14778,int_stack+13428,int_stack+31530,3);
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+11844,int_stack+14778,int_stack+32610,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13608,int_stack+18096,int_stack+18012,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13860,int_stack+18204,int_stack+18096,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14184,int_stack+13860,int_stack+13608,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+14688,int_stack+18339,int_stack+18204,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15093,int_stack+14688,int_stack+13860,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+15741,int_stack+15093,int_stack+14184,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13608,int_stack+18504,int_stack+18339,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+16581,int_stack+13608,int_stack+14688,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+17391,int_stack+16581,int_stack+15093,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5292,int_stack+17391,int_stack+15741,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+14103,int_stack+18702,int_stack+18504,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+14697,int_stack+14103,int_stack+13608,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+64005,int_stack+14697,int_stack+16581,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+13608,int_stack+64005,int_stack+17391,3);
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+64005,int_stack+13608,int_stack+5292,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+19104,int_stack+18936,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+19320,int_stack+19104,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13608,int_stack+5796,int_stack+5292,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+14616,int_stack+19590,int_stack+19320,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15426,int_stack+14616,int_stack+5796,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+16722,int_stack+15426,int_stack+13608,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13608,int_stack+19920,int_stack+19590,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+27252,int_stack+13608,int_stack+14616,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+28872,int_stack+27252,int_stack+15426,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+31032,int_stack+28872,int_stack+16722,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+14598,int_stack+20316,int_stack+19920,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+15786,int_stack+14598,int_stack+13608,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+17766,int_stack+15786,int_stack+27252,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+13608,int_stack+17766,int_stack+28872,6);
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+27252,int_stack+13608,int_stack+31032,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13608,int_stack+20868,int_stack+20784,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13860,int_stack+20976,int_stack+20868,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14184,int_stack+13860,int_stack+13608,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+14688,int_stack+21111,int_stack+20976,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15093,int_stack+14688,int_stack+13860,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+15741,int_stack+15093,int_stack+14184,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13608,int_stack+21276,int_stack+21111,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+16581,int_stack+13608,int_stack+14688,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+17391,int_stack+16581,int_stack+15093,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5292,int_stack+17391,int_stack+15741,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+14103,int_stack+21474,int_stack+21276,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+14697,int_stack+14103,int_stack+13608,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+18471,int_stack+14697,int_stack+16581,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+13608,int_stack+18471,int_stack+17391,3);
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+15228,int_stack+13608,int_stack+5292,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+21876,int_stack+21708,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+22092,int_stack+21876,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13608,int_stack+5796,int_stack+5292,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+16992,int_stack+22362,int_stack+22092,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+17802,int_stack+16992,int_stack+5796,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+19098,int_stack+17802,int_stack+13608,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13608,int_stack+22692,int_stack+22362,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+20778,int_stack+13608,int_stack+16992,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+30780,int_stack+20778,int_stack+17802,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+32940,int_stack+30780,int_stack+19098,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+16992,int_stack+23088,int_stack+22692,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+18180,int_stack+16992,int_stack+13608,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+72537,int_stack+18180,int_stack+20778,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+16992,int_stack+72537,int_stack+30780,6);
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+20232,int_stack+16992,int_stack+32940,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+16992,int_stack+24564,int_stack+24480,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+17244,int_stack+24672,int_stack+24564,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+17568,int_stack+17244,int_stack+16992,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+18072,int_stack+24807,int_stack+24672,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+18477,int_stack+18072,int_stack+17244,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+19125,int_stack+18477,int_stack+17568,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+16992,int_stack+24972,int_stack+24807,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+30780,int_stack+16992,int_stack+18072,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+31590,int_stack+30780,int_stack+18477,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5292,int_stack+31590,int_stack+19125,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+17487,int_stack+25170,int_stack+24972,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+18081,int_stack+17487,int_stack+16992,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+32670,int_stack+18081,int_stack+30780,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+13608,int_stack+32670,int_stack+31590,3);
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+30780,int_stack+13608,int_stack+5292,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5292,int_stack+25572,int_stack+25404,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+25788,int_stack+25572,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13608,int_stack+5796,int_stack+5292,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+32544,int_stack+26058,int_stack+25788,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+33354,int_stack+32544,int_stack+5796,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+34650,int_stack+33354,int_stack+13608,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13608,int_stack+26388,int_stack+26058,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+16992,int_stack+13608,int_stack+32544,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+72537,int_stack+16992,int_stack+33354,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+23760,int_stack+72537,int_stack+34650,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+32544,int_stack+26784,int_stack+26388,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+33732,int_stack+32544,int_stack+13608,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+42537,int_stack+33732,int_stack+16992,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+16992,int_stack+42537,int_stack+72537,6);
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+42537,int_stack+16992,int_stack+23760,6);
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+72537,int_stack+58713,int_stack+37245,588);
     Libderiv->ABCD[11] = int_stack + 72537;
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+32544,int_stack+0,int_stack+54993,588);
     Libderiv->ABCD[10] = int_stack + 32544;
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+52803,int_stack+49275,int_stack+3528,588);
     Libderiv->ABCD[9] = int_stack + 52803;
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+0,int_stack+67245,int_stack+62241,588);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+46065,int_stack+8316,int_stack+6552,588);
     Libderiv->ABCD[7] = int_stack + 46065;
 /*--- compute (pp|ih) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+5292,int_stack+39009,int_stack+70773,588);
     Libderiv->ABCD[6] = int_stack + 5292;
 /*--- compute (pp|ih) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+65769,int_stack+27252,int_stack+64005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 65769;
 /*--- compute (pp|ih) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+23760,int_stack+20232,int_stack+15228, 0.0, zero_stack, 1.0, int_stack+11844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 23760;
 /*--- compute (pp|ih) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+13608,int_stack+42537,int_stack+30780, 1.0, int_stack+11844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 13608;

}
