/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0fd(Libr12_t *, prim_data *);

  /* Computes (d0|fd) integrals for linear R12-methods */

void hrr_grt_order_d0fd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][3] = int_stack + 0;
 Libr12->t2vrr_classes[2][3] = int_stack + 100;
 Libr12->gvrr_classes[3][4] = int_stack + 160;
 Libr12->t2vrr_classes[2][4] = int_stack + 310;
 Libr12->t2vrr_classes[2][5] = int_stack + 400;
 Libr12->t1vrr_classes[2][3] = int_stack + 526;
 Libr12->t1vrr_classes[2][4] = int_stack + 586;
 Libr12->t1vrr_classes[2][5] = int_stack + 676;
 Libr12->rvrr_classes[2][3] = int_stack + 802;
 Libr12->rvrr_classes[2][4] = int_stack + 862;
 Libr12->rvrr_classes[2][5] = int_stack + 952;
 Libr12->gvrr_classes[2][3] = int_stack + 1078;
 Libr12->gvrr_classes[2][4] = int_stack + 1138;
 Libr12->gvrr_classes[2][5] = int_stack + 1228;
 memset(int_stack,0,1354*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1354;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0fd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1354, int_stack+1138, int_stack+1078, 6);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1534, int_stack+160, int_stack+0, 10);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1834, int_stack+1228, int_stack+1138, 6);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2104, int_stack+310, int_stack+100, int_stack+1138, int_stack+0, int_stack+1078, 2, 0);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2284, int_stack+400, int_stack+310, int_stack+1228, int_stack+160, int_stack+1138, 2, 0);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1078, int_stack+586, int_stack+526, 6);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+676, int_stack+586, 6);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+270, int_stack+862, int_stack+802, 6);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+952, int_stack+862, 6);
 /*--- compute (d0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2554, int_stack+2284, int_stack+2104, int_stack+1834, int_stack+1534, int_stack+1354, 2, 0);
     Libr12->te_ptr[3] = int_stack + 2554;
 /*--- compute (d0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2104, int_stack+0, int_stack+1078, 6);
     Libr12->te_ptr[2] = int_stack + 2104;
 /*--- compute (d0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+720, int_stack+450, int_stack+270, 6);
     Libr12->te_ptr[1] = int_stack + 720;
 /*--- compute (d0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1834, int_stack+1354, 6);
     Libr12->te_ptr[0] = int_stack + 0;

}
