/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddgg(Libr12_t *, prim_data *);

  /* Computes (dd|gg) integrals for linear R12-methods */

void hrr_grt_order_ddgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 90;
 Libr12->t2vrr_classes[2][6] = int_stack + 216;
 Libr12->t2vrr_classes[2][7] = int_stack + 384;
 Libr12->t2vrr_classes[2][8] = int_stack + 600;
 Libr12->t2vrr_classes[3][4] = int_stack + 870;
 Libr12->t2vrr_classes[3][5] = int_stack + 1020;
 Libr12->t2vrr_classes[3][6] = int_stack + 1230;
 Libr12->t2vrr_classes[3][7] = int_stack + 1510;
 Libr12->t2vrr_classes[3][8] = int_stack + 1870;
 Libr12->gvrr_classes[5][4] = int_stack + 2320;
 Libr12->t2vrr_classes[4][4] = int_stack + 2635;
 Libr12->gvrr_classes[5][5] = int_stack + 2860;
 Libr12->t2vrr_classes[4][5] = int_stack + 3301;
 Libr12->gvrr_classes[5][6] = int_stack + 3616;
 Libr12->t2vrr_classes[4][6] = int_stack + 4204;
 Libr12->gvrr_classes[5][7] = int_stack + 4624;
 Libr12->t2vrr_classes[4][7] = int_stack + 5380;
 Libr12->t2vrr_classes[4][8] = int_stack + 5920;
 Libr12->gvrr_classes[2][9] = int_stack + 6595;
 Libr12->t1vrr_classes[2][4] = int_stack + 6925;
 Libr12->t1vrr_classes[2][5] = int_stack + 7015;
 Libr12->t1vrr_classes[2][6] = int_stack + 7141;
 Libr12->t1vrr_classes[2][7] = int_stack + 7309;
 Libr12->t1vrr_classes[2][8] = int_stack + 7525;
 Libr12->gvrr_classes[3][9] = int_stack + 7795;
 Libr12->t1vrr_classes[3][4] = int_stack + 8345;
 Libr12->t1vrr_classes[3][5] = int_stack + 8495;
 Libr12->t1vrr_classes[3][6] = int_stack + 8705;
 Libr12->t1vrr_classes[3][7] = int_stack + 8985;
 Libr12->t1vrr_classes[3][8] = int_stack + 9345;
 Libr12->t1vrr_classes[4][4] = int_stack + 9795;
 Libr12->t1vrr_classes[4][5] = int_stack + 10020;
 Libr12->t1vrr_classes[4][6] = int_stack + 10335;
 Libr12->t1vrr_classes[4][7] = int_stack + 10755;
 Libr12->t1vrr_classes[4][8] = int_stack + 11295;
 Libr12->rvrr_classes[2][4] = int_stack + 11970;
 Libr12->rvrr_classes[2][5] = int_stack + 12060;
 Libr12->rvrr_classes[2][6] = int_stack + 12186;
 Libr12->rvrr_classes[2][7] = int_stack + 12354;
 Libr12->rvrr_classes[2][8] = int_stack + 12570;
 Libr12->rvrr_classes[3][4] = int_stack + 12840;
 Libr12->rvrr_classes[3][5] = int_stack + 12990;
 Libr12->rvrr_classes[3][6] = int_stack + 13200;
 Libr12->rvrr_classes[3][7] = int_stack + 13480;
 Libr12->rvrr_classes[3][8] = int_stack + 13840;
 Libr12->rvrr_classes[4][4] = int_stack + 14290;
 Libr12->rvrr_classes[4][5] = int_stack + 14515;
 Libr12->rvrr_classes[4][6] = int_stack + 14830;
 Libr12->rvrr_classes[4][7] = int_stack + 15250;
 Libr12->rvrr_classes[4][8] = int_stack + 15790;
 Libr12->gvrr_classes[2][4] = int_stack + 16465;
 Libr12->gvrr_classes[2][5] = int_stack + 16555;
 Libr12->gvrr_classes[2][6] = int_stack + 16681;
 Libr12->gvrr_classes[2][7] = int_stack + 16849;
 Libr12->gvrr_classes[2][8] = int_stack + 17065;
 Libr12->gvrr_classes[3][4] = int_stack + 17335;
 Libr12->gvrr_classes[3][5] = int_stack + 17485;
 Libr12->gvrr_classes[3][6] = int_stack + 17695;
 Libr12->gvrr_classes[3][7] = int_stack + 17975;
 Libr12->gvrr_classes[3][8] = int_stack + 18335;
 Libr12->gvrr_classes[4][4] = int_stack + 18785;
 Libr12->gvrr_classes[4][5] = int_stack + 19010;
 Libr12->gvrr_classes[4][6] = int_stack + 19325;
 Libr12->gvrr_classes[4][7] = int_stack + 19745;
 Libr12->gvrr_classes[4][8] = int_stack + 20285;
 memset(int_stack,0,20960*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 20960;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddgg(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+20960, int_stack+16555, int_stack+16465, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21230, int_stack+16681, int_stack+16555, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+21608, int_stack+21230, int_stack+20960, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+22148, int_stack+16849, int_stack+16681, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22652, int_stack+22148, int_stack+21230, 6);
 /*--- compute (d0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+23408, int_stack+22652, int_stack+21608, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24308, int_stack+17485, int_stack+17335, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24758, int_stack+17695, int_stack+17485, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+25388, int_stack+24758, int_stack+24308, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+26288, int_stack+17975, int_stack+17695, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+27128, int_stack+26288, int_stack+24758, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+28388, int_stack+27128, int_stack+25388, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+29888, int_stack+17065, int_stack+16849, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+30536, int_stack+29888, int_stack+22148, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+31544, int_stack+30536, int_stack+22652, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32804, int_stack+90, int_stack+0, int_stack+16555, int_stack+17335, int_stack+16465, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33074, int_stack+216, int_stack+90, int_stack+16681, int_stack+17485, int_stack+16555, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33452, int_stack+33074, int_stack+32804, int_stack+21230, int_stack+24308, int_stack+20960, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33992, int_stack+384, int_stack+216, int_stack+16849, int_stack+17695, int_stack+16681, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34496, int_stack+33992, int_stack+33074, int_stack+22148, int_stack+24758, int_stack+21230, 2, 0);
 /*--- compute (d0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35252, int_stack+34496, int_stack+33452, int_stack+22652, int_stack+25388, int_stack+21608, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20960, int_stack+600, int_stack+384, int_stack+17065, int_stack+17975, int_stack+16849, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32804, int_stack+20960, int_stack+33992, int_stack+29888, int_stack+26288, int_stack+22148, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20960, int_stack+32804, int_stack+34496, int_stack+30536, int_stack+27128, int_stack+22652, 2, 0);
 /*--- compute (d0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32804, int_stack+20960, int_stack+35252, int_stack+31544, int_stack+28388, int_stack+23408, 2, 0);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+20960, int_stack+19010, int_stack+18785, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21635, int_stack+19325, int_stack+19010, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+34154, int_stack+21635, int_stack+20960, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+35504, int_stack+19745, int_stack+19325, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+36764, int_stack+35504, int_stack+21635, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+38654, int_stack+36764, int_stack+34154, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+40904, int_stack+18335, int_stack+17975, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+41984, int_stack+40904, int_stack+26288, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+43664, int_stack+41984, int_stack+27128, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22580, int_stack+1020, int_stack+870, int_stack+17485, int_stack+18785, int_stack+17335, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1230, int_stack+1020, int_stack+17695, int_stack+19010, int_stack+17485, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+45764, int_stack+0, int_stack+22580, int_stack+24758, int_stack+20960, int_stack+24308, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46664, int_stack+1510, int_stack+1230, int_stack+17975, int_stack+19325, int_stack+17695, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+47504, int_stack+46664, int_stack+0, int_stack+26288, int_stack+21635, int_stack+24758, 3, 0);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+47504, int_stack+45764, int_stack+27128, int_stack+34154, int_stack+25388, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24308, int_stack+1870, int_stack+1510, int_stack+18335, int_stack+19745, int_stack+17975, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+48764, int_stack+24308, int_stack+46664, int_stack+40904, int_stack+35504, int_stack+26288, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24308, int_stack+48764, int_stack+47504, int_stack+41984, int_stack+36764, int_stack+27128, 3, 0);
 /*--- compute (f0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+45764, int_stack+24308, int_stack+0, int_stack+43664, int_stack+38654, int_stack+28388, 3, 0);
 /*--- compute (dp|[r12,T2]|gg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+24308, int_stack+45764, int_stack+32804, 225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+32804, int_stack+2860, int_stack+2320, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3616, int_stack+2860, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+48014, int_stack+0, int_stack+32804, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+49904, int_stack+4624, int_stack+3616, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+51668, int_stack+49904, int_stack+0, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+54314, int_stack+51668, int_stack+48014, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+57464, int_stack+20285, int_stack+19745, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+59084, int_stack+57464, int_stack+35504, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+61604, int_stack+59084, int_stack+36764, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1323, int_stack+3301, int_stack+2635, int_stack+19010, int_stack+2320, int_stack+18785, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17335, int_stack+4204, int_stack+3301, int_stack+19325, int_stack+2860, int_stack+19010, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1998, int_stack+17335, int_stack+1323, int_stack+21635, int_stack+32804, int_stack+20960, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32804, int_stack+5380, int_stack+4204, int_stack+19745, int_stack+3616, int_stack+19325, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64754, int_stack+32804, int_stack+17335, int_stack+35504, int_stack+0, int_stack+21635, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20960, int_stack+64754, int_stack+1998, int_stack+36764, int_stack+48014, int_stack+34154, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+48014, int_stack+5920, int_stack+5380, int_stack+20285, int_stack+4624, int_stack+19745, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+48014, int_stack+32804, int_stack+57464, int_stack+49904, int_stack+35504, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32804, int_stack+0, int_stack+64754, int_stack+59084, int_stack+51668, int_stack+36764, 4, 0);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+32804, int_stack+20960, int_stack+61604, int_stack+54314, int_stack+38654, 4, 0);
 /*--- compute (fp|[r12,T2]|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+48014, int_stack+0, int_stack+45764, 225);
 /*--- compute (d0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+45764, int_stack+31544, int_stack+23408, 6);
 /*--- compute (f0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+43664, int_stack+28388, 10);
 /*--- compute (dp|gg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+2250, int_stack+0, int_stack+45764, 225);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+47114, int_stack+6595, int_stack+17065, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+32804, int_stack+47114, int_stack+29888, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+34100, int_stack+32804, int_stack+30536, 6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+35780, int_stack+34100, int_stack+31544, 6);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+64754, int_stack+7795, int_stack+18335, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+54764, int_stack+64754, int_stack+40904, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+56924, int_stack+54764, int_stack+41984, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+28358, int_stack+56924, int_stack+43664, 10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+54764, int_stack+28358, int_stack+35780, 315);
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+40904, int_stack+61604, int_stack+38654, 15);
 /*--- compute (fp|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+16465, int_stack+40904, int_stack+0, 225);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+7015, int_stack+6925, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+60704, int_stack+7141, int_stack+7015, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+61082, int_stack+60704, int_stack+60434, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+61622, int_stack+7309, int_stack+7141, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+62126, int_stack+61622, int_stack+60704, 6);
 /*--- compute (d0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+47114, int_stack+62126, int_stack+61082, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+7525, int_stack+7309, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+62882, int_stack+60434, int_stack+61622, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+62882, int_stack+62126, 6);
 /*--- compute (d0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+61694, int_stack+60434, int_stack+47114, 6);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+47114, int_stack+8495, int_stack+8345, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+8705, int_stack+8495, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+63044, int_stack+60434, int_stack+47114, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+47114, int_stack+8985, int_stack+8705, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+63944, int_stack+47114, int_stack+60434, 10);
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+65204, int_stack+63944, int_stack+63044, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+9345, int_stack+8985, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+6300, int_stack+60434, int_stack+47114, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+37670, int_stack+6300, int_stack+63944, 10);
 /*--- compute (f0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+6300, int_stack+37670, int_stack+65204, 10);
 /*--- compute (dp|[r12,T1]|gg) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+31508, int_stack+6300, int_stack+61694, int_stack+0, int_stack+35780, int_stack+45764, 4, 4);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8550, int_stack+10020, int_stack+9795, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+10335, int_stack+10020, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+61379, int_stack+60434, int_stack+8550, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+8550, int_stack+10755, int_stack+10335, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+62729, int_stack+8550, int_stack+60434, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+64619, int_stack+62729, int_stack+61379, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+60434, int_stack+11295, int_stack+10755, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+44279, int_stack+60434, int_stack+8550, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+8550, int_stack+44279, int_stack+62729, 15);
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+44279, int_stack+8550, int_stack+64619, 15);
 /*--- compute (fp|[r12,T1]|gg) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+60434, int_stack+44279, int_stack+6300, int_stack+40904, int_stack+28358, int_stack+0, 4, 4);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+12060, int_stack+11970, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+270, int_stack+12186, int_stack+12060, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+648, int_stack+270, int_stack+0, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1188, int_stack+12354, int_stack+12186, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+28358, int_stack+1188, int_stack+270, 6);
 /*--- compute (d0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+29114, int_stack+28358, int_stack+648, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+12570, int_stack+12354, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+30014, int_stack+0, int_stack+1188, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+30014, int_stack+28358, 6);
 /*--- compute (d0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+30014, int_stack+0, int_stack+29114, 6);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+12990, int_stack+12840, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+13200, int_stack+12990, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1080, int_stack+450, int_stack+0, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+28358, int_stack+13480, int_stack+13200, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6300, int_stack+28358, int_stack+450, 10);
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+7560, int_stack+6300, int_stack+1080, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+13840, int_stack+13480, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+9060, int_stack+0, int_stack+28358, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9060, int_stack+6300, 10);
 /*--- compute (f0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+9060, int_stack+0, int_stack+7560, 10);
 /*--- compute (dp||gg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+35558, int_stack+9060, int_stack+30014, 225);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+14515, int_stack+14290, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+675, int_stack+14830, int_stack+14515, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6300, int_stack+675, int_stack+0, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7650, int_stack+15250, int_stack+14830, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11310, int_stack+7650, int_stack+675, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11310, int_stack+6300, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13200, int_stack+15790, int_stack+15250, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+28358, int_stack+13200, int_stack+7650, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+13200, int_stack+28358, int_stack+11310, 15);
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+39608, int_stack+13200, int_stack+0, 15);
 /*--- compute (fp||gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+67184, int_stack+39608, int_stack+9060, 225);
 /*--- compute (dd|[r12,T2]|gg) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+39608, int_stack+48014, int_stack+24308, 225);
     Libr12->te_ptr[3] = int_stack + 39608;
 /*--- compute (dd|[r12,T1]|gg) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+6300, int_stack+60434, int_stack+31508, int_stack+16465, int_stack+54764, int_stack+2250, 4, 4);
     Libr12->te_ptr[2] = int_stack + 6300;
 /*--- compute (dd||gg) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+47708, int_stack+67184, int_stack+35558, 225);
     Libr12->te_ptr[1] = int_stack + 47708;
 /*--- compute (dd|gg) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+55808, int_stack+16465, int_stack+2250, 225);
     Libr12->te_ptr[0] = int_stack + 55808;

}
