/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dpff(Libr12_t *, prim_data *);

  /* Computes (dp|ff) integrals for linear R12-methods */

void hrr_grt_order_dpff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][3] = int_stack + 0;
 Libr12->t2vrr_classes[2][4] = int_stack + 60;
 Libr12->t2vrr_classes[2][5] = int_stack + 150;
 Libr12->t2vrr_classes[2][6] = int_stack + 276;
 Libr12->gvrr_classes[4][3] = int_stack + 444;
 Libr12->t2vrr_classes[3][3] = int_stack + 594;
 Libr12->gvrr_classes[4][4] = int_stack + 694;
 Libr12->t2vrr_classes[3][4] = int_stack + 919;
 Libr12->gvrr_classes[4][5] = int_stack + 1069;
 Libr12->t2vrr_classes[3][5] = int_stack + 1384;
 Libr12->t2vrr_classes[3][6] = int_stack + 1594;
 Libr12->gvrr_classes[2][7] = int_stack + 1874;
 Libr12->t1vrr_classes[2][3] = int_stack + 2090;
 Libr12->t1vrr_classes[2][4] = int_stack + 2150;
 Libr12->t1vrr_classes[2][5] = int_stack + 2240;
 Libr12->t1vrr_classes[2][6] = int_stack + 2366;
 Libr12->t1vrr_classes[3][3] = int_stack + 2534;
 Libr12->t1vrr_classes[3][4] = int_stack + 2634;
 Libr12->t1vrr_classes[3][5] = int_stack + 2784;
 Libr12->t1vrr_classes[3][6] = int_stack + 2994;
 Libr12->rvrr_classes[2][3] = int_stack + 3274;
 Libr12->rvrr_classes[2][4] = int_stack + 3334;
 Libr12->rvrr_classes[2][5] = int_stack + 3424;
 Libr12->rvrr_classes[2][6] = int_stack + 3550;
 Libr12->rvrr_classes[3][3] = int_stack + 3718;
 Libr12->rvrr_classes[3][4] = int_stack + 3818;
 Libr12->rvrr_classes[3][5] = int_stack + 3968;
 Libr12->rvrr_classes[3][6] = int_stack + 4178;
 Libr12->gvrr_classes[2][3] = int_stack + 4458;
 Libr12->gvrr_classes[2][4] = int_stack + 4518;
 Libr12->gvrr_classes[2][5] = int_stack + 4608;
 Libr12->gvrr_classes[2][6] = int_stack + 4734;
 Libr12->gvrr_classes[3][3] = int_stack + 4902;
 Libr12->gvrr_classes[3][4] = int_stack + 5002;
 Libr12->gvrr_classes[3][5] = int_stack + 5152;
 Libr12->gvrr_classes[3][6] = int_stack + 5362;
 memset(int_stack,0,5642*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 5642;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dpff(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+5642, int_stack+4518, int_stack+4458, 6);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5822, int_stack+4608, int_stack+4518, 6);
 /*--- compute (d0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+6092, int_stack+5822, int_stack+5642, 6);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6452, int_stack+5002, int_stack+4902, 10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6752, int_stack+5152, int_stack+5002, 10);
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+7202, int_stack+6752, int_stack+6452, 10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7802, int_stack+4734, int_stack+4608, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8180, int_stack+7802, int_stack+5822, 6);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8720, int_stack+60, int_stack+0, int_stack+4518, int_stack+4902, int_stack+4458, 2, 0);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8900, int_stack+150, int_stack+60, int_stack+4608, int_stack+5002, int_stack+4518, 2, 0);
 /*--- compute (d0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9170, int_stack+8900, int_stack+8720, int_stack+5822, int_stack+6452, int_stack+5642, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9530, int_stack+276, int_stack+150, int_stack+4734, int_stack+5152, int_stack+4608, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9908, int_stack+9530, int_stack+8900, int_stack+7802, int_stack+6752, int_stack+5822, 2, 0);
 /*--- compute (d0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10448, int_stack+9908, int_stack+9170, int_stack+8180, int_stack+7202, int_stack+6092, 2, 0);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+5642, int_stack+694, int_stack+444, 15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8720, int_stack+1069, int_stack+694, 15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+9395, int_stack+8720, int_stack+5642, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11048, int_stack+5362, int_stack+5152, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+11678, int_stack+11048, int_stack+6752, 10);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+919, int_stack+594, int_stack+5002, int_stack+444, int_stack+4902, 3, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12578, int_stack+1384, int_stack+919, int_stack+5152, int_stack+694, int_stack+5002, 3, 0);
 /*--- compute (f0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+300, int_stack+12578, int_stack+0, int_stack+6752, int_stack+5642, int_stack+6452, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13028, int_stack+1594, int_stack+1384, int_stack+5362, int_stack+1069, int_stack+5152, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4902, int_stack+13028, int_stack+12578, int_stack+11048, int_stack+8720, int_stack+6752, 3, 0);
 /*--- compute (f0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12578, int_stack+4902, int_stack+300, int_stack+11678, int_stack+9395, int_stack+7202, 3, 0);
 /*--- compute (d0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+4902, int_stack+8180, int_stack+6092, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5502, int_stack+1874, int_stack+4734, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6006, int_stack+5502, int_stack+7802, 6);
 /*--- compute (d0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+8720, int_stack+6006, int_stack+8180, 6);
 /*--- compute (f0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+5502, int_stack+11678, int_stack+7202, 10);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6502, int_stack+2150, int_stack+2090, 6);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6682, int_stack+2240, int_stack+2150, 6);
 /*--- compute (d0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+6952, int_stack+6682, int_stack+6502, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7312, int_stack+2366, int_stack+2240, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7690, int_stack+7312, int_stack+6682, 6);
 /*--- compute (d0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+9620, int_stack+7690, int_stack+6952, 6);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6502, int_stack+2634, int_stack+2534, 10);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6802, int_stack+2784, int_stack+2634, 10);
 /*--- compute (f0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+7252, int_stack+6802, int_stack+6502, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7852, int_stack+2994, int_stack+2784, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+11048, int_stack+7852, int_stack+6802, 10);
 /*--- compute (f0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11048, int_stack+7252, 10);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+11048, int_stack+3334, int_stack+3274, 6);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11228, int_stack+3424, int_stack+3334, 6);
 /*--- compute (d0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+11498, int_stack+11228, int_stack+11048, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11858, int_stack+3550, int_stack+3424, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6502, int_stack+11858, int_stack+11228, 6);
 /*--- compute (d0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+11858, int_stack+6502, int_stack+11498, 6);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6502, int_stack+3818, int_stack+3718, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6802, int_stack+3968, int_stack+3818, 10);
 /*--- compute (f0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+7252, int_stack+6802, int_stack+6502, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7852, int_stack+4178, int_stack+3968, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1000, int_stack+7852, int_stack+6802, 10);
 /*--- compute (f0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+1900, int_stack+1000, int_stack+7252, 10);
 /*--- compute (dp|[r12,T2]|ff) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+6502, int_stack+12578, int_stack+10448, 100);
     Libr12->te_ptr[3] = int_stack + 6502;
 /*--- compute (dp|[r12,T1]|ff) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+2900, int_stack+0, int_stack+9620, int_stack+5502, int_stack+8720, int_stack+4902, 3, 3);
     Libr12->te_ptr[2] = int_stack + 2900;
 /*--- compute (dp||ff) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+1900, int_stack+11858, 100);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (dp|ff) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+8302, int_stack+5502, int_stack+4902, 100);
     Libr12->te_ptr[0] = int_stack + 8302;

}
