/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_f0hg(Libr12_t *, prim_data *);

  /* Computes (f0|hg) integrals for linear R12-methods */

void hrr_grt_order_f0hg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 315;
 Libr12->gvrr_classes[4][6] = int_stack + 525;
 Libr12->t2vrr_classes[3][6] = int_stack + 945;
 Libr12->gvrr_classes[4][7] = int_stack + 1225;
 Libr12->t2vrr_classes[3][7] = int_stack + 1765;
 Libr12->gvrr_classes[4][8] = int_stack + 2125;
 Libr12->t2vrr_classes[3][8] = int_stack + 2800;
 Libr12->t2vrr_classes[3][9] = int_stack + 3250;
 Libr12->t1vrr_classes[3][5] = int_stack + 3800;
 Libr12->t1vrr_classes[3][6] = int_stack + 4010;
 Libr12->t1vrr_classes[3][7] = int_stack + 4290;
 Libr12->t1vrr_classes[3][8] = int_stack + 4650;
 Libr12->t1vrr_classes[3][9] = int_stack + 5100;
 Libr12->rvrr_classes[3][5] = int_stack + 5650;
 Libr12->rvrr_classes[3][6] = int_stack + 5860;
 Libr12->rvrr_classes[3][7] = int_stack + 6140;
 Libr12->rvrr_classes[3][8] = int_stack + 6500;
 Libr12->rvrr_classes[3][9] = int_stack + 6950;
 Libr12->gvrr_classes[3][5] = int_stack + 7500;
 Libr12->gvrr_classes[3][6] = int_stack + 7710;
 Libr12->gvrr_classes[3][7] = int_stack + 7990;
 Libr12->gvrr_classes[3][8] = int_stack + 8350;
 Libr12->gvrr_classes[3][9] = int_stack + 8800;
 memset(int_stack,0,9350*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 9350;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_f0hg(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9350, int_stack+7710, int_stack+7500, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9980, int_stack+7990, int_stack+7710, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10820, int_stack+9980, int_stack+9350, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+12080, int_stack+8350, int_stack+7990, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13160, int_stack+12080, int_stack+9980, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+14840, int_stack+13160, int_stack+10820, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16940, int_stack+525, int_stack+0, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17885, int_stack+1225, int_stack+525, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+19145, int_stack+17885, int_stack+16940, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+21035, int_stack+2125, int_stack+1225, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22655, int_stack+21035, int_stack+17885, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+25175, int_stack+22655, int_stack+19145, 15);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+28325, int_stack+8800, int_stack+8350, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+29675, int_stack+28325, int_stack+12080, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+31835, int_stack+29675, int_stack+13160, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34635, int_stack+945, int_stack+315, int_stack+7710, int_stack+0, int_stack+7500, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35265, int_stack+1765, int_stack+945, int_stack+7990, int_stack+525, int_stack+7710, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36105, int_stack+35265, int_stack+34635, int_stack+9980, int_stack+16940, int_stack+9350, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2800, int_stack+1765, int_stack+8350, int_stack+1225, int_stack+7990, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+37365, int_stack+0, int_stack+35265, int_stack+12080, int_stack+17885, int_stack+9980, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16940, int_stack+37365, int_stack+36105, int_stack+13160, int_stack+19145, int_stack+10820, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9350, int_stack+3250, int_stack+2800, int_stack+8800, int_stack+2125, int_stack+8350, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34635, int_stack+9350, int_stack+0, int_stack+28325, int_stack+21035, int_stack+12080, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+34635, int_stack+37365, int_stack+29675, int_stack+22655, int_stack+13160, 3, 0);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+34635, int_stack+4010, int_stack+3800, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+35265, int_stack+4290, int_stack+4010, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+36105, int_stack+35265, int_stack+34635, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+37365, int_stack+4650, int_stack+4290, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+28325, int_stack+37365, int_stack+35265, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19040, int_stack+28325, int_stack+36105, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+34635, int_stack+5100, int_stack+4650, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+2800, int_stack+34635, int_stack+37365, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+34635, int_stack+2800, int_stack+28325, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+28325, int_stack+5860, int_stack+5650, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+28955, int_stack+6140, int_stack+5860, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+29795, int_stack+28955, int_stack+28325, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+2800, int_stack+6500, int_stack+6140, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3880, int_stack+2800, int_stack+28955, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+37435, int_stack+3880, int_stack+29795, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+28325, int_stack+6950, int_stack+6500, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+29675, int_stack+28325, int_stack+2800, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+5560, int_stack+29675, int_stack+3880, 10);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+28325, int_stack+0, int_stack+16940, int_stack+31835, int_stack+25175, int_stack+14840, 3, 0);
     Libr12->te_ptr[3] = int_stack + 28325;
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+34635, int_stack+19040, 10);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+16940, int_stack+5560, int_stack+37435, 10);
     Libr12->te_ptr[1] = int_stack + 16940;
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+34635, int_stack+31835, int_stack+14840, 10);
     Libr12->te_ptr[0] = int_stack + 34635;

}
