/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdhh(Libr12_t *, prim_data *);

  /* Computes (fd|hh) integrals for linear R12-methods */

void hrr_grt_order_fdhh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[3][8] = int_stack + 850;
 Libr12->t2vrr_classes[3][9] = int_stack + 1300;
 Libr12->t2vrr_classes[3][10] = int_stack + 1850;
 Libr12->t2vrr_classes[4][5] = int_stack + 2510;
 Libr12->t2vrr_classes[4][6] = int_stack + 2825;
 Libr12->t2vrr_classes[4][7] = int_stack + 3245;
 Libr12->t2vrr_classes[4][8] = int_stack + 3785;
 Libr12->t2vrr_classes[4][9] = int_stack + 4460;
 Libr12->t2vrr_classes[4][10] = int_stack + 5285;
 Libr12->gvrr_classes[6][5] = int_stack + 6275;
 Libr12->t2vrr_classes[5][5] = int_stack + 6863;
 Libr12->gvrr_classes[6][6] = int_stack + 7304;
 Libr12->t2vrr_classes[5][6] = int_stack + 8088;
 Libr12->gvrr_classes[6][7] = int_stack + 8676;
 Libr12->t2vrr_classes[5][7] = int_stack + 9684;
 Libr12->gvrr_classes[6][8] = int_stack + 10440;
 Libr12->t2vrr_classes[5][8] = int_stack + 11700;
 Libr12->gvrr_classes[6][9] = int_stack + 12645;
 Libr12->t2vrr_classes[5][9] = int_stack + 14185;
 Libr12->t2vrr_classes[5][10] = int_stack + 15340;
 Libr12->gvrr_classes[3][11] = int_stack + 16726;
 Libr12->t1vrr_classes[3][5] = int_stack + 17506;
 Libr12->t1vrr_classes[3][6] = int_stack + 17716;
 Libr12->t1vrr_classes[3][7] = int_stack + 17996;
 Libr12->t1vrr_classes[3][8] = int_stack + 18356;
 Libr12->t1vrr_classes[3][9] = int_stack + 18806;
 Libr12->t1vrr_classes[3][10] = int_stack + 19356;
 Libr12->gvrr_classes[4][11] = int_stack + 20016;
 Libr12->t1vrr_classes[4][5] = int_stack + 21186;
 Libr12->t1vrr_classes[4][6] = int_stack + 21501;
 Libr12->t1vrr_classes[4][7] = int_stack + 21921;
 Libr12->t1vrr_classes[4][8] = int_stack + 22461;
 Libr12->t1vrr_classes[4][9] = int_stack + 23136;
 Libr12->t1vrr_classes[4][10] = int_stack + 23961;
 Libr12->t1vrr_classes[5][5] = int_stack + 24951;
 Libr12->t1vrr_classes[5][6] = int_stack + 25392;
 Libr12->t1vrr_classes[5][7] = int_stack + 25980;
 Libr12->t1vrr_classes[5][8] = int_stack + 26736;
 Libr12->t1vrr_classes[5][9] = int_stack + 27681;
 Libr12->t1vrr_classes[5][10] = int_stack + 28836;
 Libr12->rvrr_classes[3][5] = int_stack + 30222;
 Libr12->rvrr_classes[3][6] = int_stack + 30432;
 Libr12->rvrr_classes[3][7] = int_stack + 30712;
 Libr12->rvrr_classes[3][8] = int_stack + 31072;
 Libr12->rvrr_classes[3][9] = int_stack + 31522;
 Libr12->rvrr_classes[3][10] = int_stack + 32072;
 Libr12->rvrr_classes[4][5] = int_stack + 32732;
 Libr12->rvrr_classes[4][6] = int_stack + 33047;
 Libr12->rvrr_classes[4][7] = int_stack + 33467;
 Libr12->rvrr_classes[4][8] = int_stack + 34007;
 Libr12->rvrr_classes[4][9] = int_stack + 34682;
 Libr12->rvrr_classes[4][10] = int_stack + 35507;
 Libr12->rvrr_classes[5][5] = int_stack + 36497;
 Libr12->rvrr_classes[5][6] = int_stack + 36938;
 Libr12->rvrr_classes[5][7] = int_stack + 37526;
 Libr12->rvrr_classes[5][8] = int_stack + 38282;
 Libr12->rvrr_classes[5][9] = int_stack + 39227;
 Libr12->rvrr_classes[5][10] = int_stack + 40382;
 Libr12->gvrr_classes[3][5] = int_stack + 41768;
 Libr12->gvrr_classes[3][6] = int_stack + 41978;
 Libr12->gvrr_classes[3][7] = int_stack + 42258;
 Libr12->gvrr_classes[3][8] = int_stack + 42618;
 Libr12->gvrr_classes[3][9] = int_stack + 43068;
 Libr12->gvrr_classes[3][10] = int_stack + 43618;
 Libr12->gvrr_classes[4][5] = int_stack + 44278;
 Libr12->gvrr_classes[4][6] = int_stack + 44593;
 Libr12->gvrr_classes[4][7] = int_stack + 45013;
 Libr12->gvrr_classes[4][8] = int_stack + 45553;
 Libr12->gvrr_classes[4][9] = int_stack + 46228;
 Libr12->gvrr_classes[4][10] = int_stack + 47053;
 Libr12->gvrr_classes[5][5] = int_stack + 48043;
 Libr12->gvrr_classes[5][6] = int_stack + 48484;
 Libr12->gvrr_classes[5][7] = int_stack + 49072;
 Libr12->gvrr_classes[5][8] = int_stack + 49828;
 Libr12->gvrr_classes[5][9] = int_stack + 50773;
 Libr12->gvrr_classes[5][10] = int_stack + 51928;
 memset(int_stack,0,53314*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 53314;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdhh(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+53314, int_stack+41978, int_stack+41768, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+53944, int_stack+42258, int_stack+41978, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+54784, int_stack+53944, int_stack+53314, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+56044, int_stack+42618, int_stack+42258, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+57124, int_stack+56044, int_stack+53944, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+58804, int_stack+57124, int_stack+54784, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+60904, int_stack+43068, int_stack+42618, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+62254, int_stack+60904, int_stack+56044, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+64414, int_stack+62254, int_stack+57124, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+67214, int_stack+64414, int_stack+58804, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+70364, int_stack+44593, int_stack+44278, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+71309, int_stack+45013, int_stack+44593, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+72569, int_stack+71309, int_stack+70364, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+74459, int_stack+45553, int_stack+45013, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+76079, int_stack+74459, int_stack+71309, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+78599, int_stack+76079, int_stack+72569, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+81749, int_stack+46228, int_stack+45553, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+83774, int_stack+81749, int_stack+74459, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+87014, int_stack+83774, int_stack+76079, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+91214, int_stack+87014, int_stack+78599, 15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+95939, int_stack+43618, int_stack+43068, 10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+97589, int_stack+95939, int_stack+60904, 10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+100289, int_stack+97589, int_stack+62254, 10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+103889, int_stack+100289, int_stack+64414, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108089, int_stack+210, int_stack+0, int_stack+41978, int_stack+44278, int_stack+41768, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108719, int_stack+490, int_stack+210, int_stack+42258, int_stack+44593, int_stack+41978, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+109559, int_stack+108719, int_stack+108089, int_stack+53944, int_stack+70364, int_stack+53314, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+110819, int_stack+850, int_stack+490, int_stack+42618, int_stack+45013, int_stack+42258, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+111899, int_stack+110819, int_stack+108719, int_stack+56044, int_stack+71309, int_stack+53944, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+113579, int_stack+111899, int_stack+109559, int_stack+57124, int_stack+72569, int_stack+54784, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53314, int_stack+1300, int_stack+850, int_stack+43068, int_stack+45553, int_stack+42618, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108089, int_stack+53314, int_stack+110819, int_stack+60904, int_stack+74459, int_stack+56044, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+115679, int_stack+108089, int_stack+111899, int_stack+62254, int_stack+76079, int_stack+57124, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54664, int_stack+115679, int_stack+113579, int_stack+64414, int_stack+78599, int_stack+58804, 3, 0);
 /*--- compute (f0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57814, int_stack+1850, int_stack+1300, int_stack+43618, int_stack+46228, int_stack+43068, 3, 0);
 /*--- compute (f0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+110249, int_stack+57814, int_stack+53314, int_stack+95939, int_stack+81749, int_stack+60904, 3, 0);
 /*--- compute (f0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57814, int_stack+110249, int_stack+108089, int_stack+97589, int_stack+83774, int_stack+62254, 3, 0);
 /*--- compute (f0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108089, int_stack+57814, int_stack+115679, int_stack+100289, int_stack+87014, int_stack+64414, 3, 0);
 /*--- compute (f0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57814, int_stack+108089, int_stack+54664, int_stack+103889, int_stack+91214, int_stack+67214, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+108089, int_stack+48484, int_stack+48043, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+109412, int_stack+49072, int_stack+48484, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+111176, int_stack+109412, int_stack+108089, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+113822, int_stack+49828, int_stack+49072, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+62224, int_stack+113822, int_stack+109412, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+53314, int_stack+62224, int_stack+111176, 21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+116090, int_stack+50773, int_stack+49828, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+118925, int_stack+116090, int_stack+113822, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+123461, int_stack+118925, int_stack+62224, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+129341, int_stack+123461, int_stack+53314, 21);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+47053, int_stack+46228, 15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+135956, int_stack+0, int_stack+81749, 15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+140006, int_stack+135956, int_stack+83774, 15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+145406, int_stack+140006, int_stack+87014, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+65752, int_stack+2825, int_stack+2510, int_stack+44593, int_stack+48043, int_stack+44278, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41768, int_stack+3245, int_stack+2825, int_stack+45013, int_stack+48484, int_stack+44593, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151706, int_stack+41768, int_stack+65752, int_stack+71309, int_stack+108089, int_stack+70364, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+153596, int_stack+3785, int_stack+3245, int_stack+45553, int_stack+49072, int_stack+45013, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+155216, int_stack+153596, int_stack+41768, int_stack+74459, int_stack+109412, int_stack+71309, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+157736, int_stack+155216, int_stack+151706, int_stack+76079, int_stack+111176, int_stack+72569, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70364, int_stack+4460, int_stack+3785, int_stack+46228, int_stack+49828, int_stack+45553, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+160886, int_stack+70364, int_stack+153596, int_stack+81749, int_stack+113822, int_stack+74459, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+164126, int_stack+160886, int_stack+155216, int_stack+83774, int_stack+62224, int_stack+76079, 4, 0);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151706, int_stack+164126, int_stack+157736, int_stack+87014, int_stack+53314, int_stack+78599, 4, 0);
 /*--- compute (g0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+156431, int_stack+5285, int_stack+4460, int_stack+47053, int_stack+50773, int_stack+46228, 4, 0);
 /*--- compute (g0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+72389, int_stack+156431, int_stack+70364, int_stack+0, int_stack+116090, int_stack+81749, 4, 0);
 /*--- compute (g0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+76439, int_stack+72389, int_stack+160886, int_stack+135956, int_stack+118925, int_stack+83774, 4, 0);
 /*--- compute (g0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+156431, int_stack+76439, int_stack+164126, int_stack+140006, int_stack+123461, int_stack+87014, 4, 0);
 /*--- compute (g0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70364, int_stack+156431, int_stack+151706, int_stack+145406, int_stack+129341, int_stack+91214, 4, 0);
 /*--- compute (fp|[r12,T2]|hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+151706, int_stack+70364, int_stack+57814, 441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+164936, int_stack+7304, int_stack+6275, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+76979, int_stack+8676, int_stack+7304, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+79331, int_stack+76979, int_stack+164936, 28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+82859, int_stack+10440, int_stack+8676, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+85883, int_stack+82859, int_stack+76979, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+166700, int_stack+85883, int_stack+79331, 28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+57724, int_stack+12645, int_stack+10440, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+172580, int_stack+57724, int_stack+82859, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+178628, int_stack+172580, int_stack+85883, 28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+186468, int_stack+178628, int_stack+166700, 28);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+2475, int_stack+51928, int_stack+50773, 21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+195288, int_stack+2475, int_stack+116090, 21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+200958, int_stack+195288, int_stack+118925, 21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+208518, int_stack+200958, int_stack+123461, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41768, int_stack+8088, int_stack+6863, int_stack+48484, int_stack+6275, int_stack+48043, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44278, int_stack+9684, int_stack+8088, int_stack+49072, int_stack+7304, int_stack+48484, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5940, int_stack+44278, int_stack+41768, int_stack+109412, int_stack+164936, int_stack+108089, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+217338, int_stack+11700, int_stack+9684, int_stack+49828, int_stack+8676, int_stack+49072, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+219606, int_stack+217338, int_stack+44278, int_stack+113822, int_stack+76979, int_stack+109412, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+223134, int_stack+219606, int_stack+5940, int_stack+62224, int_stack+79331, int_stack+111176, 5, 0);
 /*--- compute (h0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5940, int_stack+14185, int_stack+11700, int_stack+50773, int_stack+10440, int_stack+49828, 5, 0);
 /*--- compute (h0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+76979, int_stack+5940, int_stack+217338, int_stack+116090, int_stack+82859, int_stack+113822, 5, 0);
 /*--- compute (h0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108089, int_stack+76979, int_stack+219606, int_stack+118925, int_stack+85883, int_stack+62224, 5, 0);
 /*--- compute (h0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+81515, int_stack+108089, int_stack+223134, int_stack+123461, int_stack+166700, int_stack+53314, 5, 0);
 /*--- compute (h0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53314, int_stack+15340, int_stack+14185, int_stack+51928, int_stack+12645, int_stack+50773, 5, 0);
 /*--- compute (h0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+217338, int_stack+53314, int_stack+5940, int_stack+2475, int_stack+57724, int_stack+116090, 5, 0);
 /*--- compute (h0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2475, int_stack+217338, int_stack+76979, int_stack+195288, int_stack+172580, int_stack+118925, 5, 0);
 /*--- compute (h0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+217338, int_stack+2475, int_stack+108089, int_stack+200958, int_stack+178628, int_stack+123461, 5, 0);
 /*--- compute (h0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108089, int_stack+217338, int_stack+81515, int_stack+208518, int_stack+186468, int_stack+129341, 5, 0);
 /*--- compute (gp|[r12,T2]|hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+164936, int_stack+108089, int_stack+70364, 441);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+70364, int_stack+103889, int_stack+67214, 10);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+74774, int_stack+145406, int_stack+91214, 15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+81389, int_stack+74774, int_stack+70364, 441);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+108089, int_stack+16726, int_stack+43618, 10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+110069, int_stack+108089, int_stack+95939, 10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+113369, int_stack+110069, int_stack+97589, 10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+113369, int_stack+100289, 10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+108089, int_stack+94619, int_stack+103889, 10);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+20016, int_stack+47053, 15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+97589, int_stack+94619, int_stack+0, 15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+97589, int_stack+135956, 15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+0, int_stack+140006, 15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+135956, int_stack+6750, int_stack+145406, 15);
 /*--- compute (fp|ih) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+184781, int_stack+135956, int_stack+108089, 588);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+0, int_stack+208518, int_stack+129341, 21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+113969, int_stack+0, int_stack+74774, 441);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9261, int_stack+17716, int_stack+17506, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9891, int_stack+17996, int_stack+17716, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10731, int_stack+9891, int_stack+9261, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+11991, int_stack+18356, int_stack+17996, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13071, int_stack+11991, int_stack+9891, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+14751, int_stack+13071, int_stack+10731, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+9261, int_stack+18806, int_stack+18356, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+144776, int_stack+9261, int_stack+11991, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+146936, int_stack+144776, int_stack+13071, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+10611, int_stack+146936, int_stack+14751, 10);
 /*--- compute (f0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+13761, int_stack+19356, int_stack+18806, 10);
 /*--- compute (f0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+15411, int_stack+13761, int_stack+9261, 10);
 /*--- compute (f0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+15411, int_stack+144776, 10);
 /*--- compute (f0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+13761, int_stack+94619, int_stack+146936, 10);
 /*--- compute (f0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+13761, int_stack+10611, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+99029, int_stack+21501, int_stack+21186, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+99974, int_stack+21921, int_stack+21501, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+101234, int_stack+99974, int_stack+99029, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+103124, int_stack+22461, int_stack+21921, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+104744, int_stack+103124, int_stack+99974, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+144776, int_stack+104744, int_stack+101234, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+99029, int_stack+23136, int_stack+22461, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+147926, int_stack+99029, int_stack+103124, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+9261, int_stack+147926, int_stack+104744, 15);
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+101054, int_stack+9261, int_stack+144776, 15);
 /*--- compute (g0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+144776, int_stack+23961, int_stack+23136, 15);
 /*--- compute (g0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+13461, int_stack+144776, int_stack+99029, 15);
 /*--- compute (g0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+17511, int_stack+13461, int_stack+147926, 15);
 /*--- compute (g0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+144776, int_stack+17511, int_stack+9261, 15);
 /*--- compute (g0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+9261, int_stack+144776, int_stack+101054, 15);
 /*--- compute (fp|[r12,T1]|hh) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+202421, int_stack+9261, int_stack+94619, int_stack+74774, int_stack+108089, int_stack+70364, 5, 5);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+25392, int_stack+24951, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+95942, int_stack+25980, int_stack+25392, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+97706, int_stack+95942, int_stack+94619, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+100352, int_stack+26736, int_stack+25980, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+102620, int_stack+100352, int_stack+95942, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+106148, int_stack+102620, int_stack+97706, 21);
 /*--- compute (h0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+94619, int_stack+27681, int_stack+26736, 21);
 /*--- compute (h0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+144776, int_stack+94619, int_stack+100352, 21);
 /*--- compute (h0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+15876, int_stack+144776, int_stack+102620, 21);
 /*--- compute (h0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+97454, int_stack+15876, int_stack+106148, 21);
 /*--- compute (h0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+104069, int_stack+28836, int_stack+27681, 21);
 /*--- compute (h0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+107534, int_stack+104069, int_stack+94619, 21);
 /*--- compute (h0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+21756, int_stack+107534, int_stack+144776, 21);
 /*--- compute (h0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+104069, int_stack+21756, int_stack+15876, 21);
 /*--- compute (h0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+15876, int_stack+104069, int_stack+97454, 21);
 /*--- compute (gp|[r12,T1]|hh) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+41768, int_stack+15876, int_stack+9261, int_stack+0, int_stack+135956, int_stack+74774, 5, 5);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+30432, int_stack+30222, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+630, int_stack+30712, int_stack+30432, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1470, int_stack+630, int_stack+0, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+2730, int_stack+31072, int_stack+30712, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3810, int_stack+2730, int_stack+630, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+5490, int_stack+3810, int_stack+1470, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+31522, int_stack+31072, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+7590, int_stack+0, int_stack+2730, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+9750, int_stack+7590, int_stack+3810, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+1350, int_stack+9750, int_stack+5490, 10);
 /*--- compute (f0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+4500, int_stack+32072, int_stack+31522, 10);
 /*--- compute (f0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+12550, int_stack+4500, int_stack+0, 10);
 /*--- compute (f0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+15250, int_stack+12550, int_stack+7590, 10);
 /*--- compute (f0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+4500, int_stack+15250, int_stack+9750, 10);
 /*--- compute (f0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+8700, int_stack+4500, int_stack+1350, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+33047, int_stack+32732, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+945, int_stack+33467, int_stack+33047, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2205, int_stack+945, int_stack+0, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+4095, int_stack+34007, int_stack+33467, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+5715, int_stack+4095, int_stack+945, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+13110, int_stack+5715, int_stack+2205, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+34682, int_stack+34007, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+16260, int_stack+0, int_stack+4095, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+19500, int_stack+16260, int_stack+5715, 15);
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+2025, int_stack+19500, int_stack+13110, 15);
 /*--- compute (g0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+13110, int_stack+35507, int_stack+34682, 15);
 /*--- compute (g0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+23700, int_stack+13110, int_stack+0, 15);
 /*--- compute (g0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+27750, int_stack+23700, int_stack+16260, 15);
 /*--- compute (g0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+13110, int_stack+27750, int_stack+19500, 15);
 /*--- compute (g0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+19410, int_stack+13110, int_stack+2025, 15);
 /*--- compute (fp||hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+94619, int_stack+19410, int_stack+8700, 441);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+36938, int_stack+36497, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1323, int_stack+37526, int_stack+36938, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3087, int_stack+1323, int_stack+0, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+5733, int_stack+38282, int_stack+37526, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+8001, int_stack+5733, int_stack+1323, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+11529, int_stack+8001, int_stack+3087, 21);
 /*--- compute (h0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+39227, int_stack+38282, 21);
 /*--- compute (h0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+26025, int_stack+0, int_stack+5733, 21);
 /*--- compute (h0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+30561, int_stack+26025, int_stack+8001, 21);
 /*--- compute (h0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+2835, int_stack+30561, int_stack+11529, 21);
 /*--- compute (h0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+40382, int_stack+39227, 21);
 /*--- compute (h0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+12915, int_stack+9450, int_stack+0, 21);
 /*--- compute (h0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+133814, int_stack+12915, int_stack+26025, 21);
 /*--- compute (h0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+133814, int_stack+30561, 21);
 /*--- compute (h0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+133814, int_stack+9450, int_stack+2835, 21);
 /*--- compute (gp||hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+215651, int_stack+133814, int_stack+19410, 441);
 /*--- compute (fd|[r12,T2]|hh) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+164936, int_stack+151706, 441);
     Libr12->te_ptr[3] = int_stack + 0;
 /*--- compute (fd|[r12,T1]|hh) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+133814, int_stack+41768, int_stack+202421, int_stack+113969, int_stack+184781, int_stack+81389, 5, 5);
     Libr12->te_ptr[2] = int_stack + 133814;
 /*--- compute (fd||hh) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+160274, int_stack+215651, int_stack+94619, 441);
     Libr12->te_ptr[1] = int_stack + 160274;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+186734, int_stack+113969, int_stack+81389, 441);
     Libr12->te_ptr[0] = int_stack + 186734;

}
