/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0gg(Libr12_t *, prim_data *);

  /* Computes (g0|gg) integrals for linear R12-methods */

void hrr_grt_order_g0gg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][4] = int_stack + 315;
 Libr12->gvrr_classes[5][5] = int_stack + 540;
 Libr12->t2vrr_classes[4][5] = int_stack + 981;
 Libr12->gvrr_classes[5][6] = int_stack + 1296;
 Libr12->t2vrr_classes[4][6] = int_stack + 1884;
 Libr12->gvrr_classes[5][7] = int_stack + 2304;
 Libr12->t2vrr_classes[4][7] = int_stack + 3060;
 Libr12->t2vrr_classes[4][8] = int_stack + 3600;
 Libr12->t1vrr_classes[4][4] = int_stack + 4275;
 Libr12->t1vrr_classes[4][5] = int_stack + 4500;
 Libr12->t1vrr_classes[4][6] = int_stack + 4815;
 Libr12->t1vrr_classes[4][7] = int_stack + 5235;
 Libr12->t1vrr_classes[4][8] = int_stack + 5775;
 Libr12->rvrr_classes[4][4] = int_stack + 6450;
 Libr12->rvrr_classes[4][5] = int_stack + 6675;
 Libr12->rvrr_classes[4][6] = int_stack + 6990;
 Libr12->rvrr_classes[4][7] = int_stack + 7410;
 Libr12->rvrr_classes[4][8] = int_stack + 7950;
 Libr12->gvrr_classes[4][4] = int_stack + 8625;
 Libr12->gvrr_classes[4][5] = int_stack + 8850;
 Libr12->gvrr_classes[4][6] = int_stack + 9165;
 Libr12->gvrr_classes[4][7] = int_stack + 9585;
 Libr12->gvrr_classes[4][8] = int_stack + 10125;
 memset(int_stack,0,10800*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 10800;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0gg(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10800, int_stack+8850, int_stack+8625, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11475, int_stack+9165, int_stack+8850, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12420, int_stack+11475, int_stack+10800, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+13770, int_stack+9585, int_stack+9165, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+15030, int_stack+13770, int_stack+11475, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+16920, int_stack+15030, int_stack+12420, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+19170, int_stack+540, int_stack+0, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+20115, int_stack+1296, int_stack+540, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+21438, int_stack+20115, int_stack+19170, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+23328, int_stack+2304, int_stack+1296, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+25092, int_stack+23328, int_stack+20115, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+27738, int_stack+25092, int_stack+21438, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+30888, int_stack+10125, int_stack+9585, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+32508, int_stack+30888, int_stack+13770, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+35028, int_stack+32508, int_stack+15030, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38178, int_stack+981, int_stack+315, int_stack+8850, int_stack+0, int_stack+8625, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38853, int_stack+1884, int_stack+981, int_stack+9165, int_stack+540, int_stack+8850, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+39798, int_stack+38853, int_stack+38178, int_stack+11475, int_stack+19170, int_stack+10800, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3060, int_stack+1884, int_stack+9585, int_stack+1296, int_stack+9165, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41148, int_stack+0, int_stack+38853, int_stack+13770, int_stack+20115, int_stack+11475, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19170, int_stack+41148, int_stack+39798, int_stack+15030, int_stack+21438, int_stack+12420, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10800, int_stack+3600, int_stack+3060, int_stack+10125, int_stack+2304, int_stack+9585, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38178, int_stack+10800, int_stack+0, int_stack+30888, int_stack+23328, int_stack+13770, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+38178, int_stack+41148, int_stack+32508, int_stack+25092, int_stack+15030, 4, 0);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+38178, int_stack+4500, int_stack+4275, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+38853, int_stack+4815, int_stack+4500, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+39798, int_stack+38853, int_stack+38178, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+41148, int_stack+5235, int_stack+4815, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+30888, int_stack+41148, int_stack+38853, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+32778, int_stack+30888, int_stack+39798, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+38178, int_stack+5775, int_stack+5235, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+38178, int_stack+41148, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+38178, int_stack+3150, int_stack+30888, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+30888, int_stack+6675, int_stack+6450, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+31563, int_stack+6990, int_stack+6675, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+31563, int_stack+30888, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+4500, int_stack+7410, int_stack+6990, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+41328, int_stack+4500, int_stack+31563, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+21420, int_stack+41328, int_stack+3150, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+30888, int_stack+7950, int_stack+7410, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+5760, int_stack+30888, int_stack+4500, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+8280, int_stack+5760, int_stack+41328, 15);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3150, int_stack+0, int_stack+19170, int_stack+35028, int_stack+27738, int_stack+16920, 4, 0);
     Libr12->te_ptr[3] = int_stack + 3150;
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+11430, int_stack+38178, int_stack+32778, 15);
     Libr12->te_ptr[2] = int_stack + 11430;
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+38178, int_stack+8280, int_stack+21420, 15);
     Libr12->te_ptr[1] = int_stack + 38178;
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+19170, int_stack+35028, int_stack+16920, 15);
     Libr12->te_ptr[0] = int_stack + 19170;

}
