/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0hh(Libr12_t *, prim_data *);

  /* Computes (g0|hh) integrals for linear R12-methods */

void hrr_grt_order_g0hh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 441;
 Libr12->gvrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[4][6] = int_stack + 1344;
 Libr12->gvrr_classes[5][7] = int_stack + 1764;
 Libr12->t2vrr_classes[4][7] = int_stack + 2520;
 Libr12->gvrr_classes[5][8] = int_stack + 3060;
 Libr12->t2vrr_classes[4][8] = int_stack + 4005;
 Libr12->gvrr_classes[5][9] = int_stack + 4680;
 Libr12->t2vrr_classes[4][9] = int_stack + 5835;
 Libr12->t2vrr_classes[4][10] = int_stack + 6660;
 Libr12->t1vrr_classes[4][5] = int_stack + 7650;
 Libr12->t1vrr_classes[4][6] = int_stack + 7965;
 Libr12->t1vrr_classes[4][7] = int_stack + 8385;
 Libr12->t1vrr_classes[4][8] = int_stack + 8925;
 Libr12->t1vrr_classes[4][9] = int_stack + 9600;
 Libr12->t1vrr_classes[4][10] = int_stack + 10425;
 Libr12->rvrr_classes[4][5] = int_stack + 11415;
 Libr12->rvrr_classes[4][6] = int_stack + 11730;
 Libr12->rvrr_classes[4][7] = int_stack + 12150;
 Libr12->rvrr_classes[4][8] = int_stack + 12690;
 Libr12->rvrr_classes[4][9] = int_stack + 13365;
 Libr12->rvrr_classes[4][10] = int_stack + 14190;
 Libr12->gvrr_classes[4][5] = int_stack + 15180;
 Libr12->gvrr_classes[4][6] = int_stack + 15495;
 Libr12->gvrr_classes[4][7] = int_stack + 15915;
 Libr12->gvrr_classes[4][8] = int_stack + 16455;
 Libr12->gvrr_classes[4][9] = int_stack + 17130;
 Libr12->gvrr_classes[4][10] = int_stack + 17955;
 memset(int_stack,0,18945*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 18945;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0hh(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18945, int_stack+15495, int_stack+15180, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19890, int_stack+15915, int_stack+15495, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21150, int_stack+19890, int_stack+18945, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+23040, int_stack+16455, int_stack+15915, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+24660, int_stack+23040, int_stack+19890, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+27180, int_stack+24660, int_stack+21150, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+30330, int_stack+17130, int_stack+16455, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+32355, int_stack+30330, int_stack+23040, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+35595, int_stack+32355, int_stack+24660, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+39795, int_stack+35595, int_stack+27180, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44520, int_stack+756, int_stack+0, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+45843, int_stack+1764, int_stack+756, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+47607, int_stack+45843, int_stack+44520, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+50253, int_stack+3060, int_stack+1764, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+52521, int_stack+50253, int_stack+45843, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+56049, int_stack+52521, int_stack+47607, 21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+60459, int_stack+4680, int_stack+3060, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+63294, int_stack+60459, int_stack+50253, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+67830, int_stack+63294, int_stack+52521, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+73710, int_stack+67830, int_stack+56049, 21);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+80325, int_stack+17955, int_stack+17130, 15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+82800, int_stack+80325, int_stack+30330, 15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+86850, int_stack+82800, int_stack+32355, 15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+92250, int_stack+86850, int_stack+35595, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+98550, int_stack+1344, int_stack+441, int_stack+15495, int_stack+0, int_stack+15180, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+99495, int_stack+2520, int_stack+1344, int_stack+15915, int_stack+756, int_stack+15495, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+100755, int_stack+99495, int_stack+98550, int_stack+19890, int_stack+44520, int_stack+18945, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4005, int_stack+2520, int_stack+16455, int_stack+1764, int_stack+15915, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+102645, int_stack+0, int_stack+99495, int_stack+23040, int_stack+45843, int_stack+19890, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+105165, int_stack+102645, int_stack+100755, int_stack+24660, int_stack+47607, int_stack+21150, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18945, int_stack+5835, int_stack+4005, int_stack+17130, int_stack+3060, int_stack+16455, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44520, int_stack+18945, int_stack+0, int_stack+30330, int_stack+50253, int_stack+23040, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+44520, int_stack+102645, int_stack+32355, int_stack+52521, int_stack+24660, 4, 0);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20970, int_stack+0, int_stack+105165, int_stack+35595, int_stack+56049, int_stack+27180, 4, 0);
 /*--- compute (g0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25695, int_stack+6660, int_stack+5835, int_stack+17955, int_stack+4680, int_stack+17130, 4, 0);
 /*--- compute (g0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+47760, int_stack+25695, int_stack+18945, int_stack+80325, int_stack+60459, int_stack+30330, 4, 0);
 /*--- compute (g0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25695, int_stack+47760, int_stack+44520, int_stack+82800, int_stack+63294, int_stack+32355, 4, 0);
 /*--- compute (g0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44520, int_stack+25695, int_stack+0, int_stack+86850, int_stack+67830, int_stack+35595, 4, 0);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7965, int_stack+7650, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+945, int_stack+8385, int_stack+7965, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2205, int_stack+945, int_stack+0, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+4095, int_stack+8925, int_stack+8385, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+5715, int_stack+4095, int_stack+945, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+25695, int_stack+5715, int_stack+2205, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9600, int_stack+8925, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+28845, int_stack+0, int_stack+4095, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+32085, int_stack+28845, int_stack+5715, 15);
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+2025, int_stack+32085, int_stack+25695, 15);
 /*--- compute (g0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+25695, int_stack+10425, int_stack+9600, 15);
 /*--- compute (g0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+25695, int_stack+0, 15);
 /*--- compute (g0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+50820, int_stack+6750, int_stack+28845, 15);
 /*--- compute (g0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+25695, int_stack+50820, int_stack+32085, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+50820, int_stack+11730, int_stack+11415, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+51765, int_stack+12150, int_stack+11730, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+53025, int_stack+51765, int_stack+50820, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+54915, int_stack+12690, int_stack+12150, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+56535, int_stack+54915, int_stack+51765, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+59055, int_stack+56535, int_stack+53025, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+13365, int_stack+12690, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+50820, int_stack+0, int_stack+54915, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+62205, int_stack+50820, int_stack+56535, 15);
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+54060, int_stack+62205, int_stack+59055, 15);
 /*--- compute (g0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+58785, int_stack+14190, int_stack+13365, 15);
 /*--- compute (g0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+66405, int_stack+58785, int_stack+0, 15);
 /*--- compute (g0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+66405, int_stack+50820, 15);
 /*--- compute (g0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+66405, int_stack+6750, int_stack+62205, 15);
 /*--- compute (g0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6750, int_stack+44520, int_stack+20970, int_stack+92250, int_stack+73710, int_stack+39795, 4, 0);
     Libr12->te_ptr[3] = int_stack + 6750;
 /*--- compute (g0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+44520, int_stack+25695, int_stack+2025, 15);
     Libr12->te_ptr[2] = int_stack + 44520;
 /*--- compute (g0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+13365, int_stack+66405, int_stack+54060, 15);
     Libr12->te_ptr[1] = int_stack + 13365;
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+51135, int_stack+92250, int_stack+39795, 15);
     Libr12->te_ptr[0] = int_stack + 51135;

}
