/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gdhd(Libr12_t *, prim_data *);

  /* Computes (gd|hd) integrals for linear R12-methods */

void hrr_grt_order_gdhd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][6] = int_stack + 315;
 Libr12->t2vrr_classes[4][7] = int_stack + 735;
 Libr12->t2vrr_classes[5][5] = int_stack + 1275;
 Libr12->t2vrr_classes[5][6] = int_stack + 1716;
 Libr12->t2vrr_classes[5][7] = int_stack + 2304;
 Libr12->gvrr_classes[7][5] = int_stack + 3060;
 Libr12->t2vrr_classes[6][5] = int_stack + 3816;
 Libr12->gvrr_classes[7][6] = int_stack + 4404;
 Libr12->t2vrr_classes[6][6] = int_stack + 5412;
 Libr12->t2vrr_classes[6][7] = int_stack + 6196;
 Libr12->gvrr_classes[4][8] = int_stack + 7204;
 Libr12->t1vrr_classes[4][5] = int_stack + 7879;
 Libr12->t1vrr_classes[4][6] = int_stack + 8194;
 Libr12->t1vrr_classes[4][7] = int_stack + 8614;
 Libr12->gvrr_classes[5][8] = int_stack + 9154;
 Libr12->t1vrr_classes[5][5] = int_stack + 10099;
 Libr12->t1vrr_classes[5][6] = int_stack + 10540;
 Libr12->t1vrr_classes[5][7] = int_stack + 11128;
 Libr12->t1vrr_classes[6][5] = int_stack + 11884;
 Libr12->t1vrr_classes[6][6] = int_stack + 12472;
 Libr12->t1vrr_classes[6][7] = int_stack + 13256;
 Libr12->rvrr_classes[4][5] = int_stack + 14264;
 Libr12->rvrr_classes[4][6] = int_stack + 14579;
 Libr12->rvrr_classes[4][7] = int_stack + 14999;
 Libr12->rvrr_classes[5][5] = int_stack + 15539;
 Libr12->rvrr_classes[5][6] = int_stack + 15980;
 Libr12->rvrr_classes[5][7] = int_stack + 16568;
 Libr12->rvrr_classes[6][5] = int_stack + 17324;
 Libr12->rvrr_classes[6][6] = int_stack + 17912;
 Libr12->rvrr_classes[6][7] = int_stack + 18696;
 Libr12->gvrr_classes[4][5] = int_stack + 19704;
 Libr12->gvrr_classes[4][6] = int_stack + 20019;
 Libr12->gvrr_classes[4][7] = int_stack + 20439;
 Libr12->gvrr_classes[5][5] = int_stack + 20979;
 Libr12->gvrr_classes[5][6] = int_stack + 21420;
 Libr12->gvrr_classes[5][7] = int_stack + 22008;
 Libr12->gvrr_classes[6][5] = int_stack + 22764;
 Libr12->gvrr_classes[6][6] = int_stack + 23352;
 Libr12->gvrr_classes[6][7] = int_stack + 24136;
 memset(int_stack,0,25144*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 25144;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gdhd(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25144, int_stack+20019, int_stack+19704, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+26089, int_stack+21420, int_stack+20979, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+27412, int_stack+20439, int_stack+20019, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+28672, int_stack+315, int_stack+0, int_stack+20019, int_stack+20979, int_stack+19704, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29617, int_stack+735, int_stack+315, int_stack+20439, int_stack+21420, int_stack+20019, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30877, int_stack+29617, int_stack+28672, int_stack+27412, int_stack+26089, int_stack+25144, 4, 0);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+28672, int_stack+23352, int_stack+22764, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+32767, int_stack+22008, int_stack+21420, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34531, int_stack+1716, int_stack+1275, int_stack+21420, int_stack+22764, int_stack+20979, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35854, int_stack+2304, int_stack+1716, int_stack+22008, int_stack+23352, int_stack+21420, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+35854, int_stack+34531, int_stack+32767, int_stack+28672, int_stack+26089, 5, 0);
 /*--- compute (gp|[r12,T2]|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+34531, int_stack+0, int_stack+30877, 126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+30436, int_stack+4404, int_stack+3060, 36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40201, int_stack+24136, int_stack+23352, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42553, int_stack+5412, int_stack+3816, int_stack+23352, int_stack+3060, int_stack+22764, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44317, int_stack+6196, int_stack+5412, int_stack+24136, int_stack+4404, int_stack+23352, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2646, int_stack+44317, int_stack+42553, int_stack+40201, int_stack+30436, int_stack+28672, 6, 0);
 /*--- compute (hp|[r12,T2]|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+42553, int_stack+2646, int_stack+0, 126);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+27412, int_stack+25144, 15);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1890, int_stack+32767, int_stack+26089, 21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+50491, int_stack+1890, int_stack+0, 126);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+4536, int_stack+7204, int_stack+20439, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22764, int_stack+4536, int_stack+27412, 15);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+4536, int_stack+9154, int_stack+22008, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+56161, int_stack+4536, int_stack+32767, 21);
 /*--- compute (gp|id) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+59689, int_stack+56161, int_stack+22764, 168);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+30436, int_stack+40201, int_stack+28672, 28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+67249, int_stack+30436, int_stack+1890, 126);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9154, int_stack+8194, int_stack+7879, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40201, int_stack+8614, int_stack+8194, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4536, int_stack+40201, int_stack+9154, 15);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+40201, int_stack+10540, int_stack+10099, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6426, int_stack+11128, int_stack+10540, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8190, int_stack+6426, int_stack+40201, 21);
 /*--- compute (gp|[r12,T1]|hd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+75187, int_stack+8190, int_stack+4536, int_stack+1890, int_stack+22764, int_stack+0, 5, 2);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+12472, int_stack+11884, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40201, int_stack+13256, int_stack+12472, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4536, int_stack+40201, int_stack+0, 28);
 /*--- compute (hp|[r12,T1]|hd) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+19704, int_stack+4536, int_stack+8190, int_stack+30436, int_stack+56161, int_stack+1890, 5, 2);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+56161, int_stack+14579, int_stack+14264, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+57106, int_stack+14999, int_stack+14579, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+57106, int_stack+56161, 15);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+56161, int_stack+15980, int_stack+15539, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+57484, int_stack+16568, int_stack+15980, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1890, int_stack+57484, int_stack+56161, 21);
 /*--- compute (gp||hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+4536, int_stack+1890, int_stack+0, 126);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+17912, int_stack+17324, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40201, int_stack+18696, int_stack+17912, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+56161, int_stack+40201, int_stack+0, 28);
 /*--- compute (hp||hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+10206, int_stack+56161, int_stack+1890, 126);
 /*--- compute (gd|[r12,T2]|hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+80857, int_stack+42553, int_stack+34531, 126);
     Libr12->te_ptr[3] = int_stack + 80857;
 /*--- compute (gd|[r12,T1]|hd) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+27642, int_stack+19704, int_stack+75187, int_stack+67249, int_stack+59689, int_stack+50491, 5, 2);
     Libr12->te_ptr[2] = int_stack + 27642;
 /*--- compute (gd||hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+38982, int_stack+10206, int_stack+4536, 126);
     Libr12->te_ptr[1] = int_stack + 38982;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+67249, int_stack+50491, 126);
     Libr12->te_ptr[0] = int_stack + 0;

}
