/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gfhf(Libr12_t *, prim_data *);

  /* Computes (gf|hf) integrals for linear R12-methods */

void hrr_grt_order_gfhf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][6] = int_stack + 315;
 Libr12->t2vrr_classes[4][7] = int_stack + 735;
 Libr12->t2vrr_classes[4][8] = int_stack + 1275;
 Libr12->t2vrr_classes[5][5] = int_stack + 1950;
 Libr12->t2vrr_classes[5][6] = int_stack + 2391;
 Libr12->t2vrr_classes[5][7] = int_stack + 2979;
 Libr12->t2vrr_classes[5][8] = int_stack + 3735;
 Libr12->t2vrr_classes[6][5] = int_stack + 4680;
 Libr12->t2vrr_classes[6][6] = int_stack + 5268;
 Libr12->t2vrr_classes[6][7] = int_stack + 6052;
 Libr12->t2vrr_classes[6][8] = int_stack + 7060;
 Libr12->gvrr_classes[8][5] = int_stack + 8320;
 Libr12->t2vrr_classes[7][5] = int_stack + 9265;
 Libr12->gvrr_classes[8][6] = int_stack + 10021;
 Libr12->t2vrr_classes[7][6] = int_stack + 11281;
 Libr12->gvrr_classes[8][7] = int_stack + 12289;
 Libr12->t2vrr_classes[7][7] = int_stack + 13909;
 Libr12->t2vrr_classes[7][8] = int_stack + 15205;
 Libr12->gvrr_classes[4][9] = int_stack + 16825;
 Libr12->t1vrr_classes[4][5] = int_stack + 17650;
 Libr12->t1vrr_classes[4][6] = int_stack + 17965;
 Libr12->t1vrr_classes[4][7] = int_stack + 18385;
 Libr12->t1vrr_classes[4][8] = int_stack + 18925;
 Libr12->gvrr_classes[5][9] = int_stack + 19600;
 Libr12->t1vrr_classes[5][5] = int_stack + 20755;
 Libr12->t1vrr_classes[5][6] = int_stack + 21196;
 Libr12->t1vrr_classes[5][7] = int_stack + 21784;
 Libr12->t1vrr_classes[5][8] = int_stack + 22540;
 Libr12->gvrr_classes[6][9] = int_stack + 23485;
 Libr12->t1vrr_classes[6][5] = int_stack + 25025;
 Libr12->t1vrr_classes[6][6] = int_stack + 25613;
 Libr12->t1vrr_classes[6][7] = int_stack + 26397;
 Libr12->t1vrr_classes[6][8] = int_stack + 27405;
 Libr12->t1vrr_classes[7][5] = int_stack + 28665;
 Libr12->t1vrr_classes[7][6] = int_stack + 29421;
 Libr12->t1vrr_classes[7][7] = int_stack + 30429;
 Libr12->t1vrr_classes[7][8] = int_stack + 31725;
 Libr12->rvrr_classes[4][5] = int_stack + 33345;
 Libr12->rvrr_classes[4][6] = int_stack + 33660;
 Libr12->rvrr_classes[4][7] = int_stack + 34080;
 Libr12->rvrr_classes[4][8] = int_stack + 34620;
 Libr12->rvrr_classes[5][5] = int_stack + 35295;
 Libr12->rvrr_classes[5][6] = int_stack + 35736;
 Libr12->rvrr_classes[5][7] = int_stack + 36324;
 Libr12->rvrr_classes[5][8] = int_stack + 37080;
 Libr12->rvrr_classes[6][5] = int_stack + 38025;
 Libr12->rvrr_classes[6][6] = int_stack + 38613;
 Libr12->rvrr_classes[6][7] = int_stack + 39397;
 Libr12->rvrr_classes[6][8] = int_stack + 40405;
 Libr12->rvrr_classes[7][5] = int_stack + 41665;
 Libr12->rvrr_classes[7][6] = int_stack + 42421;
 Libr12->rvrr_classes[7][7] = int_stack + 43429;
 Libr12->rvrr_classes[7][8] = int_stack + 44725;
 Libr12->gvrr_classes[4][5] = int_stack + 46345;
 Libr12->gvrr_classes[4][6] = int_stack + 46660;
 Libr12->gvrr_classes[4][7] = int_stack + 47080;
 Libr12->gvrr_classes[4][8] = int_stack + 47620;
 Libr12->gvrr_classes[5][5] = int_stack + 48295;
 Libr12->gvrr_classes[5][6] = int_stack + 48736;
 Libr12->gvrr_classes[5][7] = int_stack + 49324;
 Libr12->gvrr_classes[5][8] = int_stack + 50080;
 Libr12->gvrr_classes[6][5] = int_stack + 51025;
 Libr12->gvrr_classes[6][6] = int_stack + 51613;
 Libr12->gvrr_classes[6][7] = int_stack + 52397;
 Libr12->gvrr_classes[6][8] = int_stack + 53405;
 Libr12->gvrr_classes[7][5] = int_stack + 54665;
 Libr12->gvrr_classes[7][6] = int_stack + 55421;
 Libr12->gvrr_classes[7][7] = int_stack + 56429;
 Libr12->gvrr_classes[7][8] = int_stack + 57725;
 memset(int_stack,0,59345*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 59345;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gfhf(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+59345, int_stack+46660, int_stack+46345, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+60290, int_stack+47080, int_stack+46660, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+61550, int_stack+60290, int_stack+59345, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+63440, int_stack+48736, int_stack+48295, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+64763, int_stack+49324, int_stack+48736, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+66527, int_stack+64763, int_stack+63440, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+69173, int_stack+47620, int_stack+47080, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+70793, int_stack+69173, int_stack+60290, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+73313, int_stack+315, int_stack+0, int_stack+46660, int_stack+48295, int_stack+46345, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+74258, int_stack+735, int_stack+315, int_stack+47080, int_stack+48736, int_stack+46660, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+75518, int_stack+74258, int_stack+73313, int_stack+60290, int_stack+63440, int_stack+59345, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+77408, int_stack+1275, int_stack+735, int_stack+47620, int_stack+49324, int_stack+47080, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+79028, int_stack+77408, int_stack+74258, int_stack+69173, int_stack+64763, int_stack+60290, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+81548, int_stack+79028, int_stack+75518, int_stack+70793, int_stack+66527, int_stack+61550, 4, 0);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+59345, int_stack+51613, int_stack+51025, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+73313, int_stack+52397, int_stack+51613, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+75665, int_stack+73313, int_stack+59345, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+79193, int_stack+50080, int_stack+49324, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+84698, int_stack+79193, int_stack+64763, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2391, int_stack+1950, int_stack+48736, int_stack+51025, int_stack+48295, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88226, int_stack+2979, int_stack+2391, int_stack+49324, int_stack+51613, int_stack+48736, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+89990, int_stack+88226, int_stack+0, int_stack+64763, int_stack+59345, int_stack+63440, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3735, int_stack+2979, int_stack+50080, int_stack+52397, int_stack+49324, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+92636, int_stack+0, int_stack+88226, int_stack+79193, int_stack+73313, int_stack+64763, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+92636, int_stack+89990, int_stack+84698, int_stack+75665, int_stack+66527, 5, 0);
 /*--- compute (gp|[r12,T2]|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+88226, int_stack+0, int_stack+81548, 210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+63440, int_stack+55421, int_stack+54665, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+81461, int_stack+56429, int_stack+55421, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+97676, int_stack+81461, int_stack+63440, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+102212, int_stack+53405, int_stack+52397, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+105236, int_stack+102212, int_stack+73313, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+48295, int_stack+5268, int_stack+4680, int_stack+51613, int_stack+54665, int_stack+51025, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+109940, int_stack+6052, int_stack+5268, int_stack+52397, int_stack+55421, int_stack+51613, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+112292, int_stack+109940, int_stack+48295, int_stack+73313, int_stack+63440, int_stack+59345, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+115820, int_stack+7060, int_stack+6052, int_stack+53405, int_stack+56429, int_stack+52397, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+118844, int_stack+115820, int_stack+109940, int_stack+102212, int_stack+81461, int_stack+73313, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+123548, int_stack+118844, int_stack+112292, int_stack+105236, int_stack+97676, int_stack+75665, 6, 0);
 /*--- compute (hp|[r12,T2]|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+109940, int_stack+123548, int_stack+0, 210);
 /*--- compute (gd|[r12,T2]|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+129428, int_stack+109940, int_stack+88226, 210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+88226, int_stack+10021, int_stack+8320, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+91061, int_stack+12289, int_stack+10021, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+91061, int_stack+88226, 45);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+148328, int_stack+57725, int_stack+56429, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+152216, int_stack+148328, int_stack+81461, 36);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94841, int_stack+11281, int_stack+9265, int_stack+55421, int_stack+8320, int_stack+54665, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5670, int_stack+13909, int_stack+11281, int_stack+56429, int_stack+10021, int_stack+55421, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+158264, int_stack+5670, int_stack+94841, int_stack+81461, int_stack+88226, int_stack+63440, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+162800, int_stack+15205, int_stack+13909, int_stack+57725, int_stack+12289, int_stack+56429, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54665, int_stack+162800, int_stack+5670, int_stack+148328, int_stack+91061, int_stack+81461, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5670, int_stack+54665, int_stack+158264, int_stack+152216, int_stack+0, int_stack+97676, 7, 0);
 /*--- compute (ip|[r12,T2]|hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+158264, int_stack+5670, int_stack+123548, 210);
 /*--- compute (hd|[r12,T2]|hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+175904, int_stack+158264, int_stack+109940, 210);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+109940, int_stack+70793, int_stack+61550, 15);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+113090, int_stack+84698, int_stack+66527, 21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+88226, int_stack+113090, int_stack+109940, 210);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+117500, int_stack+105236, int_stack+75665, 28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+158264, int_stack+117500, int_stack+113090, 210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+202364, int_stack+158264, int_stack+88226, 210);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+123380, int_stack+16825, int_stack+47620, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+125405, int_stack+123380, int_stack+69173, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+171494, int_stack+125405, int_stack+70793, 15);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+123380, int_stack+19600, int_stack+50080, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+123380, int_stack+79193, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+123380, int_stack+0, int_stack+84698, 21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+123380, int_stack+171494, 280);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+23485, int_stack+53405, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+12600, int_stack+102212, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+52393, int_stack+46345, int_stack+105236, 28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+60233, int_stack+52393, int_stack+123380, 280);
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+221264, int_stack+60233, int_stack+0, 280);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+102212, int_stack+152216, int_stack+97676, 36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+246464, int_stack+102212, int_stack+117500, 210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+264104, int_stack+246464, int_stack+158264, 210);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+97676, int_stack+17965, int_stack+17650, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+98621, int_stack+18385, int_stack+17965, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+99881, int_stack+98621, int_stack+97676, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+18925, int_stack+18385, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+47965, int_stack+46345, int_stack+98621, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+47965, int_stack+99881, 15);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+21196, int_stack+20755, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+47668, int_stack+21784, int_stack+21196, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49432, int_stack+47668, int_stack+46345, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+97676, int_stack+22540, int_stack+21784, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+15750, int_stack+97676, int_stack+47668, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+97676, int_stack+15750, int_stack+49432, 21);
 /*--- compute (gp|[r12,T1]|hf) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+148328, int_stack+97676, int_stack+12600, int_stack+113090, int_stack+171494, int_stack+109940, 5, 3);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+171494, int_stack+25613, int_stack+25025, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+173258, int_stack+26397, int_stack+25613, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+12600, int_stack+173258, int_stack+171494, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+16128, int_stack+27405, int_stack+26397, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+19152, int_stack+16128, int_stack+173258, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+19152, int_stack+12600, 28);
 /*--- compute (hp|[r12,T1]|hf) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+12600, int_stack+46345, int_stack+97676, int_stack+117500, int_stack+123380, int_stack+113090, 5, 3);
 /*--- compute (gd|[r12,T1]|hf) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+290564, int_stack+12600, int_stack+148328, int_stack+158264, int_stack+0, int_stack+88226, 5, 3);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+29421, int_stack+28665, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+30429, int_stack+29421, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5292, int_stack+2268, int_stack+0, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+148328, int_stack+31725, int_stack+30429, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+152216, int_stack+148328, int_stack+2268, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+109772, int_stack+152216, int_stack+5292, 36);
 /*--- compute (ip|[r12,T1]|hf) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+77873, int_stack+109772, int_stack+46345, int_stack+102212, int_stack+52393, int_stack+117500, 5, 3);
 /*--- compute (hd|[r12,T1]|hf) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+95513, int_stack+77873, int_stack+12600, int_stack+246464, int_stack+60233, int_stack+158264, 5, 3);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+246464, int_stack+33660, int_stack+33345, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+247409, int_stack+34080, int_stack+33660, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+248669, int_stack+247409, int_stack+246464, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+250559, int_stack+34620, int_stack+34080, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+252179, int_stack+250559, int_stack+247409, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+254699, int_stack+252179, int_stack+248669, 15);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+246464, int_stack+35736, int_stack+35295, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+247787, int_stack+36324, int_stack+35736, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+249551, int_stack+247787, int_stack+246464, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+252197, int_stack+37080, int_stack+36324, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+257849, int_stack+252197, int_stack+247787, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+257849, int_stack+249551, 21);
 /*--- compute (gp||hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+50755, int_stack+46345, int_stack+254699, 210);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+246464, int_stack+38613, int_stack+38025, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+248228, int_stack+39397, int_stack+38613, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+250580, int_stack+248228, int_stack+246464, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+254108, int_stack+40405, int_stack+39397, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+257132, int_stack+254108, int_stack+248228, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+60205, int_stack+257132, int_stack+250580, 28);
 /*--- compute (hp||hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+246464, int_stack+60205, int_stack+46345, 210);
 /*--- compute (gd||hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+66085, int_stack+246464, int_stack+50755, 210);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46345, int_stack+42421, int_stack+41665, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+48613, int_stack+43429, int_stack+42421, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+51637, int_stack+48613, int_stack+46345, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+56173, int_stack+44725, int_stack+43429, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+84985, int_stack+56173, int_stack+48613, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+148328, int_stack+84985, int_stack+51637, 36);
 /*--- compute (ip||hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+155888, int_stack+148328, int_stack+60205, 210);
 /*--- compute (hd||hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+155888, int_stack+246464, 210);
 /*--- compute (gf|[r12,T2]|hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+26460, int_stack+175904, int_stack+129428, 210);
     Libr12->te_ptr[3] = int_stack + 26460;
 /*--- compute (gf|[r12,T1]|hf) ---*/
   t1hrr1_build_gf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+121973, int_stack+95513, int_stack+290564, int_stack+264104, int_stack+221264, int_stack+202364, 5, 3);
     Libr12->te_ptr[2] = int_stack + 121973;
 /*--- compute (gf||hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+221264, int_stack+0, int_stack+66085, 210);
     Libr12->te_ptr[1] = int_stack + 221264;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+57960, int_stack+264104, int_stack+202364, 210);
     Libr12->te_ptr[0] = int_stack + 57960;

}
