/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0fd(Libr12_t *, prim_data *);

  /* Computes (h0|fd) integrals for linear R12-methods */

void hrr_grt_order_h0fd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][3] = int_stack + 0;
 Libr12->t2vrr_classes[5][3] = int_stack + 280;
 Libr12->gvrr_classes[6][4] = int_stack + 490;
 Libr12->t2vrr_classes[5][4] = int_stack + 910;
 Libr12->t2vrr_classes[5][5] = int_stack + 1225;
 Libr12->t1vrr_classes[5][3] = int_stack + 1666;
 Libr12->t1vrr_classes[5][4] = int_stack + 1876;
 Libr12->t1vrr_classes[5][5] = int_stack + 2191;
 Libr12->rvrr_classes[5][3] = int_stack + 2632;
 Libr12->rvrr_classes[5][4] = int_stack + 2842;
 Libr12->rvrr_classes[5][5] = int_stack + 3157;
 Libr12->gvrr_classes[5][3] = int_stack + 3598;
 Libr12->gvrr_classes[5][4] = int_stack + 3808;
 Libr12->gvrr_classes[5][5] = int_stack + 4123;
 memset(int_stack,0,4564*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4564;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0fd(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+4564, int_stack+3808, int_stack+3598, 21);
 /*--- compute (i0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+5194, int_stack+490, int_stack+0, 28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6034, int_stack+4123, int_stack+3808, 21);
 /*--- compute (h0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6979, int_stack+910, int_stack+280, int_stack+3808, int_stack+0, int_stack+3598, 5, 0);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7609, int_stack+1225, int_stack+910, int_stack+4123, int_stack+490, int_stack+3808, 5, 0);
 /*--- compute (h0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+3598, int_stack+1876, int_stack+1666, 21);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2191, int_stack+1876, 21);
 /*--- compute (h0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+2842, int_stack+2632, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1575, int_stack+3157, int_stack+2842, 21);
 /*--- compute (h0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8554, int_stack+7609, int_stack+6979, int_stack+6034, int_stack+5194, int_stack+4564, 5, 0);
     Libr12->te_ptr[3] = int_stack + 8554;
 /*--- compute (h0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+6979, int_stack+0, int_stack+3598, 21);
     Libr12->te_ptr[2] = int_stack + 6979;
 /*--- compute (h0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2520, int_stack+1575, int_stack+945, 21);
     Libr12->te_ptr[1] = int_stack + 2520;
 /*--- compute (h0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6034, int_stack+4564, 21);
     Libr12->te_ptr[0] = int_stack + 0;

}
