/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_d0hf(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+12, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+31, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+50, r12vrr_stack+40, r12vrr_stack+21, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+80, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+34, r12vrr_stack+6, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+95, r12vrr_stack+3, r12vrr_stack+31, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+101, r12vrr_stack+95, r12vrr_stack+34, r12vrr_stack+3, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+111, r12vrr_stack+101, r12vrr_stack+40, r12vrr_stack+95, r12vrr_stack+34, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+12, r12vrr_stack+31, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+126, r12vrr_stack+15, r12vrr_stack+34, r12vrr_stack+0, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+136, r12vrr_stack+21, r12vrr_stack+126, r12vrr_stack+6, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+151, r12vrr_stack+80, r12vrr_stack+136, NULL, NULL, r12vrr_stack+21);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+196, r12vrr_stack+111, r12vrr_stack+80, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+241, r12vrr_stack+196, r12vrr_stack+151, r12vrr_stack+111, r12vrr_stack+80, r12vrr_stack+50);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+331, r12vrr_stack+6, r12vrr_stack+15, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+349, r12vrr_stack+21, r12vrr_stack+126, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+379, r12vrr_stack+50, r12vrr_stack+349, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+331);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+31, r12vrr_stack+0, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+331, r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+50, r12vrr_stack+126, r12vrr_stack+331, r12vrr_stack+15, r12vrr_stack+34, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+439, r12vrr_stack+136, r12vrr_stack+50, NULL, NULL, r12vrr_stack+126);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+484, r12vrr_stack+151, r12vrr_stack+439, r12vrr_stack+80, r12vrr_stack+136, r12vrr_stack+349);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+574, r12vrr_stack+241, r12vrr_stack+484, r12vrr_stack+196, r12vrr_stack+151, r12vrr_stack+379);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+341, r12vrr_stack+136, r12vrr_stack+50, r12vrr_stack+21, r12vrr_stack+126, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+362, r12vrr_stack+80, r12vrr_stack+136, r12vrr_stack+40, r12vrr_stack+21, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+724, r12vrr_stack+362, r12vrr_stack+341, NULL, NULL, r12vrr_stack+136);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+383, r12vrr_stack+111, r12vrr_stack+80, r12vrr_stack+101, r12vrr_stack+40, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+787, r12vrr_stack+383, r12vrr_stack+362, NULL, NULL, r12vrr_stack+80);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+40, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+43, r12vrr_stack+0, r12vrr_stack+40, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+43, r12vrr_stack+31, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+65, r12vrr_stack+331, r12vrr_stack+12, r12vrr_stack+34, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+404, r12vrr_stack+50, r12vrr_stack+65, r12vrr_stack+126, r12vrr_stack+331, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+850, r12vrr_stack+341, r12vrr_stack+404, NULL, NULL, r12vrr_stack+50);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+913, r12vrr_stack+724, r12vrr_stack+850, r12vrr_stack+362, r12vrr_stack+341, r12vrr_stack+439);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1039, r12vrr_stack+787, r12vrr_stack+724, r12vrr_stack+383, r12vrr_stack+362, r12vrr_stack+151);
 tmp = r12vrr_stack + 1039;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1165, r12vrr_stack+1039, r12vrr_stack+913, r12vrr_stack+787, r12vrr_stack+724, r12vrr_stack+484);
 tmp = r12vrr_stack + 1165;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+151, r12vrr_stack+362, r12vrr_stack+341, r12vrr_stack+80, r12vrr_stack+136, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+425, r12vrr_stack+383, r12vrr_stack+362, r12vrr_stack+111, r12vrr_stack+80, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+453, r12vrr_stack+341, r12vrr_stack+404, r12vrr_stack+136, r12vrr_stack+50, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+481, r12vrr_stack+151, r12vrr_stack+453, NULL, NULL, r12vrr_stack+341);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1375, r12vrr_stack+425, r12vrr_stack+151, NULL, NULL, r12vrr_stack+362);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1459, r12vrr_stack+1375, r12vrr_stack+481, r12vrr_stack+425, r12vrr_stack+151, r12vrr_stack+724);
 tmp = r12vrr_stack + 1459;
 target_ptr = Libr12->gvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+724, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+727, r12vrr_stack+40, r12vrr_stack+724, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+733, r12vrr_stack+43, r12vrr_stack+727, r12vrr_stack+0, r12vrr_stack+40, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+80, r12vrr_stack+12, r12vrr_stack+733, r12vrr_stack+6, r12vrr_stack+43, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+743, r12vrr_stack+65, r12vrr_stack+80, r12vrr_stack+331, r12vrr_stack+12, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1627, r12vrr_stack+404, r12vrr_stack+743, r12vrr_stack+50, r12vrr_stack+65, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1655, r12vrr_stack+453, r12vrr_stack+1627, NULL, NULL, r12vrr_stack+404);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1739, r12vrr_stack+481, r12vrr_stack+1655, r12vrr_stack+151, r12vrr_stack+453, r12vrr_stack+850);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+1907, r12vrr_stack+1459, r12vrr_stack+1739, r12vrr_stack+1375, r12vrr_stack+481, r12vrr_stack+913);
 tmp = r12vrr_stack + 1907;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+850, r12vrr_stack+151, r12vrr_stack+453, r12vrr_stack+362, r12vrr_stack+341, NULL);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+886, r12vrr_stack+425, r12vrr_stack+151, r12vrr_stack+383, r12vrr_stack+362, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+922, r12vrr_stack+453, r12vrr_stack+1627, r12vrr_stack+341, r12vrr_stack+404, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2187, r12vrr_stack+850, r12vrr_stack+922, NULL, NULL, r12vrr_stack+453);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2295, r12vrr_stack+886, r12vrr_stack+850, NULL, NULL, r12vrr_stack+151);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2403, r12vrr_stack+2295, r12vrr_stack+2187, r12vrr_stack+886, r12vrr_stack+850, r12vrr_stack+481);
 tmp = r12vrr_stack + 2403;
 target_ptr = Libr12->gvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+724, r12vrr_stack+0, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+481, r12vrr_stack+727, r12vrr_stack+6, r12vrr_stack+40, r12vrr_stack+724, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+733, r12vrr_stack+481, r12vrr_stack+43, r12vrr_stack+727, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+506, r12vrr_stack+80, r12vrr_stack+491, r12vrr_stack+12, r12vrr_stack+733, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+12, r12vrr_stack+743, r12vrr_stack+506, r12vrr_stack+65, r12vrr_stack+80, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+40, r12vrr_stack+1627, r12vrr_stack+12, r12vrr_stack+404, r12vrr_stack+743, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2619, r12vrr_stack+922, r12vrr_stack+40, NULL, NULL, r12vrr_stack+1627);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2727, r12vrr_stack+2187, r12vrr_stack+2619, r12vrr_stack+850, r12vrr_stack+922, r12vrr_stack+1655);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2943, r12vrr_stack+2403, r12vrr_stack+2727, r12vrr_stack+2295, r12vrr_stack+2187, r12vrr_stack+1739);
 tmp = r12vrr_stack + 2943;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1655, r12vrr_stack+850, r12vrr_stack+922, r12vrr_stack+151, r12vrr_stack+453, NULL);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1700, r12vrr_stack+886, r12vrr_stack+850, r12vrr_stack+425, r12vrr_stack+151, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1745, r12vrr_stack+922, r12vrr_stack+40, r12vrr_stack+453, r12vrr_stack+1627, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3303, r12vrr_stack+1655, r12vrr_stack+1745, NULL, NULL, r12vrr_stack+922);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3438, r12vrr_stack+1700, r12vrr_stack+1655, NULL, NULL, r12vrr_stack+850);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3573, r12vrr_stack+3438, r12vrr_stack+3303, r12vrr_stack+1700, r12vrr_stack+1655, r12vrr_stack+2187);
 tmp = r12vrr_stack + 3573;
 target_ptr = Libr12->gvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2187, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2190, r12vrr_stack+0, r12vrr_stack+2187, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2196, r12vrr_stack+6, r12vrr_stack+2190, r12vrr_stack+724, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2206, r12vrr_stack+481, r12vrr_stack+2196, r12vrr_stack+727, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+404, r12vrr_stack+491, r12vrr_stack+2206, r12vrr_stack+733, r12vrr_stack+481, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2187, r12vrr_stack+506, r12vrr_stack+404, r12vrr_stack+80, r12vrr_stack+491, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2215, r12vrr_stack+12, r12vrr_stack+2187, r12vrr_stack+743, r12vrr_stack+506, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+724, r12vrr_stack+40, r12vrr_stack+2215, r12vrr_stack+1627, r12vrr_stack+12, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3843, r12vrr_stack+1745, r12vrr_stack+724, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3978, r12vrr_stack+3303, r12vrr_stack+3843, r12vrr_stack+1655, r12vrr_stack+1745, r12vrr_stack+2619);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+4248, r12vrr_stack+3573, r12vrr_stack+3978, r12vrr_stack+3438, r12vrr_stack+3303, r12vrr_stack+2727);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2619, r12vrr_stack+1655, r12vrr_stack+1745, r12vrr_stack+850, r12vrr_stack+922, NULL);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2674, r12vrr_stack+1700, r12vrr_stack+1655, r12vrr_stack+886, r12vrr_stack+850, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2729, r12vrr_stack+1745, r12vrr_stack+724, r12vrr_stack+922, r12vrr_stack+40, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+3843, r12vrr_stack+2619, r12vrr_stack+2729, NULL, NULL, r12vrr_stack+1745);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2729, r12vrr_stack+2674, r12vrr_stack+2619, NULL, NULL, r12vrr_stack+1655);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4698, r12vrr_stack+2729, r12vrr_stack+3843, r12vrr_stack+2674, r12vrr_stack+2619, r12vrr_stack+3303);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+0, &(Data->ss_r12_ss), NULL, r12vrr_stack+3, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+3303, r12vrr_stack+0, &(Data->ss_r12_ss), r12vrr_stack+95, r12vrr_stack+3, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+3309, r12vrr_stack+3303, r12vrr_stack+0, r12vrr_stack+101, r12vrr_stack+95, r12vrr_stack+3, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+3309, r12vrr_stack+3303, r12vrr_stack+111, r12vrr_stack+101, r12vrr_stack+95, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+404, r12vrr_stack+0, r12vrr_stack+3309, r12vrr_stack+383, r12vrr_stack+111, r12vrr_stack+101, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+724, r12vrr_stack+404, NULL, r12vrr_stack+787, r12vrr_stack+383, NULL, r12vrr_stack+111);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+3303, r12vrr_stack+404, r12vrr_stack+0, r12vrr_stack+425, r12vrr_stack+383, r12vrr_stack+111, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+0, r12vrr_stack+3303, NULL, r12vrr_stack+1375, r12vrr_stack+425, NULL, r12vrr_stack+383);

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+850, r12vrr_stack+3303, r12vrr_stack+404, r12vrr_stack+886, r12vrr_stack+425, r12vrr_stack+383, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+2187, r12vrr_stack+850, NULL, r12vrr_stack+2295, r12vrr_stack+886, NULL, r12vrr_stack+425);

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+84, r12vrr_stack+850, r12vrr_stack+3303, r12vrr_stack+1700, r12vrr_stack+886, r12vrr_stack+425, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+3843, r12vrr_stack+84, NULL, r12vrr_stack+3438, r12vrr_stack+1700, NULL, r12vrr_stack+886);

 /*--- compute (d0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3978, r12vrr_stack+1039, r12vrr_stack+1459, r12vrr_stack+1165, r12vrr_stack+574, r12vrr_stack+241);
 tmp = r12vrr_stack + 3978;
 target_ptr = Libr12->t2vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+453, r12vrr_stack+1459, r12vrr_stack+2403, r12vrr_stack+1907, r12vrr_stack+1165, r12vrr_stack+1039);
 tmp = r12vrr_stack + 453;
 target_ptr = Libr12->t2vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_d0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5028, r12vrr_stack+2403, r12vrr_stack+3573, r12vrr_stack+2943, r12vrr_stack+1907, r12vrr_stack+1459);
 tmp = r12vrr_stack + 5028;
 target_ptr = Libr12->t2vrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_d0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5244, r12vrr_stack+3573, r12vrr_stack+4698, r12vrr_stack+4248, r12vrr_stack+2943, r12vrr_stack+2403);
 tmp = r12vrr_stack + 5244;
 target_ptr = Libr12->t2vrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+241, r12vrr_stack+1039, r12vrr_stack+1165, r12vrr_stack+1459, r12vrr_stack+1375, r12vrr_stack+787);
 tmp = r12vrr_stack + 241;
 target_ptr = Libr12->t1vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1165, r12vrr_stack+1459, r12vrr_stack+1907, r12vrr_stack+2403, r12vrr_stack+2295, r12vrr_stack+1375);
 tmp = r12vrr_stack + 1165;
 target_ptr = Libr12->t1vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_d0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1745, r12vrr_stack+2403, r12vrr_stack+2943, r12vrr_stack+3573, r12vrr_stack+3438, r12vrr_stack+2295);
 tmp = r12vrr_stack + 1745;
 target_ptr = Libr12->t1vrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_d0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2894, r12vrr_stack+3573, r12vrr_stack+4248, r12vrr_stack+4698, r12vrr_stack+2729, r12vrr_stack+3438);
 tmp = r12vrr_stack + 2894;
 target_ptr = Libr12->t1vrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+2619, r12vrr_stack+724, r12vrr_stack+404, r12vrr_stack+1039, r12vrr_stack+787, r12vrr_stack+383, r12vrr_stack+196);
 tmp = r12vrr_stack + 2619;
 target_ptr = Libr12->rvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+4104, r12vrr_stack+0, r12vrr_stack+3303, r12vrr_stack+1459, r12vrr_stack+1375, r12vrr_stack+425, r12vrr_stack+787);
 tmp = r12vrr_stack + 4104;
 target_ptr = Libr12->rvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+1459, r12vrr_stack+2187, r12vrr_stack+850, r12vrr_stack+2403, r12vrr_stack+2295, r12vrr_stack+886, r12vrr_stack+1375);
 tmp = r12vrr_stack + 1459;
 target_ptr = Libr12->rvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+4272, r12vrr_stack+3843, r12vrr_stack+84, r12vrr_stack+3573, r12vrr_stack+3438, r12vrr_stack+1700, r12vrr_stack+2295);
 tmp = r12vrr_stack + 4272;
 target_ptr = Libr12->rvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];


}

