/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gpgg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+4);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+3);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+960, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+963, r12vrr_stack+0, r12vrr_stack+960, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+969, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+978, r12vrr_stack+12, r12vrr_stack+969, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+960);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+996, r12vrr_stack+30, r12vrr_stack+978, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+963);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1026, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1044, r12vrr_stack+114, r12vrr_stack+1026, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+969);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1080, r12vrr_stack+132, r12vrr_stack+1044, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+978);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+1140, r12vrr_stack+204, r12vrr_stack+1080, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+996);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+168, r12vrr_stack+78, r12vrr_stack+3, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+174, r12vrr_stack+87, r12vrr_stack+168, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1230, r12vrr_stack+93, r12vrr_stack+174, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1260, r12vrr_stack+520, r12vrr_stack+1230, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+1026);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1320, r12vrr_stack+550, r12vrr_stack+1260, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+1044);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1420, r12vrr_stack+610, r12vrr_stack+1320, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+1080);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1570, r12vrr_stack+810, r12vrr_stack+1420, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+1140);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+184, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+60, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1780, r12vrr_stack+60, r12vrr_stack+184, NULL, NULL, r12vrr_stack+284);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1825, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1840, r12vrr_stack+1825, r12vrr_stack+60, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1885, r12vrr_stack+93, r12vrr_stack+174, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1900, r12vrr_stack+184, r12vrr_stack+1885, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1945, r12vrr_stack+1780, r12vrr_stack+1900, r12vrr_stack+60, r12vrr_stack+184, r12vrr_stack+520);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2035, r12vrr_stack+1840, r12vrr_stack+1780, r12vrr_stack+1825, r12vrr_stack+60, r12vrr_stack+294);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2125, r12vrr_stack+2035, r12vrr_stack+1945, r12vrr_stack+1840, r12vrr_stack+1780, r12vrr_stack+550);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2275, r12vrr_stack+294, r12vrr_stack+1825, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2320, r12vrr_stack+2275, r12vrr_stack+1840, r12vrr_stack+294, r12vrr_stack+1825, r12vrr_stack+324);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2410, r12vrr_stack+2320, r12vrr_stack+2035, r12vrr_stack+2275, r12vrr_stack+1840, r12vrr_stack+354);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+75, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+3, r12vrr_stack+75, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+309, r12vrr_stack+168, r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+319, r12vrr_stack+174, r12vrr_stack+309, r12vrr_stack+87, r12vrr_stack+168, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+334, r12vrr_stack+1885, r12vrr_stack+319, NULL, NULL, r12vrr_stack+174);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2560, r12vrr_stack+1900, r12vrr_stack+334, r12vrr_stack+184, r12vrr_stack+1885, r12vrr_stack+1230);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2650, r12vrr_stack+1945, r12vrr_stack+2560, r12vrr_stack+1780, r12vrr_stack+1900, r12vrr_stack+1260);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2800, r12vrr_stack+2125, r12vrr_stack+2650, r12vrr_stack+2035, r12vrr_stack+1945, r12vrr_stack+1320);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3025, r12vrr_stack+2410, r12vrr_stack+2125, r12vrr_stack+2320, r12vrr_stack+2035, r12vrr_stack+610);
 tmp = r12vrr_stack + 3025;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+3250, r12vrr_stack+3025, r12vrr_stack+2800, r12vrr_stack+2410, r12vrr_stack+2125, r12vrr_stack+1420);
 tmp = r12vrr_stack + 3250;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+379, r12vrr_stack+60, r12vrr_stack+184, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3565, r12vrr_stack+1825, r12vrr_stack+60, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3586, r12vrr_stack+184, r12vrr_stack+1885, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3607, r12vrr_stack+379, r12vrr_stack+3586, NULL, NULL, r12vrr_stack+184);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3670, r12vrr_stack+3565, r12vrr_stack+379, NULL, NULL, r12vrr_stack+60);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3733, r12vrr_stack+3670, r12vrr_stack+3607, r12vrr_stack+3565, r12vrr_stack+379, r12vrr_stack+1780);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1780, r12vrr_stack+294, r12vrr_stack+1825, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3859, r12vrr_stack+1780, r12vrr_stack+3565, NULL, NULL, r12vrr_stack+1825);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3922, r12vrr_stack+3859, r12vrr_stack+3670, r12vrr_stack+1780, r12vrr_stack+3565, r12vrr_stack+1840);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1840, r12vrr_stack+1885, r12vrr_stack+319, r12vrr_stack+93, r12vrr_stack+174, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4048, r12vrr_stack+3586, r12vrr_stack+1840, NULL, NULL, r12vrr_stack+1885);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4111, r12vrr_stack+3607, r12vrr_stack+4048, r12vrr_stack+379, r12vrr_stack+3586, r12vrr_stack+1900);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4237, r12vrr_stack+3733, r12vrr_stack+4111, r12vrr_stack+3670, r12vrr_stack+3607, r12vrr_stack+1945);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4447, r12vrr_stack+3922, r12vrr_stack+3733, r12vrr_stack+3859, r12vrr_stack+3670, r12vrr_stack+2035);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4657, r12vrr_stack+4447, r12vrr_stack+4237, r12vrr_stack+3922, r12vrr_stack+3733, r12vrr_stack+2125);
 tmp = r12vrr_stack + 4657;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2035, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2038, r12vrr_stack+75, r12vrr_stack+2035, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2044, r12vrr_stack+81, r12vrr_stack+2038, r12vrr_stack+3, r12vrr_stack+75, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2054, r12vrr_stack+309, r12vrr_stack+2044, r12vrr_stack+168, r12vrr_stack+81, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2069, r12vrr_stack+319, r12vrr_stack+2054, r12vrr_stack+174, r12vrr_stack+309, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4972, r12vrr_stack+1840, r12vrr_stack+2069, NULL, NULL, r12vrr_stack+319);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5035, r12vrr_stack+4048, r12vrr_stack+4972, r12vrr_stack+3586, r12vrr_stack+1840, r12vrr_stack+334);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5161, r12vrr_stack+4111, r12vrr_stack+5035, r12vrr_stack+3607, r12vrr_stack+4048, r12vrr_stack+2560);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5371, r12vrr_stack+4237, r12vrr_stack+5161, r12vrr_stack+3733, r12vrr_stack+4111, r12vrr_stack+2650);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+5686, r12vrr_stack+4657, r12vrr_stack+5371, r12vrr_stack+4447, r12vrr_stack+4237, r12vrr_stack+2800);
 tmp = r12vrr_stack + 5686;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2090, r12vrr_stack+379, r12vrr_stack+3586, r12vrr_stack+60, r12vrr_stack+184, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+264, r12vrr_stack+3565, r12vrr_stack+379, r12vrr_stack+1825, r12vrr_stack+60, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6127, r12vrr_stack+3586, r12vrr_stack+1840, r12vrr_stack+184, r12vrr_stack+1885, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6155, r12vrr_stack+2090, r12vrr_stack+6127, NULL, NULL, r12vrr_stack+3586);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6239, r12vrr_stack+264, r12vrr_stack+2090, NULL, NULL, r12vrr_stack+379);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6323, r12vrr_stack+6239, r12vrr_stack+6155, r12vrr_stack+264, r12vrr_stack+2090, r12vrr_stack+3607);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3607, r12vrr_stack+1780, r12vrr_stack+3565, r12vrr_stack+294, r12vrr_stack+1825, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6491, r12vrr_stack+3607, r12vrr_stack+264, NULL, NULL, r12vrr_stack+3565);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6575, r12vrr_stack+6491, r12vrr_stack+6239, r12vrr_stack+3607, r12vrr_stack+264, r12vrr_stack+3670);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3635, r12vrr_stack+1840, r12vrr_stack+2069, r12vrr_stack+1885, r12vrr_stack+319, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6743, r12vrr_stack+6127, r12vrr_stack+3635, NULL, NULL, r12vrr_stack+1840);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6827, r12vrr_stack+6155, r12vrr_stack+6743, r12vrr_stack+2090, r12vrr_stack+6127, r12vrr_stack+4048);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6995, r12vrr_stack+6323, r12vrr_stack+6827, r12vrr_stack+6239, r12vrr_stack+6155, r12vrr_stack+4111);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7275, r12vrr_stack+6575, r12vrr_stack+6323, r12vrr_stack+6491, r12vrr_stack+6239, r12vrr_stack+3733);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7555, r12vrr_stack+7275, r12vrr_stack+6995, r12vrr_stack+6575, r12vrr_stack+6323, r12vrr_stack+4237);
 tmp = r12vrr_stack + 7555;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3663, r12vrr_stack+2035, r12vrr_stack+3, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3669, r12vrr_stack+2038, r12vrr_stack+3663, r12vrr_stack+75, r12vrr_stack+2035, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3679, r12vrr_stack+2044, r12vrr_stack+3669, r12vrr_stack+81, r12vrr_stack+2038, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3694, r12vrr_stack+2054, r12vrr_stack+3679, r12vrr_stack+309, r12vrr_stack+2044, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3715, r12vrr_stack+2069, r12vrr_stack+3694, r12vrr_stack+319, r12vrr_stack+2054, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3743, r12vrr_stack+3635, r12vrr_stack+3715, NULL, NULL, r12vrr_stack+2069);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7975, r12vrr_stack+6743, r12vrr_stack+3743, r12vrr_stack+6127, r12vrr_stack+3635, r12vrr_stack+4972);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+8143, r12vrr_stack+6827, r12vrr_stack+7975, r12vrr_stack+6155, r12vrr_stack+6743, r12vrr_stack+5035);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+8423, r12vrr_stack+6995, r12vrr_stack+8143, r12vrr_stack+6323, r12vrr_stack+6827, r12vrr_stack+5161);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8843, r12vrr_stack+7555, r12vrr_stack+8423, r12vrr_stack+7275, r12vrr_stack+6995, r12vrr_stack+5371);
 tmp = r12vrr_stack + 8843;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1801, r12vrr_stack+2090, r12vrr_stack+6127, r12vrr_stack+379, r12vrr_stack+3586, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9431, r12vrr_stack+264, r12vrr_stack+2090, r12vrr_stack+3565, r12vrr_stack+379, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9467, r12vrr_stack+6127, r12vrr_stack+3635, r12vrr_stack+3586, r12vrr_stack+1840, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9503, r12vrr_stack+1801, r12vrr_stack+9467, NULL, NULL, r12vrr_stack+6127);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9611, r12vrr_stack+9431, r12vrr_stack+1801, NULL, NULL, r12vrr_stack+2090);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9719, r12vrr_stack+9611, r12vrr_stack+9503, r12vrr_stack+9431, r12vrr_stack+1801, r12vrr_stack+6155);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6155, r12vrr_stack+3607, r12vrr_stack+264, r12vrr_stack+1780, r12vrr_stack+3565, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9935, r12vrr_stack+6155, r12vrr_stack+9431, NULL, NULL, r12vrr_stack+264);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10043, r12vrr_stack+9935, r12vrr_stack+9611, r12vrr_stack+6155, r12vrr_stack+9431, r12vrr_stack+6239);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3565, r12vrr_stack+3635, r12vrr_stack+3715, r12vrr_stack+1840, r12vrr_stack+2069, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6191, r12vrr_stack+9467, r12vrr_stack+3565, NULL, NULL, r12vrr_stack+3635);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10259, r12vrr_stack+9503, r12vrr_stack+6191, r12vrr_stack+1801, r12vrr_stack+9467, r12vrr_stack+6743);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10475, r12vrr_stack+9719, r12vrr_stack+10259, r12vrr_stack+9611, r12vrr_stack+9503, r12vrr_stack+6827);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10835, r12vrr_stack+10043, r12vrr_stack+9719, r12vrr_stack+9935, r12vrr_stack+9611, r12vrr_stack+6323);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11195, r12vrr_stack+10835, r12vrr_stack+10475, r12vrr_stack+10043, r12vrr_stack+9719, r12vrr_stack+6995);
 tmp = r12vrr_stack + 11195;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1837, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3601, r12vrr_stack+3, r12vrr_stack+1837, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+6299, r12vrr_stack+3663, r12vrr_stack+3601, r12vrr_stack+2035, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+6309, r12vrr_stack+3669, r12vrr_stack+6299, r12vrr_stack+2038, r12vrr_stack+3663, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+6324, r12vrr_stack+3679, r12vrr_stack+6309, r12vrr_stack+2044, r12vrr_stack+3669, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6345, r12vrr_stack+3694, r12vrr_stack+6324, r12vrr_stack+2054, r12vrr_stack+3679, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6373, r12vrr_stack+3715, r12vrr_stack+6345, r12vrr_stack+2069, r12vrr_stack+3694, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11735, r12vrr_stack+3565, r12vrr_stack+6373, NULL, NULL, r12vrr_stack+3715);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11843, r12vrr_stack+6191, r12vrr_stack+11735, r12vrr_stack+9467, r12vrr_stack+3565, r12vrr_stack+3743);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12059, r12vrr_stack+10259, r12vrr_stack+11843, r12vrr_stack+9503, r12vrr_stack+6191, r12vrr_stack+7975);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12419, r12vrr_stack+10475, r12vrr_stack+12059, r12vrr_stack+9719, r12vrr_stack+10259, r12vrr_stack+8143);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12959, r12vrr_stack+11195, r12vrr_stack+12419, r12vrr_stack+10835, r12vrr_stack+10475, r12vrr_stack+8423);
 tmp = r12vrr_stack + 12959;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6409, r12vrr_stack+1801, r12vrr_stack+9467, r12vrr_stack+2090, r12vrr_stack+6127, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13715, r12vrr_stack+9431, r12vrr_stack+1801, r12vrr_stack+264, r12vrr_stack+2090, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13760, r12vrr_stack+9467, r12vrr_stack+3565, r12vrr_stack+6127, r12vrr_stack+3635, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13805, r12vrr_stack+6409, r12vrr_stack+13760, NULL, NULL, r12vrr_stack+9467);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13940, r12vrr_stack+13715, r12vrr_stack+6409, NULL, NULL, r12vrr_stack+1801);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14075, r12vrr_stack+13940, r12vrr_stack+13805, r12vrr_stack+13715, r12vrr_stack+6409, r12vrr_stack+9503);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9503, r12vrr_stack+6155, r12vrr_stack+9431, r12vrr_stack+3607, r12vrr_stack+264, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14345, r12vrr_stack+9503, r12vrr_stack+13715, NULL, NULL, r12vrr_stack+9431);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14480, r12vrr_stack+14345, r12vrr_stack+13940, r12vrr_stack+9503, r12vrr_stack+13715, r12vrr_stack+9611);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9548, r12vrr_stack+3565, r12vrr_stack+6373, r12vrr_stack+3635, r12vrr_stack+3715, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14750, r12vrr_stack+13760, r12vrr_stack+9548, NULL, NULL, r12vrr_stack+3565);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14885, r12vrr_stack+13805, r12vrr_stack+14750, r12vrr_stack+6409, r12vrr_stack+13760, r12vrr_stack+6191);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15155, r12vrr_stack+14075, r12vrr_stack+14885, r12vrr_stack+13940, r12vrr_stack+13805, r12vrr_stack+10259);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15605, r12vrr_stack+14480, r12vrr_stack+14075, r12vrr_stack+14345, r12vrr_stack+13940, r12vrr_stack+9719);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16055, r12vrr_stack+15605, r12vrr_stack+15155, r12vrr_stack+14480, r12vrr_stack+14075, r12vrr_stack+10475);
 tmp = r12vrr_stack + 16055;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+264, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+1837, r12vrr_stack+264, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+267, r12vrr_stack+3601, r12vrr_stack+81, r12vrr_stack+3, r12vrr_stack+1837, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+277, r12vrr_stack+6299, r12vrr_stack+267, r12vrr_stack+3663, r12vrr_stack+3601, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+9593, r12vrr_stack+6309, r12vrr_stack+277, r12vrr_stack+3669, r12vrr_stack+6299, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6127, r12vrr_stack+6324, r12vrr_stack+9593, r12vrr_stack+3679, r12vrr_stack+6309, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9614, r12vrr_stack+6345, r12vrr_stack+6127, r12vrr_stack+3694, r12vrr_stack+6324, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9650, r12vrr_stack+6373, r12vrr_stack+9614, r12vrr_stack+3715, r12vrr_stack+6345, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9695, r12vrr_stack+9548, r12vrr_stack+9650, NULL, NULL, r12vrr_stack+6373);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16730, r12vrr_stack+14750, r12vrr_stack+9695, r12vrr_stack+13760, r12vrr_stack+9548, r12vrr_stack+11735);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17000, r12vrr_stack+14885, r12vrr_stack+16730, r12vrr_stack+13805, r12vrr_stack+14750, r12vrr_stack+11843);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17450, r12vrr_stack+15155, r12vrr_stack+17000, r12vrr_stack+14075, r12vrr_stack+14885, r12vrr_stack+12059);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+18125, r12vrr_stack+16055, r12vrr_stack+17450, r12vrr_stack+15605, r12vrr_stack+15155, r12vrr_stack+12419);
 tmp = r12vrr_stack + 18125;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9830, r12vrr_stack+6409, r12vrr_stack+13760, r12vrr_stack+1801, r12vrr_stack+9467, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19070, r12vrr_stack+13715, r12vrr_stack+6409, r12vrr_stack+9431, r12vrr_stack+1801, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19125, r12vrr_stack+13760, r12vrr_stack+9548, r12vrr_stack+9467, r12vrr_stack+3565, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19180, r12vrr_stack+9830, r12vrr_stack+19125, NULL, NULL, r12vrr_stack+13760);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19345, r12vrr_stack+19070, r12vrr_stack+9830, NULL, NULL, r12vrr_stack+6409);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19510, r12vrr_stack+19345, r12vrr_stack+19180, r12vrr_stack+19070, r12vrr_stack+9830, r12vrr_stack+13805);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6409, r12vrr_stack+9503, r12vrr_stack+13715, r12vrr_stack+6155, r12vrr_stack+9431, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13760, r12vrr_stack+6409, r12vrr_stack+19070, NULL, NULL, r12vrr_stack+13715);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19840, r12vrr_stack+13760, r12vrr_stack+19345, r12vrr_stack+6409, r12vrr_stack+19070, r12vrr_stack+13940);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19070, r12vrr_stack+9548, r12vrr_stack+9650, r12vrr_stack+3565, r12vrr_stack+6373, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20170, r12vrr_stack+19125, r12vrr_stack+19070, NULL, NULL, r12vrr_stack+9548);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20335, r12vrr_stack+19180, r12vrr_stack+20170, r12vrr_stack+9830, r12vrr_stack+19125, r12vrr_stack+14750);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20665, r12vrr_stack+19510, r12vrr_stack+20335, r12vrr_stack+19345, r12vrr_stack+19180, r12vrr_stack+14885);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21215, r12vrr_stack+19840, r12vrr_stack+19510, r12vrr_stack+13760, r12vrr_stack+19345, r12vrr_stack+14075);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21765, r12vrr_stack+21215, r12vrr_stack+20665, r12vrr_stack+19840, r12vrr_stack+19510, r12vrr_stack+15155);
 tmp = r12vrr_stack + 21765;
 target_ptr = Libr12->gvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+19840, r12vrr_stack+960, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (f0|00)^3 ---*/
 _BUILD_f000(Data,r12vrr_stack+19846, r12vrr_stack+963, r12vrr_stack+19840, r12vrr_stack+0, r12vrr_stack+960, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+960, r12vrr_stack+105, r12vrr_stack+78, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+19856, r12vrr_stack+969, r12vrr_stack+960, r12vrr_stack+9, r12vrr_stack+105, r12vrr_stack+3);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+48, r12vrr_stack+978, r12vrr_stack+19856, r12vrr_stack+12, r12vrr_stack+969, r12vrr_stack+19840);

 /*--- compute (g0|p0)^2 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+19874, r12vrr_stack+996, r12vrr_stack+48, r12vrr_stack+30, r12vrr_stack+978, r12vrr_stack+19846);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+969, r12vrr_stack+87, r12vrr_stack+168, NULL, NULL, r12vrr_stack+78);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1801, r12vrr_stack+1026, r12vrr_stack+969, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+960);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+19919, r12vrr_stack+1044, r12vrr_stack+1801, r12vrr_stack+114, r12vrr_stack+1026, r12vrr_stack+19856);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+19979, r12vrr_stack+1080, r12vrr_stack+19919, r12vrr_stack+132, r12vrr_stack+1044, r12vrr_stack+48);

 /*--- compute (h0|d0)^1 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+19345, r12vrr_stack+1140, r12vrr_stack+19979, r12vrr_stack+204, r12vrr_stack+1080, r12vrr_stack+19874);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+19840, r12vrr_stack+174, r12vrr_stack+309, NULL, NULL, r12vrr_stack+168);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+987, r12vrr_stack+1230, r12vrr_stack+19840, r12vrr_stack+93, r12vrr_stack+174, r12vrr_stack+969);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+87, r12vrr_stack+1260, r12vrr_stack+987, r12vrr_stack+520, r12vrr_stack+1230, r12vrr_stack+1801);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1047, r12vrr_stack+1320, r12vrr_stack+87, r12vrr_stack+550, r12vrr_stack+1260, r12vrr_stack+19919);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+13715, r12vrr_stack+1420, r12vrr_stack+1047, r12vrr_stack+610, r12vrr_stack+1320, r12vrr_stack+19979);

 /*--- compute (i0|f0)^0 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+19870, r12vrr_stack+1570, r12vrr_stack+13715, r12vrr_stack+810, r12vrr_stack+1420, r12vrr_stack+19345);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+19345, r12vrr_stack+319, r12vrr_stack+2054, NULL, NULL, r12vrr_stack+309);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+19390, r12vrr_stack+334, r12vrr_stack+19345, r12vrr_stack+1885, r12vrr_stack+319, r12vrr_stack+19840);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+520, r12vrr_stack+2560, r12vrr_stack+19390, r12vrr_stack+1900, r12vrr_stack+334, r12vrr_stack+987);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1197, r12vrr_stack+2650, r12vrr_stack+520, r12vrr_stack+1945, r12vrr_stack+2560, r12vrr_stack+87);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+13925, r12vrr_stack+2800, r12vrr_stack+1197, r12vrr_stack+2125, r12vrr_stack+2650, r12vrr_stack+1047);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+22590, r12vrr_stack+3250, r12vrr_stack+13925, r12vrr_stack+3025, r12vrr_stack+2800, r12vrr_stack+13715);
 tmp = r12vrr_stack + 22590;
 target_ptr = Libr12->gvrr_classes[6][4];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+13715, r12vrr_stack+2069, r12vrr_stack+3694, NULL, NULL, r12vrr_stack+2054);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+13778, r12vrr_stack+4972, r12vrr_stack+13715, r12vrr_stack+1840, r12vrr_stack+2069, r12vrr_stack+19345);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1840, r12vrr_stack+5035, r12vrr_stack+13778, r12vrr_stack+4048, r12vrr_stack+4972, r12vrr_stack+19390);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2560, r12vrr_stack+5161, r12vrr_stack+1840, r12vrr_stack+4111, r12vrr_stack+5035, r12vrr_stack+520);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+23010, r12vrr_stack+5371, r12vrr_stack+2560, r12vrr_stack+4237, r12vrr_stack+5161, r12vrr_stack+1197);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+960, r12vrr_stack+5686, r12vrr_stack+23010, r12vrr_stack+4657, r12vrr_stack+5371, r12vrr_stack+13925);
 tmp = r12vrr_stack + 960;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+520, r12vrr_stack+3715, r12vrr_stack+6345, NULL, NULL, r12vrr_stack+3694);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4972, r12vrr_stack+3743, r12vrr_stack+520, r12vrr_stack+3635, r12vrr_stack+3715, r12vrr_stack+13715);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5140, r12vrr_stack+7975, r12vrr_stack+4972, r12vrr_stack+6743, r12vrr_stack+3743, r12vrr_stack+13778);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+13715, r12vrr_stack+8143, r12vrr_stack+5140, r12vrr_stack+6827, r12vrr_stack+7975, r12vrr_stack+1840);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+23451, r12vrr_stack+8423, r12vrr_stack+13715, r12vrr_stack+6995, r12vrr_stack+8143, r12vrr_stack+2560);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+24039, r12vrr_stack+8843, r12vrr_stack+23451, r12vrr_stack+7555, r12vrr_stack+8423, r12vrr_stack+23010);
 tmp = r12vrr_stack + 24039;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+23010, r12vrr_stack+6373, r12vrr_stack+9614, NULL, NULL, r12vrr_stack+6345);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+23118, r12vrr_stack+11735, r12vrr_stack+23010, r12vrr_stack+3565, r12vrr_stack+6373, r12vrr_stack+520);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2560, r12vrr_stack+11843, r12vrr_stack+23118, r12vrr_stack+6191, r12vrr_stack+11735, r12vrr_stack+4972);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7975, r12vrr_stack+12059, r12vrr_stack+2560, r12vrr_stack+10259, r12vrr_stack+11843, r12vrr_stack+5140);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+24823, r12vrr_stack+12419, r12vrr_stack+7975, r12vrr_stack+10475, r12vrr_stack+12059, r12vrr_stack+13715);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+25579, r12vrr_stack+12959, r12vrr_stack+24823, r12vrr_stack+11195, r12vrr_stack+12419, r12vrr_stack+23451);
 tmp = r12vrr_stack + 25579;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+13715, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+264, r12vrr_stack+13715, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+13715, r12vrr_stack+81, r12vrr_stack+0, r12vrr_stack+1837, r12vrr_stack+264, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+13725, r12vrr_stack+267, r12vrr_stack+13715, r12vrr_stack+3601, r12vrr_stack+81, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+13740, r12vrr_stack+277, r12vrr_stack+13725, r12vrr_stack+6299, r12vrr_stack+267, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+13761, r12vrr_stack+9593, r12vrr_stack+13740, r12vrr_stack+6309, r12vrr_stack+277, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13715, r12vrr_stack+6127, r12vrr_stack+13761, r12vrr_stack+6324, r12vrr_stack+9593, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13751, r12vrr_stack+9614, r12vrr_stack+13715, r12vrr_stack+6345, r12vrr_stack+6127, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13796, r12vrr_stack+9650, r12vrr_stack+13751, NULL, NULL, r12vrr_stack+9614);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13931, r12vrr_stack+9695, r12vrr_stack+13796, r12vrr_stack+9548, r12vrr_stack+9650, r12vrr_stack+23010);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10259, r12vrr_stack+16730, r12vrr_stack+13931, r12vrr_stack+14750, r12vrr_stack+9695, r12vrr_stack+23118);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+23010, r12vrr_stack+17000, r12vrr_stack+10259, r12vrr_stack+14885, r12vrr_stack+16730, r12vrr_stack+2560);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11735, r12vrr_stack+17450, r12vrr_stack+23010, r12vrr_stack+15155, r12vrr_stack+17000, r12vrr_stack+7975);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26587, r12vrr_stack+18125, r12vrr_stack+11735, r12vrr_stack+16055, r12vrr_stack+17450, r12vrr_stack+24823);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+24823, r12vrr_stack+9650, r12vrr_stack+13751, r12vrr_stack+6373, r12vrr_stack+9614, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19345, r12vrr_stack+19070, r12vrr_stack+24823, NULL, NULL, r12vrr_stack+9650);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+24823, r12vrr_stack+20170, r12vrr_stack+19345, r12vrr_stack+19125, r12vrr_stack+19070, r12vrr_stack+9695);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11735, r12vrr_stack+20335, r12vrr_stack+24823, r12vrr_stack+19180, r12vrr_stack+20170, r12vrr_stack+16730);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7975, r12vrr_stack+20665, r12vrr_stack+11735, r12vrr_stack+19510, r12vrr_stack+20335, r12vrr_stack+17000);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11735, r12vrr_stack+21765, r12vrr_stack+7975, r12vrr_stack+21215, r12vrr_stack+20665, r12vrr_stack+17450);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+7975, &(Data->ss_r12_ss), NULL, r12vrr_stack+6, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+7975, &(Data->ss_r12_ss), r12vrr_stack+414, r12vrr_stack+6, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+7978, r12vrr_stack+0, r12vrr_stack+7975, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+6, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+6, r12vrr_stack+7978, r12vrr_stack+0, r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+414, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+21, r12vrr_stack+6, NULL, r12vrr_stack+2275, r12vrr_stack+294, NULL, r12vrr_stack+420);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+66, r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+2320, r12vrr_stack+2275, r12vrr_stack+294, r12vrr_stack+430);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+7988, r12vrr_stack+66, r12vrr_stack+21, r12vrr_stack+2410, r12vrr_stack+2320, r12vrr_stack+2275, r12vrr_stack+460);

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+430, r12vrr_stack+7988, r12vrr_stack+66, r12vrr_stack+3025, r12vrr_stack+2410, r12vrr_stack+2320, r12vrr_stack+710);
 tmp = r12vrr_stack + 430;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+7978, r12vrr_stack+1780, r12vrr_stack+294, r12vrr_stack+420, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+42, r12vrr_stack+21, NULL, r12vrr_stack+3859, r12vrr_stack+1780, NULL, r12vrr_stack+294);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+105, r12vrr_stack+42, r12vrr_stack+21, r12vrr_stack+3922, r12vrr_stack+3859, r12vrr_stack+1780, r12vrr_stack+2275);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+8138, r12vrr_stack+105, r12vrr_stack+42, r12vrr_stack+4447, r12vrr_stack+3922, r12vrr_stack+3859, r12vrr_stack+2320);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+8348, r12vrr_stack+8138, r12vrr_stack+105, r12vrr_stack+4657, r12vrr_stack+4447, r12vrr_stack+3922, r12vrr_stack+2410);
 tmp = r12vrr_stack + 8348;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+6127, r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3607, r12vrr_stack+1780, r12vrr_stack+294, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+42, r12vrr_stack+6127, NULL, r12vrr_stack+6491, r12vrr_stack+3607, NULL, r12vrr_stack+1780);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+126, r12vrr_stack+42, r12vrr_stack+6127, r12vrr_stack+6575, r12vrr_stack+6491, r12vrr_stack+3607, r12vrr_stack+3859);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+16730, r12vrr_stack+126, r12vrr_stack+42, r12vrr_stack+7275, r12vrr_stack+6575, r12vrr_stack+6491, r12vrr_stack+3922);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+17010, r12vrr_stack+16730, r12vrr_stack+126, r12vrr_stack+7555, r12vrr_stack+7275, r12vrr_stack+6575, r12vrr_stack+4447);
 tmp = r12vrr_stack + 17010;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+42, r12vrr_stack+6127, r12vrr_stack+21, r12vrr_stack+6155, r12vrr_stack+3607, r12vrr_stack+1780, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+1780, r12vrr_stack+42, NULL, r12vrr_stack+9935, r12vrr_stack+6155, NULL, r12vrr_stack+3607);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+1888, r12vrr_stack+1780, r12vrr_stack+42, r12vrr_stack+10043, r12vrr_stack+9935, r12vrr_stack+6155, r12vrr_stack+6491);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+17430, r12vrr_stack+1888, r12vrr_stack+1780, r12vrr_stack+10835, r12vrr_stack+10043, r12vrr_stack+9935, r12vrr_stack+6575);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+24823, r12vrr_stack+17430, r12vrr_stack+1888, r12vrr_stack+11195, r12vrr_stack+10835, r12vrr_stack+10043, r12vrr_stack+7275);
 tmp = r12vrr_stack + 24823;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+1780, r12vrr_stack+42, r12vrr_stack+6127, r12vrr_stack+9503, r12vrr_stack+6155, r12vrr_stack+3607, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+1825, r12vrr_stack+1780, NULL, r12vrr_stack+14345, r12vrr_stack+9503, NULL, r12vrr_stack+6155);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+6127, r12vrr_stack+1825, r12vrr_stack+1780, r12vrr_stack+14480, r12vrr_stack+14345, r12vrr_stack+9503, r12vrr_stack+9935);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+1960, r12vrr_stack+6127, r12vrr_stack+1825, r12vrr_stack+15605, r12vrr_stack+14480, r12vrr_stack+14345, r12vrr_stack+10043);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+6397, r12vrr_stack+1960, r12vrr_stack+6127, r12vrr_stack+16055, r12vrr_stack+15605, r12vrr_stack+14480, r12vrr_stack+10835);
 tmp = r12vrr_stack + 6397;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6127, r12vrr_stack+3025, r12vrr_stack+4657, r12vrr_stack+3250, r12vrr_stack+1570, r12vrr_stack+810);
 tmp = r12vrr_stack + 6127;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+4657, r12vrr_stack+7555, r12vrr_stack+5686, r12vrr_stack+3250, r12vrr_stack+3025);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19070, r12vrr_stack+7555, r12vrr_stack+11195, r12vrr_stack+8843, r12vrr_stack+5686, r12vrr_stack+4657);
 tmp = r12vrr_stack + 19070;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23010, r12vrr_stack+11195, r12vrr_stack+16055, r12vrr_stack+12959, r12vrr_stack+8843, r12vrr_stack+7555);
 tmp = r12vrr_stack + 23010;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13715, r12vrr_stack+16055, r12vrr_stack+21765, r12vrr_stack+18125, r12vrr_stack+12959, r12vrr_stack+11195);
 tmp = r12vrr_stack + 13715;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+17790, r12vrr_stack+3250, r12vrr_stack+5686, r12vrr_stack+22590, r12vrr_stack+19870, r12vrr_stack+1570);
 tmp = r12vrr_stack + 17790;
 target_ptr = Libr12->t2vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19490, r12vrr_stack+5686, r12vrr_stack+8843, r12vrr_stack+960, r12vrr_stack+22590, r12vrr_stack+3250);
 tmp = r12vrr_stack + 19490;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19931, r12vrr_stack+8843, r12vrr_stack+12959, r12vrr_stack+24039, r12vrr_stack+960, r12vrr_stack+5686);
 tmp = r12vrr_stack + 19931;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14390, r12vrr_stack+12959, r12vrr_stack+18125, r12vrr_stack+25579, r12vrr_stack+24039, r12vrr_stack+8843);
 tmp = r12vrr_stack + 14390;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9431, r12vrr_stack+18125, r12vrr_stack+11735, r12vrr_stack+26587, r12vrr_stack+25579, r12vrr_stack+12959);
 tmp = r12vrr_stack + 9431;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20519, r12vrr_stack+3025, r12vrr_stack+3250, r12vrr_stack+4657, r12vrr_stack+4447, r12vrr_stack+2410);
 tmp = r12vrr_stack + 20519;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20744, r12vrr_stack+4657, r12vrr_stack+5686, r12vrr_stack+7555, r12vrr_stack+7275, r12vrr_stack+4447);
 tmp = r12vrr_stack + 20744;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23550, r12vrr_stack+7555, r12vrr_stack+8843, r12vrr_stack+11195, r12vrr_stack+10835, r12vrr_stack+7275);
 tmp = r12vrr_stack + 23550;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4972, r12vrr_stack+11195, r12vrr_stack+12959, r12vrr_stack+16055, r12vrr_stack+15605, r12vrr_stack+10835);
 tmp = r12vrr_stack + 4972;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3565, r12vrr_stack+16055, r12vrr_stack+18125, r12vrr_stack+21765, r12vrr_stack+21215, r12vrr_stack+15605);
 tmp = r12vrr_stack + 3565;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21059, r12vrr_stack+3250, r12vrr_stack+22590, r12vrr_stack+5686, r12vrr_stack+4657, r12vrr_stack+3025);
 tmp = r12vrr_stack + 21059;
 target_ptr = Libr12->t1vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2560, r12vrr_stack+5686, r12vrr_stack+960, r12vrr_stack+8843, r12vrr_stack+7555, r12vrr_stack+4657);
 tmp = r12vrr_stack + 2560;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+960, r12vrr_stack+8843, r12vrr_stack+24039, r12vrr_stack+12959, r12vrr_stack+11195, r12vrr_stack+7555);
 tmp = r12vrr_stack + 960;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23970, r12vrr_stack+12959, r12vrr_stack+25579, r12vrr_stack+18125, r12vrr_stack+16055, r12vrr_stack+11195);
 tmp = r12vrr_stack + 23970;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+25363, r12vrr_stack+18125, r12vrr_stack+26587, r12vrr_stack+11735, r12vrr_stack+21765, r12vrr_stack+16055);
 tmp = r12vrr_stack + 25363;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||g0)^0 ---*/
 _R_BUILD_h0g0(Data,r12vrr_stack+11735, r12vrr_stack+430, r12vrr_stack+7988, r12vrr_stack+3250, r12vrr_stack+3025, r12vrr_stack+2410, r12vrr_stack+810);
 tmp = r12vrr_stack + 11735;
 target_ptr = Libr12->rvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+12050, r12vrr_stack+8348, r12vrr_stack+8138, r12vrr_stack+5686, r12vrr_stack+4657, r12vrr_stack+4447, r12vrr_stack+3025);
 tmp = r12vrr_stack + 12050;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+315, r12vrr_stack+17010, r12vrr_stack+16730, r12vrr_stack+8843, r12vrr_stack+7555, r12vrr_stack+7275, r12vrr_stack+4657);
 tmp = r12vrr_stack + 315;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+7975, r12vrr_stack+24823, r12vrr_stack+17430, r12vrr_stack+12959, r12vrr_stack+11195, r12vrr_stack+10835, r12vrr_stack+7555);
 tmp = r12vrr_stack + 7975;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+16730, r12vrr_stack+6397, r12vrr_stack+1960, r12vrr_stack+18125, r12vrr_stack+16055, r12vrr_stack+15605, r12vrr_stack+11195);
 tmp = r12vrr_stack + 16730;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];


}

