/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gphp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+4);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+521, r12vrr_stack+476, r12vrr_stack+506, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+611, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+131);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+24, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+701, r12vrr_stack+24, r12vrr_stack+161, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+170, r12vrr_stack+701, r12vrr_stack+164, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+732, r12vrr_stack+717, r12vrr_stack+491, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+180);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+180, r12vrr_stack+21, r12vrr_stack+27, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+186, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+882, r12vrr_stack+506, r12vrr_stack+867, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+927, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+226);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1017, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+256);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1167, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+316);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1317, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+376);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+196, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+161, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1542, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+196);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1560, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1578, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+161);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1614, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+1542);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1674, r12vrr_stack+216, r12vrr_stack+186, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1704, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+1560);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1764, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+1578);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1864, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+1614);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+27, r12vrr_stack+3, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+326, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+210, r12vrr_stack+180, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2014, r12vrr_stack+867, r12vrr_stack+326, NULL, NULL, r12vrr_stack+186);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2059, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+1674);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2149, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+1704);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2299, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+1764);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2524, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+1864);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+341, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+131, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2839, r12vrr_stack+131, r12vrr_stack+341, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2902, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2923, r12vrr_stack+2902, r12vrr_stack+131, NULL, NULL, r12vrr_stack+476);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2986, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+216, r12vrr_stack+186, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3007, r12vrr_stack+341, r12vrr_stack+2986, NULL, NULL, r12vrr_stack+867);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3070, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+882);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3196, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+521);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3322, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+927);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+707, r12vrr_stack+170, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+2902, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+566);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+611);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+170, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+173, r12vrr_stack+3, r12vrr_stack+170, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+542, r12vrr_stack+15, r12vrr_stack+173, r12vrr_stack+27, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+552, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+180, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+567, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+186, r12vrr_stack+316, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+588, r12vrr_stack+2986, r12vrr_stack+567, NULL, NULL, r12vrr_stack+326);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3931, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+2014);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4057, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+2059);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4267, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2149);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+1017);
 tmp = r12vrr_stack + 4582;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+2299);
 tmp = r12vrr_stack + 4897;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+651, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+476, r12vrr_stack+506, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5338, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+491, r12vrr_stack+476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5366, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+506, r12vrr_stack+867, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5394, r12vrr_stack+651, r12vrr_stack+5366, NULL, NULL, r12vrr_stack+341);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5478, r12vrr_stack+5338, r12vrr_stack+651, NULL, NULL, r12vrr_stack+131);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5562, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2839);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+717, r12vrr_stack+491, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+5338, NULL, NULL, r12vrr_stack+2902);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+2923);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2923, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+867, r12vrr_stack+326, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5982, r12vrr_stack+5366, r12vrr_stack+2923, NULL, NULL, r12vrr_stack+2986);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6066, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+3007);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6234, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+3070);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+3196);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+3322);
 tmp = r12vrr_stack + 6794;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3196, r12vrr_stack+170, r12vrr_stack+27, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3202, r12vrr_stack+173, r12vrr_stack+3196, r12vrr_stack+3, r12vrr_stack+170, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3212, r12vrr_stack+542, r12vrr_stack+3202, r12vrr_stack+15, r12vrr_stack+173, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3227, r12vrr_stack+552, r12vrr_stack+3212, r12vrr_stack+316, r12vrr_stack+542, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3248, r12vrr_stack+567, r12vrr_stack+3227, r12vrr_stack+326, r12vrr_stack+552, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7214, r12vrr_stack+2923, r12vrr_stack+3248, NULL, NULL, r12vrr_stack+567);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7298, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+588);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7466, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+3931);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7746, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+4057);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+4267);
 tmp = r12vrr_stack + 8166;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3276, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+131, r12vrr_stack+341, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2902, r12vrr_stack+131, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+111, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+341, r12vrr_stack+2986, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+3276, r12vrr_stack+111, NULL, NULL, r12vrr_stack+5366);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8862, r12vrr_stack+476, r12vrr_stack+3276, NULL, NULL, r12vrr_stack+651);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8970, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+476, r12vrr_stack+3276, r12vrr_stack+5394);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+651, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+521, r12vrr_stack+2902, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5366, r12vrr_stack+651, r12vrr_stack+476, NULL, NULL, r12vrr_stack+5338);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9186, r12vrr_stack+5366, r12vrr_stack+8862, r12vrr_stack+651, r12vrr_stack+476, r12vrr_stack+5478);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+2923, r12vrr_stack+3248, r12vrr_stack+2986, r12vrr_stack+567, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9402, r12vrr_stack+111, r12vrr_stack+476, NULL, NULL, r12vrr_stack+2923);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+8754, r12vrr_stack+9402, r12vrr_stack+3276, r12vrr_stack+111, r12vrr_stack+5982);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9726, r12vrr_stack+8970, r12vrr_stack+9510, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+6066);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10086, r12vrr_stack+9186, r12vrr_stack+8970, r12vrr_stack+5366, r12vrr_stack+8862, r12vrr_stack+5562);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10446, r12vrr_stack+10086, r12vrr_stack+9726, r12vrr_stack+9186, r12vrr_stack+8970, r12vrr_stack+6234);
 tmp = r12vrr_stack + 10446;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+15, r12vrr_stack+196, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+512, r12vrr_stack+30, r12vrr_stack+21, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+57, r12vrr_stack+161, r12vrr_stack+512, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+3);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+9186, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+15);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1542, r12vrr_stack+210, r12vrr_stack+180, NULL, NULL, r12vrr_stack+21);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+9216, r12vrr_stack+1560, r12vrr_stack+1542, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+512);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+9252, r12vrr_stack+1578, r12vrr_stack+9216, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+57);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+9312, r12vrr_stack+1614, r12vrr_stack+9252, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+9186);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+9186, r12vrr_stack+186, r12vrr_stack+316, NULL, NULL, r12vrr_stack+180);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1560, r12vrr_stack+1674, r12vrr_stack+9186, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+1542);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+8862, r12vrr_stack+1704, r12vrr_stack+1560, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+9216);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+5338, r12vrr_stack+1764, r12vrr_stack+8862, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+9252);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+5488, r12vrr_stack+1864, r12vrr_stack+5338, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+9312);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+9216, r12vrr_stack+326, r12vrr_stack+552, NULL, NULL, r12vrr_stack+316);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+9261, r12vrr_stack+2014, r12vrr_stack+9216, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+9186);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+2059, r12vrr_stack+9261, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+1560);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1770, r12vrr_stack+2149, r12vrr_stack+1620, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+8862);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+10986, r12vrr_stack+2299, r12vrr_stack+1770, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+5338);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+11301, r12vrr_stack+2524, r12vrr_stack+10986, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+5488);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+5338, r12vrr_stack+567, r12vrr_stack+3227, NULL, NULL, r12vrr_stack+552);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5401, r12vrr_stack+588, r12vrr_stack+5338, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+9216);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+867, r12vrr_stack+3931, r12vrr_stack+5401, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+9261);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+1995, r12vrr_stack+4057, r12vrr_stack+867, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+1620);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+11721, r12vrr_stack+4267, r12vrr_stack+1995, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+1770);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+12162, r12vrr_stack+4897, r12vrr_stack+11721, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+10986);
 tmp = r12vrr_stack + 12162;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+10986, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+10989, r12vrr_stack+27, r12vrr_stack+10986, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+10995, r12vrr_stack+3196, r12vrr_stack+10989, r12vrr_stack+170, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+27, r12vrr_stack+3202, r12vrr_stack+10995, r12vrr_stack+173, r12vrr_stack+3196, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+42, r12vrr_stack+3212, r12vrr_stack+27, r12vrr_stack+542, r12vrr_stack+3202, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+63, r12vrr_stack+3227, r12vrr_stack+42, r12vrr_stack+552, r12vrr_stack+3212, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+10986, r12vrr_stack+3248, r12vrr_stack+63, NULL, NULL, r12vrr_stack+3227);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+11070, r12vrr_stack+7214, r12vrr_stack+10986, r12vrr_stack+2923, r12vrr_stack+3248, r12vrr_stack+5338);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3931, r12vrr_stack+7298, r12vrr_stack+11070, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5401);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+1542, r12vrr_stack+7466, r12vrr_stack+3931, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+867);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+3931, r12vrr_stack+7746, r12vrr_stack+1542, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+1995);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+1542, r12vrr_stack+8166, r12vrr_stack+3931, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+11721);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+27, r12vrr_stack+3248, r12vrr_stack+63, r12vrr_stack+567, r12vrr_stack+3227, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8862, r12vrr_stack+476, r12vrr_stack+27, NULL, NULL, r12vrr_stack+3248);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9186, r12vrr_stack+9402, r12vrr_stack+8862, r12vrr_stack+111, r12vrr_stack+476, r12vrr_stack+7214);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+27, r12vrr_stack+9510, r12vrr_stack+9186, r12vrr_stack+8754, r12vrr_stack+9402, r12vrr_stack+7298);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3931, r12vrr_stack+9726, r12vrr_stack+27, r12vrr_stack+8970, r12vrr_stack+9510, r12vrr_stack+7466);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+10446, r12vrr_stack+3931, r12vrr_stack+10086, r12vrr_stack+9726, r12vrr_stack+7746);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+3931, &(Data->ss_r12_ss), NULL, r12vrr_stack+24, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+3934, r12vrr_stack+3931, &(Data->ss_r12_ss), r12vrr_stack+701, r12vrr_stack+24, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+3940, r12vrr_stack+3934, r12vrr_stack+3931, r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+24, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+3950, r12vrr_stack+3940, r12vrr_stack+3934, r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+701, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+3965, r12vrr_stack+3950, r12vrr_stack+3940, r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+707, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+3986, r12vrr_stack+3965, NULL, r12vrr_stack+3532, r12vrr_stack+521, NULL, r12vrr_stack+717);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+4049, r12vrr_stack+3986, r12vrr_stack+3965, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+732);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+4175, r12vrr_stack+4049, r12vrr_stack+3986, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+777);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+10986, r12vrr_stack+4175, r12vrr_stack+4049, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+1167);
 tmp = r12vrr_stack + 10986;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+3986, r12vrr_stack+3965, r12vrr_stack+3950, r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+717, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+4014, r12vrr_stack+3986, NULL, r12vrr_stack+5730, r12vrr_stack+2839, NULL, r12vrr_stack+521);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+4385, r12vrr_stack+4014, r12vrr_stack+3986, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+3532);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+2839, r12vrr_stack+4385, r12vrr_stack+4014, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+3595);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+3119, r12vrr_stack+2839, r12vrr_stack+4385, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+3721);
 tmp = r12vrr_stack + 3119;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9510, r12vrr_stack+4582, r12vrr_stack+6794, r12vrr_stack+4897, r12vrr_stack+2524, r12vrr_stack+1317);
 tmp = r12vrr_stack + 9510;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7214, r12vrr_stack+6794, r12vrr_stack+10446, r12vrr_stack+8166, r12vrr_stack+4897, r12vrr_stack+4582);
 tmp = r12vrr_stack + 7214;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11721, r12vrr_stack+4897, r12vrr_stack+8166, r12vrr_stack+12162, r12vrr_stack+11301, r12vrr_stack+2524);
 tmp = r12vrr_stack + 11721;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5338, r12vrr_stack+8166, r12vrr_stack+8754, r12vrr_stack+1542, r12vrr_stack+12162, r12vrr_stack+4897);
 tmp = r12vrr_stack + 5338;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11301, r12vrr_stack+4582, r12vrr_stack+4897, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+3721);
 tmp = r12vrr_stack + 11301;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7634, r12vrr_stack+6794, r12vrr_stack+8166, r12vrr_stack+10446, r12vrr_stack+10086, r12vrr_stack+6514);
 tmp = r12vrr_stack + 7634;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9825, r12vrr_stack+4897, r12vrr_stack+12162, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4582);
 tmp = r12vrr_stack + 9825;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5926, r12vrr_stack+8166, r12vrr_stack+1542, r12vrr_stack+8754, r12vrr_stack+10446, r12vrr_stack+6794);
 tmp = r12vrr_stack + 5926;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+8754, r12vrr_stack+10986, r12vrr_stack+4175, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+1317);
 tmp = r12vrr_stack + 8754;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+12162, r12vrr_stack+3119, r12vrr_stack+2839, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+4582);
 tmp = r12vrr_stack + 12162;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];


}

