/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_hdhg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+5);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+960, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+975, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+990, r12vrr_stack+975, r12vrr_stack+960, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+975, NULL, NULL, r12vrr_stack+274);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1095, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1110, r12vrr_stack+960, r12vrr_stack+1095, NULL, NULL, r12vrr_stack+284);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1155, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+294);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1245, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+324);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1335, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+354);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+324, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+324, r12vrr_stack+6, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+414, r12vrr_stack+324, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+420, r12vrr_stack+81, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1485, r12vrr_stack+337, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1530, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+430);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+460);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+78, r12vrr_stack+6, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+430, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+440, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+455, r12vrr_stack+1095, r12vrr_stack+440, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+520);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1860, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+550);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2010, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+610);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2235, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+710);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2460, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+810);

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+500, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+500, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+503, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2775, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+500);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+2793, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+54);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+2823, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+2841, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+503);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+2877, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+2775);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+2937, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+2793);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+168, r12vrr_stack+93, r12vrr_stack+430, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3027, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+2823);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3087, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+2841);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+3187, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+2877);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+3337, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+2937);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+198, r12vrr_stack+6, r12vrr_stack+3, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+710, r12vrr_stack+414, r12vrr_stack+198, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+720, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+87, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+735, r12vrr_stack+440, r12vrr_stack+720, NULL, NULL, r12vrr_stack+430);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3547, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+168);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3637, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+3027);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3787, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+3087);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4012, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+3187);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+4327, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+3337);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+780, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+294, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4747, r12vrr_stack+780, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1095);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4810, r12vrr_stack+294, r12vrr_stack+780, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4873, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+1110);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1110, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4999, r12vrr_stack+1110, r12vrr_stack+294, NULL, NULL, r12vrr_stack+975);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5062, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+990);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+93, r12vrr_stack+430, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+5188, r12vrr_stack+352, r12vrr_stack+990, NULL, NULL, r12vrr_stack+440);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5251, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+455);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5377, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+1770);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5587, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1155);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5797, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+1860);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+327, r12vrr_stack+420, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1110, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1245);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1335);

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1032, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+1032, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+198, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1050, r12vrr_stack+710, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+198, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1065, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+430, r12vrr_stack+710, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1194, r12vrr_stack+990, r12vrr_stack+1065, NULL, NULL, r12vrr_stack+720);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1257, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+735);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6763, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+3547);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6973, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+3637);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7288, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+3787);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+2010);
 tmp = r12vrr_stack + 7729;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+4012);
 tmp = r12vrr_stack + 8170;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1383, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+960, r12vrr_stack+1095, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1411, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+975, r12vrr_stack+960, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8758, r12vrr_stack+1411, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+780);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1439, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+1035, r12vrr_stack+975, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8842, r12vrr_stack+1439, r12vrr_stack+1411, NULL, NULL, r12vrr_stack+294);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+960, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+1095, r12vrr_stack+440, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8926, r12vrr_stack+1383, r12vrr_stack+960, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9010, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+4747);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9178, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+4810);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9346, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+4873);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+337, r12vrr_stack+1035, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1439, NULL, NULL, r12vrr_stack+1110);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+4999);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+5062);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4859, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+440, r12vrr_stack+720, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4887, r12vrr_stack+960, r12vrr_stack+4859, NULL, NULL, r12vrr_stack+990);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4971, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+5188);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+10074, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+5251);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10354, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+5377);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+5587);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+5797);
 tmp = r12vrr_stack + 11194;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5587, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5590, r12vrr_stack+1032, r12vrr_stack+5587, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5596, r12vrr_stack+48, r12vrr_stack+5590, r12vrr_stack+3, r12vrr_stack+1032, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+5596, r12vrr_stack+198, r12vrr_stack+48, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5606, r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+710, r12vrr_stack+420, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5627, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+720, r12vrr_stack+1050, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5655, r12vrr_stack+4859, r12vrr_stack+5627, NULL, NULL, r12vrr_stack+1065);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+11782, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+1194);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+11950, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1257);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+12230, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+6763);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+12650, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+6973);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+7288);
 tmp = r12vrr_stack + 13238;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+780, r12vrr_stack+352, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5139, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+294, r12vrr_stack+780, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+5139, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+373, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+1110, r12vrr_stack+294, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14130, r12vrr_stack+373, r12vrr_stack+5139, NULL, NULL, r12vrr_stack+1411);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+264, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+352, r12vrr_stack+990, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+5739, r12vrr_stack+264, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14346, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+8926);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14562, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+8758);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14778, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+9010);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+1011, r12vrr_stack+1110, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+373, NULL, NULL, r12vrr_stack+1439);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+8842);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+9178);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8794, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+990, r12vrr_stack+1065, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+264, r12vrr_stack+8794, NULL, NULL, r12vrr_stack+4859);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+4887);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15930, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+4971);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16290, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+10074);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+9346);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+10354);
 tmp = r12vrr_stack + 17370;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+8830, r12vrr_stack+5587, r12vrr_stack+3, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+8836, r12vrr_stack+5590, r12vrr_stack+8830, r12vrr_stack+1032, r12vrr_stack+5587, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+8846, r12vrr_stack+5596, r12vrr_stack+8836, r12vrr_stack+48, r12vrr_stack+5590, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1035, r12vrr_stack+8846, r12vrr_stack+420, r12vrr_stack+5596, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8861, r12vrr_stack+5606, r12vrr_stack+352, r12vrr_stack+1050, r12vrr_stack+1035, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8889, r12vrr_stack+5627, r12vrr_stack+8861, r12vrr_stack+1065, r12vrr_stack+5606, NULL);

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9142, r12vrr_stack+8794, r12vrr_stack+8889, NULL, NULL, r12vrr_stack+5627);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9250, r12vrr_stack+9034, r12vrr_stack+9142, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+5655);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+15714, r12vrr_stack+9250, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+11782);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18486, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+11950);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19026, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+12230);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+12650);
 tmp = r12vrr_stack + 19782;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1086, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+1383, r12vrr_stack+960, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9466, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+1411, r12vrr_stack+1383, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+9466, r12vrr_stack+1086, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9511, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+1439, r12vrr_stack+1411, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20925, r12vrr_stack+9511, r12vrr_stack+9466, NULL, NULL, r12vrr_stack+5139);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1383, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+960, r12vrr_stack+4859, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+1086, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+264);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21195, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+9466, r12vrr_stack+1086, r12vrr_stack+14238);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21465, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+9511, r12vrr_stack+9466, r12vrr_stack+14022);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21735, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+14346);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+4747, r12vrr_stack+1439, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+9511, NULL, NULL, r12vrr_stack+373);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14022, r12vrr_stack+9511, r12vrr_stack+14130);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14562);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+8794, r12vrr_stack+8889, r12vrr_stack+4859, r12vrr_stack+5627, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14373, r12vrr_stack+1383, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+8794);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14508, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+9034);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22905, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+15714);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+23355, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+15930);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14778);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+16290);
 tmp = r12vrr_stack + 24705;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1032, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+1032, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+14778, r12vrr_stack+8830, r12vrr_stack+48, r12vrr_stack+5587, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+14788, r12vrr_stack+8836, r12vrr_stack+14778, r12vrr_stack+5590, r12vrr_stack+8830, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+14803, r12vrr_stack+8846, r12vrr_stack+14788, r12vrr_stack+5596, r12vrr_stack+8836, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+14824, r12vrr_stack+352, r12vrr_stack+14803, r12vrr_stack+1035, r12vrr_stack+8846, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14852, r12vrr_stack+8861, r12vrr_stack+14824, r12vrr_stack+5606, r12vrr_stack+352, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14888, r12vrr_stack+8889, r12vrr_stack+14852, r12vrr_stack+5627, r12vrr_stack+8861, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14933, r12vrr_stack+14067, r12vrr_stack+14888, NULL, NULL, r12vrr_stack+8889);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+14373, r12vrr_stack+14933, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+9142);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25920, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+9250);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26370, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+18126);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27045, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+18486);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+19026);
 tmp = r12vrr_stack + 27990;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15068, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+5739, r12vrr_stack+264, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14112, r12vrr_stack+9466, r12vrr_stack+1086, r12vrr_stack+5139, r12vrr_stack+5739, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+14112, r12vrr_stack+15068, NULL, NULL, r12vrr_stack+1086);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+9511, r12vrr_stack+9466, r12vrr_stack+373, r12vrr_stack+5139, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29415, r12vrr_stack+5739, r12vrr_stack+14112, NULL, NULL, r12vrr_stack+9466);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14167, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+264, r12vrr_stack+8794, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+15068, r12vrr_stack+14167, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29745, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14112, r12vrr_stack+15068, r12vrr_stack+21060);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30075, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+20790);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30405, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+21195);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+9511, r12vrr_stack+8758, r12vrr_stack+373, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+9511);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+20925);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+21465);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20845, r12vrr_stack+14067, r12vrr_stack+14888, r12vrr_stack+8794, r12vrr_stack+8889, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+14167, r12vrr_stack+20845, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21390, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+15068, r12vrr_stack+14167, r12vrr_stack+14373);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14508);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32385, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+22905);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21735);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+23355);
 tmp = r12vrr_stack + 34035;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5794, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+373, r12vrr_stack+1032, r12vrr_stack+5794, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+379, r12vrr_stack+48, r12vrr_stack+373, r12vrr_stack+3, r12vrr_stack+1032, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+15123, r12vrr_stack+14778, r12vrr_stack+379, r12vrr_stack+8830, r12vrr_stack+48, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+389, r12vrr_stack+14788, r12vrr_stack+15123, r12vrr_stack+8836, r12vrr_stack+14778, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+20900, r12vrr_stack+14803, r12vrr_stack+389, r12vrr_stack+8846, r12vrr_stack+14788, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+20928, r12vrr_stack+14824, r12vrr_stack+20900, r12vrr_stack+352, r12vrr_stack+14803, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20964, r12vrr_stack+14852, r12vrr_stack+20928, r12vrr_stack+8861, r12vrr_stack+14824, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21720, r12vrr_stack+14888, r12vrr_stack+20964, r12vrr_stack+8889, r12vrr_stack+14852, NULL);

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21775, r12vrr_stack+20845, r12vrr_stack+21720, NULL, NULL, r12vrr_stack+14888);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+14933);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35520, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+25650);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36070, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+25920);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36895, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+26370);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+27045);
 tmp = r12vrr_stack + 38050;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21940, r12vrr_stack+15068, r12vrr_stack+14167, r12vrr_stack+1086, r12vrr_stack+1383, NULL);

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22006, r12vrr_stack+14112, r12vrr_stack+15068, r12vrr_stack+9466, r12vrr_stack+1086, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+22006, r12vrr_stack+21940, NULL, NULL, r12vrr_stack+15068);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22072, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+9511, r12vrr_stack+9466, NULL);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+22072, r12vrr_stack+22006, NULL, NULL, r12vrr_stack+14112);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+9556, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+1383, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39986, r12vrr_stack+21940, r12vrr_stack+9556, NULL, NULL, r12vrr_stack+14167);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40184, r12vrr_stack+39590, r12vrr_stack+39986, r12vrr_stack+22006, r12vrr_stack+21940, r12vrr_stack+29580);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40580, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+22072, r12vrr_stack+22006, r12vrr_stack+29250);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40976, r12vrr_stack+40580, r12vrr_stack+40184, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+29745);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22006, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+14022, r12vrr_stack+9511, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+22006, r12vrr_stack+22072, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41636, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+22006, r12vrr_stack+22072, r12vrr_stack+29415);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42032, r12vrr_stack+41636, r12vrr_stack+40580, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+30075);

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+14067, r12vrr_stack+14888, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+9556, r12vrr_stack+39788, NULL, NULL, r12vrr_stack+20845);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29448, r12vrr_stack+39986, r12vrr_stack+29250, r12vrr_stack+21940, r12vrr_stack+9556, r12vrr_stack+21225);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42692, r12vrr_stack+40184, r12vrr_stack+29448, r12vrr_stack+39590, r12vrr_stack+39986, r12vrr_stack+21390);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+43352, r12vrr_stack+40976, r12vrr_stack+42692, r12vrr_stack+40580, r12vrr_stack+40184, r12vrr_stack+31835);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+44342, r12vrr_stack+42032, r12vrr_stack+40976, r12vrr_stack+41636, r12vrr_stack+40580, r12vrr_stack+30405);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+45332, r12vrr_stack+44342, r12vrr_stack+43352, r12vrr_stack+42032, r12vrr_stack+40976, r12vrr_stack+32385);
 tmp = r12vrr_stack + 45332;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+40580, r12vrr_stack+500, r12vrr_stack+3, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+40586, r12vrr_stack+54, r12vrr_stack+40580, r12vrr_stack+0, r12vrr_stack+500, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+105, r12vrr_stack+78, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+60, r12vrr_stack+503, r12vrr_stack+21, r12vrr_stack+9, r12vrr_stack+105, r12vrr_stack+3);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+960, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+40580);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+1086, r12vrr_stack+2793, r12vrr_stack+960, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+40586);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+30, r12vrr_stack+87, r12vrr_stack+414, NULL, NULL, r12vrr_stack+78);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+40596, r12vrr_stack+2823, r12vrr_stack+30, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+21);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+264, r12vrr_stack+2841, r12vrr_stack+40596, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+60);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+9466, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+960);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+14112, r12vrr_stack+2937, r12vrr_stack+9466, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+1086);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+780, r12vrr_stack+430, r12vrr_stack+710, NULL, NULL, r12vrr_stack+414);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+780, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+30);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+40632, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+40596);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+40732, r12vrr_stack+3087, r12vrr_stack+40632, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+264);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+41636, r12vrr_stack+3187, r12vrr_stack+40732, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+9466);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+41846, r12vrr_stack+3337, r12vrr_stack+41636, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+14112);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+810, r12vrr_stack+720, r12vrr_stack+1050, NULL, NULL, r12vrr_stack+710);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+855, r12vrr_stack+735, r12vrr_stack+810, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+780);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+42126, r12vrr_stack+3547, r12vrr_stack+855, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+204);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+42276, r12vrr_stack+3637, r12vrr_stack+42126, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+40632);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+29844, r12vrr_stack+3787, r12vrr_stack+42276, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+40732);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+30159, r12vrr_stack+4012, r12vrr_stack+29844, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+41636);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+46718, r12vrr_stack+4327, r12vrr_stack+30159, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+41846);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1770, r12vrr_stack+1065, r12vrr_stack+5606, NULL, NULL, r12vrr_stack+1050);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1833, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+810);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1959, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+855);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+30579, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+42126);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+47258, r12vrr_stack+6973, r12vrr_stack+30579, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+42276);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+47699, r12vrr_stack+7288, r12vrr_stack+47258, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+29844);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+48287, r12vrr_stack+8170, r12vrr_stack+47699, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+30159);
 tmp = r12vrr_stack + 48287;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5797, r12vrr_stack+5627, r12vrr_stack+8861, NULL, NULL, r12vrr_stack+5606);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5881, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+1770);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5139, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+1833);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+49043, r12vrr_stack+11950, r12vrr_stack+5139, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+1959);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+49463, r12vrr_stack+12230, r12vrr_stack+49043, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+30579);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+50051, r12vrr_stack+12650, r12vrr_stack+49463, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+47258);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+50835, r12vrr_stack+13238, r12vrr_stack+50051, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+47699);
 tmp = r12vrr_stack + 50835;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10074, r12vrr_stack+8889, r12vrr_stack+14852, NULL, NULL, r12vrr_stack+8861);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10182, r12vrr_stack+9142, r12vrr_stack+10074, r12vrr_stack+8794, r12vrr_stack+8889, r12vrr_stack+5797);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10398, r12vrr_stack+9250, r12vrr_stack+10182, r12vrr_stack+9034, r12vrr_stack+9142, r12vrr_stack+5881);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+51843, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+15714, r12vrr_stack+9250, r12vrr_stack+5139);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+52383, r12vrr_stack+18486, r12vrr_stack+51843, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+49043);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+53139, r12vrr_stack+19026, r12vrr_stack+52383, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+49463);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+54147, r12vrr_stack+19782, r12vrr_stack+53139, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+50051);
 tmp = r12vrr_stack + 54147;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14888, r12vrr_stack+20964, NULL, NULL, r12vrr_stack+14852);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15849, r12vrr_stack+14933, r12vrr_stack+15714, r12vrr_stack+14067, r12vrr_stack+14888, r12vrr_stack+10074);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16119, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+14373, r12vrr_stack+14933, r12vrr_stack+10182);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+55443, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+10398);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+56118, r12vrr_stack+26370, r12vrr_stack+55443, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+51843);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+57063, r12vrr_stack+27045, r12vrr_stack+56118, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+52383);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+58323, r12vrr_stack+27990, r12vrr_stack+57063, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+53139);
 tmp = r12vrr_stack + 58323;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+22905, r12vrr_stack+5794, r12vrr_stack+0, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+22911, r12vrr_stack+373, r12vrr_stack+22905, r12vrr_stack+1032, r12vrr_stack+5794, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+945, r12vrr_stack+379, r12vrr_stack+22911, r12vrr_stack+48, r12vrr_stack+373, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+15123, r12vrr_stack+945, r12vrr_stack+14778, r12vrr_stack+379, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+22921, r12vrr_stack+389, r12vrr_stack+990, r12vrr_stack+14788, r12vrr_stack+15123, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+22949, r12vrr_stack+20900, r12vrr_stack+22921, r12vrr_stack+14803, r12vrr_stack+389, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+20928, r12vrr_stack+22949, r12vrr_stack+14824, r12vrr_stack+20900, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+20964, r12vrr_stack+14067, r12vrr_stack+14852, r12vrr_stack+20928, NULL);

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22985, r12vrr_stack+21720, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+20964);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23150, r12vrr_stack+21775, r12vrr_stack+22985, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+15714);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23480, r12vrr_stack+35190, r12vrr_stack+23150, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+15849);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+59943, r12vrr_stack+35520, r12vrr_stack+23480, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+16119);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+60768, r12vrr_stack+36070, r12vrr_stack+59943, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+55443);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+61923, r12vrr_stack+36895, r12vrr_stack+60768, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+56118);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+63463, r12vrr_stack+38050, r12vrr_stack+61923, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+57063);
 tmp = r12vrr_stack + 63463;
 target_ptr = Libr12->gvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+2169, r12vrr_stack+21720, r12vrr_stack+5739, r12vrr_stack+14888, r12vrr_stack+20964, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+39788, r12vrr_stack+2169, NULL, NULL, r12vrr_stack+21720);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+29250, r12vrr_stack+39590, r12vrr_stack+9556, r12vrr_stack+39788, r12vrr_stack+21775);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+32231, r12vrr_stack+29448, r12vrr_stack+31835, r12vrr_stack+39986, r12vrr_stack+29250, r12vrr_stack+35190);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+65443, r12vrr_stack+42692, r12vrr_stack+32231, r12vrr_stack+40184, r12vrr_stack+29448, r12vrr_stack+35520);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+66433, r12vrr_stack+43352, r12vrr_stack+65443, r12vrr_stack+40976, r12vrr_stack+42692, r12vrr_stack+36070);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+67819, r12vrr_stack+45332, r12vrr_stack+66433, r12vrr_stack+44342, r12vrr_stack+43352, r12vrr_stack+36895);
 tmp = r12vrr_stack + 67819;
 target_ptr = Libr12->gvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^7 ---*/
 _BUILD_p000(Data,r12vrr_stack+1032, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (d0|00)^6 ---*/
 _BUILD_d000(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+1032, Data->F+6, Data->F+7, NULL);

 /*--- compute (f0|00)^5 ---*/
 _BUILD_f000(Data,r12vrr_stack+9556, r12vrr_stack+40580, r12vrr_stack+48, r12vrr_stack+500, r12vrr_stack+3, NULL);

 /*--- compute (g0|00)^4 ---*/
 _BUILD_g000(Data,r12vrr_stack+9566, r12vrr_stack+40586, r12vrr_stack+9556, r12vrr_stack+54, r12vrr_stack+40580, NULL);

 /*--- compute (p0|p0)^7 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+9581, r12vrr_stack+78, r12vrr_stack+6, NULL, NULL, Data->F+8);

 /*--- compute (d0|p0)^6 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+9590, r12vrr_stack+21, r12vrr_stack+9581, r12vrr_stack+105, r12vrr_stack+78, r12vrr_stack+1032);

 /*--- compute (f0|p0)^5 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+32891, r12vrr_stack+60, r12vrr_stack+9590, r12vrr_stack+503, r12vrr_stack+21, r12vrr_stack+48);

 /*--- compute (g0|p0)^4 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+32921, r12vrr_stack+960, r12vrr_stack+32891, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+9556);

 /*--- compute (h0|p0)^3 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+6049, r12vrr_stack+1086, r12vrr_stack+32921, r12vrr_stack+2793, r12vrr_stack+960, r12vrr_stack+9566);

 /*--- compute (p0|d0)^7 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9608, r12vrr_stack+414, r12vrr_stack+198, NULL, NULL, r12vrr_stack+6);

 /*--- compute (d0|d0)^6 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1086, r12vrr_stack+30, r12vrr_stack+9608, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+9581);

 /*--- compute (f0|d0)^5 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+87, r12vrr_stack+40596, r12vrr_stack+1086, r12vrr_stack+2823, r12vrr_stack+30, r12vrr_stack+9590);

 /*--- compute (g0|d0)^4 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+32966, r12vrr_stack+264, r12vrr_stack+87, r12vrr_stack+2841, r12vrr_stack+40596, r12vrr_stack+32891);

 /*--- compute (h0|d0)^3 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+33056, r12vrr_stack+9466, r12vrr_stack+32966, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+32921);

 /*--- compute (i0|d0)^2 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+21225, r12vrr_stack+14112, r12vrr_stack+33056, r12vrr_stack+2937, r12vrr_stack+9466, r12vrr_stack+6049);

 /*--- compute (p0|f0)^7 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+960, r12vrr_stack+710, r12vrr_stack+420, NULL, NULL, r12vrr_stack+198);

 /*--- compute (d0|f0)^6 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+264, r12vrr_stack+780, r12vrr_stack+960, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+9608);

 /*--- compute (f0|f0)^5 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+430, r12vrr_stack+204, r12vrr_stack+264, r12vrr_stack+168, r12vrr_stack+780, r12vrr_stack+1086);

 /*--- compute (g0|f0)^4 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+530, r12vrr_stack+40632, r12vrr_stack+430, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+87);

 /*--- compute (h0|f0)^3 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+2775, r12vrr_stack+40732, r12vrr_stack+530, r12vrr_stack+3087, r12vrr_stack+40632, r12vrr_stack+32966);

 /*--- compute (i0|f0)^2 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+4859, r12vrr_stack+41636, r12vrr_stack+2775, r12vrr_stack+3187, r12vrr_stack+40732, r12vrr_stack+33056);

 /*--- compute (k0|f0)^1 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+14373, r12vrr_stack+41846, r12vrr_stack+4859, r12vrr_stack+3337, r12vrr_stack+41636, r12vrr_stack+21225);

 /*--- compute (p0|g0)^7 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1086, r12vrr_stack+1050, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^6 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+21225, r12vrr_stack+810, r12vrr_stack+1086, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+960);

 /*--- compute (f0|g0)^5 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+21315, r12vrr_stack+855, r12vrr_stack+21225, r12vrr_stack+735, r12vrr_stack+810, r12vrr_stack+264);

 /*--- compute (g0|g0)^4 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+21465, r12vrr_stack+42126, r12vrr_stack+21315, r12vrr_stack+3547, r12vrr_stack+855, r12vrr_stack+430);

 /*--- compute (h0|g0)^3 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+32891, r12vrr_stack+42276, r12vrr_stack+21465, r12vrr_stack+3637, r12vrr_stack+42126, r12vrr_stack+530);

 /*--- compute (i0|g0)^2 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+2985, r12vrr_stack+29844, r12vrr_stack+32891, r12vrr_stack+3787, r12vrr_stack+42276, r12vrr_stack+2775);

 /*--- compute (k0|g0)^1 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+3405, r12vrr_stack+30159, r12vrr_stack+2985, r12vrr_stack+4012, r12vrr_stack+29844, r12vrr_stack+4859);

 /*--- compute (l0|g0)^0 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+39854, r12vrr_stack+46718, r12vrr_stack+3405, r12vrr_stack+4327, r12vrr_stack+30159, r12vrr_stack+14373);

 /*--- compute (p0|h0)^7 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+6049, r12vrr_stack+5606, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^6 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+14112, r12vrr_stack+1770, r12vrr_stack+6049, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+1086);

 /*--- compute (f0|h0)^5 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2775, r12vrr_stack+1833, r12vrr_stack+14112, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+21225);

 /*--- compute (g0|h0)^4 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+14373, r12vrr_stack+1959, r12vrr_stack+2775, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+21315);

 /*--- compute (h0|h0)^3 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+29844, r12vrr_stack+30579, r12vrr_stack+14373, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+21465);

 /*--- compute (i0|h0)^2 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+40529, r12vrr_stack+47258, r12vrr_stack+29844, r12vrr_stack+6973, r12vrr_stack+30579, r12vrr_stack+32891);

 /*--- compute (k0|h0)^1 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+41117, r12vrr_stack+47699, r12vrr_stack+40529, r12vrr_stack+7288, r12vrr_stack+47258, r12vrr_stack+2985);

 /*--- compute (l0|h0)^0 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+6763, r12vrr_stack+48287, r12vrr_stack+41117, r12vrr_stack+8170, r12vrr_stack+47699, r12vrr_stack+3405);
 tmp = r12vrr_stack + 6763;
 target_ptr = Libr12->gvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^7 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2985, r12vrr_stack+8861, r12vrr_stack+14824, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^6 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3069, r12vrr_stack+5797, r12vrr_stack+2985, r12vrr_stack+5627, r12vrr_stack+8861, r12vrr_stack+6049);

 /*--- compute (f0|i0)^5 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4859, r12vrr_stack+5881, r12vrr_stack+3069, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+14112);

 /*--- compute (g0|i0)^4 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+3237, r12vrr_stack+5139, r12vrr_stack+4859, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+2775);

 /*--- compute (h0|i0)^3 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+3657, r12vrr_stack+49043, r12vrr_stack+3237, r12vrr_stack+11950, r12vrr_stack+5139, r12vrr_stack+14373);

 /*--- compute (i0|i0)^2 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+47258, r12vrr_stack+49463, r12vrr_stack+3657, r12vrr_stack+12230, r12vrr_stack+49043, r12vrr_stack+29844);

 /*--- compute (k0|i0)^1 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+29844, r12vrr_stack+50051, r12vrr_stack+47258, r12vrr_stack+12650, r12vrr_stack+49463, r12vrr_stack+40529);

 /*--- compute (l0|i0)^0 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+11782, r12vrr_stack+50835, r12vrr_stack+29844, r12vrr_stack+13238, r12vrr_stack+50051, r12vrr_stack+41117);
 tmp = r12vrr_stack + 11782;
 target_ptr = Libr12->gvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^7 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+14852, r12vrr_stack+20928, NULL, NULL, r12vrr_stack+14824);

 /*--- compute (d0|k0)^6 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+40529, r12vrr_stack+10074, r12vrr_stack+9034, r12vrr_stack+8889, r12vrr_stack+14852, r12vrr_stack+2985);

 /*--- compute (f0|k0)^5 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+40745, r12vrr_stack+10182, r12vrr_stack+40529, r12vrr_stack+9142, r12vrr_stack+10074, r12vrr_stack+3069);

 /*--- compute (g0|k0)^4 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41105, r12vrr_stack+10398, r12vrr_stack+40745, r12vrr_stack+9250, r12vrr_stack+10182, r12vrr_stack+4859);

 /*--- compute (h0|k0)^3 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4859, r12vrr_stack+51843, r12vrr_stack+41105, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+3237);

 /*--- compute (i0|k0)^2 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41645, r12vrr_stack+52383, r12vrr_stack+4859, r12vrr_stack+18486, r12vrr_stack+51843, r12vrr_stack+3657);

 /*--- compute (k0|k0)^1 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+49043, r12vrr_stack+53139, r12vrr_stack+41645, r12vrr_stack+19026, r12vrr_stack+52383, r12vrr_stack+47258);

 /*--- compute (l0|k0)^0 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+54147, r12vrr_stack+49043, r12vrr_stack+19782, r12vrr_stack+53139, r12vrr_stack+29844);
 tmp = r12vrr_stack + 18126;
 target_ptr = Libr12->gvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^7 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29844, r12vrr_stack+20964, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+20928);

 /*--- compute (d0|l0)^6 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29979, r12vrr_stack+15714, r12vrr_stack+29844, r12vrr_stack+14888, r12vrr_stack+20964, r12vrr_stack+9034);

 /*--- compute (f0|l0)^5 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+15849, r12vrr_stack+29979, r12vrr_stack+14933, r12vrr_stack+15714, r12vrr_stack+40529);

 /*--- compute (g0|l0)^4 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+30249, r12vrr_stack+16119, r12vrr_stack+9034, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+40745);

 /*--- compute (h0|l0)^3 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+47258, r12vrr_stack+55443, r12vrr_stack+30249, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+41105);

 /*--- compute (i0|l0)^2 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+51843, r12vrr_stack+56118, r12vrr_stack+47258, r12vrr_stack+26370, r12vrr_stack+55443, r12vrr_stack+4859);

 /*--- compute (k0|l0)^1 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+69667, r12vrr_stack+57063, r12vrr_stack+51843, r12vrr_stack+27045, r12vrr_stack+56118, r12vrr_stack+41645);

 /*--- compute (l0|l0)^0 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+58323, r12vrr_stack+69667, r12vrr_stack+27990, r12vrr_stack+57063, r12vrr_stack+49043);
 tmp = r12vrr_stack + 25650;
 target_ptr = Libr12->gvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^16 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49043, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /*--- compute (00|d0)^15 ---*/
 _BUILD_00d0(Data,r12vrr_stack+49046, r12vrr_stack+0, r12vrr_stack+49043, Data->F+15, Data->F+16, NULL);

 /*--- compute (00|f0)^14 ---*/
 _BUILD_00f0(Data,r12vrr_stack+49052, r12vrr_stack+22905, r12vrr_stack+49046, r12vrr_stack+5794, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^13 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+22911, r12vrr_stack+49052, r12vrr_stack+373, r12vrr_stack+22905, NULL);

 /*--- compute (00|h0)^12 ---*/
 _BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+945, r12vrr_stack+0, r12vrr_stack+379, r12vrr_stack+22911, NULL);

 /*--- compute (00|i0)^11 ---*/
 _BUILD_00i0(Data,r12vrr_stack+0, r12vrr_stack+990, r12vrr_stack+7708, r12vrr_stack+15123, r12vrr_stack+945, NULL);

 /*--- compute (00|k0)^10 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19746, r12vrr_stack+22921, r12vrr_stack+0, r12vrr_stack+389, r12vrr_stack+990, NULL);

 /*--- compute (00|l0)^9 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+22949, r12vrr_stack+19746, r12vrr_stack+20900, r12vrr_stack+22921, NULL);

 /*--- compute (00|m0)^8 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5794, r12vrr_stack+14067, r12vrr_stack+0, r12vrr_stack+20928, r12vrr_stack+22949, NULL);

 /*--- compute (p0|m0)^7 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5849, r12vrr_stack+5739, r12vrr_stack+5794, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^6 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+49043, r12vrr_stack+22985, r12vrr_stack+5849, r12vrr_stack+21720, r12vrr_stack+5739, r12vrr_stack+29844);

 /*--- compute (f0|m0)^5 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+23150, r12vrr_stack+49043, r12vrr_stack+21775, r12vrr_stack+22985, r12vrr_stack+29979);

 /*--- compute (g0|m0)^4 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+49043, r12vrr_stack+23480, r12vrr_stack+21225, r12vrr_stack+35190, r12vrr_stack+23150, r12vrr_stack+9034);

 /*--- compute (h0|m0)^3 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+55443, r12vrr_stack+59943, r12vrr_stack+49043, r12vrr_stack+35520, r12vrr_stack+23480, r12vrr_stack+30249);

 /*--- compute (i0|m0)^2 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+49043, r12vrr_stack+60768, r12vrr_stack+55443, r12vrr_stack+36070, r12vrr_stack+59943, r12vrr_stack+47258);

 /*--- compute (k0|m0)^1 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+55443, r12vrr_stack+61923, r12vrr_stack+49043, r12vrr_stack+36895, r12vrr_stack+60768, r12vrr_stack+51843);

 /*--- compute (l0|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+63463, r12vrr_stack+55443, r12vrr_stack+38050, r12vrr_stack+61923, r12vrr_stack+69667);

 /*--- compute (00|n0)^7 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69667, r12vrr_stack+5739, r12vrr_stack+5794, r12vrr_stack+20964, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^6 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+5794, r12vrr_stack+2169, r12vrr_stack+69667, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (d0|n0)^5 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69667, r12vrr_stack+39590, r12vrr_stack+5794, r12vrr_stack+39788, r12vrr_stack+2169, r12vrr_stack+22985);

 /*--- compute (f0|n0)^4 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+70063, r12vrr_stack+31835, r12vrr_stack+69667, r12vrr_stack+29250, r12vrr_stack+39590, r12vrr_stack+23150);

 /*--- compute (g0|n0)^3 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+70723, r12vrr_stack+32231, r12vrr_stack+70063, r12vrr_stack+29448, r12vrr_stack+31835, r12vrr_stack+23480);

 /*--- compute (h0|n0)^2 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+65443, r12vrr_stack+70723, r12vrr_stack+42692, r12vrr_stack+32231, r12vrr_stack+59943);

 /*--- compute (i0|n0)^1 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69667, r12vrr_stack+66433, r12vrr_stack+29250, r12vrr_stack+43352, r12vrr_stack+65443, r12vrr_stack+60768);

 /*--- compute (k0|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+55443, r12vrr_stack+67819, r12vrr_stack+69667, r12vrr_stack+45332, r12vrr_stack+66433, r12vrr_stack+61923);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+69667, &(Data->ss_r12_ss), NULL, r12vrr_stack+324, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+69670, r12vrr_stack+69667, &(Data->ss_r12_ss), r12vrr_stack+81, r12vrr_stack+324, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+69676, r12vrr_stack+69670, r12vrr_stack+69667, r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+324, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+69686, r12vrr_stack+69676, r12vrr_stack+69670, r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+81, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+69686, r12vrr_stack+69676, r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+327, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+69701, r12vrr_stack+7708, NULL, r12vrr_stack+1131, r12vrr_stack+1011, NULL, r12vrr_stack+337);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+69764, r12vrr_stack+69701, r12vrr_stack+7708, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1485);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+69890, r12vrr_stack+69764, r12vrr_stack+69701, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1530);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+27675, r12vrr_stack+69890, r12vrr_stack+69764, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1620);

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+70100, r12vrr_stack+27675, r12vrr_stack+69890, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+2235);
 tmp = r12vrr_stack + 70100;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+70541, r12vrr_stack+70100, r12vrr_stack+27675, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+2460);
 tmp = r12vrr_stack + 70541;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+69686, r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+337, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+27703, r12vrr_stack+27675, NULL, r12vrr_stack+4775, r12vrr_stack+4747, NULL, r12vrr_stack+1011);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+27675, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1131);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+69667, r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+6112);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+71129, r12vrr_stack+69667, r12vrr_stack+27787, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+6238);

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+65443, r12vrr_stack+71129, r12vrr_stack+69667, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+6448);
 tmp = r12vrr_stack + 65443;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+66031, r12vrr_stack+65443, r12vrr_stack+71129, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+7729);
 tmp = r12vrr_stack + 66031;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1011, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+71129, r12vrr_stack+19746, NULL, r12vrr_stack+8926, r12vrr_stack+8758, NULL, r12vrr_stack+4747);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+71237, r12vrr_stack+71129, r12vrr_stack+19746, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+4775);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+4775, r12vrr_stack+71237, r12vrr_stack+71129, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+9626);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+71237, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+9794);

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+71129, r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+10774);
 tmp = r12vrr_stack + 71129;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+29250, r12vrr_stack+71129, r12vrr_stack+5135, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+11194);
 tmp = r12vrr_stack + 29250;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+4775, r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+4747, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+27675, r12vrr_stack+4775, NULL, r12vrr_stack+14238, r12vrr_stack+14022, NULL, r12vrr_stack+8758);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+4820, r12vrr_stack+27675, r12vrr_stack+4775, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+8926);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+5090, r12vrr_stack+4820, r12vrr_stack+27675, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+15138);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+5540, r12vrr_stack+5090, r12vrr_stack+4820, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+15354);

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+66815, r12vrr_stack+5540, r12vrr_stack+5090, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+16830);
 tmp = r12vrr_stack + 66815;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+59943, r12vrr_stack+66815, r12vrr_stack+5540, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+17370);
 tmp = r12vrr_stack + 59943;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+4820, r12vrr_stack+4775, r12vrr_stack+19746, r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+8758, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+4820, NULL, r12vrr_stack+21060, r12vrr_stack+20790, NULL, r12vrr_stack+14022);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+4820, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+14238);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+22185);

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+8923, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+22455);

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+24030);
 tmp = r12vrr_stack + 8758;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+20790, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24705);
 tmp = r12vrr_stack + 14022;
 target_ptr = Libr12->rvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20790, r12vrr_stack+7729, r12vrr_stack+11194, r12vrr_stack+8170, r12vrr_stack+4327, r12vrr_stack+2460);
 tmp = r12vrr_stack + 20790;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21231, r12vrr_stack+11194, r12vrr_stack+17370, r12vrr_stack+13238, r12vrr_stack+8170, r12vrr_stack+7729);
 tmp = r12vrr_stack + 21231;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21819, r12vrr_stack+17370, r12vrr_stack+24705, r12vrr_stack+19782, r12vrr_stack+13238, r12vrr_stack+11194);
 tmp = r12vrr_stack + 21819;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+22575, r12vrr_stack+24705, r12vrr_stack+34035, r12vrr_stack+27990, r12vrr_stack+19782, r12vrr_stack+17370);
 tmp = r12vrr_stack + 22575;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+15562, r12vrr_stack+34035, r12vrr_stack+45332, r12vrr_stack+38050, r12vrr_stack+27990, r12vrr_stack+24705);
 tmp = r12vrr_stack + 15562;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9913, r12vrr_stack+8170, r12vrr_stack+13238, r12vrr_stack+48287, r12vrr_stack+46718, r12vrr_stack+4327);
 tmp = r12vrr_stack + 9913;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4747, r12vrr_stack+13238, r12vrr_stack+19782, r12vrr_stack+50835, r12vrr_stack+48287, r12vrr_stack+8170);
 tmp = r12vrr_stack + 4747;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+30258, r12vrr_stack+19782, r12vrr_stack+27990, r12vrr_stack+54147, r12vrr_stack+50835, r12vrr_stack+13238);
 tmp = r12vrr_stack + 30258;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+31266, r12vrr_stack+27990, r12vrr_stack+38050, r12vrr_stack+58323, r12vrr_stack+54147, r12vrr_stack+19782);
 tmp = r12vrr_stack + 31266;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+61203, r12vrr_stack+38050, r12vrr_stack+67819, r12vrr_stack+63463, r12vrr_stack+58323, r12vrr_stack+27990);
 tmp = r12vrr_stack + 61203;
 target_ptr = Libr12->t2vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5531, r12vrr_stack+48287, r12vrr_stack+50835, r12vrr_stack+6763, r12vrr_stack+39854, r12vrr_stack+46718);
 tmp = r12vrr_stack + 5531;
 target_ptr = Libr12->t2vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+46718, r12vrr_stack+50835, r12vrr_stack+54147, r12vrr_stack+11782, r12vrr_stack+6763, r12vrr_stack+48287);
 tmp = r12vrr_stack + 46718;
 target_ptr = Libr12->t2vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39590, r12vrr_stack+54147, r12vrr_stack+58323, r12vrr_stack+18126, r12vrr_stack+11782, r12vrr_stack+50835);
 tmp = r12vrr_stack + 39590;
 target_ptr = Libr12->t2vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+40886, r12vrr_stack+58323, r12vrr_stack+63463, r12vrr_stack+25650, r12vrr_stack+18126, r12vrr_stack+54147);
 tmp = r12vrr_stack + 40886;
 target_ptr = Libr12->t2vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+51843, r12vrr_stack+63463, r12vrr_stack+55443, r12vrr_stack+35190, r12vrr_stack+25650, r12vrr_stack+58323);
 tmp = r12vrr_stack + 51843;
 target_ptr = Libr12->t2vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+47726, r12vrr_stack+7729, r12vrr_stack+8170, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+6448);
 tmp = r12vrr_stack + 47726;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32526, r12vrr_stack+11194, r12vrr_stack+13238, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+10774);
 tmp = r12vrr_stack + 32526;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+42506, r12vrr_stack+17370, r12vrr_stack+19782, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+16830);
 tmp = r12vrr_stack + 42506;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+43262, r12vrr_stack+24705, r12vrr_stack+27990, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24030);
 tmp = r12vrr_stack + 43262;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+23520, r12vrr_stack+34035, r12vrr_stack+38050, r12vrr_stack+45332, r12vrr_stack+44342, r12vrr_stack+33210);
 tmp = r12vrr_stack + 23520;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16717, r12vrr_stack+8170, r12vrr_stack+48287, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+7729);
 tmp = r12vrr_stack + 16717;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+33114, r12vrr_stack+13238, r12vrr_stack+50835, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+11194);
 tmp = r12vrr_stack + 33114;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+44207, r12vrr_stack+19782, r12vrr_stack+54147, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+17370);
 tmp = r12vrr_stack + 44207;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+49043, r12vrr_stack+27990, r12vrr_stack+58323, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+24705);
 tmp = r12vrr_stack + 49043;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+38050, r12vrr_stack+63463, r12vrr_stack+67819, r12vrr_stack+45332, r12vrr_stack+34035);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+45215, r12vrr_stack+48287, r12vrr_stack+6763, r12vrr_stack+50835, r12vrr_stack+13238, r12vrr_stack+8170);
 tmp = r12vrr_stack + 45215;
 target_ptr = Libr12->t1vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6287, r12vrr_stack+50835, r12vrr_stack+11782, r12vrr_stack+54147, r12vrr_stack+19782, r12vrr_stack+13238);
 tmp = r12vrr_stack + 6287;
 target_ptr = Libr12->t1vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11782, r12vrr_stack+54147, r12vrr_stack+18126, r12vrr_stack+58323, r12vrr_stack+27990, r12vrr_stack+19782);
 tmp = r12vrr_stack + 11782;
 target_ptr = Libr12->t1vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+18126, r12vrr_stack+58323, r12vrr_stack+25650, r12vrr_stack+63463, r12vrr_stack+38050, r12vrr_stack+27990);
 tmp = r12vrr_stack + 18126;
 target_ptr = Libr12->t1vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+25650, r12vrr_stack+63463, r12vrr_stack+35190, r12vrr_stack+55443, r12vrr_stack+67819, r12vrr_stack+38050);
 tmp = r12vrr_stack + 25650;
 target_ptr = Libr12->t1vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||h0)^0 ---*/
 _R_BUILD_k0h0(Data,r12vrr_stack+55443, r12vrr_stack+70541, r12vrr_stack+70100, r12vrr_stack+48287, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+4327);
 tmp = r12vrr_stack + 55443;
 target_ptr = Libr12->rvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||i0)^0 ---*/
 _R_BUILD_k0i0(Data,r12vrr_stack+56199, r12vrr_stack+66031, r12vrr_stack+65443, r12vrr_stack+50835, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+8170);
 tmp = r12vrr_stack + 56199;
 target_ptr = Libr12->rvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||k0)^0 ---*/
 _R_BUILD_k0k0(Data,r12vrr_stack+65443, r12vrr_stack+29250, r12vrr_stack+71129, r12vrr_stack+54147, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+13238);
 tmp = r12vrr_stack + 65443;
 target_ptr = Libr12->rvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||l0)^0 ---*/
 _R_BUILD_k0l0(Data,r12vrr_stack+53823, r12vrr_stack+59943, r12vrr_stack+66815, r12vrr_stack+58323, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+19782);
 tmp = r12vrr_stack + 53823;
 target_ptr = Libr12->rvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+66739, r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+63463, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+27990);
 tmp = r12vrr_stack + 66739;
 target_ptr = Libr12->rvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];


}

