/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_ddhd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dd|hd) integrals */

void d12hrr_order_ddhd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][7][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][10] = int_stack + 540;
 Libderiv->deriv_classes[4][7][9] = int_stack + 1080;
 Libderiv->deriv_classes[4][7][8] = int_stack + 1620;
 Libderiv->deriv_classes[4][7][7] = int_stack + 2160;
 Libderiv->dvrr_classes[4][6] = int_stack + 2700;
 Libderiv->deriv_classes[4][7][6] = int_stack + 3120;
 Libderiv->deriv_classes[4][7][2] = int_stack + 3660;
 Libderiv->deriv_classes[4][7][1] = int_stack + 4200;
 Libderiv->dvrr_classes[3][7] = int_stack + 4740;
 Libderiv->deriv_classes[4][7][0] = int_stack + 5100;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 5640;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 5766;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 5934;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 6150;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 6360;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 6640;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 7000;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 7315;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 7735;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 8275;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 8401;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 8569;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 8785;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 8995;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 9275;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 9635;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 9950;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 10370;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 10910;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 11036;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 11204;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 11420;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 11630;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 11910;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 12270;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 12585;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 13005;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 13545;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 13671;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 13839;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 14055;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 14265;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 14545;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 14905;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 15220;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 15640;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 16180;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 16306;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 16474;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 16690;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 16900;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 17180;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 17540;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 17855;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 18275;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 18815;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 18941;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 19109;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 19325;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 19535;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 19815;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 20175;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 20490;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 20910;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 21450;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 21576;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 21744;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 21960;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 22170;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 22450;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 22810;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 23125;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 23545;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 24085;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 24211;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 24379;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 24595;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 24805;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 25085;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 25445;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 25760;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 26180;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 26720;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 26846;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 27014;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 27230;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 27440;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 27720;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 28080;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 28395;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 28815;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 29355;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 29481;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 29649;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 29865;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 30075;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 30355;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 30715;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 31030;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 31450;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 31990;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 32116;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 32284;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 32500;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 32710;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 32990;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 33350;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 33665;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 34085;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 34625;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 34751;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 34919;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 35135;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 35345;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 35625;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 35985;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 36300;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 36720;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 37260;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 37386;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 37554;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 37770;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 37980;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 38260;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 38620;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 38935;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 39355;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 39895;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 40021;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 40189;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 40405;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 40615;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 40895;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 41255;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 41570;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 41990;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 42530;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 42656;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 42824;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 43040;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 43250;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 43530;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 43890;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 44205;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 44625;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 45165;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 45291;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 45459;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 45675;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 45885;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 46165;
 Libderiv->deriv_classes[4][5][11] = int_stack + 46525;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 46840;
 Libderiv->deriv_classes[4][6][11] = int_stack + 47155;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 47575;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 47995;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 48535;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 48661;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 48829;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 49045;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 49255;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 49535;
 Libderiv->deriv_classes[4][5][10] = int_stack + 49895;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 50210;
 Libderiv->deriv_classes[4][6][10] = int_stack + 50525;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 50945;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 51365;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 51905;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 52031;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 52199;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 52415;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 52625;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 52905;
 Libderiv->deriv_classes[4][5][9] = int_stack + 53265;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 53580;
 Libderiv->deriv_classes[4][6][9] = int_stack + 53895;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 54315;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 54735;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 55275;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 55401;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 55569;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 55785;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 55995;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 56275;
 Libderiv->deriv_classes[4][5][8] = int_stack + 56635;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 56950;
 Libderiv->deriv_classes[4][6][8] = int_stack + 57265;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 57685;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 58105;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 58645;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 58771;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 58939;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 59155;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 59365;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 59645;
 Libderiv->deriv_classes[4][5][7] = int_stack + 60005;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 60320;
 Libderiv->deriv_classes[4][6][7] = int_stack + 60635;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 61055;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 61475;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 62015;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 62141;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 62309;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 62525;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 62735;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 63015;
 Libderiv->dvrr_classes[4][5] = int_stack + 63375;
 Libderiv->deriv_classes[4][5][6] = int_stack + 63690;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 64005;
 Libderiv->deriv_classes[4][6][6] = int_stack + 64320;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 64740;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 65160;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 65700;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 65826;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 65994;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 66210;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 66420;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 66700;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 67060;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 67375;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 67795;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 68335;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 68461;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 68629;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 68845;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 69055;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 69335;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 69695;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 70010;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 70430;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 70970;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 71096;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 71264;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 71480;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 71690;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 71970;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 72330;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 72645;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 73065;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 73605;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 73731;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 73899;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 74115;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 74325;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 74605;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 74965;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 75280;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 75700;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 76240;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 76366;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 76534;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 76750;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 76960;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 77240;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 77600;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 77915;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 78335;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 78875;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 79001;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 79169;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 79385;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 79595;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 79875;
 Libderiv->deriv_classes[4][5][2] = int_stack + 80235;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 80550;
 Libderiv->deriv_classes[4][6][2] = int_stack + 80865;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 81285;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 81705;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 82245;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 82371;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 82539;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 82755;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 82965;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 83245;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 83605;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 83920;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 84340;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 84880;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 85006;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 85174;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 85390;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 85600;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 85880;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 86240;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 86555;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 86975;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 87515;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 87641;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 87809;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 88025;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 88235;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 88515;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 88875;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 89190;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 89610;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 90150;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 90276;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 90444;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 90660;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 90870;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 91150;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 91510;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 91825;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 92245;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 92785;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 92911;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 93079;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 93295;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 93505;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 93785;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 94145;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 94460;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 94880;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 95420;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 95546;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 95714;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 95930;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 96140;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 96420;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 96780;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 97095;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 97515;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 98055;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 98181;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 98349;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 98565;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 98775;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 99055;
 Libderiv->deriv_classes[4][5][1] = int_stack + 99415;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 99730;
 Libderiv->deriv_classes[4][6][1] = int_stack + 100045;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 100465;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 100885;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 101425;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 101551;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 101719;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 101935;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 102145;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 102425;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 102785;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 103100;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 103520;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 104060;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 104186;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 104354;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 104570;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 104780;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 105060;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 105420;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 105735;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 106155;
 Libderiv->deriv_classes[2][5][11] = int_stack + 106695;
 Libderiv->deriv_classes[2][6][11] = int_stack + 106821;
 Libderiv->deriv_classes[2][7][11] = int_stack + 106989;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 107205;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 107331;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 107499;
 Libderiv->deriv_classes[3][5][11] = int_stack + 107715;
 Libderiv->deriv_classes[3][6][11] = int_stack + 107925;
 Libderiv->deriv_classes[3][7][11] = int_stack + 108205;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 108565;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 108775;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 109055;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 109415;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 109730;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 110150;
 Libderiv->deriv_classes[2][5][10] = int_stack + 110690;
 Libderiv->deriv_classes[2][6][10] = int_stack + 110816;
 Libderiv->deriv_classes[2][7][10] = int_stack + 110984;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 111200;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 111326;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 111494;
 Libderiv->deriv_classes[3][5][10] = int_stack + 111710;
 Libderiv->deriv_classes[3][6][10] = int_stack + 111920;
 Libderiv->deriv_classes[3][7][10] = int_stack + 112200;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 112560;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 112770;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 113050;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 113410;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 113725;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 114145;
 Libderiv->deriv_classes[2][5][9] = int_stack + 114685;
 Libderiv->deriv_classes[2][6][9] = int_stack + 114811;
 Libderiv->deriv_classes[2][7][9] = int_stack + 114979;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 115195;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 115321;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 115489;
 Libderiv->deriv_classes[3][5][9] = int_stack + 115705;
 Libderiv->deriv_classes[3][6][9] = int_stack + 115915;
 Libderiv->deriv_classes[3][7][9] = int_stack + 116195;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 116555;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 116765;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 117045;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 117405;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 117720;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 118140;
 Libderiv->deriv_classes[2][5][8] = int_stack + 118680;
 Libderiv->deriv_classes[2][6][8] = int_stack + 118806;
 Libderiv->deriv_classes[2][7][8] = int_stack + 118974;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 119190;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 119316;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 119484;
 Libderiv->deriv_classes[3][5][8] = int_stack + 119700;
 Libderiv->deriv_classes[3][6][8] = int_stack + 119910;
 Libderiv->deriv_classes[3][7][8] = int_stack + 120190;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 120550;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 120760;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 121040;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 121400;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 121715;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 122135;
 Libderiv->deriv_classes[2][5][7] = int_stack + 122675;
 Libderiv->deriv_classes[2][6][7] = int_stack + 122801;
 Libderiv->deriv_classes[2][7][7] = int_stack + 122969;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 123185;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 123311;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 123479;
 Libderiv->deriv_classes[3][5][7] = int_stack + 123695;
 Libderiv->deriv_classes[3][6][7] = int_stack + 123905;
 Libderiv->deriv_classes[3][7][7] = int_stack + 124185;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 124545;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 124755;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 125035;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 125395;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 125710;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 126130;
 Libderiv->deriv_classes[2][5][6] = int_stack + 126670;
 Libderiv->deriv_classes[2][6][6] = int_stack + 126796;
 Libderiv->deriv_classes[2][7][6] = int_stack + 126964;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 127180;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 127306;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 127474;
 Libderiv->dvrr_classes[3][5] = int_stack + 127690;
 Libderiv->deriv_classes[3][5][6] = int_stack + 127900;
 Libderiv->dvrr_classes[3][6] = int_stack + 128110;
 Libderiv->deriv_classes[3][6][6] = int_stack + 128390;
 Libderiv->deriv_classes[3][7][6] = int_stack + 128670;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 129030;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 129240;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 129520;
 Libderiv->deriv_classes[4][5][0] = int_stack + 129880;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 130195;
 Libderiv->deriv_classes[4][6][0] = int_stack + 130510;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 130930;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 131350;
 Libderiv->deriv_classes[2][5][2] = int_stack + 131890;
 Libderiv->deriv_classes[2][6][2] = int_stack + 132016;
 Libderiv->deriv_classes[2][7][2] = int_stack + 132184;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 132400;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 132526;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 132694;
 Libderiv->deriv_classes[3][5][2] = int_stack + 132910;
 Libderiv->deriv_classes[3][6][2] = int_stack + 133120;
 Libderiv->deriv_classes[3][7][2] = int_stack + 133400;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 133760;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 133970;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 134250;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 134610;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 134925;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 135345;
 Libderiv->deriv_classes[2][5][1] = int_stack + 135885;
 Libderiv->deriv_classes[2][6][1] = int_stack + 136011;
 Libderiv->deriv_classes[2][7][1] = int_stack + 136179;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 136395;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 136521;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 136689;
 Libderiv->deriv_classes[3][5][1] = int_stack + 136905;
 Libderiv->deriv_classes[3][6][1] = int_stack + 137115;
 Libderiv->deriv_classes[3][7][1] = int_stack + 137395;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 137755;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 137965;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 138245;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 138605;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 138920;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 139340;
 Libderiv->dvrr_classes[2][5] = int_stack + 139880;
 Libderiv->dvrr_classes[2][6] = int_stack + 140006;
 Libderiv->dvrr_classes[2][7] = int_stack + 140174;
 Libderiv->deriv_classes[2][5][0] = int_stack + 140390;
 Libderiv->deriv_classes[2][6][0] = int_stack + 140516;
 Libderiv->deriv_classes[2][7][0] = int_stack + 140684;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 140900;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 141026;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 141194;
 Libderiv->deriv_classes[3][5][0] = int_stack + 141410;
 Libderiv->deriv_classes[3][6][0] = int_stack + 141620;
 Libderiv->deriv_classes[3][7][0] = int_stack + 141900;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 142260;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 142470;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 142750;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 143110;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 143425;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 143845;
 memset(int_stack,0,1155080);

 Libderiv->dvrr_stack = int_stack + 365410;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_ddhd(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+144385,int_stack+140006,int_stack+139880,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+144763,int_stack+106821,int_stack+106695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139880,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+106989,int_stack+106821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140006,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+145645,int_stack+145141,int_stack+144763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+146401,int_stack+128110,int_stack+127690,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+147031,int_stack+107925,int_stack+107715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127690,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+108205,int_stack+107925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128110,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+148501,int_stack+147661,int_stack+147031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+149761,int_stack+148501,int_stack+145645,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152029,int_stack+2700,int_stack+63375,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+152974,int_stack+47155,int_stack+46525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63375,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+153919,int_stack+0,int_stack+47155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+155179,int_stack+153919,int_stack+152974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+157069,int_stack+155179,int_stack+148501,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+153919,int_stack+110816,int_stack+110690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139880, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+110984,int_stack+110816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140006, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+154297,int_stack+145141,int_stack+153919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+155053,int_stack+111920,int_stack+111710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127690, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+112200,int_stack+111920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128110, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+155683,int_stack+147661,int_stack+155053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+160849,int_stack+155683,int_stack+154297,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+163117,int_stack+50525,int_stack+49895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63375, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164062,int_stack+540,int_stack+50525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+165322,int_stack+164062,int_stack+163117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+167212,int_stack+165322,int_stack+155683,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164062,int_stack+114811,int_stack+114685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139880, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+114979,int_stack+114811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140006, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+164440,int_stack+145141,int_stack+164062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+165196,int_stack+115915,int_stack+115705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127690, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+116195,int_stack+115915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128110, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+165826,int_stack+147661,int_stack+165196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+170992,int_stack+165826,int_stack+164440,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+53895,int_stack+53265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+173260,int_stack+1080,int_stack+53895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+174520,int_stack+173260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+176410,int_stack+174520,int_stack+165826,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173260,int_stack+118806,int_stack+118680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+118974,int_stack+118806, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+173638,int_stack+145141,int_stack+173260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+174394,int_stack+119910,int_stack+119700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+120190,int_stack+119910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+175024,int_stack+147661,int_stack+174394, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+180190,int_stack+175024,int_stack+173638,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+182458,int_stack+57265,int_stack+56635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+183403,int_stack+1620,int_stack+57265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+184663,int_stack+183403,int_stack+182458, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+186553,int_stack+184663,int_stack+175024,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+183403,int_stack+122801,int_stack+122675, 0.0, zero_stack, 1.0, int_stack+139880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+122969,int_stack+122801, 0.0, zero_stack, 1.0, int_stack+140006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+183781,int_stack+145141,int_stack+183403, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184537,int_stack+123905,int_stack+123695, 0.0, zero_stack, 1.0, int_stack+127690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+124185,int_stack+123905, 0.0, zero_stack, 1.0, int_stack+128110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+185167,int_stack+147661,int_stack+184537, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+190333,int_stack+185167,int_stack+183781,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+945,int_stack+60635,int_stack+60005, 0.0, zero_stack, 1.0, int_stack+63375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+192601,int_stack+2160,int_stack+60635, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+193861,int_stack+192601,int_stack+945, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+195751,int_stack+193861,int_stack+185167,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+126796,int_stack+126670, 1.0, int_stack+139880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+126964,int_stack+126796, 1.0, int_stack+140006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+192979,int_stack+145141,int_stack+192601, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+128390,int_stack+127900, 1.0, int_stack+127690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+128670,int_stack+128390, 1.0, int_stack+128110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+194365,int_stack+147661,int_stack+193735, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+199531,int_stack+194365,int_stack+192979,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+201799,int_stack+64320,int_stack+63690, 1.0, int_stack+63375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+3120,int_stack+64320, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+204004,int_stack+202744,int_stack+201799, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+205894,int_stack+204004,int_stack+194365,126);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+140174,int_stack+140006,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+152029,int_stack+145141,int_stack+144385,6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+147661,int_stack+4740,int_stack+128110,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+147661,int_stack+146401,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+209674,int_stack+202744,int_stack+152029,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+144385,int_stack+132016,int_stack+131890,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+132184,int_stack+132016,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+147661,int_stack+145141,int_stack+144385,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+146401,int_stack+133120,int_stack+132910,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+204004,int_stack+133400,int_stack+133120,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1890,int_stack+204004,int_stack+146401,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+211942,int_stack+1890,int_stack+147661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+204004,int_stack+80865,int_stack+80235,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+214210,int_stack+3660,int_stack+80865,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+215470,int_stack+214210,int_stack+204004,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+217360,int_stack+215470,int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+136011,int_stack+135885,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+136179,int_stack+136011,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+214588,int_stack+145141,int_stack+214210,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+215344,int_stack+137115,int_stack+136905,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+215974,int_stack+137395,int_stack+137115,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+221140,int_stack+215974,int_stack+215344,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+222400,int_stack+221140,int_stack+214588, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+204949,int_stack+100045,int_stack+99415,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+215974,int_stack+4200,int_stack+100045,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3150,int_stack+215974,int_stack+204949,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+224668,int_stack+3150,int_stack+221140, 0.0, zero_stack, 1.0, int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+140516,int_stack+140390,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+140684,int_stack+140516,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3528,int_stack+145141,int_stack+3150,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4284,int_stack+141620,int_stack+141410,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+215974,int_stack+141900,int_stack+141620,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+228448,int_stack+215974,int_stack+4284,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+229708,int_stack+228448,int_stack+3528, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152029,int_stack+130510,int_stack+129880,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+215974,int_stack+5100,int_stack+130510,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+215974,int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+233866,int_stack+231976,int_stack+228448, 1.0, int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+5766,int_stack+5640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+106695,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+5934,int_stack+5766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+106821,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+144763,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+6360,int_stack+6150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+107715,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+6640,int_stack+6360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+107925,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+215974,int_stack+232606,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+147031,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+237646,int_stack+215974,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+7315,int_stack+7000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+46525,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+7735,int_stack+7315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+47155,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4914,int_stack+202744,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+152974,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+239914,int_stack+4914,int_stack+215974,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215974,int_stack+8401,int_stack+8275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106695, 1.0, int_stack+110690,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+8569,int_stack+8401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106821, 1.0, int_stack+110816,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+216352,int_stack+145141,int_stack+215974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144763, 1.0, int_stack+153919,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4914,int_stack+8995,int_stack+8785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107715, 1.0, int_stack+111710,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5544,int_stack+9275,int_stack+8995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107925, 1.0, int_stack+111920,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+5544,int_stack+4914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147031, 1.0, int_stack+155053,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+4914,int_stack+202744,int_stack+216352,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+9950,int_stack+9635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46525, 1.0, int_stack+49895,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8127,int_stack+10370,int_stack+9950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47155, 1.0, int_stack+50525,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+8127,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152974, 1.0, int_stack+163117,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+243694,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+11036,int_stack+10910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+110690, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+11204,int_stack+11036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+110816, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+153919, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+11630,int_stack+11420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+111710, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+11910,int_stack+11630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+111920, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+155053, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+8442,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+12585,int_stack+12270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+49895, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+13005,int_stack+12585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+50525, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10710,int_stack+202744,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+163117, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+247474,int_stack+10710,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+13671,int_stack+13545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106695, 0.0, zero_stack, 1.0, int_stack+114685,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+13839,int_stack+13671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106821, 0.0, zero_stack, 1.0, int_stack+114811,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144763, 0.0, zero_stack, 1.0, int_stack+164062,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10710,int_stack+14265,int_stack+14055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107715, 0.0, zero_stack, 1.0, int_stack+115705,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11340,int_stack+14545,int_stack+14265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107925, 0.0, zero_stack, 1.0, int_stack+115915,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+11340,int_stack+10710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147031, 0.0, zero_stack, 1.0, int_stack+165196,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+10710,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12978,int_stack+15220,int_stack+14905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46525, 0.0, zero_stack, 1.0, int_stack+53265,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+15640,int_stack+15220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47155, 0.0, zero_stack, 1.0, int_stack+53895,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+12978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152974, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+251254,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+16306,int_stack+16180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110690, 1.0, int_stack+114685, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+16474,int_stack+16306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110816, 1.0, int_stack+114811, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153919, 1.0, int_stack+164062, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+16900,int_stack+16690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111710, 1.0, int_stack+115705, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+17180,int_stack+16900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111920, 1.0, int_stack+115915, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155053, 1.0, int_stack+165196, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+12978,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+17855,int_stack+17540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49895, 1.0, int_stack+53265, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+18275,int_stack+17855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50525, 1.0, int_stack+53895, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15246,int_stack+202744,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163117, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+255034,int_stack+15246,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+18941,int_stack+18815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+114685, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+19109,int_stack+18941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+114811, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+164062, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15246,int_stack+19535,int_stack+19325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+115705, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15876,int_stack+19815,int_stack+19535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+115915, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+15876,int_stack+15246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+165196, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+15246,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17514,int_stack+20490,int_stack+20175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+53265, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+20910,int_stack+20490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+53895, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+17514,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+21576,int_stack+21450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118680,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+21744,int_stack+21576, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118806,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144763, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173260,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+22170,int_stack+21960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119700,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+22450,int_stack+22170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119910,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174394,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+258814,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+23125,int_stack+22810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56635,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+23545,int_stack+23125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57265,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21294,int_stack+202744,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182458,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+261082,int_stack+21294,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+24211,int_stack+24085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110690, 0.0, zero_stack, 1.0, int_stack+118680, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+24379,int_stack+24211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110816, 0.0, zero_stack, 1.0, int_stack+118806, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153919, 0.0, zero_stack, 1.0, int_stack+173260, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21294,int_stack+24805,int_stack+24595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111710, 0.0, zero_stack, 1.0, int_stack+119700, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21924,int_stack+25085,int_stack+24805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111920, 0.0, zero_stack, 1.0, int_stack+119910, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+21924,int_stack+21294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155053, 0.0, zero_stack, 1.0, int_stack+174394, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+21294,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23562,int_stack+25760,int_stack+25445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49895, 0.0, zero_stack, 1.0, int_stack+56635, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+26180,int_stack+25760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50525, 0.0, zero_stack, 1.0, int_stack+57265, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+23562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163117, 0.0, zero_stack, 1.0, int_stack+182458, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+264862,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+26846,int_stack+26720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114685, 1.0, int_stack+118680, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+27014,int_stack+26846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114811, 1.0, int_stack+118806, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164062, 1.0, int_stack+173260, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+27440,int_stack+27230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115705, 1.0, int_stack+119700, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+27720,int_stack+27440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115915, 1.0, int_stack+119910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165196, 1.0, int_stack+174394, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+23562,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+28395,int_stack+28080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53265, 1.0, int_stack+56635, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+28815,int_stack+28395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53895, 1.0, int_stack+57265, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25830,int_stack+202744,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+182458, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+268642,int_stack+25830,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+29481,int_stack+29355, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+29649,int_stack+29481, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25830,int_stack+30075,int_stack+29865, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+119700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+26460,int_stack+30355,int_stack+30075, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+119910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+26460,int_stack+25830, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+174394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+25830,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28098,int_stack+31030,int_stack+30715, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+31450,int_stack+31030, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+57265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+28098, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+182458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+28098,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+32116,int_stack+31990, 0.0, zero_stack, 1.0, int_stack+106695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122675,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+32284,int_stack+32116, 0.0, zero_stack, 1.0, int_stack+106821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122801,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 1.0, int_stack+144763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183403,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+32710,int_stack+32500, 0.0, zero_stack, 1.0, int_stack+107715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123695,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+32990,int_stack+32710, 0.0, zero_stack, 1.0, int_stack+107925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123905,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 1.0, int_stack+147031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184537,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+272422,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+33665,int_stack+33350, 0.0, zero_stack, 1.0, int_stack+46525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60005,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+34085,int_stack+33665, 0.0, zero_stack, 1.0, int_stack+47155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60635,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31878,int_stack+202744,int_stack+231976, 0.0, zero_stack, 1.0, int_stack+152974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+274690,int_stack+31878,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+34751,int_stack+34625, 0.0, zero_stack, 1.0, int_stack+110690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122675, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+34919,int_stack+34751, 0.0, zero_stack, 1.0, int_stack+110816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122801, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+153919, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183403, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31878,int_stack+35345,int_stack+35135, 0.0, zero_stack, 1.0, int_stack+111710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123695, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32508,int_stack+35625,int_stack+35345, 0.0, zero_stack, 1.0, int_stack+111920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123905, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+32508,int_stack+31878, 0.0, zero_stack, 1.0, int_stack+155053, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184537, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+31878,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34146,int_stack+36300,int_stack+35985, 0.0, zero_stack, 1.0, int_stack+49895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60005, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+36720,int_stack+36300, 0.0, zero_stack, 1.0, int_stack+50525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60635, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+34146, 0.0, zero_stack, 1.0, int_stack+163117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+278470,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+37386,int_stack+37260, 0.0, zero_stack, 1.0, int_stack+114685, 0.0, zero_stack, 1.0, int_stack+122675, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+37554,int_stack+37386, 0.0, zero_stack, 1.0, int_stack+114811, 0.0, zero_stack, 1.0, int_stack+122801, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 1.0, int_stack+164062, 0.0, zero_stack, 1.0, int_stack+183403, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+37980,int_stack+37770, 0.0, zero_stack, 1.0, int_stack+115705, 0.0, zero_stack, 1.0, int_stack+123695, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+38260,int_stack+37980, 0.0, zero_stack, 1.0, int_stack+115915, 0.0, zero_stack, 1.0, int_stack+123905, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 1.0, int_stack+165196, 0.0, zero_stack, 1.0, int_stack+184537, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+34146,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+38935,int_stack+38620, 0.0, zero_stack, 1.0, int_stack+53265, 0.0, zero_stack, 1.0, int_stack+60005, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+39355,int_stack+38935, 0.0, zero_stack, 1.0, int_stack+53895, 0.0, zero_stack, 1.0, int_stack+60635, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36414,int_stack+202744,int_stack+231976, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+282250,int_stack+36414,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+40021,int_stack+39895, 0.0, zero_stack, 1.0, int_stack+118680, 1.0, int_stack+122675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+40189,int_stack+40021, 0.0, zero_stack, 1.0, int_stack+118806, 1.0, int_stack+122801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+173260, 1.0, int_stack+183403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36414,int_stack+40615,int_stack+40405, 0.0, zero_stack, 1.0, int_stack+119700, 1.0, int_stack+123695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37044,int_stack+40895,int_stack+40615, 0.0, zero_stack, 1.0, int_stack+119910, 1.0, int_stack+123905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+37044,int_stack+36414, 0.0, zero_stack, 1.0, int_stack+174394, 1.0, int_stack+184537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+36414,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38682,int_stack+41570,int_stack+41255, 0.0, zero_stack, 1.0, int_stack+56635, 1.0, int_stack+60005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+41990,int_stack+41570, 0.0, zero_stack, 1.0, int_stack+57265, 1.0, int_stack+60635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+38682, 0.0, zero_stack, 1.0, int_stack+182458, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+38682,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+42656,int_stack+42530, 0.0, zero_stack, 2.0, int_stack+122675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+42824,int_stack+42656, 0.0, zero_stack, 2.0, int_stack+122801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203122,int_stack+145141,int_stack+202744, 0.0, zero_stack, 2.0, int_stack+183403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+43250,int_stack+43040, 0.0, zero_stack, 2.0, int_stack+123695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+232606,int_stack+43530,int_stack+43250, 0.0, zero_stack, 2.0, int_stack+123905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+232606,int_stack+231976, 0.0, zero_stack, 2.0, int_stack+184537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+286030,int_stack+7182,int_stack+203122,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+44205,int_stack+43890, 0.0, zero_stack, 2.0, int_stack+60005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+44625,int_stack+44205, 0.0, zero_stack, 2.0, int_stack+60635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+42462,int_stack+202744,int_stack+231976, 0.0, zero_stack, 2.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+288298,int_stack+42462,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+45291,int_stack+45165, 1.0, int_stack+106695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126670,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145141,int_stack+45459,int_stack+45291, 1.0, int_stack+106821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126796,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7560,int_stack+145141,int_stack+7182, 1.0, int_stack+144763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192601,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+144763,int_stack+45885,int_stack+45675, 1.0, int_stack+107715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127900,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42462,int_stack+46165,int_stack+45885, 1.0, int_stack+107925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128390,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+42462,int_stack+144763, 1.0, int_stack+147031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193735,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+42462,int_stack+202744,int_stack+7560,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44730,int_stack+47575,int_stack+46840, 1.0, int_stack+46525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63690,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+47995,int_stack+47575, 1.0, int_stack+47155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64320,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+44730, 1.0, int_stack+152974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201799,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+44730,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+48661,int_stack+48535, 1.0, int_stack+110690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126670, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+203122,int_stack+48829,int_stack+48661, 1.0, int_stack+110816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126796, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+203122,int_stack+202744, 1.0, int_stack+153919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192601, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+147031,int_stack+49255,int_stack+49045, 1.0, int_stack+111710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127900, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+49535,int_stack+49255, 1.0, int_stack+111920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128390, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+202744,int_stack+147031, 1.0, int_stack+155053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193735, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+292078,int_stack+7182,int_stack+231976,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+50945,int_stack+50210, 1.0, int_stack+49895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63690, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+51365,int_stack+50945, 1.0, int_stack+50525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64320, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+202744,int_stack+231976, 1.0, int_stack+163117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201799, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+294346,int_stack+48510,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+52031,int_stack+51905, 1.0, int_stack+114685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126670, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7560,int_stack+52199,int_stack+52031, 1.0, int_stack+114811, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126796, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+7560,int_stack+7182, 1.0, int_stack+164062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192601, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+155053,int_stack+52625,int_stack+52415, 1.0, int_stack+115705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127900, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+52905,int_stack+52625, 1.0, int_stack+115915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128390, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+7182,int_stack+155053, 1.0, int_stack+165196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193735, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+49266,int_stack+202744,int_stack+48510,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+54315,int_stack+53580, 1.0, int_stack+53265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63690, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+51534,int_stack+54735,int_stack+54315, 1.0, int_stack+53895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64320, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+51534,int_stack+7182, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201799, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+298126,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+202744,int_stack+55401,int_stack+55275, 1.0, int_stack+118680, 0.0, zero_stack, 1.0, int_stack+126670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+203122,int_stack+55569,int_stack+55401, 1.0, int_stack+118806, 0.0, zero_stack, 1.0, int_stack+126796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+203122,int_stack+202744, 1.0, int_stack+173260, 0.0, zero_stack, 1.0, int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+165196,int_stack+55995,int_stack+55785, 1.0, int_stack+119700, 0.0, zero_stack, 1.0, int_stack+127900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+56275,int_stack+55995, 1.0, int_stack+119910, 0.0, zero_stack, 1.0, int_stack+128390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+202744,int_stack+165196, 1.0, int_stack+174394, 0.0, zero_stack, 1.0, int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+51534,int_stack+7182,int_stack+48510,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+57685,int_stack+56950, 1.0, int_stack+56635, 0.0, zero_stack, 1.0, int_stack+63690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+58105,int_stack+57685, 1.0, int_stack+57265, 0.0, zero_stack, 1.0, int_stack+64320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+202744,int_stack+0, 1.0, int_stack+182458, 0.0, zero_stack, 1.0, int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+53802,int_stack+231976,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173260,int_stack+58771,int_stack+58645, 1.0, int_stack+122675, 1.0, int_stack+126670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+58939,int_stack+58771, 1.0, int_stack+122801, 1.0, int_stack+126796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+173260, 1.0, int_stack+183403, 1.0, int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+174394,int_stack+59365,int_stack+59155, 1.0, int_stack+123695, 1.0, int_stack+127900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+59645,int_stack+59365, 1.0, int_stack+123905, 1.0, int_stack+128390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202744,int_stack+231976,int_stack+174394, 1.0, int_stack+184537, 1.0, int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+57582,int_stack+202744,int_stack+7686,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+61055,int_stack+60320, 1.0, int_stack+60005, 1.0, int_stack+63690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+61475,int_stack+61055, 1.0, int_stack+60635, 1.0, int_stack+64320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+0, 1.0, int_stack+945, 1.0, int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+301906,int_stack+231976,int_stack+202744,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173260,int_stack+62141,int_stack+62015, 2.0, int_stack+126670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+62309,int_stack+62141, 2.0, int_stack+126796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+203248,int_stack+202744,int_stack+173260, 2.0, int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184537,int_stack+62735,int_stack+62525, 2.0, int_stack+127900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+63015,int_stack+62735, 2.0, int_stack+128390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+231976,int_stack+184537, 2.0, int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+59850,int_stack+7182,int_stack+203248,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+64740,int_stack+64005, 2.0, int_stack+63690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+65160,int_stack+64740, 2.0, int_stack+64320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+202744,int_stack+231976, 2.0, int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+305686,int_stack+0,int_stack+7182,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+65826,int_stack+65700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131890,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+65994,int_stack+65826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132016,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+66420,int_stack+66210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132910,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+66700,int_stack+66420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133120,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+201799,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+62118,int_stack+201799,int_stack+7686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+203059,int_stack+67375,int_stack+67060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80235,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+67795,int_stack+67375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80865,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+203059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204004,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+64386,int_stack+0,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+68461,int_stack+68335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131890, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201799,int_stack+68629,int_stack+68461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132016, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+201799,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+69055,int_stack+68845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132910, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201799,int_stack+69335,int_stack+69055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133120, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+201799,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+309466,int_stack+7182,int_stack+48510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+201799,int_stack+70010,int_stack+69695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80235, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+70430,int_stack+70010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80865, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+202744,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204004, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+311734,int_stack+0,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+71096,int_stack+70970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131890, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+71264,int_stack+71096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132016, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+71690,int_stack+71480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+71970,int_stack+71690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133120, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+201799,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+68166,int_stack+201799,int_stack+7686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+203059,int_stack+72645,int_stack+72330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80235, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+73065,int_stack+72645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80865, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+203059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204004, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+315514,int_stack+0,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+73731,int_stack+73605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201799,int_stack+73899,int_stack+73731, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+201799,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+74325,int_stack+74115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201799,int_stack+74605,int_stack+74325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+201799,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+70434,int_stack+7182,int_stack+48510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+201799,int_stack+75280,int_stack+74965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202744,int_stack+75700,int_stack+75280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+202744,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+319294,int_stack+0,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+76366,int_stack+76240, 0.0, zero_stack, 1.0, int_stack+131890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+76534,int_stack+76366, 0.0, zero_stack, 1.0, int_stack+132016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 0.0, zero_stack, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+76960,int_stack+76750, 0.0, zero_stack, 1.0, int_stack+132910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+77240,int_stack+76960, 0.0, zero_stack, 1.0, int_stack+133120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+201799,int_stack+0,int_stack+193735, 0.0, zero_stack, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+72702,int_stack+201799,int_stack+7686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+203059,int_stack+77915,int_stack+77600, 0.0, zero_stack, 1.0, int_stack+80235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+78335,int_stack+77915, 0.0, zero_stack, 1.0, int_stack+80865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+203059, 0.0, zero_stack, 1.0, int_stack+204004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+74970,int_stack+0,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+79001,int_stack+78875, 1.0, int_stack+131890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201799,int_stack+79169,int_stack+79001, 1.0, int_stack+132016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+201799,int_stack+192601, 1.0, int_stack+144385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+79595,int_stack+79385, 1.0, int_stack+132910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+144385,int_stack+79875,int_stack+79595, 1.0, int_stack+133120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+144385,int_stack+193735, 1.0, int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+323074,int_stack+7182,int_stack+48510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+146401,int_stack+81285,int_stack+80550, 1.0, int_stack+80235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+144385,int_stack+81705,int_stack+81285, 1.0, int_stack+80865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+144385,int_stack+146401, 1.0, int_stack+204004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+325342,int_stack+0,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+194365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+82371,int_stack+82245,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+82539,int_stack+82371,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+82965,int_stack+82755,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+83245,int_stack+82965,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+146401,int_stack+0,int_stack+193735,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+201799,int_stack+146401,int_stack+7686, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+147661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+83920,int_stack+83605,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+84340,int_stack+83920,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+0,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+78750,int_stack+231976,int_stack+146401, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+85006,int_stack+84880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135885,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+85174,int_stack+85006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136011,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146905,int_stack+146401,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214210,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+85600,int_stack+85390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136905,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+85880,int_stack+85600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137115,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+231976,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215344,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+82530,int_stack+7182,int_stack+146905, 0.0, zero_stack, 1.0, int_stack+145645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+86555,int_stack+86240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99415,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+86975,int_stack+86555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100045,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+146401,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204949,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+329122,int_stack+0,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+148501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+87641,int_stack+87515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135885, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+87809,int_stack+87641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136011, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214210, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+88235,int_stack+88025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136905, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+88515,int_stack+88235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137115, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146401,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215344, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+84798,int_stack+146401,int_stack+7686, 0.0, zero_stack, 1.0, int_stack+154297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+89190,int_stack+88875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99415, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+89610,int_stack+89190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100045, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204949, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+332902,int_stack+231976,int_stack+146401, 0.0, zero_stack, 1.0, int_stack+155683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+90276,int_stack+90150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135885, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+90444,int_stack+90276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136011, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146905,int_stack+146401,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214210, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+90870,int_stack+90660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136905, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+91150,int_stack+90870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137115, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+231976,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215344, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+87066,int_stack+7182,int_stack+146905, 0.0, zero_stack, 1.0, int_stack+164440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+91825,int_stack+91510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99415, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+92245,int_stack+91825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100045, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+146401,int_stack+231976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204949, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+336682,int_stack+0,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+165826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+92911,int_stack+92785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+93079,int_stack+92911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+93505,int_stack+93295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+93785,int_stack+93505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146401,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+89334,int_stack+146401,int_stack+7686, 0.0, zero_stack, 1.0, int_stack+173638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+94460,int_stack+94145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+94880,int_stack+94460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+91602,int_stack+231976,int_stack+146401, 0.0, zero_stack, 1.0, int_stack+175024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+95546,int_stack+95420, 0.0, zero_stack, 1.0, int_stack+135885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+95714,int_stack+95546, 0.0, zero_stack, 1.0, int_stack+136011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146905,int_stack+146401,int_stack+192601, 0.0, zero_stack, 1.0, int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+96140,int_stack+95930, 0.0, zero_stack, 1.0, int_stack+136905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+96420,int_stack+96140, 0.0, zero_stack, 1.0, int_stack+137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+231976,int_stack+193735, 0.0, zero_stack, 1.0, int_stack+215344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+340462,int_stack+7182,int_stack+146905, 0.0, zero_stack, 1.0, int_stack+183781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+97095,int_stack+96780, 0.0, zero_stack, 1.0, int_stack+99415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+97515,int_stack+97095, 0.0, zero_stack, 1.0, int_stack+100045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+146401,int_stack+231976, 0.0, zero_stack, 1.0, int_stack+204949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+342730,int_stack+0,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+185167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192601,int_stack+98181,int_stack+98055, 1.0, int_stack+135885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+98349,int_stack+98181, 1.0, int_stack+136011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+192601, 1.0, int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+98775,int_stack+98565, 1.0, int_stack+136905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+99055,int_stack+98775, 1.0, int_stack+137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146401,int_stack+0,int_stack+193735, 1.0, int_stack+215344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+95382,int_stack+146401,int_stack+7686, 0.0, zero_stack, 1.0, int_stack+192979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215344,int_stack+100465,int_stack+99730, 1.0, int_stack+99415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+100885,int_stack+100465, 1.0, int_stack+100045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+215344, 1.0, int_stack+204949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+346510,int_stack+0,int_stack+146401, 0.0, zero_stack, 1.0, int_stack+194365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+101551,int_stack+101425,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+101719,int_stack+101551,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+146905,int_stack+146401,int_stack+214210,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+102145,int_stack+101935,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+102425,int_stack+102145,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+193735,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+97650,int_stack+7182,int_stack+146905, 0.0, zero_stack, 1.0, int_stack+147661, 1.0, int_stack+214588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+103100,int_stack+102785,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+103520,int_stack+103100,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+146401,int_stack+0,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+99918,int_stack+231976,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+1890, 1.0, int_stack+221140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+104186,int_stack+104060,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+104354,int_stack+104186,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+214210,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+104780,int_stack+104570,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+105060,int_stack+104780,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+146401,int_stack+231976,int_stack+193735,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+350290,int_stack+146401,int_stack+7686, 0.0, zero_stack, 2.0, int_stack+214588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+231976,int_stack+105735,int_stack+105420,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+106155,int_stack+105735,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+231976,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+352558,int_stack+0,int_stack+146401, 0.0, zero_stack, 2.0, int_stack+221140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+107331,int_stack+107205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140390,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146401,int_stack+107499,int_stack+107331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140516,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146905,int_stack+146401,int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+108775,int_stack+108565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141410,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+109055,int_stack+108775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4284,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+103698,int_stack+7182,int_stack+146905, 1.0, int_stack+145645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+109730,int_stack+109415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129880,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+110150,int_stack+109730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130510,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+215344,int_stack+231976,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+105966,int_stack+215344,int_stack+7182, 1.0, int_stack+148501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+111326,int_stack+111200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140390, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+111494,int_stack+111326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140516, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+112770,int_stack+112560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141410, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+215344,int_stack+113050,int_stack+112770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+215344,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4284, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+144385,int_stack+0,int_stack+7686, 1.0, int_stack+154297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215344,int_stack+113725,int_stack+113410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129880, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+114145,int_stack+113725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130510, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+215344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+109746,int_stack+231976,int_stack+0, 1.0, int_stack+155683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+115321,int_stack+115195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140390, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+115489,int_stack+115321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140516, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+0,int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+116765,int_stack+116555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141410, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+117045,int_stack+116765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4284, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+113526,int_stack+7182,int_stack+48510, 1.0, int_stack+164440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+117720,int_stack+117405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129880, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+118140,int_stack+117720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130510, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+215344,int_stack+231976,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+152974,int_stack+215344,int_stack+7182, 1.0, int_stack+165826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+119316,int_stack+119190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+119484,int_stack+119316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+214210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+120760,int_stack+120550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+215344,int_stack+121040,int_stack+120760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+215344,int_stack+193735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+115794,int_stack+0,int_stack+7686, 1.0, int_stack+173638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215344,int_stack+121715,int_stack+121400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+122135,int_stack+121715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+215344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+118062,int_stack+231976,int_stack+0, 1.0, int_stack+175024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+123311,int_stack+123185, 0.0, zero_stack, 1.0, int_stack+140390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+123479,int_stack+123311, 0.0, zero_stack, 1.0, int_stack+140516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+0,int_stack+214210, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+124755,int_stack+124545, 0.0, zero_stack, 1.0, int_stack+141410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+125035,int_stack+124755, 0.0, zero_stack, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+193735, 0.0, zero_stack, 1.0, int_stack+4284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+173260,int_stack+7182,int_stack+48510, 1.0, int_stack+183781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+125710,int_stack+125395, 0.0, zero_stack, 1.0, int_stack+129880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+126130,int_stack+125710, 0.0, zero_stack, 1.0, int_stack+130510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+215344,int_stack+231976,int_stack+0, 0.0, zero_stack, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+121842,int_stack+215344,int_stack+7182, 1.0, int_stack+185167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+127306,int_stack+127180, 1.0, int_stack+140390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+127474,int_stack+127306, 1.0, int_stack+140516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+214210, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193735,int_stack+129240,int_stack+129030, 1.0, int_stack+141410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+215344,int_stack+129520,int_stack+129240, 1.0, int_stack+141620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+215344,int_stack+193735, 1.0, int_stack+4284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+182458,int_stack+0,int_stack+7686, 1.0, int_stack+192979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215344,int_stack+130930,int_stack+130195, 1.0, int_stack+129880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+131350,int_stack+130930, 1.0, int_stack+130510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+215344, 1.0, int_stack+152029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+125622,int_stack+231976,int_stack+0, 1.0, int_stack+194365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+132526,int_stack+132400,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+132694,int_stack+132526,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+0,int_stack+3150,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4284,int_stack+133970,int_stack+133760,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+134250,int_stack+133970,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+4284,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+192601,int_stack+7182,int_stack+48510, 1.0, int_stack+147661, 0.0, zero_stack, 1.0, int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152029,int_stack+134925,int_stack+134610,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+135345,int_stack+134925,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+0,int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+129402,int_stack+231976,int_stack+7182, 1.0, int_stack+1890, 0.0, zero_stack, 1.0, int_stack+228448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+214210,int_stack+136521,int_stack+136395,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+136689,int_stack+136521,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7686,int_stack+7182,int_stack+214210,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4284,int_stack+137965,int_stack+137755,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+231976,int_stack+138245,int_stack+137965,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+231976,int_stack+4284,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+1260,int_stack+0,int_stack+7686, 1.0, int_stack+214588, 1.0, int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152029,int_stack+138920,int_stack+138605,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+139340,int_stack+138920,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+7182,int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+133182,int_stack+231976,int_stack+0, 1.0, int_stack+221140, 1.0, int_stack+228448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+221140,int_stack+141026,int_stack+140900,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+221518,int_stack+141194,int_stack+141026,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+48510,int_stack+221518,int_stack+221140,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4284,int_stack+142470,int_stack+142260,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+221140,int_stack+142750,int_stack+142470,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+221140,int_stack+4284,10);
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+214210,int_stack+0,int_stack+48510, 2.0, int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152029,int_stack+143425,int_stack+143110,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+221140,int_stack+143845,int_stack+143425,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+231976,int_stack+221140,int_stack+152029,15);
 /*--- compute (fp|hd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+136962,int_stack+231976,int_stack+0, 2.0, int_stack+228448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+356338,int_stack+157069,int_stack+149761,126);
     Libderiv->ABCD[11] = int_stack + 356338;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+360874,int_stack+167212,int_stack+160849,126);
     Libderiv->ABCD[10] = int_stack + 360874;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+163117,int_stack+176410,int_stack+170992,126);
     Libderiv->ABCD[9] = int_stack + 163117;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+175528,int_stack+186553,int_stack+180190,126);
     Libderiv->ABCD[8] = int_stack + 175528;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+184726,int_stack+195751,int_stack+190333,126);
     Libderiv->ABCD[7] = int_stack + 184726;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+194869,int_stack+205894,int_stack+199531,126);
     Libderiv->ABCD[6] = int_stack + 194869;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+204067,int_stack+217360,int_stack+211942, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 204067;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+216478,int_stack+224668,int_stack+222400, 0.0, zero_stack, 1.0, int_stack+209674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 216478;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+224668,int_stack+233866,int_stack+229708, 1.0, int_stack+209674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 224668;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+231976,int_stack+239914,int_stack+237646,126);
     Libderiv->ABCD[155] = int_stack + 231976;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+236512,int_stack+243694,int_stack+4914,126);
     Libderiv->ABCD[143] = int_stack + 236512;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+241048,int_stack+247474,int_stack+8442,126);
     Libderiv->ABCD[142] = int_stack + 241048;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+245584,int_stack+251254,int_stack+10710,126);
     Libderiv->ABCD[131] = int_stack + 245584;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+250120,int_stack+255034,int_stack+12978,126);
     Libderiv->ABCD[130] = int_stack + 250120;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+3528,int_stack+17514,int_stack+15246,126);
     Libderiv->ABCD[129] = int_stack + 3528;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+8064,int_stack+261082,int_stack+258814,126);
     Libderiv->ABCD[119] = int_stack + 8064;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+254656,int_stack+264862,int_stack+21294,126);
     Libderiv->ABCD[118] = int_stack + 254656;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+259192,int_stack+268642,int_stack+23562,126);
     Libderiv->ABCD[117] = int_stack + 259192;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+263728,int_stack+28098,int_stack+25830,126);
     Libderiv->ABCD[116] = int_stack + 263728;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+12600,int_stack+274690,int_stack+272422,126);
     Libderiv->ABCD[107] = int_stack + 12600;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+268264,int_stack+278470,int_stack+31878,126);
     Libderiv->ABCD[106] = int_stack + 268264;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+272800,int_stack+282250,int_stack+34146,126);
     Libderiv->ABCD[105] = int_stack + 272800;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+277336,int_stack+38682,int_stack+36414,126);
     Libderiv->ABCD[104] = int_stack + 277336;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+17136,int_stack+288298,int_stack+286030,126);
     Libderiv->ABCD[103] = int_stack + 17136;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+281872,int_stack+44730,int_stack+42462,126);
     Libderiv->ABCD[95] = int_stack + 281872;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+286408,int_stack+294346,int_stack+292078,126);
     Libderiv->ABCD[94] = int_stack + 286408;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+290944,int_stack+298126,int_stack+49266,126);
     Libderiv->ABCD[93] = int_stack + 290944;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+295480,int_stack+53802,int_stack+51534,126);
     Libderiv->ABCD[92] = int_stack + 295480;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+21672,int_stack+301906,int_stack+57582,126);
     Libderiv->ABCD[91] = int_stack + 21672;
 /*--- compute (dd|hd) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+300016,int_stack+305686,int_stack+59850,126);
     Libderiv->ABCD[90] = int_stack + 300016;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+304552,int_stack+64386,int_stack+62118, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[47] = int_stack + 304552;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+26208,int_stack+311734,int_stack+309466, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+160849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[46] = int_stack + 26208;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+309088,int_stack+315514,int_stack+68166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[45] = int_stack + 309088;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+313624,int_stack+319294,int_stack+70434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[44] = int_stack + 313624;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+318160,int_stack+74970,int_stack+72702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[43] = int_stack + 318160;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+30744,int_stack+325342,int_stack+323074, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[42] = int_stack + 30744;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+322696,int_stack+78750,int_stack+201799, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+211942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[38] = int_stack + 322696;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+35280,int_stack+329122,int_stack+82530, 0.0, zero_stack, 1.0, int_stack+149761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[35] = int_stack + 35280;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+327232,int_stack+332902,int_stack+84798, 0.0, zero_stack, 1.0, int_stack+160849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[34] = int_stack + 327232;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+331768,int_stack+336682,int_stack+87066, 0.0, zero_stack, 1.0, int_stack+170992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[33] = int_stack + 331768;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+39816,int_stack+91602,int_stack+89334, 0.0, zero_stack, 1.0, int_stack+180190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[32] = int_stack + 39816;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+44352,int_stack+342730,int_stack+340462, 0.0, zero_stack, 1.0, int_stack+190333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[31] = int_stack + 44352;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+336304,int_stack+346510,int_stack+95382, 0.0, zero_stack, 1.0, int_stack+199531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[30] = int_stack + 336304;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+340840,int_stack+99918,int_stack+97650, 0.0, zero_stack, 1.0, int_stack+211942, 1.0, int_stack+222400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[26] = int_stack + 340840;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+345376,int_stack+352558,int_stack+350290, 0.0, zero_stack, 2.0, int_stack+222400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[25] = int_stack + 345376;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+349912,int_stack+105966,int_stack+103698, 1.0, int_stack+149761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[23] = int_stack + 349912;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+48888,int_stack+109746,int_stack+144385, 1.0, int_stack+160849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[22] = int_stack + 48888;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+53424,int_stack+152974,int_stack+113526, 1.0, int_stack+170992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[21] = int_stack + 53424;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+57960,int_stack+118062,int_stack+115794, 1.0, int_stack+180190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[20] = int_stack + 57960;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+62496,int_stack+121842,int_stack+173260, 1.0, int_stack+190333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[19] = int_stack + 62496;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+67032,int_stack+125622,int_stack+182458, 1.0, int_stack+199531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[18] = int_stack + 67032;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+71568,int_stack+129402,int_stack+192601, 1.0, int_stack+211942, 0.0, zero_stack, 1.0, int_stack+229708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[14] = int_stack + 71568;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+76104,int_stack+133182,int_stack+1260, 1.0, int_stack+222400, 1.0, int_stack+229708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[13] = int_stack + 76104;
 /*--- compute (dd|hd) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+80640,int_stack+136962,int_stack+214210, 2.0, int_stack+229708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[12] = int_stack + 80640;

}
