/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_fdgd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|gd) integrals */

void d12hrr_order_fdgd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][6][10] = int_stack + 588;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1176;
 Libderiv->deriv_classes[5][6][8] = int_stack + 1764;
 Libderiv->deriv_classes[5][6][7] = int_stack + 2352;
 Libderiv->dvrr_classes[5][5] = int_stack + 2940;
 Libderiv->deriv_classes[5][6][6] = int_stack + 3381;
 Libderiv->deriv_classes[5][6][2] = int_stack + 3969;
 Libderiv->deriv_classes[5][6][1] = int_stack + 4557;
 Libderiv->dvrr_classes[4][6] = int_stack + 5145;
 Libderiv->deriv_classes[5][6][0] = int_stack + 5565;
 Libderiv->deriv2_classes[3][4][143] = int_stack + 6153;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 6303;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 6513;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 6793;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 7018;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 7333;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 7753;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 8068;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 8509;
 Libderiv->deriv2_classes[3][4][131] = int_stack + 9097;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 9247;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 9457;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 9737;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 9962;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 10277;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 10697;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 11012;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 11453;
 Libderiv->deriv2_classes[3][4][130] = int_stack + 12041;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 12191;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 12401;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 12681;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 12906;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 13221;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 13641;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 13956;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 14397;
 Libderiv->deriv2_classes[3][4][119] = int_stack + 14985;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 15135;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 15345;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 15625;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 15850;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 16165;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 16585;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 16900;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 17341;
 Libderiv->deriv2_classes[3][4][118] = int_stack + 17929;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 18079;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 18289;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 18569;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 18794;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 19109;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 19529;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 19844;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 20285;
 Libderiv->deriv2_classes[3][4][117] = int_stack + 20873;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 21023;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 21233;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 21513;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 21738;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 22053;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 22473;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 22788;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 23229;
 Libderiv->deriv2_classes[3][4][107] = int_stack + 23817;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 23967;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 24177;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 24457;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 24682;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 24997;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 25417;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 25732;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 26173;
 Libderiv->deriv2_classes[3][4][106] = int_stack + 26761;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 26911;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 27121;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 27401;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 27626;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 27941;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 28361;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 28676;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 29117;
 Libderiv->deriv2_classes[3][4][105] = int_stack + 29705;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 29855;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 30065;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 30345;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 30570;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 30885;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 31305;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 31620;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 32061;
 Libderiv->deriv2_classes[3][4][104] = int_stack + 32649;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 32799;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 33009;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 33289;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 33514;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 33829;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 34249;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 34564;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 35005;
 Libderiv->deriv2_classes[3][4][95] = int_stack + 35593;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 35743;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 35953;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 36233;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 36458;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 36773;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 37193;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 37508;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 37949;
 Libderiv->deriv2_classes[3][4][94] = int_stack + 38537;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 38687;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 38897;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 39177;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 39402;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 39717;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 40137;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 40452;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 40893;
 Libderiv->deriv2_classes[3][4][93] = int_stack + 41481;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 41631;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 41841;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 42121;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 42346;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 42661;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 43081;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 43396;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 43837;
 Libderiv->deriv2_classes[3][4][92] = int_stack + 44425;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 44575;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 44785;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 45065;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 45290;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 45605;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 46025;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 46340;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 46781;
 Libderiv->deriv2_classes[3][4][91] = int_stack + 47369;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 47519;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 47729;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 48009;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 48234;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 48549;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 48969;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 49284;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 49725;
 Libderiv->deriv2_classes[3][4][83] = int_stack + 50313;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 50463;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 50673;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 50953;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 51178;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 51493;
 Libderiv->deriv_classes[5][4][11] = int_stack + 51913;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 52228;
 Libderiv->deriv_classes[5][5][11] = int_stack + 52543;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 52984;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 53425;
 Libderiv->deriv2_classes[3][4][82] = int_stack + 54013;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 54163;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 54373;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 54653;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 54878;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 55193;
 Libderiv->deriv_classes[5][4][10] = int_stack + 55613;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 55928;
 Libderiv->deriv_classes[5][5][10] = int_stack + 56243;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 56684;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 57125;
 Libderiv->deriv2_classes[3][4][81] = int_stack + 57713;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 57863;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 58073;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 58353;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 58578;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 58893;
 Libderiv->deriv_classes[5][4][9] = int_stack + 59313;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 59628;
 Libderiv->deriv_classes[5][5][9] = int_stack + 59943;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 60384;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 60825;
 Libderiv->deriv2_classes[3][4][80] = int_stack + 61413;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 61563;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 61773;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 62053;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 62278;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 62593;
 Libderiv->deriv_classes[5][4][8] = int_stack + 63013;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 63328;
 Libderiv->deriv_classes[5][5][8] = int_stack + 63643;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 64084;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 64525;
 Libderiv->deriv2_classes[3][4][79] = int_stack + 65113;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 65263;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 65473;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 65753;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 65978;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 66293;
 Libderiv->deriv_classes[5][4][7] = int_stack + 66713;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 67028;
 Libderiv->deriv_classes[5][5][7] = int_stack + 67343;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 67784;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 68225;
 Libderiv->deriv2_classes[3][4][78] = int_stack + 68813;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 68963;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 69173;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 69453;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 69678;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 69993;
 Libderiv->dvrr_classes[5][4] = int_stack + 70413;
 Libderiv->deriv_classes[5][4][6] = int_stack + 70728;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 71043;
 Libderiv->deriv_classes[5][5][6] = int_stack + 71358;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 71799;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 72240;
 Libderiv->deriv2_classes[3][4][35] = int_stack + 72828;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 72978;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 73188;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 73468;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 73693;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 74008;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 74428;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 74743;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 75184;
 Libderiv->deriv2_classes[3][4][34] = int_stack + 75772;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 75922;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 76132;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 76412;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 76637;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 76952;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 77372;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 77687;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 78128;
 Libderiv->deriv2_classes[3][4][33] = int_stack + 78716;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 78866;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 79076;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 79356;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 79581;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 79896;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 80316;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 80631;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 81072;
 Libderiv->deriv2_classes[3][4][32] = int_stack + 81660;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 81810;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 82020;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 82300;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 82525;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 82840;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 83260;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 83575;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 84016;
 Libderiv->deriv2_classes[3][4][31] = int_stack + 84604;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 84754;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 84964;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 85244;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 85469;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 85784;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 86204;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 86519;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 86960;
 Libderiv->deriv2_classes[3][4][30] = int_stack + 87548;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 87698;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 87908;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 88188;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 88413;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 88728;
 Libderiv->deriv_classes[5][4][2] = int_stack + 89148;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 89463;
 Libderiv->deriv_classes[5][5][2] = int_stack + 89778;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 90219;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 90660;
 Libderiv->deriv2_classes[3][4][26] = int_stack + 91248;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 91398;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 91608;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 91888;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 92113;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 92428;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 92848;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 93163;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 93604;
 Libderiv->deriv2_classes[3][4][23] = int_stack + 94192;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 94342;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 94552;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 94832;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 95057;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 95372;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 95792;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 96107;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 96548;
 Libderiv->deriv2_classes[3][4][22] = int_stack + 97136;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 97286;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 97496;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 97776;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 98001;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 98316;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 98736;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 99051;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 99492;
 Libderiv->deriv2_classes[3][4][21] = int_stack + 100080;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 100230;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 100440;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 100720;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 100945;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 101260;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 101680;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 101995;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 102436;
 Libderiv->deriv2_classes[3][4][20] = int_stack + 103024;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 103174;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 103384;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 103664;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 103889;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 104204;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 104624;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 104939;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 105380;
 Libderiv->deriv2_classes[3][4][19] = int_stack + 105968;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 106118;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 106328;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 106608;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 106833;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 107148;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 107568;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 107883;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 108324;
 Libderiv->deriv2_classes[3][4][18] = int_stack + 108912;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 109062;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 109272;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 109552;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 109777;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 110092;
 Libderiv->deriv_classes[5][4][1] = int_stack + 110512;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 110827;
 Libderiv->deriv_classes[5][5][1] = int_stack + 111142;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 111583;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 112024;
 Libderiv->deriv2_classes[3][4][14] = int_stack + 112612;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 112762;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 112972;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 113252;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 113477;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 113792;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 114212;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 114527;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 114968;
 Libderiv->deriv2_classes[3][4][13] = int_stack + 115556;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 115706;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 115916;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 116196;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 116421;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 116736;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 117156;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 117471;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 117912;
 Libderiv->deriv_classes[3][4][11] = int_stack + 118500;
 Libderiv->deriv_classes[3][5][11] = int_stack + 118650;
 Libderiv->deriv_classes[3][6][11] = int_stack + 118860;
 Libderiv->deriv2_classes[3][4][11] = int_stack + 119140;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 119290;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 119500;
 Libderiv->deriv_classes[4][4][11] = int_stack + 119780;
 Libderiv->deriv_classes[4][5][11] = int_stack + 120005;
 Libderiv->deriv_classes[4][6][11] = int_stack + 120320;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 120740;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 120965;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 121280;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 121700;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 122015;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 122456;
 Libderiv->deriv_classes[3][4][10] = int_stack + 123044;
 Libderiv->deriv_classes[3][5][10] = int_stack + 123194;
 Libderiv->deriv_classes[3][6][10] = int_stack + 123404;
 Libderiv->deriv2_classes[3][4][10] = int_stack + 123684;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 123834;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 124044;
 Libderiv->deriv_classes[4][4][10] = int_stack + 124324;
 Libderiv->deriv_classes[4][5][10] = int_stack + 124549;
 Libderiv->deriv_classes[4][6][10] = int_stack + 124864;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 125284;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 125509;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 125824;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 126244;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 126559;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 127000;
 Libderiv->deriv_classes[3][4][9] = int_stack + 127588;
 Libderiv->deriv_classes[3][5][9] = int_stack + 127738;
 Libderiv->deriv_classes[3][6][9] = int_stack + 127948;
 Libderiv->deriv2_classes[3][4][9] = int_stack + 128228;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 128378;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 128588;
 Libderiv->deriv_classes[4][4][9] = int_stack + 128868;
 Libderiv->deriv_classes[4][5][9] = int_stack + 129093;
 Libderiv->deriv_classes[4][6][9] = int_stack + 129408;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 129828;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 130053;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 130368;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 130788;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 131103;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 131544;
 Libderiv->deriv_classes[3][4][8] = int_stack + 132132;
 Libderiv->deriv_classes[3][5][8] = int_stack + 132282;
 Libderiv->deriv_classes[3][6][8] = int_stack + 132492;
 Libderiv->deriv2_classes[3][4][8] = int_stack + 132772;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 132922;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 133132;
 Libderiv->deriv_classes[4][4][8] = int_stack + 133412;
 Libderiv->deriv_classes[4][5][8] = int_stack + 133637;
 Libderiv->deriv_classes[4][6][8] = int_stack + 133952;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 134372;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 134597;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 134912;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 135332;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 135647;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 136088;
 Libderiv->deriv_classes[3][4][7] = int_stack + 136676;
 Libderiv->deriv_classes[3][5][7] = int_stack + 136826;
 Libderiv->deriv_classes[3][6][7] = int_stack + 137036;
 Libderiv->deriv2_classes[3][4][7] = int_stack + 137316;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 137466;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 137676;
 Libderiv->deriv_classes[4][4][7] = int_stack + 137956;
 Libderiv->deriv_classes[4][5][7] = int_stack + 138181;
 Libderiv->deriv_classes[4][6][7] = int_stack + 138496;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 138916;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 139141;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 139456;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 139876;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 140191;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 140632;
 Libderiv->deriv_classes[3][4][6] = int_stack + 141220;
 Libderiv->deriv_classes[3][5][6] = int_stack + 141370;
 Libderiv->deriv_classes[3][6][6] = int_stack + 141580;
 Libderiv->deriv2_classes[3][4][6] = int_stack + 141860;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 142010;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 142220;
 Libderiv->dvrr_classes[4][4] = int_stack + 142500;
 Libderiv->deriv_classes[4][4][6] = int_stack + 142725;
 Libderiv->dvrr_classes[4][5] = int_stack + 142950;
 Libderiv->deriv_classes[4][5][6] = int_stack + 143265;
 Libderiv->deriv_classes[4][6][6] = int_stack + 143580;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 144000;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 144225;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 144540;
 Libderiv->deriv_classes[5][4][0] = int_stack + 144960;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 145275;
 Libderiv->deriv_classes[5][5][0] = int_stack + 145590;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 146031;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 146472;
 Libderiv->deriv_classes[3][4][2] = int_stack + 147060;
 Libderiv->deriv_classes[3][5][2] = int_stack + 147210;
 Libderiv->deriv_classes[3][6][2] = int_stack + 147420;
 Libderiv->deriv2_classes[3][4][2] = int_stack + 147700;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 147850;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 148060;
 Libderiv->deriv_classes[4][4][2] = int_stack + 148340;
 Libderiv->deriv_classes[4][5][2] = int_stack + 148565;
 Libderiv->deriv_classes[4][6][2] = int_stack + 148880;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 149300;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 149525;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 149840;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 150260;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 150575;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 151016;
 Libderiv->deriv_classes[3][4][1] = int_stack + 151604;
 Libderiv->deriv_classes[3][5][1] = int_stack + 151754;
 Libderiv->deriv_classes[3][6][1] = int_stack + 151964;
 Libderiv->deriv2_classes[3][4][1] = int_stack + 152244;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 152394;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 152604;
 Libderiv->deriv_classes[4][4][1] = int_stack + 152884;
 Libderiv->deriv_classes[4][5][1] = int_stack + 153109;
 Libderiv->deriv_classes[4][6][1] = int_stack + 153424;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 153844;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 154069;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 154384;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 154804;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 155119;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 155560;
 Libderiv->dvrr_classes[3][4] = int_stack + 156148;
 Libderiv->dvrr_classes[3][5] = int_stack + 156298;
 Libderiv->dvrr_classes[3][6] = int_stack + 156508;
 Libderiv->deriv_classes[3][4][0] = int_stack + 156788;
 Libderiv->deriv_classes[3][5][0] = int_stack + 156938;
 Libderiv->deriv_classes[3][6][0] = int_stack + 157148;
 Libderiv->deriv2_classes[3][4][0] = int_stack + 157428;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 157578;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 157788;
 Libderiv->deriv_classes[4][4][0] = int_stack + 158068;
 Libderiv->deriv_classes[4][5][0] = int_stack + 158293;
 Libderiv->deriv_classes[4][6][0] = int_stack + 158608;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 159028;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 159253;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 159568;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 159988;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 160303;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 160744;
 memset(int_stack,0,1290656);

 Libderiv->dvrr_stack = int_stack + 425041;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_fdgd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+161332,int_stack+156298,int_stack+156148,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+161782,int_stack+118650,int_stack+118500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156148,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+118860,int_stack+118650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156298,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+162862,int_stack+162232,int_stack+161782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+163762,int_stack+142950,int_stack+142500,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+120005,int_stack+119780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142500,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+165112,int_stack+120320,int_stack+120005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+166057,int_stack+165112,int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+167407,int_stack+166057,int_stack+162862,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+165112,int_stack+2940,int_stack+70413,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+170107,int_stack+52543,int_stack+51913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70413,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+171052,int_stack+0,int_stack+52543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+172375,int_stack+171052,int_stack+170107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+174265,int_stack+172375,int_stack+166057,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171052,int_stack+123194,int_stack+123044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156148, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+123404,int_stack+123194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156298, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+171502,int_stack+162232,int_stack+171052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172402,int_stack+124549,int_stack+124324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142500, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173077,int_stack+124864,int_stack+124549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+178315,int_stack+173077,int_stack+172402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+179665,int_stack+178315,int_stack+171502,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+173077,int_stack+56243,int_stack+55613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70413, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+182365,int_stack+588,int_stack+56243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+183688,int_stack+182365,int_stack+173077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+185578,int_stack+183688,int_stack+178315,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+182365,int_stack+127738,int_stack+127588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156148, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+127948,int_stack+127738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156298, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+182815,int_stack+162232,int_stack+182365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183715,int_stack+129093,int_stack+128868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142500, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184390,int_stack+129408,int_stack+129093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+189628,int_stack+184390,int_stack+183715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+190978,int_stack+189628,int_stack+182815,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+184390,int_stack+59943,int_stack+59313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70413, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+193678,int_stack+1176,int_stack+59943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+195001,int_stack+193678,int_stack+184390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+196891,int_stack+195001,int_stack+189628,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+193678,int_stack+132282,int_stack+132132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+132492,int_stack+132282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+194128,int_stack+162232,int_stack+193678, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+195028,int_stack+133637,int_stack+133412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+195703,int_stack+133952,int_stack+133637, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+195703,int_stack+195028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+200941,int_stack+0,int_stack+194128,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+195703,int_stack+63643,int_stack+63013, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+203641,int_stack+1764,int_stack+63643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+204964,int_stack+203641,int_stack+195703, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+206854,int_stack+204964,int_stack+0,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+203641,int_stack+136826,int_stack+136676, 0.0, zero_stack, 1.0, int_stack+156148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+137036,int_stack+136826, 0.0, zero_stack, 1.0, int_stack+156298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+204091,int_stack+162232,int_stack+203641, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+204991,int_stack+138181,int_stack+137956, 0.0, zero_stack, 1.0, int_stack+142500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205666,int_stack+138496,int_stack+138181, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+210904,int_stack+205666,int_stack+204991, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+212254,int_stack+210904,int_stack+204091,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+205666,int_stack+67343,int_stack+66713, 0.0, zero_stack, 1.0, int_stack+70413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214954,int_stack+2352,int_stack+67343, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+216277,int_stack+214954,int_stack+205666, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+218167,int_stack+216277,int_stack+210904,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+141370,int_stack+141220, 1.0, int_stack+156148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+141580,int_stack+141370, 1.0, int_stack+156298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+215404,int_stack+162232,int_stack+214954, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+216304,int_stack+143265,int_stack+142725, 1.0, int_stack+142500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+216979,int_stack+143580,int_stack+143265, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1350,int_stack+216979,int_stack+216304, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+222217,int_stack+1350,int_stack+215404,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+216979,int_stack+71358,int_stack+70728, 1.0, int_stack+70413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+224917,int_stack+3381,int_stack+71358, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+226240,int_stack+224917,int_stack+216979, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+228130,int_stack+226240,int_stack+1350,90);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+156508,int_stack+156298,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+165112,int_stack+162232,int_stack+161332,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224917,int_stack+5145,int_stack+142950,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+225862,int_stack+224917,int_stack+163762,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+232180,int_stack+225862,int_stack+165112,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+161332,int_stack+147210,int_stack+147060,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+147420,int_stack+147210,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+224917,int_stack+162232,int_stack+161332,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+163762,int_stack+148565,int_stack+148340,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+148880,int_stack+148565,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+234880,int_stack+2700,int_stack+163762,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+236230,int_stack+234880,int_stack+224917, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+89778,int_stack+89148,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+238930,int_stack+3969,int_stack+89778,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+240253,int_stack+238930,int_stack+2700,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+242143,int_stack+240253,int_stack+234880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+151754,int_stack+151604,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+151964,int_stack+151754,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+239380,int_stack+162232,int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+240280,int_stack+153109,int_stack+152884,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+240955,int_stack+153424,int_stack+153109,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+246193,int_stack+240955,int_stack+240280,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+247543,int_stack+246193,int_stack+239380, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+240955,int_stack+111142,int_stack+110512,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+250243,int_stack+4557,int_stack+111142,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+3645,int_stack+250243,int_stack+240955,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+250243,int_stack+3645,int_stack+246193, 0.0, zero_stack, 1.0, int_stack+225862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3645,int_stack+156938,int_stack+156788,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+157148,int_stack+156938,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+4095,int_stack+162232,int_stack+3645,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+227212,int_stack+158293,int_stack+158068,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+158608,int_stack+158293,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+255238,int_stack+254293,int_stack+227212,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+256588,int_stack+255238,int_stack+4095, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+165112,int_stack+145590,int_stack+144960,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+259288,int_stack+5565,int_stack+145590,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+260611,int_stack+259288,int_stack+165112,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+262501,int_stack+260611,int_stack+255238, 1.0, int_stack+225862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+6303,int_stack+6153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118500,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+6513,int_stack+6303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118650,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+259288,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+161782,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+7018,int_stack+6793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+119780,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+7333,int_stack+7018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+120005,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+260188,int_stack+254293,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+164437,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+4995,int_stack+260188,int_stack+259288,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+8068,int_stack+7753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+51913,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+225817,int_stack+8509,int_stack+8068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+52543,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+225817,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+170107,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+268441,int_stack+266551,int_stack+260188,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+9247,int_stack+9097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118500, 1.0, int_stack+123044,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+9457,int_stack+9247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118650, 1.0, int_stack+123194,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161782, 1.0, int_stack+171052,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+9962,int_stack+9737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119780, 1.0, int_stack+124324,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+225817,int_stack+10277,int_stack+9962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120005, 1.0, int_stack+124549,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+259288,int_stack+225817,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164437, 1.0, int_stack+172402,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+7695,int_stack+259288,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+11012,int_stack+10697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51913, 1.0, int_stack+55613,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+225817,int_stack+11453,int_stack+11012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52543, 1.0, int_stack+56243,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+225817,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170107, 1.0, int_stack+173077,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+272491,int_stack+266551,int_stack+259288,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+259288,int_stack+12191,int_stack+12041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+123044, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+12401,int_stack+12191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+123194, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+259738,int_stack+162232,int_stack+259288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+171052, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+260638,int_stack+12906,int_stack+12681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+124324, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+13221,int_stack+12906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+124549, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+254293,int_stack+260638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+172402, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+10395,int_stack+266551,int_stack+259738,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+13956,int_stack+13641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+55613, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259288,int_stack+14397,int_stack+13956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56243, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+260611,int_stack+259288,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173077, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+276541,int_stack+260611,int_stack+266551,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+15135,int_stack+14985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118500, 0.0, zero_stack, 1.0, int_stack+127588,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+15345,int_stack+15135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118650, 0.0, zero_stack, 1.0, int_stack+127738,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161782, 0.0, zero_stack, 1.0, int_stack+182365,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+15850,int_stack+15625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119780, 0.0, zero_stack, 1.0, int_stack+128868,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259288,int_stack+16165,int_stack+15850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120005, 0.0, zero_stack, 1.0, int_stack+129093,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+260233,int_stack+259288,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164437, 0.0, zero_stack, 1.0, int_stack+183715,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+13095,int_stack+260233,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+16900,int_stack+16585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51913, 0.0, zero_stack, 1.0, int_stack+59313,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+17341,int_stack+16900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52543, 0.0, zero_stack, 1.0, int_stack+59943,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+15795,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170107, 0.0, zero_stack, 1.0, int_stack+184390,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+280591,int_stack+15795,int_stack+260233,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+15795,int_stack+18079,int_stack+17929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123044, 1.0, int_stack+127588, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+18289,int_stack+18079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123194, 1.0, int_stack+127738, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16245,int_stack+162232,int_stack+15795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171052, 1.0, int_stack+182365, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+17145,int_stack+18794,int_stack+18569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124324, 1.0, int_stack+128868, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+19109,int_stack+18794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124549, 1.0, int_stack+129093, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17820,int_stack+254293,int_stack+17145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172402, 1.0, int_stack+183715, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+259288,int_stack+17820,int_stack+16245,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+19844,int_stack+19529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55613, 1.0, int_stack+59313, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15795,int_stack+20285,int_stack+19844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56243, 1.0, int_stack+59943, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+15795,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173077, 1.0, int_stack+184390, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+284641,int_stack+266551,int_stack+17820,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+21023,int_stack+20873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+127588, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+21233,int_stack+21023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+127738, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+182365, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+21738,int_stack+21513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+128868, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15795,int_stack+22053,int_stack+21738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+129093, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16740,int_stack+15795,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+183715, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+18090,int_stack+16740,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+22788,int_stack+22473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+59313, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+23229,int_stack+22788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+59943, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+20790,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184390, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+288691,int_stack+20790,int_stack+16740,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+20790,int_stack+23967,int_stack+23817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132132,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+24177,int_stack+23967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132282,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+21240,int_stack+162232,int_stack+20790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193678,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+22140,int_stack+24682,int_stack+24457, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133412,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+24997,int_stack+24682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133637,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22815,int_stack+254293,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195028,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+292741,int_stack+22815,int_stack+21240,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+25732,int_stack+25417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63013,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20790,int_stack+26173,int_stack+25732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63643,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+20790,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170107, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195703,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+295441,int_stack+266551,int_stack+22815,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+26911,int_stack+26761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123044, 0.0, zero_stack, 1.0, int_stack+132132, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+27121,int_stack+26911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123194, 0.0, zero_stack, 1.0, int_stack+132282, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171052, 0.0, zero_stack, 1.0, int_stack+193678, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+27626,int_stack+27401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124324, 0.0, zero_stack, 1.0, int_stack+133412, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20790,int_stack+27941,int_stack+27626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124549, 0.0, zero_stack, 1.0, int_stack+133637, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+21735,int_stack+20790,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172402, 0.0, zero_stack, 1.0, int_stack+195028, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+23085,int_stack+21735,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+28676,int_stack+28361, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55613, 0.0, zero_stack, 1.0, int_stack+63013, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+29117,int_stack+28676, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56243, 0.0, zero_stack, 1.0, int_stack+63643, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+25785,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173077, 0.0, zero_stack, 1.0, int_stack+195703, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+299491,int_stack+25785,int_stack+21735,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+25785,int_stack+29855,int_stack+29705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127588, 1.0, int_stack+132132, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+30065,int_stack+29855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127738, 1.0, int_stack+132282, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26235,int_stack+162232,int_stack+25785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182365, 1.0, int_stack+193678, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27135,int_stack+30570,int_stack+30345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128868, 1.0, int_stack+133412, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+30885,int_stack+30570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129093, 1.0, int_stack+133637, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+27810,int_stack+254293,int_stack+27135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183715, 1.0, int_stack+195028, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+303541,int_stack+27810,int_stack+26235,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+31620,int_stack+31305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59313, 1.0, int_stack+63013, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25785,int_stack+32061,int_stack+31620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59943, 1.0, int_stack+63643, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+25785,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184390, 1.0, int_stack+195703, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+306241,int_stack+266551,int_stack+27810,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+32799,int_stack+32649, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+132132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+33009,int_stack+32799, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+132282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+193678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+33514,int_stack+33289, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+133412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25785,int_stack+33829,int_stack+33514, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+133637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26730,int_stack+25785,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+195028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+28080,int_stack+26730,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+34564,int_stack+34249, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+63013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+35005,int_stack+34564, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+63643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30780,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+195703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+310291,int_stack+30780,int_stack+26730,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+30780,int_stack+35743,int_stack+35593, 0.0, zero_stack, 1.0, int_stack+118500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136676,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+35953,int_stack+35743, 0.0, zero_stack, 1.0, int_stack+118650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136826,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31230,int_stack+162232,int_stack+30780, 0.0, zero_stack, 1.0, int_stack+161782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203641,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+32130,int_stack+36458,int_stack+36233, 0.0, zero_stack, 1.0, int_stack+119780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137956,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+36773,int_stack+36458, 0.0, zero_stack, 1.0, int_stack+120005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138181,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+32805,int_stack+254293,int_stack+32130, 0.0, zero_stack, 1.0, int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204991,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+34155,int_stack+32805,int_stack+31230,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+37508,int_stack+37193, 0.0, zero_stack, 1.0, int_stack+51913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66713,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30780,int_stack+37949,int_stack+37508, 0.0, zero_stack, 1.0, int_stack+52543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67343,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+30780,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+170107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205666,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+314341,int_stack+266551,int_stack+32805,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+38687,int_stack+38537, 0.0, zero_stack, 1.0, int_stack+123044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136676, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+38897,int_stack+38687, 0.0, zero_stack, 1.0, int_stack+123194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136826, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 1.0, int_stack+171052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203641, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+39402,int_stack+39177, 0.0, zero_stack, 1.0, int_stack+124324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137956, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30780,int_stack+39717,int_stack+39402, 0.0, zero_stack, 1.0, int_stack+124549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138181, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31725,int_stack+30780,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+172402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204991, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+36855,int_stack+31725,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+40452,int_stack+40137, 0.0, zero_stack, 1.0, int_stack+55613, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66713, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+40893,int_stack+40452, 0.0, zero_stack, 1.0, int_stack+56243, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67343, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+266551,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+173077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205666, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+318391,int_stack+39555,int_stack+31725,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39555,int_stack+41631,int_stack+41481, 0.0, zero_stack, 1.0, int_stack+127588, 0.0, zero_stack, 1.0, int_stack+136676, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+41841,int_stack+41631, 0.0, zero_stack, 1.0, int_stack+127738, 0.0, zero_stack, 1.0, int_stack+136826, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+40005,int_stack+162232,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+182365, 0.0, zero_stack, 1.0, int_stack+203641, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+40905,int_stack+42346,int_stack+42121, 0.0, zero_stack, 1.0, int_stack+128868, 0.0, zero_stack, 1.0, int_stack+137956, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+42661,int_stack+42346, 0.0, zero_stack, 1.0, int_stack+129093, 0.0, zero_stack, 1.0, int_stack+138181, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+41580,int_stack+254293,int_stack+40905, 0.0, zero_stack, 1.0, int_stack+183715, 0.0, zero_stack, 1.0, int_stack+204991, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+30780,int_stack+41580,int_stack+40005,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+43396,int_stack+43081, 0.0, zero_stack, 1.0, int_stack+59313, 0.0, zero_stack, 1.0, int_stack+66713, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+43837,int_stack+43396, 0.0, zero_stack, 1.0, int_stack+59943, 0.0, zero_stack, 1.0, int_stack+67343, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+39555,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+184390, 0.0, zero_stack, 1.0, int_stack+205666, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+322441,int_stack+266551,int_stack+41580,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+266551,int_stack+44575,int_stack+44425, 0.0, zero_stack, 1.0, int_stack+132132, 1.0, int_stack+136676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+44785,int_stack+44575, 0.0, zero_stack, 1.0, int_stack+132282, 1.0, int_stack+136826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+267001,int_stack+162232,int_stack+266551, 0.0, zero_stack, 1.0, int_stack+193678, 1.0, int_stack+203641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+45290,int_stack+45065, 0.0, zero_stack, 1.0, int_stack+133412, 1.0, int_stack+137956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+45605,int_stack+45290, 0.0, zero_stack, 1.0, int_stack+133637, 1.0, int_stack+138181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+33480, 0.0, zero_stack, 1.0, int_stack+195028, 1.0, int_stack+204991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+40905,int_stack+39555,int_stack+267001,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+46340,int_stack+46025, 0.0, zero_stack, 1.0, int_stack+63013, 1.0, int_stack+66713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+46781,int_stack+46340, 0.0, zero_stack, 1.0, int_stack+63643, 1.0, int_stack+67343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43605,int_stack+266551,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+195703, 1.0, int_stack+205666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+326491,int_stack+43605,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39555,int_stack+47519,int_stack+47369, 0.0, zero_stack, 2.0, int_stack+136676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+47729,int_stack+47519, 0.0, zero_stack, 2.0, int_stack+136826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+40005,int_stack+162232,int_stack+39555, 0.0, zero_stack, 2.0, int_stack+203641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+48234,int_stack+48009, 0.0, zero_stack, 2.0, int_stack+137956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+48549,int_stack+48234, 0.0, zero_stack, 2.0, int_stack+138181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43605,int_stack+254293,int_stack+33480, 0.0, zero_stack, 2.0, int_stack+204991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+44955,int_stack+43605,int_stack+40005,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+49284,int_stack+48969, 0.0, zero_stack, 2.0, int_stack+66713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+49725,int_stack+49284, 0.0, zero_stack, 2.0, int_stack+67343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+39555,int_stack+254293, 0.0, zero_stack, 2.0, int_stack+205666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+330541,int_stack+266551,int_stack+43605,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+43605,int_stack+50463,int_stack+50313, 1.0, int_stack+118500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141220,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+162232,int_stack+50673,int_stack+50463, 1.0, int_stack+118650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141370,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+44055,int_stack+162232,int_stack+43605, 1.0, int_stack+161782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214954,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+51178,int_stack+50953, 1.0, int_stack+119780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142725,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+51493,int_stack+51178, 1.0, int_stack+120005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143265,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+33480, 1.0, int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216304,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+47655,int_stack+39555,int_stack+44055,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+52984,int_stack+52228, 1.0, int_stack+51913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70728,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43605,int_stack+53425,int_stack+52984, 1.0, int_stack+52543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71358,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+43605,int_stack+254293, 1.0, int_stack+170107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216979,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+334591,int_stack+266551,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39555,int_stack+54163,int_stack+54013, 1.0, int_stack+123044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141220, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40005,int_stack+54373,int_stack+54163, 1.0, int_stack+123194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141370, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+40005,int_stack+39555, 1.0, int_stack+171052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214954, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+54878,int_stack+54653, 1.0, int_stack+124324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142725, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+55193,int_stack+54878, 1.0, int_stack+124549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143265, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 1.0, int_stack+172402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216304, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+50355,int_stack+39555,int_stack+266551,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+56684,int_stack+55928, 1.0, int_stack+55613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70728, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+57125,int_stack+56684, 1.0, int_stack+56243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71358, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+266551,int_stack+254293, 1.0, int_stack+173077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216979, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+338641,int_stack+53055,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39555,int_stack+57863,int_stack+57713, 1.0, int_stack+127588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141220, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40005,int_stack+58073,int_stack+57863, 1.0, int_stack+127738, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141370, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+40005,int_stack+39555, 1.0, int_stack+182365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214954, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+58578,int_stack+58353, 1.0, int_stack+128868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142725, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+58893,int_stack+58578, 1.0, int_stack+129093, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143265, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 1.0, int_stack+183715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216304, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+53955,int_stack+39555,int_stack+53055,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+60384,int_stack+59628, 1.0, int_stack+59313, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70728, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56655,int_stack+60825,int_stack+60384, 1.0, int_stack+59943, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71358, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+56655,int_stack+254293, 1.0, int_stack+184390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216979, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+56655,int_stack+266551,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+182365,int_stack+61563,int_stack+61413, 1.0, int_stack+132132, 0.0, zero_stack, 1.0, int_stack+141220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+61773,int_stack+61563, 1.0, int_stack+132282, 0.0, zero_stack, 1.0, int_stack+141370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+182365, 1.0, int_stack+193678, 0.0, zero_stack, 1.0, int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+62278,int_stack+62053, 1.0, int_stack+133412, 0.0, zero_stack, 1.0, int_stack+142725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+62593,int_stack+62278, 1.0, int_stack+133637, 0.0, zero_stack, 1.0, int_stack+143265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 1.0, int_stack+195028, 0.0, zero_stack, 1.0, int_stack+216304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+342691,int_stack+39555,int_stack+53055,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+64084,int_stack+63328, 1.0, int_stack+63013, 0.0, zero_stack, 1.0, int_stack+70728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+64525,int_stack+64084, 1.0, int_stack+63643, 0.0, zero_stack, 1.0, int_stack+71358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+60705,int_stack+266551,int_stack+254293, 1.0, int_stack+195703, 0.0, zero_stack, 1.0, int_stack+216979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+345391,int_stack+60705,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+193678,int_stack+65263,int_stack+65113, 1.0, int_stack+136676, 1.0, int_stack+141220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+65473,int_stack+65263, 1.0, int_stack+136826, 1.0, int_stack+141370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+193678, 1.0, int_stack+203641, 1.0, int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+65978,int_stack+65753, 1.0, int_stack+137956, 1.0, int_stack+142725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+66293,int_stack+65978, 1.0, int_stack+138181, 1.0, int_stack+143265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 1.0, int_stack+204991, 1.0, int_stack+216304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+60705,int_stack+39555,int_stack+53055,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+67784,int_stack+67028, 1.0, int_stack+66713, 1.0, int_stack+70728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+63405,int_stack+68225,int_stack+67784, 1.0, int_stack+67343, 1.0, int_stack+71358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+63405,int_stack+254293, 1.0, int_stack+205666, 1.0, int_stack+216979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+63405,int_stack+266551,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+203641,int_stack+68963,int_stack+68813, 2.0, int_stack+141220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+69173,int_stack+68963, 2.0, int_stack+141370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+203641, 2.0, int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+69678,int_stack+69453, 2.0, int_stack+142725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+69993,int_stack+69678, 2.0, int_stack+143265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 2.0, int_stack+216304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+67455,int_stack+39555,int_stack+53055,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+71799,int_stack+71043, 2.0, int_stack+70728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+72240,int_stack+71799, 2.0, int_stack+71358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+70155,int_stack+266551,int_stack+254293, 2.0, int_stack+216979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+349441,int_stack+70155,int_stack+39555,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+72978,int_stack+72828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147060,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+73188,int_stack+72978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147210,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+73693,int_stack+73468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148340,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+74008,int_stack+73693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148565,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+70155,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+74743,int_stack+74428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89148,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+72855,int_stack+75184,int_stack+74743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89778,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+72855,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+353491,int_stack+266551,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+166057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+75922,int_stack+75772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147060, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+76132,int_stack+75922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147210, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+76637,int_stack+76412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148340, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+76952,int_stack+76637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148565, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+72855,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+77687,int_stack+77372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89148, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+78128,int_stack+77687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89778, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+75555,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+357541,int_stack+75555,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+78866,int_stack+78716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147060, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+79076,int_stack+78866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147210, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+79581,int_stack+79356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148340, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+79896,int_stack+79581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148565, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+75555,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+80631,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89148, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+78255,int_stack+81072,int_stack+80631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89778, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+78255,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+361591,int_stack+266551,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+81810,int_stack+81660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+82020,int_stack+81810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+82525,int_stack+82300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+82840,int_stack+82525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+78255,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+194128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+83575,int_stack+83260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+84016,int_stack+83575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+80955,int_stack+266551,int_stack+254293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+365641,int_stack+80955,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+84754,int_stack+84604, 0.0, zero_stack, 1.0, int_stack+147060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+84964,int_stack+84754, 0.0, zero_stack, 1.0, int_stack+147210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+85469,int_stack+85244, 0.0, zero_stack, 1.0, int_stack+148340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+85784,int_stack+85469, 0.0, zero_stack, 1.0, int_stack+148565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 0.0, zero_stack, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+80955,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+86519,int_stack+86204, 0.0, zero_stack, 1.0, int_stack+89148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+83655,int_stack+86960,int_stack+86519, 0.0, zero_stack, 1.0, int_stack+89778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+83655,int_stack+254293, 0.0, zero_stack, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+369691,int_stack+266551,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+87698,int_stack+87548, 1.0, int_stack+147060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+87908,int_stack+87698, 1.0, int_stack+147210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 1.0, int_stack+161332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+164437,int_stack+88413,int_stack+88188, 1.0, int_stack+148340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+88728,int_stack+88413, 1.0, int_stack+148565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+254293,int_stack+164437, 1.0, int_stack+163762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+83655,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+90219,int_stack+89463, 1.0, int_stack+89148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+163762,int_stack+90660,int_stack+90219, 1.0, int_stack+89778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+163762,int_stack+254293, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+86355,int_stack+266551,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+91398,int_stack+91248,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+91608,int_stack+91398,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+92113,int_stack+91888,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+92428,int_stack+92113,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+373741,int_stack+39555,int_stack+53055, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+224917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+93163,int_stack+92848,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+93604,int_stack+93163,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+90405,int_stack+266551,int_stack+2700,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+376441,int_stack+90405,int_stack+39555, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+234880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+94342,int_stack+94192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151604,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+94552,int_stack+94342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151754,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+95057,int_stack+94832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152884,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+95372,int_stack+95057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153109,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240280,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+90405,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+162862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+96107,int_stack+95792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110512,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93105,int_stack+96548,int_stack+96107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111142,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+93105,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240955,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+380491,int_stack+266551,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+166057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+97286,int_stack+97136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151604, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+97496,int_stack+97286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151754, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238930, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+98001,int_stack+97776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152884, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+98316,int_stack+98001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153109, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240280, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+93105,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+171502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+99051,int_stack+98736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110512, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+99492,int_stack+99051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111142, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95805,int_stack+266551,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240955, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+384541,int_stack+95805,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+178315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+100230,int_stack+100080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151604, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+100440,int_stack+100230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151754, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238930, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+100945,int_stack+100720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152884, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+101260,int_stack+100945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153109, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240280, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+95805,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+182815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+101995,int_stack+101680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110512, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+98505,int_stack+102436,int_stack+101995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111142, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+98505,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240955, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+98505,int_stack+266551,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+189628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+103174,int_stack+103024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+103384,int_stack+103174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+103889,int_stack+103664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+104204,int_stack+103889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+388591,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+194128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+104939,int_stack+104624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+105380,int_stack+104939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+102555,int_stack+266551,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+391291,int_stack+102555,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+106118,int_stack+105968, 0.0, zero_stack, 1.0, int_stack+151604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+106328,int_stack+106118, 0.0, zero_stack, 1.0, int_stack+151754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 0.0, zero_stack, 1.0, int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+106833,int_stack+106608, 0.0, zero_stack, 1.0, int_stack+152884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+107148,int_stack+106833, 0.0, zero_stack, 1.0, int_stack+153109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 1.0, int_stack+240280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+102555,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+204091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+107883,int_stack+107568, 0.0, zero_stack, 1.0, int_stack+110512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+105255,int_stack+108324,int_stack+107883, 0.0, zero_stack, 1.0, int_stack+111142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+105255,int_stack+2700, 0.0, zero_stack, 1.0, int_stack+240955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+395341,int_stack+266551,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+210904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214954,int_stack+109062,int_stack+108912, 1.0, int_stack+151604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+109272,int_stack+109062, 1.0, int_stack+151754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+214954, 1.0, int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+109777,int_stack+109552, 1.0, int_stack+152884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+110092,int_stack+109777, 1.0, int_stack+153109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 1.0, int_stack+240280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+105255,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+215404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+111583,int_stack+110827, 1.0, int_stack+110512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+112024,int_stack+111583, 1.0, int_stack+111142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+107955,int_stack+266551,int_stack+2700, 1.0, int_stack+240955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+399391,int_stack+107955,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+112762,int_stack+112612,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+112972,int_stack+112762,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+113477,int_stack+113252,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+113792,int_stack+113477,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+107955,int_stack+39555,int_stack+53055, 0.0, zero_stack, 1.0, int_stack+224917, 1.0, int_stack+239380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+114527,int_stack+114212,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+110655,int_stack+114968,int_stack+114527,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+110655,int_stack+2700,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+110655,int_stack+266551,int_stack+39555, 0.0, zero_stack, 1.0, int_stack+234880, 1.0, int_stack+246193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+115706,int_stack+115556,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+115916,int_stack+115706,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+116421,int_stack+116196,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+116736,int_stack+116421,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+403441,int_stack+39555,int_stack+53055, 0.0, zero_stack, 2.0, int_stack+239380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+117471,int_stack+117156,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+266551,int_stack+117912,int_stack+117471,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+114705,int_stack+266551,int_stack+2700,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+406141,int_stack+114705,int_stack+39555, 0.0, zero_stack, 2.0, int_stack+246193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+119290,int_stack+119140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156788,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+119500,int_stack+119290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156938,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+39555,int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3645,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+120965,int_stack+120740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158068,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+121280,int_stack+120965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158293,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39555,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227212,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+114705,int_stack+39555,int_stack+53055, 1.0, int_stack+162862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+122015,int_stack+121700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144960,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117405,int_stack+122456,int_stack+122015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145590,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+117405,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+117405,int_stack+266551,int_stack+39555, 1.0, int_stack+166057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+123834,int_stack+123684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156788, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+166057,int_stack+124044,int_stack+123834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156938, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+166057,int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3645, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+125509,int_stack+125284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158068, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+125824,int_stack+125509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158293, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+166057,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227212, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+121455,int_stack+166057,int_stack+53055, 1.0, int_stack+171502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+126559,int_stack+126244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144960, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39555,int_stack+127000,int_stack+126559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145590, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+39555,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+124155,int_stack+266551,int_stack+166057, 1.0, int_stack+178315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+128378,int_stack+128228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156788, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+178315,int_stack+128588,int_stack+128378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156938, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+178315,int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3645, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+130053,int_stack+129828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158068, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+130368,int_stack+130053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158293, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+178315,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227212, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+161332,int_stack+178315,int_stack+53055, 1.0, int_stack+182815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+131103,int_stack+130788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144960, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+166057,int_stack+131544,int_stack+131103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145590, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+166057,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+128205,int_stack+266551,int_stack+178315, 1.0, int_stack+189628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+132922,int_stack+132772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+189628,int_stack+133132,int_stack+132922, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+189628,int_stack+238930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+134597,int_stack+134372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+134912,int_stack+134597, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+189628,int_stack+2700,int_stack+33480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+132255,int_stack+189628,int_stack+53055, 1.0, int_stack+194128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+135647,int_stack+135332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+178315,int_stack+136088,int_stack+135647, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+178315,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+170107,int_stack+266551,int_stack+189628, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+137466,int_stack+137316, 0.0, zero_stack, 1.0, int_stack+156788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+137676,int_stack+137466, 0.0, zero_stack, 1.0, int_stack+156938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+0,int_stack+238930, 0.0, zero_stack, 1.0, int_stack+3645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+139141,int_stack+138916, 0.0, zero_stack, 1.0, int_stack+158068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2700,int_stack+139456,int_stack+139141, 0.0, zero_stack, 1.0, int_stack+158293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+2700,int_stack+33480, 0.0, zero_stack, 1.0, int_stack+227212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+134955,int_stack+0,int_stack+53055, 1.0, int_stack+204091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+140191,int_stack+139876, 0.0, zero_stack, 1.0, int_stack+144960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+189628,int_stack+140632,int_stack+140191, 0.0, zero_stack, 1.0, int_stack+145590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+189628,int_stack+2700, 0.0, zero_stack, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+137655,int_stack+266551,int_stack+0, 1.0, int_stack+210904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+142010,int_stack+141860, 1.0, int_stack+156788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+210904,int_stack+142220,int_stack+142010, 1.0, int_stack+156938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+210904,int_stack+238930, 1.0, int_stack+3645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+144225,int_stack+144000, 1.0, int_stack+158068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+144540,int_stack+144225, 1.0, int_stack+158293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+210904,int_stack+254293,int_stack+33480, 1.0, int_stack+227212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+141705,int_stack+210904,int_stack+53055, 1.0, int_stack+215404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+146031,int_stack+145275, 1.0, int_stack+144960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+146472,int_stack+146031, 1.0, int_stack+145590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+0,int_stack+254293, 1.0, int_stack+165112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+410191,int_stack+266551,int_stack+210904, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+147850,int_stack+147700,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+210904,int_stack+148060,int_stack+147850,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+210904,int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+149525,int_stack+149300,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+149840,int_stack+149525,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+210904,int_stack+254293,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+0,int_stack+210904,int_stack+53055, 1.0, int_stack+224917, 0.0, zero_stack, 1.0, int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+150575,int_stack+150260,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224917,int_stack+151016,int_stack+150575,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+226240,int_stack+224917,int_stack+254293,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+144405,int_stack+226240,int_stack+210904, 1.0, int_stack+234880, 0.0, zero_stack, 1.0, int_stack+255238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+238930,int_stack+152394,int_stack+152244,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234880,int_stack+152604,int_stack+152394,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+234880,int_stack+238930,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+154069,int_stack+153844,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+154384,int_stack+154069,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+234880,int_stack+254293,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+224917,int_stack+234880,int_stack+53055, 1.0, int_stack+239380, 1.0, int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+155119,int_stack+154804,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+238930,int_stack+155560,int_stack+155119,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+240253,int_stack+238930,int_stack+254293,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+148455,int_stack+240253,int_stack+234880, 1.0, int_stack+246193, 1.0, int_stack+255238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+246193,int_stack+157578,int_stack+157428,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+246643,int_stack+157788,int_stack+157578,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+53055,int_stack+246643,int_stack+246193,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33480,int_stack+159253,int_stack+159028,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+254293,int_stack+159568,int_stack+159253,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+246193,int_stack+254293,int_stack+33480,15);
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+238930,int_stack+246193,int_stack+53055, 2.0, int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+254293,int_stack+160303,int_stack+159988,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234880,int_stack+160744,int_stack+160303,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+266551,int_stack+234880,int_stack+254293,21);
 /*--- compute (gp|gd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+152505,int_stack+266551,int_stack+246193, 2.0, int_stack+255238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+414241,int_stack+174265,int_stack+167407,90);
     Libderiv->ABCD[11] = int_stack + 414241;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+174157,int_stack+185578,int_stack+179665,90);
     Libderiv->ABCD[10] = int_stack + 174157;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+182365,int_stack+196891,int_stack+190978,90);
     Libderiv->ABCD[9] = int_stack + 182365;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+193678,int_stack+206854,int_stack+200941,90);
     Libderiv->ABCD[8] = int_stack + 193678;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+203641,int_stack+218167,int_stack+212254,90);
     Libderiv->ABCD[7] = int_stack + 203641;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+214954,int_stack+228130,int_stack+222217,90);
     Libderiv->ABCD[6] = int_stack + 214954;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+419641,int_stack+242143,int_stack+236230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[2] = int_stack + 419641;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+241630,int_stack+250243,int_stack+247543, 0.0, zero_stack, 1.0, int_stack+232180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[1] = int_stack + 241630;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+250243,int_stack+262501,int_stack+256588, 1.0, int_stack+232180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[0] = int_stack + 250243;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+227617,int_stack+268441,int_stack+4995,90);
     Libderiv->ABCD[155] = int_stack + 227617;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+261988,int_stack+272491,int_stack+7695,90);
     Libderiv->ABCD[143] = int_stack + 261988;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+2700,int_stack+276541,int_stack+10395,90);
     Libderiv->ABCD[142] = int_stack + 2700;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+267388,int_stack+280591,int_stack+13095,90);
     Libderiv->ABCD[131] = int_stack + 267388;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+8100,int_stack+284641,int_stack+259288,90);
     Libderiv->ABCD[130] = int_stack + 8100;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+272788,int_stack+288691,int_stack+18090,90);
     Libderiv->ABCD[129] = int_stack + 272788;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+13500,int_stack+295441,int_stack+292741,90);
     Libderiv->ABCD[119] = int_stack + 13500;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+278188,int_stack+299491,int_stack+23085,90);
     Libderiv->ABCD[118] = int_stack + 278188;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+18900,int_stack+306241,int_stack+303541,90);
     Libderiv->ABCD[117] = int_stack + 18900;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+283588,int_stack+310291,int_stack+28080,90);
     Libderiv->ABCD[116] = int_stack + 283588;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+24300,int_stack+314341,int_stack+34155,90);
     Libderiv->ABCD[107] = int_stack + 24300;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+288988,int_stack+318391,int_stack+36855,90);
     Libderiv->ABCD[106] = int_stack + 288988;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+33480,int_stack+322441,int_stack+30780,90);
     Libderiv->ABCD[105] = int_stack + 33480;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+294388,int_stack+326491,int_stack+40905,90);
     Libderiv->ABCD[104] = int_stack + 294388;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+38880,int_stack+330541,int_stack+44955,90);
     Libderiv->ABCD[103] = int_stack + 38880;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+299788,int_stack+334591,int_stack+47655,90);
     Libderiv->ABCD[95] = int_stack + 299788;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+44280,int_stack+338641,int_stack+50355,90);
     Libderiv->ABCD[94] = int_stack + 44280;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+305188,int_stack+56655,int_stack+53955,90);
     Libderiv->ABCD[93] = int_stack + 305188;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+49680,int_stack+345391,int_stack+342691,90);
     Libderiv->ABCD[92] = int_stack + 49680;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+55080,int_stack+63405,int_stack+60705,90);
     Libderiv->ABCD[91] = int_stack + 55080;
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+60480,int_stack+349441,int_stack+67455,90);
     Libderiv->ABCD[90] = int_stack + 60480;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+310588,int_stack+353491,int_stack+70155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[47] = int_stack + 310588;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+65880,int_stack+357541,int_stack+72855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[46] = int_stack + 65880;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+315988,int_stack+361591,int_stack+75555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[45] = int_stack + 315988;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+71280,int_stack+365641,int_stack+78255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[44] = int_stack + 71280;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+321388,int_stack+369691,int_stack+80955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[43] = int_stack + 321388;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+76680,int_stack+86355,int_stack+83655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[42] = int_stack + 76680;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+82080,int_stack+376441,int_stack+373741, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+236230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[38] = int_stack + 82080;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+326788,int_stack+380491,int_stack+90405, 0.0, zero_stack, 1.0, int_stack+167407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[35] = int_stack + 326788;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+87480,int_stack+384541,int_stack+93105, 0.0, zero_stack, 1.0, int_stack+179665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[34] = int_stack + 87480;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+332188,int_stack+98505,int_stack+95805, 0.0, zero_stack, 1.0, int_stack+190978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[33] = int_stack + 332188;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+92880,int_stack+391291,int_stack+388591, 0.0, zero_stack, 1.0, int_stack+200941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[32] = int_stack + 92880;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+337588,int_stack+395341,int_stack+102555, 0.0, zero_stack, 1.0, int_stack+212254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[31] = int_stack + 337588;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+98280,int_stack+399391,int_stack+105255, 0.0, zero_stack, 1.0, int_stack+222217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[30] = int_stack + 98280;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+342988,int_stack+110655,int_stack+107955, 0.0, zero_stack, 1.0, int_stack+236230, 1.0, int_stack+247543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[26] = int_stack + 342988;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+103680,int_stack+406141,int_stack+403441, 0.0, zero_stack, 2.0, int_stack+247543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[25] = int_stack + 103680;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+109080,int_stack+117405,int_stack+114705, 1.0, int_stack+167407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[23] = int_stack + 109080;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+114480,int_stack+124155,int_stack+121455, 1.0, int_stack+179665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[22] = int_stack + 114480;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+119880,int_stack+128205,int_stack+161332, 1.0, int_stack+190978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[21] = int_stack + 119880;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+125280,int_stack+170107,int_stack+132255, 1.0, int_stack+200941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[20] = int_stack + 125280;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+156555,int_stack+137655,int_stack+134955, 1.0, int_stack+212254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[19] = int_stack + 156555;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+130680,int_stack+410191,int_stack+141705, 1.0, int_stack+222217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[18] = int_stack + 130680;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+136080,int_stack+144405,int_stack+0, 1.0, int_stack+236230, 0.0, zero_stack, 1.0, int_stack+256588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[14] = int_stack + 136080;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+141480,int_stack+148455,int_stack+224917, 1.0, int_stack+247543, 1.0, int_stack+256588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[13] = int_stack + 141480;
 /*--- compute (fd|gd) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+146880,int_stack+152505,int_stack+238930, 2.0, int_stack+256588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[12] = int_stack + 146880;

}
