/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gghf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|hf) integrals */

void d12hrr_order_gghf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[8][8][11] = int_stack + 0;
 Libderiv->deriv_classes[8][8][10] = int_stack + 2025;
 Libderiv->deriv_classes[8][8][9] = int_stack + 4050;
 Libderiv->deriv_classes[8][8][8] = int_stack + 6075;
 Libderiv->deriv_classes[8][8][7] = int_stack + 8100;
 Libderiv->dvrr_classes[8][7] = int_stack + 10125;
 Libderiv->deriv_classes[8][8][6] = int_stack + 11745;
 Libderiv->deriv_classes[8][8][2] = int_stack + 13770;
 Libderiv->deriv_classes[8][8][1] = int_stack + 15795;
 Libderiv->dvrr_classes[7][8] = int_stack + 17820;
 Libderiv->deriv_classes[8][8][0] = int_stack + 19440;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 21465;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 21780;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 22200;
 Libderiv->deriv2_classes[4][8][143] = int_stack + 22740;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 23415;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 23856;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 24444;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 25200;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 26145;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 26733;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 27517;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 28525;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 29785;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 30541;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 31549;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 32845;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 34465;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 35410;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 36670;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 38290;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 40315;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 40630;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 41050;
 Libderiv->deriv2_classes[4][8][131] = int_stack + 41590;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 42265;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 42706;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 43294;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 44050;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 44995;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 45583;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 46367;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 47375;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 48635;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 49391;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 50399;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 51695;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 53315;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 54260;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 55520;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 57140;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 59165;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 59480;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 59900;
 Libderiv->deriv2_classes[4][8][130] = int_stack + 60440;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 61115;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 61556;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 62144;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 62900;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 63845;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 64433;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 65217;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 66225;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 67485;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 68241;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 69249;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 70545;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 72165;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 73110;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 74370;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 75990;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 78015;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 78330;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 78750;
 Libderiv->deriv2_classes[4][8][119] = int_stack + 79290;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 79965;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 80406;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 80994;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 81750;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 82695;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 83283;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 84067;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 85075;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 86335;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 87091;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 88099;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 89395;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 91015;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 91960;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 93220;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 94840;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 96865;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 97180;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 97600;
 Libderiv->deriv2_classes[4][8][118] = int_stack + 98140;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 98815;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 99256;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 99844;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 100600;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 101545;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 102133;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 102917;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 103925;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 105185;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 105941;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 106949;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 108245;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 109865;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 110810;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 112070;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 113690;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 115715;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 116030;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 116450;
 Libderiv->deriv2_classes[4][8][117] = int_stack + 116990;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 117665;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 118106;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 118694;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 119450;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 120395;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 120983;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 121767;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 122775;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 124035;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 124791;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 125799;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 127095;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 128715;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 129660;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 130920;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 132540;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 134565;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 134880;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 135300;
 Libderiv->deriv2_classes[4][8][107] = int_stack + 135840;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 136515;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 136956;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 137544;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 138300;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 139245;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 139833;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 140617;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 141625;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 142885;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 143641;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 144649;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 145945;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 147565;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 148510;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 149770;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 151390;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 153415;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 153730;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 154150;
 Libderiv->deriv2_classes[4][8][106] = int_stack + 154690;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 155365;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 155806;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 156394;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 157150;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 158095;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 158683;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 159467;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 160475;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 161735;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 162491;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 163499;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 164795;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 166415;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 167360;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 168620;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 170240;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 172265;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 172580;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 173000;
 Libderiv->deriv2_classes[4][8][105] = int_stack + 173540;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 174215;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 174656;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 175244;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 176000;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 176945;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 177533;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 178317;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 179325;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 180585;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 181341;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 182349;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 183645;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 185265;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 186210;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 187470;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 189090;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 191115;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 191430;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 191850;
 Libderiv->deriv2_classes[4][8][104] = int_stack + 192390;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 193065;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 193506;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 194094;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 194850;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 195795;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 196383;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 197167;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 198175;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 199435;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 200191;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 201199;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 202495;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 204115;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 205060;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 206320;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 207940;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 209965;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 210280;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 210700;
 Libderiv->deriv2_classes[4][8][95] = int_stack + 211240;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 211915;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 212356;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 212944;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 213700;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 214645;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 215233;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 216017;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 217025;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 218285;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 219041;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 220049;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 221345;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 222965;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 223910;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 225170;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 226790;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 228815;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 229130;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 229550;
 Libderiv->deriv2_classes[4][8][94] = int_stack + 230090;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 230765;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 231206;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 231794;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 232550;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 233495;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 234083;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 234867;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 235875;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 237135;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 237891;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 238899;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 240195;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 241815;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 242760;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 244020;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 245640;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 247665;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 247980;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 248400;
 Libderiv->deriv2_classes[4][8][93] = int_stack + 248940;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 249615;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 250056;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 250644;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 251400;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 252345;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 252933;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 253717;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 254725;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 255985;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 256741;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 257749;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 259045;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 260665;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 261610;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 262870;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 264490;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 266515;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 266830;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 267250;
 Libderiv->deriv2_classes[4][8][92] = int_stack + 267790;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 268465;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 268906;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 269494;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 270250;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 271195;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 271783;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 272567;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 273575;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 274835;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 275591;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 276599;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 277895;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 279515;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 280460;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 281720;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 283340;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 285365;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 285680;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 286100;
 Libderiv->deriv2_classes[4][8][91] = int_stack + 286640;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 287315;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 287756;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 288344;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 289100;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 290045;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 290633;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 291417;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 292425;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 293685;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 294441;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 295449;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 296745;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 298365;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 299310;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 300570;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 302190;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 304215;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 304530;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 304950;
 Libderiv->deriv2_classes[4][8][83] = int_stack + 305490;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 306165;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 306606;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 307194;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 307950;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 308895;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 309483;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 310267;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 311275;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 312535;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 313291;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 314299;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 315595;
 Libderiv->deriv_classes[8][5][11] = int_stack + 317215;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 318160;
 Libderiv->deriv_classes[8][6][11] = int_stack + 319105;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 320365;
 Libderiv->deriv_classes[8][7][11] = int_stack + 321625;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 323245;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 324865;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 326890;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 327205;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 327625;
 Libderiv->deriv2_classes[4][8][82] = int_stack + 328165;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 328840;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 329281;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 329869;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 330625;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 331570;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 332158;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 332942;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 333950;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 335210;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 335966;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 336974;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 338270;
 Libderiv->deriv_classes[8][5][10] = int_stack + 339890;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 340835;
 Libderiv->deriv_classes[8][6][10] = int_stack + 341780;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 343040;
 Libderiv->deriv_classes[8][7][10] = int_stack + 344300;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 345920;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 347540;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 349565;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 349880;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 350300;
 Libderiv->deriv2_classes[4][8][81] = int_stack + 350840;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 351515;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 351956;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 352544;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 353300;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 354245;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 354833;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 355617;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 356625;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 357885;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 358641;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 359649;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 360945;
 Libderiv->deriv_classes[8][5][9] = int_stack + 362565;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 363510;
 Libderiv->deriv_classes[8][6][9] = int_stack + 364455;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 365715;
 Libderiv->deriv_classes[8][7][9] = int_stack + 366975;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 368595;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 370215;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 372240;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 372555;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 372975;
 Libderiv->deriv2_classes[4][8][80] = int_stack + 373515;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 374190;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 374631;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 375219;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 375975;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 376920;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 377508;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 378292;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 379300;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 380560;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 381316;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 382324;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 383620;
 Libderiv->deriv_classes[8][5][8] = int_stack + 385240;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 386185;
 Libderiv->deriv_classes[8][6][8] = int_stack + 387130;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 388390;
 Libderiv->deriv_classes[8][7][8] = int_stack + 389650;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 391270;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 392890;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 394915;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 395230;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 395650;
 Libderiv->deriv2_classes[4][8][79] = int_stack + 396190;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 396865;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 397306;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 397894;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 398650;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 399595;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 400183;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 400967;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 401975;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 403235;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 403991;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 404999;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 406295;
 Libderiv->deriv_classes[8][5][7] = int_stack + 407915;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 408860;
 Libderiv->deriv_classes[8][6][7] = int_stack + 409805;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 411065;
 Libderiv->deriv_classes[8][7][7] = int_stack + 412325;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 413945;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 415565;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 417590;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 417905;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 418325;
 Libderiv->deriv2_classes[4][8][78] = int_stack + 418865;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 419540;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 419981;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 420569;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 421325;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 422270;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 422858;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 423642;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 424650;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 425910;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 426666;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 427674;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 428970;
 Libderiv->dvrr_classes[8][5] = int_stack + 430590;
 Libderiv->deriv_classes[8][5][6] = int_stack + 431535;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 432480;
 Libderiv->dvrr_classes[8][6] = int_stack + 433425;
 Libderiv->deriv_classes[8][6][6] = int_stack + 434685;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 435945;
 Libderiv->deriv_classes[8][7][6] = int_stack + 437205;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 438825;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 440445;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 442470;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 442785;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 443205;
 Libderiv->deriv2_classes[4][8][35] = int_stack + 443745;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 444420;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 444861;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 445449;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 446205;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 447150;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 447738;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 448522;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 449530;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 450790;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 451546;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 452554;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 453850;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 455470;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 456415;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 457675;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 459295;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 461320;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 461635;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 462055;
 Libderiv->deriv2_classes[4][8][34] = int_stack + 462595;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 463270;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 463711;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 464299;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 465055;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 466000;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 466588;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 467372;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 468380;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 469640;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 470396;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 471404;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 472700;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 474320;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 475265;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 476525;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 478145;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 480170;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 480485;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 480905;
 Libderiv->deriv2_classes[4][8][33] = int_stack + 481445;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 482120;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 482561;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 483149;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 483905;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 484850;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 485438;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 486222;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 487230;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 488490;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 489246;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 490254;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 491550;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 493170;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 494115;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 495375;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 496995;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 499020;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 499335;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 499755;
 Libderiv->deriv2_classes[4][8][32] = int_stack + 500295;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 500970;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 501411;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 501999;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 502755;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 503700;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 504288;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 505072;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 506080;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 507340;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 508096;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 509104;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 510400;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 512020;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 512965;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 514225;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 515845;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 517870;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 518185;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 518605;
 Libderiv->deriv2_classes[4][8][31] = int_stack + 519145;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 519820;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 520261;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 520849;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 521605;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 522550;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 523138;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 523922;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 524930;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 526190;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 526946;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 527954;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 529250;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 530870;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 531815;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 533075;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 534695;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 536720;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 537035;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 537455;
 Libderiv->deriv2_classes[4][8][30] = int_stack + 537995;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 538670;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 539111;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 539699;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 540455;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 541400;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 541988;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 542772;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 543780;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 545040;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 545796;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 546804;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 548100;
 Libderiv->deriv_classes[8][5][2] = int_stack + 549720;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 550665;
 Libderiv->deriv_classes[8][6][2] = int_stack + 551610;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 552870;
 Libderiv->deriv_classes[8][7][2] = int_stack + 554130;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 555750;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 557370;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 559395;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 559710;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 560130;
 Libderiv->deriv2_classes[4][8][26] = int_stack + 560670;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 561345;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 561786;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 562374;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 563130;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 564075;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 564663;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 565447;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 566455;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 567715;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 568471;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 569479;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 570775;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 572395;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 573340;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 574600;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 576220;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 578245;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 578560;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 578980;
 Libderiv->deriv2_classes[4][8][23] = int_stack + 579520;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 580195;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 580636;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 581224;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 581980;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 582925;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 583513;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 584297;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 585305;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 586565;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 587321;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 588329;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 589625;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 591245;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 592190;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 593450;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 595070;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 597095;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 597410;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 597830;
 Libderiv->deriv2_classes[4][8][22] = int_stack + 598370;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 599045;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 599486;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 600074;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 600830;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 601775;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 602363;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 603147;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 604155;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 605415;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 606171;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 607179;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 608475;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 610095;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 611040;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 612300;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 613920;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 615945;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 616260;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 616680;
 Libderiv->deriv2_classes[4][8][21] = int_stack + 617220;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 617895;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 618336;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 618924;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 619680;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 620625;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 621213;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 621997;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 623005;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 624265;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 625021;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 626029;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 627325;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 628945;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 629890;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 631150;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 632770;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 634795;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 635110;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 635530;
 Libderiv->deriv2_classes[4][8][20] = int_stack + 636070;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 636745;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 637186;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 637774;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 638530;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 639475;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 640063;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 640847;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 641855;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 643115;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 643871;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 644879;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 646175;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 647795;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 648740;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 650000;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 651620;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 653645;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 653960;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 654380;
 Libderiv->deriv2_classes[4][8][19] = int_stack + 654920;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 655595;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 656036;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 656624;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 657380;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 658325;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 658913;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 659697;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 660705;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 661965;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 662721;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 663729;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 665025;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 666645;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 667590;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 668850;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 670470;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 672495;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 672810;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 673230;
 Libderiv->deriv2_classes[4][8][18] = int_stack + 673770;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 674445;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 674886;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 675474;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 676230;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 677175;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 677763;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 678547;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 679555;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 680815;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 681571;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 682579;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 683875;
 Libderiv->deriv_classes[8][5][1] = int_stack + 685495;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 686440;
 Libderiv->deriv_classes[8][6][1] = int_stack + 687385;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 688645;
 Libderiv->deriv_classes[8][7][1] = int_stack + 689905;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 691525;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 693145;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 695170;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 695485;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 695905;
 Libderiv->deriv2_classes[4][8][14] = int_stack + 696445;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 697120;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 697561;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 698149;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 698905;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 699850;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 700438;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 701222;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 702230;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 703490;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 704246;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 705254;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 706550;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 708170;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 709115;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 710375;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 711995;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 714020;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 714335;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 714755;
 Libderiv->deriv2_classes[4][8][13] = int_stack + 715295;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 715970;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 716411;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 716999;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 717755;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 718700;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 719288;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 720072;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 721080;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 722340;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 723096;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 724104;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 725400;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 727020;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 727965;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 729225;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 730845;
 Libderiv->deriv_classes[4][5][11] = int_stack + 732870;
 Libderiv->deriv_classes[4][6][11] = int_stack + 733185;
 Libderiv->deriv_classes[4][7][11] = int_stack + 733605;
 Libderiv->deriv_classes[4][8][11] = int_stack + 734145;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 734820;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 735135;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 735555;
 Libderiv->deriv2_classes[4][8][11] = int_stack + 736095;
 Libderiv->deriv_classes[5][5][11] = int_stack + 736770;
 Libderiv->deriv_classes[5][6][11] = int_stack + 737211;
 Libderiv->deriv_classes[5][7][11] = int_stack + 737799;
 Libderiv->deriv_classes[5][8][11] = int_stack + 738555;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 739500;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 739941;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 740529;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 741285;
 Libderiv->deriv_classes[6][5][11] = int_stack + 742230;
 Libderiv->deriv_classes[6][6][11] = int_stack + 742818;
 Libderiv->deriv_classes[6][7][11] = int_stack + 743602;
 Libderiv->deriv_classes[6][8][11] = int_stack + 744610;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 745870;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 746458;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 747242;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 748250;
 Libderiv->deriv_classes[7][5][11] = int_stack + 749510;
 Libderiv->deriv_classes[7][6][11] = int_stack + 750266;
 Libderiv->deriv_classes[7][7][11] = int_stack + 751274;
 Libderiv->deriv_classes[7][8][11] = int_stack + 752570;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 754190;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 754946;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 755954;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 757250;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 758870;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 759815;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 761075;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 762695;
 Libderiv->deriv_classes[4][5][10] = int_stack + 764720;
 Libderiv->deriv_classes[4][6][10] = int_stack + 765035;
 Libderiv->deriv_classes[4][7][10] = int_stack + 765455;
 Libderiv->deriv_classes[4][8][10] = int_stack + 765995;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 766670;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 766985;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 767405;
 Libderiv->deriv2_classes[4][8][10] = int_stack + 767945;
 Libderiv->deriv_classes[5][5][10] = int_stack + 768620;
 Libderiv->deriv_classes[5][6][10] = int_stack + 769061;
 Libderiv->deriv_classes[5][7][10] = int_stack + 769649;
 Libderiv->deriv_classes[5][8][10] = int_stack + 770405;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 771350;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 771791;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 772379;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 773135;
 Libderiv->deriv_classes[6][5][10] = int_stack + 774080;
 Libderiv->deriv_classes[6][6][10] = int_stack + 774668;
 Libderiv->deriv_classes[6][7][10] = int_stack + 775452;
 Libderiv->deriv_classes[6][8][10] = int_stack + 776460;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 777720;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 778308;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 779092;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 780100;
 Libderiv->deriv_classes[7][5][10] = int_stack + 781360;
 Libderiv->deriv_classes[7][6][10] = int_stack + 782116;
 Libderiv->deriv_classes[7][7][10] = int_stack + 783124;
 Libderiv->deriv_classes[7][8][10] = int_stack + 784420;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 786040;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 786796;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 787804;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 789100;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 790720;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 791665;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 792925;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 794545;
 Libderiv->deriv_classes[4][5][9] = int_stack + 796570;
 Libderiv->deriv_classes[4][6][9] = int_stack + 796885;
 Libderiv->deriv_classes[4][7][9] = int_stack + 797305;
 Libderiv->deriv_classes[4][8][9] = int_stack + 797845;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 798520;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 798835;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 799255;
 Libderiv->deriv2_classes[4][8][9] = int_stack + 799795;
 Libderiv->deriv_classes[5][5][9] = int_stack + 800470;
 Libderiv->deriv_classes[5][6][9] = int_stack + 800911;
 Libderiv->deriv_classes[5][7][9] = int_stack + 801499;
 Libderiv->deriv_classes[5][8][9] = int_stack + 802255;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 803200;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 803641;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 804229;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 804985;
 Libderiv->deriv_classes[6][5][9] = int_stack + 805930;
 Libderiv->deriv_classes[6][6][9] = int_stack + 806518;
 Libderiv->deriv_classes[6][7][9] = int_stack + 807302;
 Libderiv->deriv_classes[6][8][9] = int_stack + 808310;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 809570;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 810158;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 810942;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 811950;
 Libderiv->deriv_classes[7][5][9] = int_stack + 813210;
 Libderiv->deriv_classes[7][6][9] = int_stack + 813966;
 Libderiv->deriv_classes[7][7][9] = int_stack + 814974;
 Libderiv->deriv_classes[7][8][9] = int_stack + 816270;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 817890;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 818646;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 819654;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 820950;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 822570;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 823515;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 824775;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 826395;
 Libderiv->deriv_classes[4][5][8] = int_stack + 828420;
 Libderiv->deriv_classes[4][6][8] = int_stack + 828735;
 Libderiv->deriv_classes[4][7][8] = int_stack + 829155;
 Libderiv->deriv_classes[4][8][8] = int_stack + 829695;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 830370;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 830685;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 831105;
 Libderiv->deriv2_classes[4][8][8] = int_stack + 831645;
 Libderiv->deriv_classes[5][5][8] = int_stack + 832320;
 Libderiv->deriv_classes[5][6][8] = int_stack + 832761;
 Libderiv->deriv_classes[5][7][8] = int_stack + 833349;
 Libderiv->deriv_classes[5][8][8] = int_stack + 834105;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 835050;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 835491;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 836079;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 836835;
 Libderiv->deriv_classes[6][5][8] = int_stack + 837780;
 Libderiv->deriv_classes[6][6][8] = int_stack + 838368;
 Libderiv->deriv_classes[6][7][8] = int_stack + 839152;
 Libderiv->deriv_classes[6][8][8] = int_stack + 840160;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 841420;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 842008;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 842792;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 843800;
 Libderiv->deriv_classes[7][5][8] = int_stack + 845060;
 Libderiv->deriv_classes[7][6][8] = int_stack + 845816;
 Libderiv->deriv_classes[7][7][8] = int_stack + 846824;
 Libderiv->deriv_classes[7][8][8] = int_stack + 848120;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 849740;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 850496;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 851504;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 852800;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 854420;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 855365;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 856625;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 858245;
 Libderiv->deriv_classes[4][5][7] = int_stack + 860270;
 Libderiv->deriv_classes[4][6][7] = int_stack + 860585;
 Libderiv->deriv_classes[4][7][7] = int_stack + 861005;
 Libderiv->deriv_classes[4][8][7] = int_stack + 861545;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 862220;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 862535;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 862955;
 Libderiv->deriv2_classes[4][8][7] = int_stack + 863495;
 Libderiv->deriv_classes[5][5][7] = int_stack + 864170;
 Libderiv->deriv_classes[5][6][7] = int_stack + 864611;
 Libderiv->deriv_classes[5][7][7] = int_stack + 865199;
 Libderiv->deriv_classes[5][8][7] = int_stack + 865955;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 866900;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 867341;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 867929;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 868685;
 Libderiv->deriv_classes[6][5][7] = int_stack + 869630;
 Libderiv->deriv_classes[6][6][7] = int_stack + 870218;
 Libderiv->deriv_classes[6][7][7] = int_stack + 871002;
 Libderiv->deriv_classes[6][8][7] = int_stack + 872010;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 873270;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 873858;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 874642;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 875650;
 Libderiv->deriv_classes[7][5][7] = int_stack + 876910;
 Libderiv->deriv_classes[7][6][7] = int_stack + 877666;
 Libderiv->deriv_classes[7][7][7] = int_stack + 878674;
 Libderiv->deriv_classes[7][8][7] = int_stack + 879970;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 881590;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 882346;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 883354;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 884650;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 886270;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 887215;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 888475;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 890095;
 Libderiv->deriv_classes[4][5][6] = int_stack + 892120;
 Libderiv->deriv_classes[4][6][6] = int_stack + 892435;
 Libderiv->deriv_classes[4][7][6] = int_stack + 892855;
 Libderiv->deriv_classes[4][8][6] = int_stack + 893395;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 894070;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 894385;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 894805;
 Libderiv->deriv2_classes[4][8][6] = int_stack + 895345;
 Libderiv->deriv_classes[5][5][6] = int_stack + 896020;
 Libderiv->deriv_classes[5][6][6] = int_stack + 896461;
 Libderiv->deriv_classes[5][7][6] = int_stack + 897049;
 Libderiv->deriv_classes[5][8][6] = int_stack + 897805;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 898750;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 899191;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 899779;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 900535;
 Libderiv->deriv_classes[6][5][6] = int_stack + 901480;
 Libderiv->deriv_classes[6][6][6] = int_stack + 902068;
 Libderiv->deriv_classes[6][7][6] = int_stack + 902852;
 Libderiv->deriv_classes[6][8][6] = int_stack + 903860;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 905120;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 905708;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 906492;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 907500;
 Libderiv->dvrr_classes[7][5] = int_stack + 908760;
 Libderiv->deriv_classes[7][5][6] = int_stack + 909516;
 Libderiv->dvrr_classes[7][6] = int_stack + 910272;
 Libderiv->deriv_classes[7][6][6] = int_stack + 911280;
 Libderiv->dvrr_classes[7][7] = int_stack + 912288;
 Libderiv->deriv_classes[7][7][6] = int_stack + 913584;
 Libderiv->deriv_classes[7][8][6] = int_stack + 914880;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 916500;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 917256;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 918264;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 919560;
 Libderiv->deriv_classes[8][5][0] = int_stack + 921180;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 922125;
 Libderiv->deriv_classes[8][6][0] = int_stack + 923070;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 924330;
 Libderiv->deriv_classes[8][7][0] = int_stack + 925590;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 927210;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 928830;
 Libderiv->deriv_classes[4][5][2] = int_stack + 930855;
 Libderiv->deriv_classes[4][6][2] = int_stack + 931170;
 Libderiv->deriv_classes[4][7][2] = int_stack + 931590;
 Libderiv->deriv_classes[4][8][2] = int_stack + 932130;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 932805;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 933120;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 933540;
 Libderiv->deriv2_classes[4][8][2] = int_stack + 934080;
 Libderiv->deriv_classes[5][5][2] = int_stack + 934755;
 Libderiv->deriv_classes[5][6][2] = int_stack + 935196;
 Libderiv->deriv_classes[5][7][2] = int_stack + 935784;
 Libderiv->deriv_classes[5][8][2] = int_stack + 936540;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 937485;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 937926;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 938514;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 939270;
 Libderiv->deriv_classes[6][5][2] = int_stack + 940215;
 Libderiv->deriv_classes[6][6][2] = int_stack + 940803;
 Libderiv->deriv_classes[6][7][2] = int_stack + 941587;
 Libderiv->deriv_classes[6][8][2] = int_stack + 942595;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 943855;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 944443;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 945227;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 946235;
 Libderiv->deriv_classes[7][5][2] = int_stack + 947495;
 Libderiv->deriv_classes[7][6][2] = int_stack + 948251;
 Libderiv->deriv_classes[7][7][2] = int_stack + 949259;
 Libderiv->deriv_classes[7][8][2] = int_stack + 950555;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 952175;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 952931;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 953939;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 955235;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 956855;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 957800;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 959060;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 960680;
 Libderiv->deriv_classes[4][5][1] = int_stack + 962705;
 Libderiv->deriv_classes[4][6][1] = int_stack + 963020;
 Libderiv->deriv_classes[4][7][1] = int_stack + 963440;
 Libderiv->deriv_classes[4][8][1] = int_stack + 963980;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 964655;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 964970;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 965390;
 Libderiv->deriv2_classes[4][8][1] = int_stack + 965930;
 Libderiv->deriv_classes[5][5][1] = int_stack + 966605;
 Libderiv->deriv_classes[5][6][1] = int_stack + 967046;
 Libderiv->deriv_classes[5][7][1] = int_stack + 967634;
 Libderiv->deriv_classes[5][8][1] = int_stack + 968390;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 969335;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 969776;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 970364;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 971120;
 Libderiv->deriv_classes[6][5][1] = int_stack + 972065;
 Libderiv->deriv_classes[6][6][1] = int_stack + 972653;
 Libderiv->deriv_classes[6][7][1] = int_stack + 973437;
 Libderiv->deriv_classes[6][8][1] = int_stack + 974445;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 975705;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 976293;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 977077;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 978085;
 Libderiv->deriv_classes[7][5][1] = int_stack + 979345;
 Libderiv->deriv_classes[7][6][1] = int_stack + 980101;
 Libderiv->deriv_classes[7][7][1] = int_stack + 981109;
 Libderiv->deriv_classes[7][8][1] = int_stack + 982405;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 984025;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 984781;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 985789;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 987085;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 988705;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 989650;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 990910;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 992530;
 Libderiv->dvrr_classes[4][5] = int_stack + 994555;
 Libderiv->dvrr_classes[4][6] = int_stack + 994870;
 Libderiv->dvrr_classes[4][7] = int_stack + 995290;
 Libderiv->dvrr_classes[4][8] = int_stack + 995830;
 Libderiv->deriv_classes[4][5][0] = int_stack + 996505;
 Libderiv->deriv_classes[4][6][0] = int_stack + 996820;
 Libderiv->deriv_classes[4][7][0] = int_stack + 997240;
 Libderiv->deriv_classes[4][8][0] = int_stack + 997780;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 998455;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 998770;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 999190;
 Libderiv->deriv2_classes[4][8][0] = int_stack + 999730;
 Libderiv->dvrr_classes[5][5] = int_stack + 1000405;
 Libderiv->dvrr_classes[5][6] = int_stack + 1000846;
 Libderiv->dvrr_classes[5][7] = int_stack + 1001434;
 Libderiv->dvrr_classes[5][8] = int_stack + 1002190;
 Libderiv->deriv_classes[5][5][0] = int_stack + 1003135;
 Libderiv->deriv_classes[5][6][0] = int_stack + 1003576;
 Libderiv->deriv_classes[5][7][0] = int_stack + 1004164;
 Libderiv->deriv_classes[5][8][0] = int_stack + 1004920;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 1005865;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 1006306;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 1006894;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 1007650;
 Libderiv->dvrr_classes[6][5] = int_stack + 1008595;
 Libderiv->dvrr_classes[6][6] = int_stack + 1009183;
 Libderiv->dvrr_classes[6][7] = int_stack + 1009967;
 Libderiv->dvrr_classes[6][8] = int_stack + 1010975;
 Libderiv->deriv_classes[6][5][0] = int_stack + 1012235;
 Libderiv->deriv_classes[6][6][0] = int_stack + 1012823;
 Libderiv->deriv_classes[6][7][0] = int_stack + 1013607;
 Libderiv->deriv_classes[6][8][0] = int_stack + 1014615;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 1015875;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 1016463;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 1017247;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 1018255;
 Libderiv->deriv_classes[7][5][0] = int_stack + 1019515;
 Libderiv->deriv_classes[7][6][0] = int_stack + 1020271;
 Libderiv->deriv_classes[7][7][0] = int_stack + 1021279;
 Libderiv->deriv_classes[7][8][0] = int_stack + 1022575;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 1024195;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 1024951;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 1025959;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 1027255;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 1028875;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 1029820;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 1031080;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 1032700;
 memset(int_stack,0,8277800);

 Libderiv->dvrr_stack = int_stack + 5282830;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gghf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1034725,int_stack+994870,int_stack+994555,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1035670,int_stack+995290,int_stack+994870,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1036930,int_stack+1035670,int_stack+1034725,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1038820,int_stack+733185,int_stack+732870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994555,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1039765,int_stack+733605,int_stack+733185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994870,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1041025,int_stack+1039765,int_stack+1038820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1042915,int_stack+734145,int_stack+733605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995290,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1044535,int_stack+1042915,int_stack+1039765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035670,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1047055,int_stack+1044535,int_stack+1041025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036930,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1042915,int_stack+1000846,int_stack+1000405,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1044238,int_stack+1001434,int_stack+1000846,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1050205,int_stack+1044238,int_stack+1042915,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1052851,int_stack+737211,int_stack+736770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000405,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1054174,int_stack+737799,int_stack+737211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1055938,int_stack+1054174,int_stack+1052851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1058584,int_stack+738555,int_stack+737799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001434,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1060852,int_stack+1058584,int_stack+1054174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1044238,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1064380,int_stack+1060852,int_stack+1055938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1068790,int_stack+1064380,int_stack+1047055,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1058584,int_stack+1009183,int_stack+1008595,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1060348,int_stack+1009967,int_stack+1009183,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1078240,int_stack+1060348,int_stack+1058584,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1081768,int_stack+742818,int_stack+742230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008595,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1083532,int_stack+743602,int_stack+742818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009183,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1085884,int_stack+1083532,int_stack+1081768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1089412,int_stack+744610,int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009967,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1092436,int_stack+1089412,int_stack+1083532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060348,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1097140,int_stack+1092436,int_stack+1085884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1103020,int_stack+1097140,int_stack+1064380,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1116250,int_stack+1103020,int_stack+1068790,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1089412,int_stack+910272,int_stack+908760,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1091680,int_stack+912288,int_stack+910272,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1135150,int_stack+1091680,int_stack+1089412,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1094704,int_stack+750266,int_stack+749510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+908760,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1139686,int_stack+751274,int_stack+750266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+910272,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1142710,int_stack+1139686,int_stack+1094704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1147246,int_stack+752570,int_stack+751274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912288,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1151134,int_stack+1147246,int_stack+1139686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091680,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1157182,int_stack+1151134,int_stack+1142710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1164742,int_stack+1157182,int_stack+1097140,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1182382,int_stack+1164742,int_stack+1103020,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1208842,int_stack+1182382,int_stack+1116250,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1147246,int_stack+433425,int_stack+430590,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1150081,int_stack+10125,int_stack+433425,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1240342,int_stack+1150081,int_stack+1147246,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1153861,int_stack+319105,int_stack+317215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1246012,int_stack+321625,int_stack+319105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1249792,int_stack+1246012,int_stack+1153861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147246,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1255462,int_stack+0,int_stack+321625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1260322,int_stack+1255462,int_stack+1246012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150081,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1267882,int_stack+1260322,int_stack+1249792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1277332,int_stack+1267882,int_stack+1157182,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1300012,int_stack+1277332,int_stack+1164742,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1255462,int_stack+1300012,int_stack+1182382,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+738555,int_stack+765035,int_stack+764720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994555, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+744610,int_stack+765455,int_stack+765035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994870, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1299562,int_stack+744610,int_stack+738555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+752570,int_stack+765995,int_stack+765455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995290, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1301452,int_stack+752570,int_stack+744610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035670, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1303972,int_stack+1301452,int_stack+1299562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036930, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1301452,int_stack+769061,int_stack+768620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000405, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1307122,int_stack+769649,int_stack+769061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1308886,int_stack+1307122,int_stack+1301452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1311532,int_stack+770405,int_stack+769649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001434, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1313800,int_stack+1311532,int_stack+1307122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1044238, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1317328,int_stack+1313800,int_stack+1308886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1321738,int_stack+1317328,int_stack+1303972,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1311532,int_stack+774668,int_stack+774080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008595, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1313296,int_stack+775452,int_stack+774668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009183, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1331188,int_stack+1313296,int_stack+1311532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1334716,int_stack+776460,int_stack+775452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009967, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1337740,int_stack+1334716,int_stack+1313296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060348, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1342444,int_stack+1337740,int_stack+1331188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1348324,int_stack+1342444,int_stack+1317328,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1361554,int_stack+1348324,int_stack+1321738,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1334716,int_stack+782116,int_stack+781360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+908760, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1336984,int_stack+783124,int_stack+782116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+910272, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1380454,int_stack+1336984,int_stack+1334716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1384990,int_stack+784420,int_stack+783124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912288, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1388878,int_stack+1384990,int_stack+1336984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091680, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1394926,int_stack+1388878,int_stack+1380454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1402486,int_stack+1394926,int_stack+1342444,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1420126,int_stack+1402486,int_stack+1348324,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1446586,int_stack+1420126,int_stack+1361554,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1384990,int_stack+341780,int_stack+339890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1387825,int_stack+344300,int_stack+341780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1478086,int_stack+1387825,int_stack+1384990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147246, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1483756,int_stack+2025,int_stack+344300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1488616,int_stack+1483756,int_stack+1387825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150081, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1496176,int_stack+1488616,int_stack+1478086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1505626,int_stack+1496176,int_stack+1394926,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1528306,int_stack+1505626,int_stack+1402486,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1483756,int_stack+1528306,int_stack+1420126,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+770405,int_stack+796885,int_stack+796570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994555, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+776460,int_stack+797305,int_stack+796885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994870, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1527856,int_stack+776460,int_stack+770405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+784420,int_stack+797845,int_stack+797305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995290, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1529746,int_stack+784420,int_stack+776460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035670, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1532266,int_stack+1529746,int_stack+1527856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036930, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1529746,int_stack+800911,int_stack+800470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1535416,int_stack+801499,int_stack+800911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1537180,int_stack+1535416,int_stack+1529746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1539826,int_stack+802255,int_stack+801499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001434, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1542094,int_stack+1539826,int_stack+1535416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1044238, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1545622,int_stack+1542094,int_stack+1537180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1550032,int_stack+1545622,int_stack+1532266,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1539826,int_stack+806518,int_stack+805930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008595, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1541590,int_stack+807302,int_stack+806518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009183, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1559482,int_stack+1541590,int_stack+1539826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1391605,int_stack+808310,int_stack+807302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009967, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1563010,int_stack+1391605,int_stack+1541590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060348, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1567714,int_stack+1563010,int_stack+1559482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1573594,int_stack+1567714,int_stack+1545622,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1586824,int_stack+1573594,int_stack+1550032,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1563010,int_stack+813966,int_stack+813210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+908760, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1391605,int_stack+814974,int_stack+813966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+910272, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1605724,int_stack+1391605,int_stack+1563010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+816270,int_stack+814974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912288, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1610260,int_stack+0,int_stack+1391605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091680, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1616308,int_stack+1610260,int_stack+1605724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1623868,int_stack+1616308,int_stack+1567714,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1641508,int_stack+1623868,int_stack+1573594,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1667968,int_stack+1641508,int_stack+1586824,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1610260,int_stack+364455,int_stack+362565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+366975,int_stack+364455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1699468,int_stack+0,int_stack+1610260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1705138,int_stack+4050,int_stack+366975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1709998,int_stack+1705138,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150081, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1717558,int_stack+1709998,int_stack+1699468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1727008,int_stack+1717558,int_stack+1616308,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1749688,int_stack+1727008,int_stack+1623868,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1705138,int_stack+1749688,int_stack+1641508,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+802255,int_stack+828735,int_stack+828420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+808310,int_stack+829155,int_stack+828735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1749238,int_stack+808310,int_stack+802255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+816270,int_stack+829695,int_stack+829155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1751128,int_stack+816270,int_stack+808310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1753648,int_stack+1751128,int_stack+1749238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1751128,int_stack+832761,int_stack+832320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1756798,int_stack+833349,int_stack+832761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1758562,int_stack+1756798,int_stack+1751128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1761208,int_stack+834105,int_stack+833349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1763476,int_stack+1761208,int_stack+1756798, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1044238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1767004,int_stack+1763476,int_stack+1758562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1771414,int_stack+1767004,int_stack+1753648,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1761208,int_stack+838368,int_stack+837780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1762972,int_stack+839152,int_stack+838368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1780864,int_stack+1762972,int_stack+1761208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1613095,int_stack+840160,int_stack+839152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1784392,int_stack+1613095,int_stack+1762972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1789096,int_stack+1784392,int_stack+1780864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1794976,int_stack+1789096,int_stack+1767004,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1808206,int_stack+1794976,int_stack+1771414,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1784392,int_stack+845816,int_stack+845060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+908760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1613095,int_stack+846824,int_stack+845816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+910272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1827106,int_stack+1613095,int_stack+1784392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1831642,int_stack+848120,int_stack+846824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1835530,int_stack+1831642,int_stack+1613095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1841578,int_stack+1835530,int_stack+1827106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1849138,int_stack+1841578,int_stack+1789096,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1866778,int_stack+1849138,int_stack+1794976,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1893238,int_stack+1866778,int_stack+1808206,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1831642,int_stack+387130,int_stack+385240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1834477,int_stack+389650,int_stack+387130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1924738,int_stack+1834477,int_stack+1831642, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1930408,int_stack+6075,int_stack+389650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935268,int_stack+1930408,int_stack+1834477, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1942828,int_stack+1935268,int_stack+1924738, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1952278,int_stack+1942828,int_stack+1841578,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1974958,int_stack+1952278,int_stack+1849138,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1930408,int_stack+1974958,int_stack+1866778,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+834105,int_stack+860585,int_stack+860270, 0.0, zero_stack, 1.0, int_stack+994555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840160,int_stack+861005,int_stack+860585, 0.0, zero_stack, 1.0, int_stack+994870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1974508,int_stack+840160,int_stack+834105, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+848120,int_stack+861545,int_stack+861005, 0.0, zero_stack, 1.0, int_stack+995290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1976398,int_stack+848120,int_stack+840160, 0.0, zero_stack, 1.0, int_stack+1035670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1978918,int_stack+1976398,int_stack+1974508, 0.0, zero_stack, 1.0, int_stack+1036930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1976398,int_stack+864611,int_stack+864170, 0.0, zero_stack, 1.0, int_stack+1000405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1982068,int_stack+865199,int_stack+864611, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1983832,int_stack+1982068,int_stack+1976398, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1986478,int_stack+865955,int_stack+865199, 0.0, zero_stack, 1.0, int_stack+1001434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1988746,int_stack+1986478,int_stack+1982068, 0.0, zero_stack, 1.0, int_stack+1044238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1992274,int_stack+1988746,int_stack+1983832, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1996684,int_stack+1992274,int_stack+1978918,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1986478,int_stack+870218,int_stack+869630, 0.0, zero_stack, 1.0, int_stack+1008595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1988242,int_stack+871002,int_stack+870218, 0.0, zero_stack, 1.0, int_stack+1009183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2006134,int_stack+1988242,int_stack+1986478, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1838257,int_stack+872010,int_stack+871002, 0.0, zero_stack, 1.0, int_stack+1009967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2009662,int_stack+1838257,int_stack+1988242, 0.0, zero_stack, 1.0, int_stack+1060348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2014366,int_stack+2009662,int_stack+2006134, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2020246,int_stack+2014366,int_stack+1992274,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2033476,int_stack+2020246,int_stack+1996684,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2009662,int_stack+877666,int_stack+876910, 0.0, zero_stack, 1.0, int_stack+908760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1838257,int_stack+878674,int_stack+877666, 0.0, zero_stack, 1.0, int_stack+910272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2052376,int_stack+1838257,int_stack+2009662, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+879970,int_stack+878674, 0.0, zero_stack, 1.0, int_stack+912288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2056912,int_stack+3780,int_stack+1838257, 0.0, zero_stack, 1.0, int_stack+1091680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2062960,int_stack+2056912,int_stack+2052376, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2070520,int_stack+2062960,int_stack+2014366,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2088160,int_stack+2070520,int_stack+2020246,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2114620,int_stack+2088160,int_stack+2033476,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2056912,int_stack+409805,int_stack+407915, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+412325,int_stack+409805, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2146120,int_stack+3780,int_stack+2056912, 0.0, zero_stack, 1.0, int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2151790,int_stack+8100,int_stack+412325, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2156650,int_stack+2151790,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+1150081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2164210,int_stack+2156650,int_stack+2146120, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2173660,int_stack+2164210,int_stack+2062960,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2196340,int_stack+2173660,int_stack+2070520,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2151790,int_stack+2196340,int_stack+2088160,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+865955,int_stack+892435,int_stack+892120, 1.0, int_stack+994555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+872010,int_stack+892855,int_stack+892435, 1.0, int_stack+994870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2195890,int_stack+872010,int_stack+865955, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+879970,int_stack+893395,int_stack+892855, 1.0, int_stack+995290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2197780,int_stack+879970,int_stack+872010, 1.0, int_stack+1035670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2200300,int_stack+2197780,int_stack+2195890, 1.0, int_stack+1036930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2197780,int_stack+896461,int_stack+896020, 1.0, int_stack+1000405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2203450,int_stack+897049,int_stack+896461, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205214,int_stack+2203450,int_stack+2197780, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2207860,int_stack+897805,int_stack+897049, 1.0, int_stack+1001434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2210128,int_stack+2207860,int_stack+2203450, 1.0, int_stack+1044238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2213656,int_stack+2210128,int_stack+2205214, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2218066,int_stack+2213656,int_stack+2200300,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2207860,int_stack+902068,int_stack+901480, 1.0, int_stack+1008595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2209624,int_stack+902852,int_stack+902068, 1.0, int_stack+1009183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2227516,int_stack+2209624,int_stack+2207860, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2059747,int_stack+903860,int_stack+902852, 1.0, int_stack+1009967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2231044,int_stack+2059747,int_stack+2209624, 1.0, int_stack+1060348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2235748,int_stack+2231044,int_stack+2227516, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2241628,int_stack+2235748,int_stack+2213656,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2254858,int_stack+2241628,int_stack+2218066,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2231044,int_stack+911280,int_stack+909516, 1.0, int_stack+908760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2059747,int_stack+913584,int_stack+911280, 1.0, int_stack+910272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2273758,int_stack+2059747,int_stack+2231044, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2278294,int_stack+914880,int_stack+913584, 1.0, int_stack+912288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2282182,int_stack+2278294,int_stack+2059747, 1.0, int_stack+1091680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2288230,int_stack+2282182,int_stack+2273758, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2295790,int_stack+2288230,int_stack+2235748,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2313430,int_stack+2295790,int_stack+2241628,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2339890,int_stack+2313430,int_stack+2254858,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2278294,int_stack+434685,int_stack+431535, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2281129,int_stack+437205,int_stack+434685, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+2281129,int_stack+2278294, 1.0, int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2377060,int_stack+11745,int_stack+437205, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2381920,int_stack+2377060,int_stack+2281129, 1.0, int_stack+1150081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2389480,int_stack+2381920,int_stack+2371390, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2398930,int_stack+2389480,int_stack+2288230,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2421610,int_stack+2398930,int_stack+2295790,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2377060,int_stack+2421610,int_stack+2313430,210);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+914880,int_stack+995830,int_stack+995290,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1240342,int_stack+914880,int_stack+1035670,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1242862,int_stack+1240342,int_stack+1036930,15);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089412,int_stack+1002190,int_stack+1001434,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+1089412,int_stack+1044238,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2424688,int_stack+2421160,int_stack+1050205,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2429098,int_stack+2424688,int_stack+1242862,210);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2421160,int_stack+1010975,int_stack+1009967,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2438548,int_stack+2421160,int_stack+1060348,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2443252,int_stack+2438548,int_stack+1078240,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2449132,int_stack+2443252,int_stack+2424688,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2462362,int_stack+2449132,int_stack+2429098,210);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2438548,int_stack+17820,int_stack+912288,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1147246,int_stack+2438548,int_stack+1091680,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2481262,int_stack+1147246,int_stack+1135150,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2488822,int_stack+2481262,int_stack+2443252,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2506462,int_stack+2488822,int_stack+2449132,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2532922,int_stack+2506462,int_stack+2462362,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+430590,int_stack+931170,int_stack+930855,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433425,int_stack+931590,int_stack+931170,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1135150,int_stack+433425,int_stack+430590,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+17820,int_stack+932130,int_stack+931590,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1240342,int_stack+17820,int_stack+433425,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1147246,int_stack+1240342,int_stack+1135150,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1240342,int_stack+935196,int_stack+934755,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1137040,int_stack+935784,int_stack+935196,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1050205,int_stack+1137040,int_stack+1240342,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1150396,int_stack+936540,int_stack+935784,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1078240,int_stack+1150396,int_stack+1137040,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2438548,int_stack+1078240,int_stack+1050205,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2564422,int_stack+2438548,int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1242862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+940803,int_stack+940215,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1150396,int_stack+941587,int_stack+940803,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2421160,int_stack+1150396,int_stack+1078240,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089412,int_stack+942595,int_stack+941587,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1058584,int_stack+1089412,int_stack+1150396,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7560,int_stack+1058584,int_stack+2421160,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2573872,int_stack+7560,int_stack+2438548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2587102,int_stack+2573872,int_stack+2564422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1058584,int_stack+948251,int_stack+947495,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1060852,int_stack+949259,int_stack+948251,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1089412,int_stack+1060852,int_stack+1058584,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1042915,int_stack+950555,int_stack+949259,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+1042915,int_stack+1060852,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2612050,int_stack+2606002,int_stack+1089412,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2619610,int_stack+2612050,int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2443252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2637250,int_stack+2619610,int_stack+2573872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2663710,int_stack+2637250,int_stack+2587102, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2462362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+551610,int_stack+549720,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1042915,int_stack+554130,int_stack+551610,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+1042915,int_stack+2606002,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2700880,int_stack+13770,int_stack+554130,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2705740,int_stack+2700880,int_stack+1042915,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2713300,int_stack+2705740,int_stack+2695210,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2722750,int_stack+2713300,int_stack+2612050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2481262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2745430,int_stack+2722750,int_stack+2619610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2488822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2700880,int_stack+2745430,int_stack+2637250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2506462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+936540,int_stack+963020,int_stack+962705,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+942595,int_stack+963440,int_stack+963020,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2744980,int_stack+942595,int_stack+936540,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+950555,int_stack+963980,int_stack+963440,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2746870,int_stack+950555,int_stack+942595,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2749390,int_stack+2746870,int_stack+2744980,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2746870,int_stack+967046,int_stack+966605,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1080004,int_stack+967634,int_stack+967046,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2752540,int_stack+1080004,int_stack+2746870,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2755186,int_stack+968390,int_stack+967634,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2757454,int_stack+2755186,int_stack+1080004,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2760982,int_stack+2757454,int_stack+2752540,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2765392,int_stack+2760982,int_stack+2749390, 0.0, zero_stack, 1.0, int_stack+1242862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2755186,int_stack+972653,int_stack+972065,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2756950,int_stack+973437,int_stack+972653,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2774842,int_stack+2756950,int_stack+2755186,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2608837,int_stack+974445,int_stack+973437,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2778370,int_stack+2608837,int_stack+2756950,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2783074,int_stack+2778370,int_stack+2774842,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2788954,int_stack+2783074,int_stack+2760982, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2802184,int_stack+2788954,int_stack+2765392, 0.0, zero_stack, 1.0, int_stack+2429098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2778370,int_stack+980101,int_stack+979345,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2608837,int_stack+981109,int_stack+980101,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2821084,int_stack+2608837,int_stack+2778370,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1034725,int_stack+982405,int_stack+981109,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2825620,int_stack+1034725,int_stack+2608837,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2831668,int_stack+2825620,int_stack+2821084,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2839228,int_stack+2831668,int_stack+2783074, 0.0, zero_stack, 1.0, int_stack+2443252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2856868,int_stack+2839228,int_stack+2788954, 0.0, zero_stack, 1.0, int_stack+2449132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2883328,int_stack+2856868,int_stack+2802184, 0.0, zero_stack, 1.0, int_stack+2462362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2825620,int_stack+687385,int_stack+685495,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1034725,int_stack+689905,int_stack+687385,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+1034725,int_stack+2825620,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2920498,int_stack+15795,int_stack+689905,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2925358,int_stack+2920498,int_stack+1034725,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2932918,int_stack+2925358,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2942368,int_stack+2932918,int_stack+2831668, 0.0, zero_stack, 1.0, int_stack+2481262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2965048,int_stack+2942368,int_stack+2839228, 0.0, zero_stack, 1.0, int_stack+2488822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2920498,int_stack+2965048,int_stack+2856868, 0.0, zero_stack, 1.0, int_stack+2506462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+968390,int_stack+996820,int_stack+996505,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+974445,int_stack+997240,int_stack+996820,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2964598,int_stack+974445,int_stack+968390,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+982405,int_stack+997780,int_stack+997240,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2966488,int_stack+982405,int_stack+974445,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2969008,int_stack+2966488,int_stack+2964598,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2966488,int_stack+1003576,int_stack+1003135,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2972158,int_stack+1004164,int_stack+1003576,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2973922,int_stack+2972158,int_stack+2966488,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2976568,int_stack+1004920,int_stack+1004164,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2978836,int_stack+2976568,int_stack+2972158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2982364,int_stack+2978836,int_stack+2973922,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2986774,int_stack+2982364,int_stack+2969008, 1.0, int_stack+1242862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2976568,int_stack+1012823,int_stack+1012235,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2978332,int_stack+1013607,int_stack+1012823,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2996224,int_stack+2978332,int_stack+2976568,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2828455,int_stack+1014615,int_stack+1013607,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13440,int_stack+2828455,int_stack+2978332,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2999752,int_stack+13440,int_stack+2996224,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3005632,int_stack+2999752,int_stack+2982364, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3018862,int_stack+3005632,int_stack+2986774, 1.0, int_stack+2429098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2424688,int_stack+1020271,int_stack+1019515,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2426956,int_stack+1021279,int_stack+1020271,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2429980,int_stack+2426956,int_stack+2424688,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2434516,int_stack+1022575,int_stack+1021279,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3037762,int_stack+2434516,int_stack+2426956,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3043810,int_stack+3037762,int_stack+2429980,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3051370,int_stack+3043810,int_stack+2999752, 1.0, int_stack+2443252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3069010,int_stack+3051370,int_stack+3005632, 1.0, int_stack+2449132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3095470,int_stack+3069010,int_stack+3018862, 1.0, int_stack+2462362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3037762,int_stack+923070,int_stack+921180,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2434516,int_stack+925590,int_stack+923070,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13440,int_stack+2434516,int_stack+3037762,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2442958,int_stack+19440,int_stack+925590,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2447818,int_stack+2442958,int_stack+2434516,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2455378,int_stack+2447818,int_stack+13440,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3126970,int_stack+2455378,int_stack+3043810, 1.0, int_stack+2481262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2442958,int_stack+3126970,int_stack+3051370, 1.0, int_stack+2488822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3126970,int_stack+2442958,int_stack+3069010, 1.0, int_stack+2506462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+21780,int_stack+21465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+732870,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+22200,int_stack+21780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+733185,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2442958,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1038820,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+22740,int_stack+22200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+733605,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2444848,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1039765,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2447368,int_stack+2444848,int_stack+2442958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1041025,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2442958,int_stack+23856,int_stack+23415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+736770,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2444281,int_stack+24444,int_stack+23856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+737211,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2450518,int_stack+2444281,int_stack+2442958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1052851,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453164,int_stack+25200,int_stack+24444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+737799,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455432,int_stack+2453164,int_stack+2444281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1054174,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2442958,int_stack+2455432,int_stack+2450518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1055938,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2450518,int_stack+2442958,int_stack+2447368,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2447368,int_stack+26733,int_stack+26145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+742230,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2459968,int_stack+27517,int_stack+26733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+742818,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2462320,int_stack+2459968,int_stack+2447368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1081768,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2447368,int_stack+28525,int_stack+27517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+743602,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2465848,int_stack+2447368,int_stack+2459968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1083532,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2470552,int_stack+2465848,int_stack+2462320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1085884,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2476432,int_stack+2470552,int_stack+2442958,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2489662,int_stack+2476432,int_stack+2450518,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2442958,int_stack+30541,int_stack+29785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+749510,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2445226,int_stack+31549,int_stack+30541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+750266,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2448250,int_stack+2445226,int_stack+2442958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1094704,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452786,int_stack+32845,int_stack+31549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+751274,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2456674,int_stack+2452786,int_stack+2445226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1139686,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2462722,int_stack+2456674,int_stack+2448250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1142710,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2442958,int_stack+2462722,int_stack+2470552,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+2442958,int_stack+2476432,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3197530,int_stack+3171070,int_stack+2489662,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2470282,int_stack+35410,int_stack+34465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+317215,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2473117,int_stack+36670,int_stack+35410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+319105,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2476897,int_stack+2473117,int_stack+2470282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1153861,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2482567,int_stack+38290,int_stack+36670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+321625,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2487427,int_stack+2482567,int_stack+2473117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1246012,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2494987,int_stack+2487427,int_stack+2476897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1249792,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2470282,int_stack+2494987,int_stack+2462722,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2492962,int_stack+2470282,int_stack+2442958,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2442958,int_stack+2492962,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+40630,int_stack+40315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+732870, 1.0, int_stack+764720,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+41050,int_stack+40630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733185, 1.0, int_stack+765035,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1038820, 1.0, int_stack+738555,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+41590,int_stack+41050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733605, 1.0, int_stack+765455,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039765, 1.0, int_stack+744610,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041025, 1.0, int_stack+1299562,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+42706,int_stack+42265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+736770, 1.0, int_stack+768620,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3172393,int_stack+43294,int_stack+42706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737211, 1.0, int_stack+769061,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3178630,int_stack+3172393,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052851, 1.0, int_stack+1301452,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3181276,int_stack+44050,int_stack+43294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737799, 1.0, int_stack+769649,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3183544,int_stack+3181276,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054174, 1.0, int_stack+1307122,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3171070,int_stack+3183544,int_stack+3178630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055938, 1.0, int_stack+1308886,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+3171070,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3175480,int_stack+45583,int_stack+44995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742230, 1.0, int_stack+774080,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3188080,int_stack+46367,int_stack+45583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742818, 1.0, int_stack+774668,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3190432,int_stack+3188080,int_stack+3175480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081768, 1.0, int_stack+1311532,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3175480,int_stack+47375,int_stack+46367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602, 1.0, int_stack+775452,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2487058,int_stack+3175480,int_stack+3188080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083532, 1.0, int_stack+1313296,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2491762,int_stack+2487058,int_stack+3190432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085884, 1.0, int_stack+1331188,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2497642,int_stack+2491762,int_stack+3171070,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2510872,int_stack+2497642,int_stack+3178630,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+49391,int_stack+48635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749510, 1.0, int_stack+781360,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3173338,int_stack+50399,int_stack+49391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750266, 1.0, int_stack+782116,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3176362,int_stack+3173338,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094704, 1.0, int_stack+1334716,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3180898,int_stack+51695,int_stack+50399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751274, 1.0, int_stack+783124,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3184786,int_stack+3180898,int_stack+3173338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1139686, 1.0, int_stack+1336984,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19110,int_stack+3184786,int_stack+3176362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142710, 1.0, int_stack+1380454,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+19110,int_stack+2491762,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+26670,int_stack+3171070,int_stack+2497642,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3229030,int_stack+26670,int_stack+2510872,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3188710,int_stack+54260,int_stack+53315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317215, 1.0, int_stack+339890,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3191545,int_stack+55520,int_stack+54260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319105, 1.0, int_stack+341780,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2487058,int_stack+3191545,int_stack+3188710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1153861, 1.0, int_stack+1384990,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2492728,int_stack+57140,int_stack+55520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321625, 1.0, int_stack+344300,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2497588,int_stack+2492728,int_stack+3191545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1246012, 1.0, int_stack+1387825,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2505148,int_stack+2497588,int_stack+2487058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249792, 1.0, int_stack+1478086,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3260530,int_stack+2505148,int_stack+19110,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2487058,int_stack+3260530,int_stack+3171070,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3260530,int_stack+2487058,int_stack+26670,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+59480,int_stack+59165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+764720, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+59900,int_stack+59480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+765035, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2487058,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+738555, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+60440,int_stack+59900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+765455, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2488948,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+744610, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2491468,int_stack+2488948,int_stack+2487058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1299562, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2487058,int_stack+61556,int_stack+61115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+768620, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2488381,int_stack+62144,int_stack+61556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+769061, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2494618,int_stack+2488381,int_stack+2487058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1301452, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2497264,int_stack+62900,int_stack+62144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+769649, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2499532,int_stack+2497264,int_stack+2488381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1307122, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2487058,int_stack+2499532,int_stack+2494618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1308886, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2494618,int_stack+2487058,int_stack+2491468,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2491468,int_stack+64433,int_stack+63845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+774080, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2504068,int_stack+65217,int_stack+64433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+774668, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2506420,int_stack+2504068,int_stack+2491468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1311532, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2491468,int_stack+66225,int_stack+65217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+775452, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2509948,int_stack+2491468,int_stack+2504068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1313296, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2514652,int_stack+2509948,int_stack+2506420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1331188, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3171070,int_stack+2514652,int_stack+2487058,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+19110,int_stack+3171070,int_stack+2494618,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2487058,int_stack+68241,int_stack+67485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+781360, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2489326,int_stack+69249,int_stack+68241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+782116, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2492350,int_stack+2489326,int_stack+2487058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1334716, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2496886,int_stack+70545,int_stack+69249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+783124, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2500774,int_stack+2496886,int_stack+2489326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1336984, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2506822,int_stack+2500774,int_stack+2492350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1380454, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2487058,int_stack+2506822,int_stack+2514652,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+38010,int_stack+2487058,int_stack+3171070,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3304630,int_stack+38010,int_stack+19110,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19110,int_stack+73110,int_stack+72165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+339890, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21945,int_stack+74370,int_stack+73110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+341780, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25725,int_stack+21945,int_stack+19110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1384990, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31395,int_stack+75990,int_stack+74370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+344300, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+31395,int_stack+21945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1387825, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3178630,int_stack+3171070,int_stack+25725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1478086, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3336130,int_stack+3178630,int_stack+2506822,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3358810,int_stack+3336130,int_stack+2487058,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2487058,int_stack+3358810,int_stack+38010,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+78330,int_stack+78015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+732870, 0.0, zero_stack, 1.0, int_stack+796570,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+78750,int_stack+78330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733185, 0.0, zero_stack, 1.0, int_stack+796885,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3336130,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1038820, 0.0, zero_stack, 1.0, int_stack+770405,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+79290,int_stack+78750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733605, 0.0, zero_stack, 1.0, int_stack+797305,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3338020,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039765, 0.0, zero_stack, 1.0, int_stack+776460,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3340540,int_stack+3338020,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041025, 0.0, zero_stack, 1.0, int_stack+1527856,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3336130,int_stack+80406,int_stack+79965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+736770, 0.0, zero_stack, 1.0, int_stack+800470,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+80994,int_stack+80406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737211, 0.0, zero_stack, 1.0, int_stack+800911,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3337453,int_stack+2531158,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052851, 0.0, zero_stack, 1.0, int_stack+1529746,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3343690,int_stack+81750,int_stack+80994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737799, 0.0, zero_stack, 1.0, int_stack+801499,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3345958,int_stack+3343690,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054174, 0.0, zero_stack, 1.0, int_stack+1535416,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3349486,int_stack+3345958,int_stack+3337453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055938, 0.0, zero_stack, 1.0, int_stack+1537180,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3353896,int_stack+3349486,int_stack+3340540,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+83283,int_stack+82695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742230, 0.0, zero_stack, 1.0, int_stack+805930,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3336130,int_stack+84067,int_stack+83283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742818, 0.0, zero_stack, 1.0, int_stack+806518,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3338482,int_stack+3336130,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081768, 0.0, zero_stack, 1.0, int_stack+1539826,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3342010,int_stack+85075,int_stack+84067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack, 1.0, int_stack+807302,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3363346,int_stack+3342010,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083532, 0.0, zero_stack, 1.0, int_stack+1541590,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3342010,int_stack+3363346,int_stack+3338482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085884, 0.0, zero_stack, 1.0, int_stack+1559482,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3363346,int_stack+3342010,int_stack+3349486,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3171070,int_stack+3363346,int_stack+3353896,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3376576,int_stack+87091,int_stack+86335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749510, 0.0, zero_stack, 1.0, int_stack+813210,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3378844,int_stack+88099,int_stack+87091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750266, 0.0, zero_stack, 1.0, int_stack+813966,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3381868,int_stack+3378844,int_stack+3376576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094704, 0.0, zero_stack, 1.0, int_stack+1563010,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3386404,int_stack+89395,int_stack+88099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751274, 0.0, zero_stack, 1.0, int_stack+814974,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3347890,int_stack+3386404,int_stack+3378844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1139686, 0.0, zero_stack, 1.0, int_stack+1391605,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3189970,int_stack+3347890,int_stack+3381868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142710, 0.0, zero_stack, 1.0, int_stack+1605724,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3376576,int_stack+3189970,int_stack+3342010,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3336130,int_stack+3376576,int_stack+3363346,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+19110,int_stack+3336130,int_stack+3171070,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+91960,int_stack+91015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317215, 0.0, zero_stack, 1.0, int_stack+362565,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3173905,int_stack+93220,int_stack+91960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319105, 0.0, zero_stack, 1.0, int_stack+364455,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3177685,int_stack+3173905,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1153861, 0.0, zero_stack, 1.0, int_stack+1610260,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3183355,int_stack+94840,int_stack+93220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321625, 0.0, zero_stack, 1.0, int_stack+366975,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3362590,int_stack+3183355,int_stack+3173905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1246012, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+50610,int_stack+3362590,int_stack+3177685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249792, 0.0, zero_stack, 1.0, int_stack+1699468,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+60060,int_stack+50610,int_stack+3189970,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3394216,int_stack+60060,int_stack+3376576,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+50610,int_stack+3394216,int_stack+3336130,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+97180,int_stack+96865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+764720, 1.0, int_stack+796570, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+97600,int_stack+97180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765035, 1.0, int_stack+796885, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3336130,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738555, 1.0, int_stack+770405, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+98140,int_stack+97600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765455, 1.0, int_stack+797305, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3338020,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+744610, 1.0, int_stack+776460, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3340540,int_stack+3338020,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299562, 1.0, int_stack+1527856, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3336130,int_stack+99256,int_stack+98815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768620, 1.0, int_stack+800470, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+99844,int_stack+99256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769061, 1.0, int_stack+800911, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3337453,int_stack+2531158,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301452, 1.0, int_stack+1529746, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3343690,int_stack+100600,int_stack+99844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769649, 1.0, int_stack+801499, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3345958,int_stack+3343690,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307122, 1.0, int_stack+1535416, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3349486,int_stack+3345958,int_stack+3337453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1308886, 1.0, int_stack+1537180, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3353896,int_stack+3349486,int_stack+3340540,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+102133,int_stack+101545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774080, 1.0, int_stack+805930, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3336130,int_stack+102917,int_stack+102133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774668, 1.0, int_stack+806518, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3338482,int_stack+3336130,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1311532, 1.0, int_stack+1539826, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3342010,int_stack+103925,int_stack+102917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775452, 1.0, int_stack+807302, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3363346,int_stack+3342010,int_stack+3336130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1313296, 1.0, int_stack+1541590, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3342010,int_stack+3363346,int_stack+3338482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331188, 1.0, int_stack+1559482, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3363346,int_stack+3342010,int_stack+3349486,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3376576,int_stack+3363346,int_stack+3353896,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3395476,int_stack+105941,int_stack+105185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781360, 1.0, int_stack+813210, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3397744,int_stack+106949,int_stack+105941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782116, 1.0, int_stack+813966, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3400768,int_stack+3397744,int_stack+3395476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334716, 1.0, int_stack+1563010, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3405304,int_stack+108245,int_stack+106949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783124, 1.0, int_stack+814974, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3409192,int_stack+3405304,int_stack+3397744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336984, 1.0, int_stack+1391605, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3415240,int_stack+3409192,int_stack+3400768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1380454, 1.0, int_stack+1605724, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3395476,int_stack+3415240,int_stack+3342010,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3395476,int_stack+3363346,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3336130,int_stack+3171070,int_stack+3376576,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3422800,int_stack+110810,int_stack+109865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339890, 1.0, int_stack+362565, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3425635,int_stack+112070,int_stack+110810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341780, 1.0, int_stack+364455, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3367630,int_stack+3425635,int_stack+3422800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384990, 1.0, int_stack+1610260, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3373300,int_stack+113690,int_stack+112070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344300, 1.0, int_stack+366975, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3378160,int_stack+3373300,int_stack+3425635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1387825, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3385720,int_stack+3378160,int_stack+3367630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1478086, 1.0, int_stack+1699468, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3422800,int_stack+3385720,int_stack+3415240,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3445480,int_stack+3422800,int_stack+3395476,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3367630,int_stack+3445480,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+116030,int_stack+115715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+796570, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+116450,int_stack+116030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+796885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+770405, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+116990,int_stack+116450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+797305, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+776460, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1527856, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+118106,int_stack+117665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+800470, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+118694,int_stack+118106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+800911, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1529746, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+119450,int_stack+118694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+801499, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1535416, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1537180, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3411730,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+120983,int_stack+120395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+805930, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+121767,int_stack+120983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+806518, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1539826, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+122775,int_stack+121767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+807302, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1541590, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1559482, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3421180,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3434410,int_stack+3421180,int_stack+3411730,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3411730,int_stack+124791,int_stack+124035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+813210, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3413998,int_stack+125799,int_stack+124791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+813966, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3413998,int_stack+3411730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1563010, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3417022,int_stack+127095,int_stack+125799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+814974, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3417022,int_stack+3413998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1391605, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3411730,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1605724, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3453310,int_stack+3411730,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3453310,int_stack+3421180,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+94710,int_stack+3171070,int_stack+3434410,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3419290,int_stack+129660,int_stack+128715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+362565, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3422125,int_stack+130920,int_stack+129660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+364455, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3425905,int_stack+3422125,int_stack+3419290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1610260, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3431575,int_stack+132540,int_stack+130920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366975, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3436435,int_stack+3431575,int_stack+3422125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3470950,int_stack+3436435,int_stack+3425905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1699468, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3419290,int_stack+3470950,int_stack+3411730,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3470950,int_stack+3419290,int_stack+3453310,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3411730,int_stack+3470950,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+134880,int_stack+134565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+732870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828420,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+135300,int_stack+134880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828735,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1038820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802255,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+135840,int_stack+135300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829155,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808310,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1749238,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+136956,int_stack+136515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+736770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832320,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+137544,int_stack+136956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832761,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1751128,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+138300,int_stack+137544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+833349,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756798,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055938, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1758562,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3455830,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+139833,int_stack+139245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837780,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+140617,int_stack+139833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+742818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838368,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1761208,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+141625,int_stack+140617, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+839152,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1762972,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780864,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3465280,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3478510,int_stack+3465280,int_stack+3455830,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3455830,int_stack+143641,int_stack+142885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+845060,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3458098,int_stack+144649,int_stack+143641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+750266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+845816,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3458098,int_stack+3455830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1784392,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3461122,int_stack+145945,int_stack+144649, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+846824,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3461122,int_stack+3458098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1139686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1613095,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3455830,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1827106,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+126210,int_stack+3455830,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+126210,int_stack+3465280,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3497410,int_stack+3171070,int_stack+3478510,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3463390,int_stack+148510,int_stack+147565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385240,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3466225,int_stack+149770,int_stack+148510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387130,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3470005,int_stack+3466225,int_stack+3463390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1153861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1831642,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3475675,int_stack+151390,int_stack+149770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389650,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3480535,int_stack+3475675,int_stack+3466225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1246012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1834477,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+143850,int_stack+3480535,int_stack+3470005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924738,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3463390,int_stack+143850,int_stack+3455830,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3528910,int_stack+3463390,int_stack+126210,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3564190,int_stack+3528910,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+153730,int_stack+153415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+764720, 0.0, zero_stack, 1.0, int_stack+828420, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+154150,int_stack+153730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765035, 0.0, zero_stack, 1.0, int_stack+828735, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738555, 0.0, zero_stack, 1.0, int_stack+802255, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+154690,int_stack+154150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765455, 0.0, zero_stack, 1.0, int_stack+829155, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+744610, 0.0, zero_stack, 1.0, int_stack+808310, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299562, 0.0, zero_stack, 1.0, int_stack+1749238, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+155806,int_stack+155365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768620, 0.0, zero_stack, 1.0, int_stack+832320, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+156394,int_stack+155806, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769061, 0.0, zero_stack, 1.0, int_stack+832761, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301452, 0.0, zero_stack, 1.0, int_stack+1751128, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+157150,int_stack+156394, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769649, 0.0, zero_stack, 1.0, int_stack+833349, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307122, 0.0, zero_stack, 1.0, int_stack+1756798, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1308886, 0.0, zero_stack, 1.0, int_stack+1758562, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528910,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+158683,int_stack+158095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774080, 0.0, zero_stack, 1.0, int_stack+837780, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+159467,int_stack+158683, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774668, 0.0, zero_stack, 1.0, int_stack+838368, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1311532, 0.0, zero_stack, 1.0, int_stack+1761208, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+160475,int_stack+159467, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775452, 0.0, zero_stack, 1.0, int_stack+839152, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1313296, 0.0, zero_stack, 1.0, int_stack+1762972, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331188, 0.0, zero_stack, 1.0, int_stack+1780864, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3538360,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+126210,int_stack+3538360,int_stack+3528910,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+162491,int_stack+161735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781360, 0.0, zero_stack, 1.0, int_stack+845060, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531178,int_stack+163499,int_stack+162491, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782116, 0.0, zero_stack, 1.0, int_stack+845816, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3531178,int_stack+3528910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334716, 0.0, zero_stack, 1.0, int_stack+1784392, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3534202,int_stack+164795,int_stack+163499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783124, 0.0, zero_stack, 1.0, int_stack+846824, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3534202,int_stack+3531178, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336984, 0.0, zero_stack, 1.0, int_stack+1613095, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528910,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1380454, 0.0, zero_stack, 1.0, int_stack+1827106, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+145110,int_stack+3528910,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+145110,int_stack+3538360,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3455830,int_stack+3171070,int_stack+126210,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+126210,int_stack+167360,int_stack+166415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339890, 0.0, zero_stack, 1.0, int_stack+385240, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+129045,int_stack+168620,int_stack+167360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341780, 0.0, zero_stack, 1.0, int_stack+387130, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+132825,int_stack+129045,int_stack+126210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384990, 0.0, zero_stack, 1.0, int_stack+1831642, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+138495,int_stack+170240,int_stack+168620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344300, 0.0, zero_stack, 1.0, int_stack+389650, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3536470,int_stack+138495,int_stack+129045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1387825, 0.0, zero_stack, 1.0, int_stack+1834477, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3544030,int_stack+3536470,int_stack+132825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1478086, 0.0, zero_stack, 1.0, int_stack+1924738, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3608290,int_stack+3544030,int_stack+3528910,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3528910,int_stack+3608290,int_stack+145110,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+126210,int_stack+3528910,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+172580,int_stack+172265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796570, 1.0, int_stack+828420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+173000,int_stack+172580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796885, 1.0, int_stack+828735, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770405, 1.0, int_stack+802255, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+173540,int_stack+173000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797305, 1.0, int_stack+829155, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776460, 1.0, int_stack+808310, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1527856, 1.0, int_stack+1749238, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+174656,int_stack+174215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+800470, 1.0, int_stack+832320, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+175244,int_stack+174656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+800911, 1.0, int_stack+832761, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1529746, 1.0, int_stack+1751128, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+176000,int_stack+175244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+801499, 1.0, int_stack+833349, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1535416, 1.0, int_stack+1756798, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1537180, 1.0, int_stack+1758562, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528910,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+177533,int_stack+176945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805930, 1.0, int_stack+837780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+178317,int_stack+177533, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+806518, 1.0, int_stack+838368, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1539826, 1.0, int_stack+1761208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+179325,int_stack+178317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+807302, 1.0, int_stack+839152, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1541590, 1.0, int_stack+1762972, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1559482, 1.0, int_stack+1780864, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3538360,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3608290,int_stack+3538360,int_stack+3528910,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+181341,int_stack+180585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+813210, 1.0, int_stack+845060, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531178,int_stack+182349,int_stack+181341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+813966, 1.0, int_stack+845816, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3531178,int_stack+3528910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1563010, 1.0, int_stack+1784392, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3534202,int_stack+183645,int_stack+182349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814974, 1.0, int_stack+846824, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3534202,int_stack+3531178, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1391605, 1.0, int_stack+1613095, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528910,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1605724, 1.0, int_stack+1827106, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3627190,int_stack+3528910,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3627190,int_stack+3538360,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3644830,int_stack+3171070,int_stack+3608290,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3608290,int_stack+186210,int_stack+185265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362565, 1.0, int_stack+385240, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3611125,int_stack+187470,int_stack+186210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364455, 1.0, int_stack+387130, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3614905,int_stack+3611125,int_stack+3608290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1610260, 1.0, int_stack+1831642, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3620575,int_stack+189090,int_stack+187470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366975, 1.0, int_stack+389650, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3536470,int_stack+3620575,int_stack+3611125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+1834477, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3544030,int_stack+3536470,int_stack+3614905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1699468, 1.0, int_stack+1924738, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3676330,int_stack+3544030,int_stack+3528910,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3528910,int_stack+3676330,int_stack+3627190,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3676330,int_stack+3528910,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+191430,int_stack+191115, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+828420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+191850,int_stack+191430, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+828735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+802255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+192390,int_stack+191850, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+829155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+808310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1749238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+193506,int_stack+193065, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+832320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+194094,int_stack+193506, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+832761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1751128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+194850,int_stack+194094, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+833349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1756798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1758562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528910,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+196383,int_stack+195795, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+837780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+197167,int_stack+196383, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+838368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1761208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+198175,int_stack+197167, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+839152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1762972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1780864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3538360,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3608290,int_stack+3538360,int_stack+3528910,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+200191,int_stack+199435, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+845060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531178,int_stack+201199,int_stack+200191, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+845816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3531178,int_stack+3528910, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1784392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3534202,int_stack+202495,int_stack+201199, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+846824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3534202,int_stack+3531178, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1613095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528910,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1827106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3627190,int_stack+3528910,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3627190,int_stack+3538360,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+170310,int_stack+3171070,int_stack+3608290,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3608290,int_stack+205060,int_stack+204115, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+385240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3611125,int_stack+206320,int_stack+205060, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+387130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3614905,int_stack+3611125,int_stack+3608290, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1831642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3620575,int_stack+207940,int_stack+206320, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+389650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3536470,int_stack+3620575,int_stack+3611125, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1834477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3544030,int_stack+3536470,int_stack+3614905, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1924738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3720430,int_stack+3544030,int_stack+3528910,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3528910,int_stack+3720430,int_stack+3627190,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3720430,int_stack+3528910,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+210280,int_stack+209965, 0.0, zero_stack, 1.0, int_stack+732870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860270,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+210700,int_stack+210280, 0.0, zero_stack, 1.0, int_stack+733185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860585,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+1038820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834105,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+211240,int_stack+210700, 0.0, zero_stack, 1.0, int_stack+733605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861005,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+1039765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840160,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1041025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974508,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+212356,int_stack+211915, 0.0, zero_stack, 1.0, int_stack+736770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864170,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+212944,int_stack+212356, 0.0, zero_stack, 1.0, int_stack+737211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864611,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1052851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1976398,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+213700,int_stack+212944, 0.0, zero_stack, 1.0, int_stack+737799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865199,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1054174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1982068,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+1055938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1983832,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528910,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+215233,int_stack+214645, 0.0, zero_stack, 1.0, int_stack+742230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+869630,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+216017,int_stack+215233, 0.0, zero_stack, 1.0, int_stack+742818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870218,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1081768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1986478,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+217025,int_stack+216017, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871002,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1083532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1988242,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 1.0, int_stack+1085884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006134,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3538360,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3608290,int_stack+3538360,int_stack+3528910,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+219041,int_stack+218285, 0.0, zero_stack, 1.0, int_stack+749510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876910,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531178,int_stack+220049,int_stack+219041, 0.0, zero_stack, 1.0, int_stack+750266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877666,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3531178,int_stack+3528910, 0.0, zero_stack, 1.0, int_stack+1094704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2009662,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3534202,int_stack+221345,int_stack+220049, 0.0, zero_stack, 1.0, int_stack+751274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878674,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3534202,int_stack+3531178, 0.0, zero_stack, 1.0, int_stack+1139686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1838257,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528910,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1142710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052376,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3627190,int_stack+3528910,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3627190,int_stack+3538360,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3764530,int_stack+3171070,int_stack+3608290,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3608290,int_stack+223910,int_stack+222965, 0.0, zero_stack, 1.0, int_stack+317215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407915,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3611125,int_stack+225170,int_stack+223910, 0.0, zero_stack, 1.0, int_stack+319105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409805,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3614905,int_stack+3611125,int_stack+3608290, 0.0, zero_stack, 1.0, int_stack+1153861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2056912,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3620575,int_stack+226790,int_stack+225170, 0.0, zero_stack, 1.0, int_stack+321625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412325,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3536470,int_stack+3620575,int_stack+3611125, 0.0, zero_stack, 1.0, int_stack+1246012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3544030,int_stack+3536470,int_stack+3614905, 0.0, zero_stack, 1.0, int_stack+1249792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2146120,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+201810,int_stack+3544030,int_stack+3528910,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3528910,int_stack+201810,int_stack+3627190,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3796030,int_stack+3528910,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+229130,int_stack+228815, 0.0, zero_stack, 1.0, int_stack+764720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860270, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+229550,int_stack+229130, 0.0, zero_stack, 1.0, int_stack+765035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860585, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+738555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834105, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+230090,int_stack+229550, 0.0, zero_stack, 1.0, int_stack+765455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861005, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+744610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840160, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1299562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974508, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+231206,int_stack+230765, 0.0, zero_stack, 1.0, int_stack+768620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864170, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+231794,int_stack+231206, 0.0, zero_stack, 1.0, int_stack+769061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864611, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1301452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1976398, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+232550,int_stack+231794, 0.0, zero_stack, 1.0, int_stack+769649, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865199, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1307122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1982068, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+1308886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1983832, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528910,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+234083,int_stack+233495, 0.0, zero_stack, 1.0, int_stack+774080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+869630, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+234867,int_stack+234083, 0.0, zero_stack, 1.0, int_stack+774668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870218, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1311532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1986478, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+235875,int_stack+234867, 0.0, zero_stack, 1.0, int_stack+775452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871002, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1313296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1988242, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 1.0, int_stack+1331188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006134, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3538360,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+201810,int_stack+3538360,int_stack+3528910,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+237891,int_stack+237135, 0.0, zero_stack, 1.0, int_stack+781360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876910, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531178,int_stack+238899,int_stack+237891, 0.0, zero_stack, 1.0, int_stack+782116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877666, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3531178,int_stack+3528910, 0.0, zero_stack, 1.0, int_stack+1334716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2009662, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3534202,int_stack+240195,int_stack+238899, 0.0, zero_stack, 1.0, int_stack+783124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878674, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3534202,int_stack+3531178, 0.0, zero_stack, 1.0, int_stack+1336984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1838257, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528910,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1380454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052376, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+220710,int_stack+3528910,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+220710,int_stack+3538360,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3608290,int_stack+3171070,int_stack+201810,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+201810,int_stack+242760,int_stack+241815, 0.0, zero_stack, 1.0, int_stack+339890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407915, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+204645,int_stack+244020,int_stack+242760, 0.0, zero_stack, 1.0, int_stack+341780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409805, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+238350,int_stack+204645,int_stack+201810, 0.0, zero_stack, 1.0, int_stack+1384990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2056912, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+208425,int_stack+245640,int_stack+244020, 0.0, zero_stack, 1.0, int_stack+344300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412325, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3536470,int_stack+208425,int_stack+204645, 0.0, zero_stack, 1.0, int_stack+1387825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+201810,int_stack+3536470,int_stack+238350, 0.0, zero_stack, 1.0, int_stack+1478086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2146120, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3536470,int_stack+201810,int_stack+3528910,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+3536470,int_stack+220710,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+201810,int_stack+3840130,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+247980,int_stack+247665, 0.0, zero_stack, 1.0, int_stack+796570, 0.0, zero_stack, 1.0, int_stack+860270, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+248400,int_stack+247980, 0.0, zero_stack, 1.0, int_stack+796885, 0.0, zero_stack, 1.0, int_stack+860585, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+770405, 0.0, zero_stack, 1.0, int_stack+834105, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+248940,int_stack+248400, 0.0, zero_stack, 1.0, int_stack+797305, 0.0, zero_stack, 1.0, int_stack+861005, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+776460, 0.0, zero_stack, 1.0, int_stack+840160, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1527856, 0.0, zero_stack, 1.0, int_stack+1974508, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+250056,int_stack+249615, 0.0, zero_stack, 1.0, int_stack+800470, 0.0, zero_stack, 1.0, int_stack+864170, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+250644,int_stack+250056, 0.0, zero_stack, 1.0, int_stack+800911, 0.0, zero_stack, 1.0, int_stack+864611, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1529746, 0.0, zero_stack, 1.0, int_stack+1976398, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+251400,int_stack+250644, 0.0, zero_stack, 1.0, int_stack+801499, 0.0, zero_stack, 1.0, int_stack+865199, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1535416, 0.0, zero_stack, 1.0, int_stack+1982068, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+1537180, 0.0, zero_stack, 1.0, int_stack+1983832, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3840130,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+252933,int_stack+252345, 0.0, zero_stack, 1.0, int_stack+805930, 0.0, zero_stack, 1.0, int_stack+869630, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+253717,int_stack+252933, 0.0, zero_stack, 1.0, int_stack+806518, 0.0, zero_stack, 1.0, int_stack+870218, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1539826, 0.0, zero_stack, 1.0, int_stack+1986478, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+254725,int_stack+253717, 0.0, zero_stack, 1.0, int_stack+807302, 0.0, zero_stack, 1.0, int_stack+871002, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1541590, 0.0, zero_stack, 1.0, int_stack+1988242, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 1.0, int_stack+1559482, 0.0, zero_stack, 1.0, int_stack+2006134, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3849580,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3528910,int_stack+3849580,int_stack+3840130,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+256741,int_stack+255985, 0.0, zero_stack, 1.0, int_stack+813210, 0.0, zero_stack, 1.0, int_stack+876910, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3842398,int_stack+257749,int_stack+256741, 0.0, zero_stack, 1.0, int_stack+813966, 0.0, zero_stack, 1.0, int_stack+877666, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3842398,int_stack+3840130, 0.0, zero_stack, 1.0, int_stack+1563010, 0.0, zero_stack, 1.0, int_stack+2009662, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3845422,int_stack+259045,int_stack+257749, 0.0, zero_stack, 1.0, int_stack+814974, 0.0, zero_stack, 1.0, int_stack+878674, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3845422,int_stack+3842398, 0.0, zero_stack, 1.0, int_stack+1391605, 0.0, zero_stack, 1.0, int_stack+1838257, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3840130,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1605724, 0.0, zero_stack, 1.0, int_stack+2052376, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3862810,int_stack+3840130,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3862810,int_stack+3849580,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3880450,int_stack+3171070,int_stack+3528910,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+261610,int_stack+260665, 0.0, zero_stack, 1.0, int_stack+362565, 0.0, zero_stack, 1.0, int_stack+407915, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531745,int_stack+262870,int_stack+261610, 0.0, zero_stack, 1.0, int_stack+364455, 0.0, zero_stack, 1.0, int_stack+409805, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3535525,int_stack+3531745,int_stack+3528910, 0.0, zero_stack, 1.0, int_stack+1610260, 0.0, zero_stack, 1.0, int_stack+2056912, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3541195,int_stack+264490,int_stack+262870, 0.0, zero_stack, 1.0, int_stack+366975, 0.0, zero_stack, 1.0, int_stack+412325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3546055,int_stack+3541195,int_stack+3531745, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3553615,int_stack+3546055,int_stack+3535525, 0.0, zero_stack, 1.0, int_stack+1699468, 0.0, zero_stack, 1.0, int_stack+2146120, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3528910,int_stack+3553615,int_stack+3840130,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3911950,int_stack+3528910,int_stack+3862810,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3947230,int_stack+3911950,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+266830,int_stack+266515, 0.0, zero_stack, 1.0, int_stack+828420, 1.0, int_stack+860270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+267250,int_stack+266830, 0.0, zero_stack, 1.0, int_stack+828735, 1.0, int_stack+860585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+802255, 1.0, int_stack+834105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+267790,int_stack+267250, 0.0, zero_stack, 1.0, int_stack+829155, 1.0, int_stack+861005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+808310, 1.0, int_stack+840160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1749238, 1.0, int_stack+1974508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+268906,int_stack+268465, 0.0, zero_stack, 1.0, int_stack+832320, 1.0, int_stack+864170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+269494,int_stack+268906, 0.0, zero_stack, 1.0, int_stack+832761, 1.0, int_stack+864611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1751128, 1.0, int_stack+1976398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+270250,int_stack+269494, 0.0, zero_stack, 1.0, int_stack+833349, 1.0, int_stack+865199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1756798, 1.0, int_stack+1982068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+1758562, 1.0, int_stack+1983832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3911950,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+271783,int_stack+271195, 0.0, zero_stack, 1.0, int_stack+837780, 1.0, int_stack+869630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+272567,int_stack+271783, 0.0, zero_stack, 1.0, int_stack+838368, 1.0, int_stack+870218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1761208, 1.0, int_stack+1986478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+273575,int_stack+272567, 0.0, zero_stack, 1.0, int_stack+839152, 1.0, int_stack+871002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1762972, 1.0, int_stack+1988242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 1.0, int_stack+1780864, 1.0, int_stack+2006134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3921400,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3528910,int_stack+3921400,int_stack+3911950,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3911950,int_stack+275591,int_stack+274835, 0.0, zero_stack, 1.0, int_stack+845060, 1.0, int_stack+876910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3914218,int_stack+276599,int_stack+275591, 0.0, zero_stack, 1.0, int_stack+845816, 1.0, int_stack+877666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3914218,int_stack+3911950, 0.0, zero_stack, 1.0, int_stack+1784392, 1.0, int_stack+2009662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3917242,int_stack+277895,int_stack+276599, 0.0, zero_stack, 1.0, int_stack+846824, 1.0, int_stack+878674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3917242,int_stack+3914218, 0.0, zero_stack, 1.0, int_stack+1613095, 1.0, int_stack+1838257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3911950,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1827106, 1.0, int_stack+2052376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3840130,int_stack+3911950,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3840130,int_stack+3921400,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+245910,int_stack+3171070,int_stack+3528910,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528910,int_stack+280460,int_stack+279515, 0.0, zero_stack, 1.0, int_stack+385240, 1.0, int_stack+407915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3531745,int_stack+281720,int_stack+280460, 0.0, zero_stack, 1.0, int_stack+387130, 1.0, int_stack+409805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3535525,int_stack+3531745,int_stack+3528910, 0.0, zero_stack, 1.0, int_stack+1831642, 1.0, int_stack+2056912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3541195,int_stack+283340,int_stack+281720, 0.0, zero_stack, 1.0, int_stack+389650, 1.0, int_stack+412325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3546055,int_stack+3541195,int_stack+3531745, 0.0, zero_stack, 1.0, int_stack+1834477, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3553615,int_stack+3546055,int_stack+3535525, 0.0, zero_stack, 1.0, int_stack+1924738, 1.0, int_stack+2146120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3857770,int_stack+3553615,int_stack+3911950,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3911950,int_stack+3857770,int_stack+3840130,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3991330,int_stack+3911950,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+285680,int_stack+285365, 0.0, zero_stack, 2.0, int_stack+860270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+286100,int_stack+285680, 0.0, zero_stack, 2.0, int_stack+860585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 2.0, int_stack+834105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+286640,int_stack+286100, 0.0, zero_stack, 2.0, int_stack+861005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 2.0, int_stack+840160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 2.0, int_stack+1974508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+287756,int_stack+287315, 0.0, zero_stack, 2.0, int_stack+864170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+288344,int_stack+287756, 0.0, zero_stack, 2.0, int_stack+864611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 2.0, int_stack+1976398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+289100,int_stack+288344, 0.0, zero_stack, 2.0, int_stack+865199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 2.0, int_stack+1982068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3184426,int_stack+3180898,int_stack+3172393, 0.0, zero_stack, 2.0, int_stack+1983832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3911950,int_stack+3184426,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+290633,int_stack+290045, 0.0, zero_stack, 2.0, int_stack+869630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+291417,int_stack+290633, 0.0, zero_stack, 2.0, int_stack+870218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 2.0, int_stack+1986478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3176950,int_stack+292425,int_stack+291417, 0.0, zero_stack, 2.0, int_stack+871002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188836,int_stack+3176950,int_stack+3171070, 0.0, zero_stack, 2.0, int_stack+1988242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3176950,int_stack+3188836,int_stack+3173422, 0.0, zero_stack, 2.0, int_stack+2006134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3921400,int_stack+3176950,int_stack+3184426,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3840130,int_stack+3921400,int_stack+3911950,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3911950,int_stack+294441,int_stack+293685, 0.0, zero_stack, 2.0, int_stack+876910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3914218,int_stack+295449,int_stack+294441, 0.0, zero_stack, 2.0, int_stack+877666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+3914218,int_stack+3911950, 0.0, zero_stack, 2.0, int_stack+2009662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3917242,int_stack+296745,int_stack+295449, 0.0, zero_stack, 2.0, int_stack+878674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3182830,int_stack+3917242,int_stack+3914218, 0.0, zero_stack, 2.0, int_stack+1838257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3911950,int_stack+3182830,int_stack+3171070, 0.0, zero_stack, 2.0, int_stack+2052376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3859030,int_stack+3911950,int_stack+3176950,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3859030,int_stack+3921400,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3528910,int_stack+3171070,int_stack+3840130,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+299310,int_stack+298365, 0.0, zero_stack, 2.0, int_stack+407915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3876670,int_stack+300570,int_stack+299310, 0.0, zero_stack, 2.0, int_stack+409805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3842965,int_stack+3876670,int_stack+3840130, 0.0, zero_stack, 2.0, int_stack+2056912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3848635,int_stack+302190,int_stack+300570, 0.0, zero_stack, 2.0, int_stack+412325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3919510,int_stack+3848635,int_stack+3876670, 0.0, zero_stack, 2.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3848635,int_stack+3919510,int_stack+3842965, 0.0, zero_stack, 2.0, int_stack+2146120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3919510,int_stack+3848635,int_stack+3911950,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+3919510,int_stack+3859030,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4070710,int_stack+4035430,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+304530,int_stack+304215, 1.0, int_stack+732870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892120,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+304950,int_stack+304530, 1.0, int_stack+733185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892435,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 1.0, int_stack+1038820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865955,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+305490,int_stack+304950, 1.0, int_stack+733605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892855,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 1.0, int_stack+1039765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872010,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 1.0, int_stack+1041025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195890,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+306606,int_stack+306165, 1.0, int_stack+736770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896020,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+307194,int_stack+306606, 1.0, int_stack+737211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896461,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 1.0, int_stack+1052851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197780,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+307950,int_stack+307194, 1.0, int_stack+737799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897049,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3180898,int_stack+3178630,int_stack+2531158, 1.0, int_stack+1054174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2203450,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1038505,int_stack+3180898,int_stack+3172393, 1.0, int_stack+1055938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205214,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+1038505,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+309483,int_stack+308895, 1.0, int_stack+742230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901480,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3188080,int_stack+310267,int_stack+309483, 1.0, int_stack+742818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902068,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3190432,int_stack+3188080,int_stack+2531158, 1.0, int_stack+1081768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207860,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3193960,int_stack+311275,int_stack+310267, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902852,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1052851,int_stack+3193960,int_stack+3188080, 1.0, int_stack+1083532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209624,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3171070,int_stack+1052851,int_stack+3190432, 1.0, int_stack+1085884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227516,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+3171070,int_stack+1038505,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3178630,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1038505,int_stack+313291,int_stack+312535, 1.0, int_stack+749510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909516,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1052851,int_stack+314299,int_stack+313291, 1.0, int_stack+750266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911280,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1081768,int_stack+1052851,int_stack+1038505, 1.0, int_stack+1094704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231044,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1038505,int_stack+315595,int_stack+314299, 1.0, int_stack+751274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913584,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3176950,int_stack+1038505,int_stack+1052851, 1.0, int_stack+1139686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2059747,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3182998,int_stack+3176950,int_stack+1081768, 1.0, int_stack+1142710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273758,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3911950,int_stack+3182998,int_stack+3171070,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3840130,int_stack+3911950,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+277410,int_stack+3840130,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+320365,int_stack+318160, 1.0, int_stack+317215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431535,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3560410,int_stack+323245,int_stack+320365, 1.0, int_stack+319105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434685,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4038265,int_stack+3560410,int_stack+4035430, 1.0, int_stack+1153861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2278294,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4043935,int_stack+324865,int_stack+323245, 1.0, int_stack+321625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437205,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4048795,int_stack+4043935,int_stack+3560410, 1.0, int_stack+1246012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2281129,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4056355,int_stack+4048795,int_stack+4038265, 1.0, int_stack+1249792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371390,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4114810,int_stack+4056355,int_stack+3182998,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+4114810,int_stack+3911950,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4114810,int_stack+4035430,int_stack+3840130,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+327205,int_stack+326890, 1.0, int_stack+764720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892120, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+327625,int_stack+327205, 1.0, int_stack+765035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892435, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+1014615,int_stack+1004920, 1.0, int_stack+738555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865955, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+328165,int_stack+327625, 1.0, int_stack+765455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892855, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3842020,int_stack+1022575,int_stack+1014615, 1.0, int_stack+744610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872010, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3844540,int_stack+3842020,int_stack+3840130, 1.0, int_stack+1299562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195890, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1299562,int_stack+329281,int_stack+328840, 1.0, int_stack+768620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896020, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+329869,int_stack+329281, 1.0, int_stack+769061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896461, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+2531158,int_stack+1299562, 1.0, int_stack+1301452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197780, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1299562,int_stack+330625,int_stack+329869, 1.0, int_stack+769649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897049, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3847690,int_stack+1299562,int_stack+2531158, 1.0, int_stack+1307122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2203450, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1299562,int_stack+3847690,int_stack+3840130, 1.0, int_stack+1308886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205214, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3847690,int_stack+1299562,int_stack+3844540,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+332158,int_stack+331570, 1.0, int_stack+774080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901480, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3840130,int_stack+332942,int_stack+332158, 1.0, int_stack+774668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902068, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3842482,int_stack+3840130,int_stack+2531158, 1.0, int_stack+1311532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207860, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3857140,int_stack+333950,int_stack+332942, 1.0, int_stack+775452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902852, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3860164,int_stack+3857140,int_stack+3840130, 1.0, int_stack+1313296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209624, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3864868,int_stack+3860164,int_stack+3842482, 1.0, int_stack+1331188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227516, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+3864868,int_stack+1299562,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3847690,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1299562,int_stack+335966,int_stack+335210, 1.0, int_stack+781360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909516, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1331188,int_stack+336974,int_stack+335966, 1.0, int_stack+782116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911280, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+1331188,int_stack+1299562, 1.0, int_stack+1334716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231044, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1299562,int_stack+338270,int_stack+336974, 1.0, int_stack+783124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913584, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844666,int_stack+1299562,int_stack+1331188, 1.0, int_stack+1336984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2059747, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1331188,int_stack+3844666,int_stack+3840130, 1.0, int_stack+1380454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273758, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3840130,int_stack+1331188,int_stack+3864868,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3840130,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3911950,int_stack+3171070,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+343040,int_stack+340835, 1.0, int_stack+339890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431535, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3943450,int_stack+345920,int_stack+343040, 1.0, int_stack+341780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434685, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4038265,int_stack+3943450,int_stack+4035430, 1.0, int_stack+1384990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2278294, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4043935,int_stack+347540,int_stack+345920, 1.0, int_stack+344300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437205, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4048795,int_stack+4043935,int_stack+3943450, 1.0, int_stack+1387825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2281129, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4056355,int_stack+4048795,int_stack+4038265, 1.0, int_stack+1478086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371390, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3857770,int_stack+4056355,int_stack+1331188,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+3857770,int_stack+3840130,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4158910,int_stack+4035430,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+349880,int_stack+349565, 1.0, int_stack+796570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892120, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+350300,int_stack+349880, 1.0, int_stack+796885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892435, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 1.0, int_stack+770405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865955, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+350840,int_stack+350300, 1.0, int_stack+797305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892855, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 1.0, int_stack+776460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 1.0, int_stack+1527856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1527856,int_stack+351956,int_stack+351515, 1.0, int_stack+800470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896020, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+352544,int_stack+351956, 1.0, int_stack+800911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896461, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+2531158,int_stack+1527856, 1.0, int_stack+1529746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197780, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1527856,int_stack+353300,int_stack+352544, 1.0, int_stack+801499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897049, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+1527856,int_stack+2531158, 1.0, int_stack+1535416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2203450, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1527856,int_stack+3178630,int_stack+3171070, 1.0, int_stack+1537180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205214, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+1527856,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+354833,int_stack+354245, 1.0, int_stack+805930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901480, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+355617,int_stack+354833, 1.0, int_stack+806518, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902068, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 1.0, int_stack+1539826, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207860, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3188080,int_stack+356625,int_stack+355617, 1.0, int_stack+807302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902852, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3191104,int_stack+3188080,int_stack+3171070, 1.0, int_stack+1541590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209624, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1535416,int_stack+3191104,int_stack+3173422, 1.0, int_stack+1559482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227516, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+1535416,int_stack+1527856,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3178630,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1527856,int_stack+358641,int_stack+357885, 1.0, int_stack+813210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909516, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1559482,int_stack+359649,int_stack+358641, 1.0, int_stack+813966, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911280, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1559482,int_stack+1527856, 1.0, int_stack+1563010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231044, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1527856,int_stack+360945,int_stack+359649, 1.0, int_stack+814974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3175606,int_stack+1527856,int_stack+1559482, 1.0, int_stack+1391605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2059747, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1559482,int_stack+3175606,int_stack+3171070, 1.0, int_stack+1605724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273758, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+1559482,int_stack+1535416,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3840130,int_stack+3171070,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+308910,int_stack+3840130,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+365715,int_stack+363510, 1.0, int_stack+362565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431535, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3943450,int_stack+368595,int_stack+365715, 1.0, int_stack+364455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434685, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1478086,int_stack+3943450,int_stack+4035430, 1.0, int_stack+1610260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2278294, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4035430,int_stack+370215,int_stack+368595, 1.0, int_stack+366975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437205, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4040290,int_stack+4035430,int_stack+3943450, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2281129, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4047850,int_stack+4040290,int_stack+1478086, 1.0, int_stack+1699468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+340410,int_stack+4047850,int_stack+1559482,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+340410,int_stack+3171070,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4203010,int_stack+4035430,int_stack+3840130,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+372555,int_stack+372240, 1.0, int_stack+828420, 0.0, zero_stack, 1.0, int_stack+892120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+372975,int_stack+372555, 1.0, int_stack+828735, 0.0, zero_stack, 1.0, int_stack+892435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+1014615,int_stack+1004920, 1.0, int_stack+802255, 0.0, zero_stack, 1.0, int_stack+865955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+373515,int_stack+372975, 1.0, int_stack+829155, 0.0, zero_stack, 1.0, int_stack+892855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3842020,int_stack+1022575,int_stack+1014615, 1.0, int_stack+808310, 0.0, zero_stack, 1.0, int_stack+872010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3844540,int_stack+3842020,int_stack+3840130, 1.0, int_stack+1749238, 0.0, zero_stack, 1.0, int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1749238,int_stack+374631,int_stack+374190, 1.0, int_stack+832320, 0.0, zero_stack, 1.0, int_stack+896020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+375219,int_stack+374631, 1.0, int_stack+832761, 0.0, zero_stack, 1.0, int_stack+896461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+2531158,int_stack+1749238, 1.0, int_stack+1751128, 0.0, zero_stack, 1.0, int_stack+2197780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1749238,int_stack+375975,int_stack+375219, 1.0, int_stack+833349, 0.0, zero_stack, 1.0, int_stack+897049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3847690,int_stack+1749238,int_stack+2531158, 1.0, int_stack+1756798, 0.0, zero_stack, 1.0, int_stack+2203450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1749238,int_stack+3847690,int_stack+3840130, 1.0, int_stack+1758562, 0.0, zero_stack, 1.0, int_stack+2205214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3847690,int_stack+1749238,int_stack+3844540,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+377508,int_stack+376920, 1.0, int_stack+837780, 0.0, zero_stack, 1.0, int_stack+901480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3840130,int_stack+378292,int_stack+377508, 1.0, int_stack+838368, 0.0, zero_stack, 1.0, int_stack+902068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3842482,int_stack+3840130,int_stack+2531158, 1.0, int_stack+1761208, 0.0, zero_stack, 1.0, int_stack+2207860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3857140,int_stack+379300,int_stack+378292, 1.0, int_stack+839152, 0.0, zero_stack, 1.0, int_stack+902852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3860164,int_stack+3857140,int_stack+3840130, 1.0, int_stack+1762972, 0.0, zero_stack, 1.0, int_stack+2209624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3864868,int_stack+3860164,int_stack+3842482, 1.0, int_stack+1780864, 0.0, zero_stack, 1.0, int_stack+2227516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+3864868,int_stack+1749238,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3847690,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1749238,int_stack+381316,int_stack+380560, 1.0, int_stack+845060, 0.0, zero_stack, 1.0, int_stack+909516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1780864,int_stack+382324,int_stack+381316, 1.0, int_stack+845816, 0.0, zero_stack, 1.0, int_stack+911280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+1780864,int_stack+1749238, 1.0, int_stack+1784392, 0.0, zero_stack, 1.0, int_stack+2231044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1749238,int_stack+383620,int_stack+382324, 1.0, int_stack+846824, 0.0, zero_stack, 1.0, int_stack+913584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844666,int_stack+1749238,int_stack+1780864, 1.0, int_stack+1613095, 0.0, zero_stack, 1.0, int_stack+2059747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1780864,int_stack+3844666,int_stack+3840130, 1.0, int_stack+1827106, 0.0, zero_stack, 1.0, int_stack+2273758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3840130,int_stack+1780864,int_stack+3864868,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3840130,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+340410,int_stack+3171070,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+388390,int_stack+386185, 1.0, int_stack+385240, 0.0, zero_stack, 1.0, int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+391270,int_stack+388390, 1.0, int_stack+387130, 0.0, zero_stack, 1.0, int_stack+434685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1699468,int_stack+0,int_stack+4035430, 1.0, int_stack+1831642, 0.0, zero_stack, 1.0, int_stack+2278294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4035430,int_stack+392890,int_stack+391270, 1.0, int_stack+389650, 0.0, zero_stack, 1.0, int_stack+437205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4040290,int_stack+4035430,int_stack+0, 1.0, int_stack+1834477, 0.0, zero_stack, 1.0, int_stack+2281129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4047850,int_stack+4040290,int_stack+1699468, 1.0, int_stack+1924738, 0.0, zero_stack, 1.0, int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3857770,int_stack+4047850,int_stack+1780864,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+3857770,int_stack+3840130,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4247110,int_stack+4035430,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+395230,int_stack+394915, 1.0, int_stack+860270, 1.0, int_stack+892120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+395650,int_stack+395230, 1.0, int_stack+860585, 1.0, int_stack+892435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 1.0, int_stack+834105, 1.0, int_stack+865955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+396190,int_stack+395650, 1.0, int_stack+861005, 1.0, int_stack+892855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 1.0, int_stack+840160, 1.0, int_stack+872010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 1.0, int_stack+1974508, 1.0, int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1974508,int_stack+397306,int_stack+396865, 1.0, int_stack+864170, 1.0, int_stack+896020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+397894,int_stack+397306, 1.0, int_stack+864611, 1.0, int_stack+896461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+2531158,int_stack+1974508, 1.0, int_stack+1976398, 1.0, int_stack+2197780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1974508,int_stack+398650,int_stack+397894, 1.0, int_stack+865199, 1.0, int_stack+897049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+1974508,int_stack+2531158, 1.0, int_stack+1982068, 1.0, int_stack+2203450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1974508,int_stack+3178630,int_stack+3171070, 1.0, int_stack+1983832, 1.0, int_stack+2205214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+1974508,int_stack+3175480,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+400183,int_stack+399595, 1.0, int_stack+869630, 1.0, int_stack+901480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+400967,int_stack+400183, 1.0, int_stack+870218, 1.0, int_stack+902068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3173422,int_stack+3171070,int_stack+2531158, 1.0, int_stack+1986478, 1.0, int_stack+2207860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3188080,int_stack+401975,int_stack+400967, 1.0, int_stack+871002, 1.0, int_stack+902852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3191104,int_stack+3188080,int_stack+3171070, 1.0, int_stack+1988242, 1.0, int_stack+2209624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1982068,int_stack+3191104,int_stack+3173422, 1.0, int_stack+2006134, 1.0, int_stack+2227516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+1982068,int_stack+1974508,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3178630,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1974508,int_stack+403991,int_stack+403235, 1.0, int_stack+876910, 1.0, int_stack+909516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2006134,int_stack+404999,int_stack+403991, 1.0, int_stack+877666, 1.0, int_stack+911280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+2006134,int_stack+1974508, 1.0, int_stack+2009662, 1.0, int_stack+2231044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1974508,int_stack+406295,int_stack+404999, 1.0, int_stack+878674, 1.0, int_stack+913584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3175606,int_stack+1974508,int_stack+2006134, 1.0, int_stack+1838257, 1.0, int_stack+2059747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2006134,int_stack+3175606,int_stack+3171070, 1.0, int_stack+2052376, 1.0, int_stack+2273758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+2006134,int_stack+1982068,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3840130,int_stack+3171070,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+371910,int_stack+3840130,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+411065,int_stack+408860, 1.0, int_stack+407915, 1.0, int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+413945,int_stack+411065, 1.0, int_stack+409805, 1.0, int_stack+434685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1924738,int_stack+0,int_stack+4035430, 1.0, int_stack+2056912, 1.0, int_stack+2278294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4035430,int_stack+415565,int_stack+413945, 1.0, int_stack+412325, 1.0, int_stack+437205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4040290,int_stack+4035430,int_stack+0, 1.0, int_stack+3780, 1.0, int_stack+2281129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4047850,int_stack+4040290,int_stack+1924738, 1.0, int_stack+2146120, 1.0, int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4291210,int_stack+4047850,int_stack+2006134,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+4291210,int_stack+3171070,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4291210,int_stack+4035430,int_stack+3840130,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+417905,int_stack+417590, 2.0, int_stack+892120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+418325,int_stack+417905, 2.0, int_stack+892435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+1014615,int_stack+1004920, 2.0, int_stack+865955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+418865,int_stack+418325, 2.0, int_stack+892855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3842020,int_stack+1022575,int_stack+1014615, 2.0, int_stack+872010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3844540,int_stack+3842020,int_stack+3840130, 2.0, int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+419981,int_stack+419540, 2.0, int_stack+896020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+420569,int_stack+419981, 2.0, int_stack+896461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+2531158,int_stack+2195890, 2.0, int_stack+2197780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+421325,int_stack+420569, 2.0, int_stack+897049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3847690,int_stack+2195890,int_stack+2531158, 2.0, int_stack+2203450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+3847690,int_stack+3840130, 2.0, int_stack+2205214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3847690,int_stack+2195890,int_stack+3844540,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+422858,int_stack+422270, 2.0, int_stack+901480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3840130,int_stack+423642,int_stack+422858, 2.0, int_stack+902068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3842482,int_stack+3840130,int_stack+2531158, 2.0, int_stack+2207860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3857140,int_stack+424650,int_stack+423642, 2.0, int_stack+902852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3860164,int_stack+3857140,int_stack+3840130, 2.0, int_stack+2209624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3864868,int_stack+3860164,int_stack+3842482, 2.0, int_stack+2227516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4035430,int_stack+3864868,int_stack+2195890,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4048660,int_stack+4035430,int_stack+3847690,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+426666,int_stack+425910, 2.0, int_stack+909516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2227516,int_stack+427674,int_stack+426666, 2.0, int_stack+911280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3840130,int_stack+2227516,int_stack+2195890, 2.0, int_stack+2231044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+428970,int_stack+427674, 2.0, int_stack+913584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844666,int_stack+2195890,int_stack+2227516, 2.0, int_stack+2059747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3844666,int_stack+3840130, 2.0, int_stack+2273758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3840130,int_stack+0,int_stack+3864868,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3840130,int_stack+4035430,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+4335310,int_stack+3171070,int_stack+4048660,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4035430,int_stack+435945,int_stack+432480, 2.0, int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3943450,int_stack+438825,int_stack+435945, 2.0, int_stack+434685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2146120,int_stack+3943450,int_stack+4035430, 2.0, int_stack+2278294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4035430,int_stack+440445,int_stack+438825, 2.0, int_stack+437205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4040290,int_stack+4035430,int_stack+3943450, 2.0, int_stack+2281129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4047850,int_stack+4040290,int_stack+2146120, 2.0, int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3857770,int_stack+4047850,int_stack+0,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4035430,int_stack+3857770,int_stack+3840130,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4366810,int_stack+4035430,int_stack+3171070,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+442785,int_stack+442470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930855,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+443205,int_stack+442785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931170,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+443745,int_stack+443205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931590,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3173590,int_stack+3171070,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431535,int_stack+444861,int_stack+444420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934755,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+445449,int_stack+444861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935196,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3176740,int_stack+2531158,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3171070,int_stack+446205,int_stack+445449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935784,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3179386,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137040,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+3179386,int_stack+3176740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3176740,int_stack+2195890,int_stack+3173590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1047055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+447738,int_stack+447150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940215,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3186190,int_stack+448522,int_stack+447738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940803,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188542,int_stack+3186190,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3192070,int_stack+449530,int_stack+448522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+941587,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3192070,int_stack+3186190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150396,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4035430,int_stack+3171070,int_stack+3188542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2421160,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4041310,int_stack+4035430,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3840130,int_stack+4041310,int_stack+3176740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1068790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+451546,int_stack+450790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947495,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+452554,int_stack+451546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+948251,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+453850,int_stack+452554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949259,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060852,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+4035430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+403410,int_stack+3171070,int_stack+4041310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1103020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4035430,int_stack+403410,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1116250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+456415,int_stack+455470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549720,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+457675,int_stack+456415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551610,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+4066930,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2606002,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+459295,int_stack+457675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554130,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3852550,int_stack+3844990,int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695210,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+434685,int_stack+3852550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1157182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+434685,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1164742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4410910,int_stack+3840130,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+461635,int_stack+461320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930855, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+462055,int_stack+461635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931170, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+462595,int_stack+462055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931590, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403410,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+405930,int_stack+403410,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431535,int_stack+463711,int_stack+463270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934755, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+464299,int_stack+463711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935196, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409080,int_stack+2531158,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+403410,int_stack+465055,int_stack+464299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935784, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+411726,int_stack+403410,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137040, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+411726,int_stack+409080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+409080,int_stack+2195890,int_stack+405930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1303972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+466588,int_stack+466000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940215, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+418530,int_stack+467372,int_stack+466588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940803, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+420882,int_stack+418530,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+424410,int_stack+468380,int_stack+467372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+941587, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403410,int_stack+424410,int_stack+418530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150396, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424410,int_stack+403410,int_stack+420882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2421160, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3840130,int_stack+424410,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1317328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3853360,int_stack+3840130,int_stack+409080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+470396,int_stack+469640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947495, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403410,int_stack+471404,int_stack+470396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+948251, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+406434,int_stack+403410,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+472700,int_stack+471404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949259, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+410970,int_stack+2195890,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060852, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+410970,int_stack+406434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+403410,int_stack+0,int_stack+424410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1342444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+403410,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1348324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+434685,int_stack+3171070,int_stack+3853360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+475265,int_stack+474320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549720, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+476525,int_stack+475265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551610, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+4066930,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2606002, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+478145,int_stack+476525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554130, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3852550,int_stack+3844990,int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695210, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4455010,int_stack+3852550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1394926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+4455010,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1402486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4455010,int_stack+3840130,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1420126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+480485,int_stack+480170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930855, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+480905,int_stack+480485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931170, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+481445,int_stack+480905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3173590,int_stack+3171070,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431535,int_stack+482561,int_stack+482120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934755, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+483149,int_stack+482561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935196, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3176740,int_stack+2531158,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3171070,int_stack+483905,int_stack+483149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935784, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3179386,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137040, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+3179386,int_stack+3176740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3176740,int_stack+2195890,int_stack+3173590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1532266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+485438,int_stack+484850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940215, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3186190,int_stack+486222,int_stack+485438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940803, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188542,int_stack+3186190,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3192070,int_stack+487230,int_stack+486222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+941587, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3192070,int_stack+3186190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3840130,int_stack+3171070,int_stack+3188542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3846010,int_stack+3840130,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1545622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3859240,int_stack+3846010,int_stack+3176740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1550032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+489246,int_stack+488490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947495, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+490254,int_stack+489246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+948251, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+491550,int_stack+490254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949259, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+403410,int_stack+3171070,int_stack+3846010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1573594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4499110,int_stack+403410,int_stack+3859240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1586824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+494115,int_stack+493170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549720, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+495375,int_stack+494115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551610, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+4066930,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+496995,int_stack+495375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554130, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3852550,int_stack+3844990,int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+466185,int_stack+3852550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1616308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+466185,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1623868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4530610,int_stack+3840130,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1641508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+499335,int_stack+499020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+499755,int_stack+499335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+500295,int_stack+499755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403410,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+405930,int_stack+403410,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431535,int_stack+501411,int_stack+500970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+501999,int_stack+501411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409080,int_stack+2531158,int_stack+431535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+403410,int_stack+502755,int_stack+501999, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+935784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+411726,int_stack+403410,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+411726,int_stack+409080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+409080,int_stack+2195890,int_stack+405930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1753648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+504288,int_stack+503700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+418530,int_stack+505072,int_stack+504288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940803, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+420882,int_stack+418530,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+424410,int_stack+506080,int_stack+505072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+941587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403410,int_stack+424410,int_stack+418530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424410,int_stack+403410,int_stack+420882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3840130,int_stack+424410,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1767004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3853360,int_stack+3840130,int_stack+409080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1771414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+508096,int_stack+507340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403410,int_stack+509104,int_stack+508096, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+948251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+406434,int_stack+403410,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+510400,int_stack+509104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+410970,int_stack+2195890,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+410970,int_stack+406434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+403410,int_stack+0,int_stack+424410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1789096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+403410,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1794976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+466185,int_stack+3171070,int_stack+3853360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1808206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+512965,int_stack+512020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+514225,int_stack+512965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+4066930,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+515845,int_stack+514225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3852550,int_stack+3844990,int_stack+2371390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4574710,int_stack+3852550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+4574710,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1849138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4574710,int_stack+3840130,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1866778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+518185,int_stack+517870, 0.0, zero_stack, 1.0, int_stack+930855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+518605,int_stack+518185, 0.0, zero_stack, 1.0, int_stack+931170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+519145,int_stack+518605, 0.0, zero_stack, 1.0, int_stack+931590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3173590,int_stack+3171070,int_stack+431535, 0.0, zero_stack, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431535,int_stack+520261,int_stack+519820, 0.0, zero_stack, 1.0, int_stack+934755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+520849,int_stack+520261, 0.0, zero_stack, 1.0, int_stack+935196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3176740,int_stack+2531158,int_stack+431535, 0.0, zero_stack, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3171070,int_stack+521605,int_stack+520849, 0.0, zero_stack, 1.0, int_stack+935784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3179386,int_stack+3171070,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1137040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+3179386,int_stack+3176740, 0.0, zero_stack, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3176740,int_stack+2195890,int_stack+3173590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1978918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+523138,int_stack+522550, 0.0, zero_stack, 1.0, int_stack+940215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3186190,int_stack+523922,int_stack+523138, 0.0, zero_stack, 1.0, int_stack+940803, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188542,int_stack+3186190,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3192070,int_stack+524930,int_stack+523922, 0.0, zero_stack, 1.0, int_stack+941587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3192070,int_stack+3186190, 0.0, zero_stack, 1.0, int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3840130,int_stack+3171070,int_stack+3188542, 0.0, zero_stack, 1.0, int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3846010,int_stack+3840130,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1992274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3859240,int_stack+3846010,int_stack+3176740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1996684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+526946,int_stack+526190, 0.0, zero_stack, 1.0, int_stack+947495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+527954,int_stack+526946, 0.0, zero_stack, 1.0, int_stack+948251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+529250,int_stack+527954, 0.0, zero_stack, 1.0, int_stack+949259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1060852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094, 0.0, zero_stack, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2014366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+403410,int_stack+3171070,int_stack+3846010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2020246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+497685,int_stack+403410,int_stack+3859240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2033476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+531815,int_stack+530870, 0.0, zero_stack, 1.0, int_stack+549720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+533075,int_stack+531815, 0.0, zero_stack, 1.0, int_stack+551610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+4066930,int_stack+3840130, 0.0, zero_stack, 1.0, int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+534695,int_stack+533075, 0.0, zero_stack, 1.0, int_stack+554130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+4066930, 0.0, zero_stack, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3852550,int_stack+3844990,int_stack+2371390, 0.0, zero_stack, 1.0, int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4618810,int_stack+3852550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3840130,int_stack+4618810,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2070520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4618810,int_stack+3840130,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2088160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+537035,int_stack+536720, 1.0, int_stack+930855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+537455,int_stack+537035, 1.0, int_stack+931170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431535,int_stack+1014615,int_stack+1004920, 1.0, int_stack+430590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+537995,int_stack+537455, 1.0, int_stack+931590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403410,int_stack+1022575,int_stack+1014615, 1.0, int_stack+433425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+405930,int_stack+403410,int_stack+431535, 1.0, int_stack+1135150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1135150,int_stack+539111,int_stack+538670, 1.0, int_stack+934755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+539699,int_stack+539111, 1.0, int_stack+935196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409080,int_stack+2531158,int_stack+1135150, 1.0, int_stack+1240342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1240342,int_stack+540455,int_stack+539699, 1.0, int_stack+935784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1242610,int_stack+1240342,int_stack+2531158, 1.0, int_stack+1137040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+1242610,int_stack+409080, 1.0, int_stack+1050205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+409080,int_stack+2195890,int_stack+405930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2200300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+541988,int_stack+541400, 1.0, int_stack+940215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1050205,int_stack+542772,int_stack+541988, 1.0, int_stack+940803, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052557,int_stack+1050205,int_stack+2531158, 1.0, int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+418530,int_stack+543780,int_stack+542772, 1.0, int_stack+941587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+421554,int_stack+418530,int_stack+1050205, 1.0, int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1150396,int_stack+421554,int_stack+1052557, 1.0, int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+418530,int_stack+1150396,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2213656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+3840130,int_stack+418530,int_stack+409080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2218066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+545796,int_stack+545040, 1.0, int_stack+947495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+546804,int_stack+545796, 1.0, int_stack+948251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1050205,int_stack+2421160,int_stack+2195890, 1.0, int_stack+1058584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+548100,int_stack+546804, 1.0, int_stack+949259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1054741,int_stack+2195890,int_stack+2421160, 1.0, int_stack+1060852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+1054741,int_stack+1050205, 1.0, int_stack+1089412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3859030,int_stack+0,int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2235748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+3859030,int_stack+418530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2241628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4662910,int_stack+3171070,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3840130,int_stack+552870,int_stack+550665, 1.0, int_stack+549720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3876670,int_stack+555750,int_stack+552870, 1.0, int_stack+551610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2371390,int_stack+3876670,int_stack+3840130, 1.0, int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3840130,int_stack+557370,int_stack+555750, 1.0, int_stack+554130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3844990,int_stack+3840130,int_stack+3876670, 1.0, int_stack+1042915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1050205,int_stack+3844990,int_stack+2371390, 1.0, int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+1050205,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2288230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+3859030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2295790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4729690,int_stack+4694410,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2313430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+559710,int_stack+559395,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+560130,int_stack+559710,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+560670,int_stack+560130,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+561786,int_stack+561345,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+562374,int_stack+561786,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+1078240,int_stack+3171070,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+563130,int_stack+562374,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+1078240,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+3172393,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2195890,int_stack+3175480, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1147246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+564663,int_stack+564075,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+565447,int_stack+564663,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+1078240,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+566455,int_stack+565447,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+3191608,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2438548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4707640,int_stack+4694410,int_stack+3178630, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2564422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+568471,int_stack+567715,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+569479,int_stack+568471,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+570775,int_stack+569479,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+403410,int_stack+3171070,int_stack+4694410, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2573872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3840130,int_stack+403410,int_stack+4707640, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2587102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+573340,int_stack+572395,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+574600,int_stack+573340,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+576220,int_stack+574600,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+529185,int_stack+4706830,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2612050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+529185,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2619610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+529185,int_stack+4694410,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2637250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+578560,int_stack+578245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962705,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+578980,int_stack+578560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963020,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+403410,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936540,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+579520,int_stack+578980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963440,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+405300,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942595,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+407820,int_stack+405300,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744980,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403410,int_stack+580636,int_stack+580195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+966605,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+581224,int_stack+580636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967046,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+404733,int_stack+1078240,int_stack+403410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2746870,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+410970,int_stack+581980,int_stack+581224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967634,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+410970,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080004,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+404733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2752540,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+410970,int_stack+2195890,int_stack+407820, 0.0, zero_stack, 1.0, int_stack+1047055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+583513,int_stack+582925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972065,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+584297,int_stack+583513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972653,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+420420,int_stack+2421160,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2755186,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+423948,int_stack+585305,int_stack+584297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973437,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+426972,int_stack+423948,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2756950,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+403410,int_stack+426972,int_stack+420420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2774842,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+420420,int_stack+403410,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1064380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4694410,int_stack+420420,int_stack+410970, 0.0, zero_stack, 1.0, int_stack+1068790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+587321,int_stack+586565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979345,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+588329,int_stack+587321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+980101,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409290,int_stack+2421160,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2778370,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+589625,int_stack+588329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+981109,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+413826,int_stack+2195890,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2608837,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+413826,int_stack+409290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2821084,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+403410, 0.0, zero_stack, 1.0, int_stack+1097140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+420420, 0.0, zero_stack, 1.0, int_stack+1103020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4800250,int_stack+4773790,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+1116250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+592190,int_stack+591245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685495,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+593450,int_stack+592190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687385,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825620,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+595070,int_stack+593450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689905,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+4706830,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1157182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1164742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4831750,int_stack+4694410,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+1182382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+597410,int_stack+597095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962705, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+597830,int_stack+597410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963020, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936540, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+598370,int_stack+597830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963440, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942595, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744980, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+599486,int_stack+599045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+966605, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+600074,int_stack+599486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967046, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+1078240,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2746870, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4781350,int_stack+600830,int_stack+600074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967634, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+4781350,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080004, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+4775113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2752540, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2195890,int_stack+4778200, 0.0, zero_stack, 1.0, int_stack+1303972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+602363,int_stack+601775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972065, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+603147,int_stack+602363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972653, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4790800,int_stack+2421160,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2755186, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4794328,int_stack+604155,int_stack+603147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973437, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4773790,int_stack+4794328,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2756950, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4794328,int_stack+4773790,int_stack+4790800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2774842, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+4794328,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1317328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4707640,int_stack+4694410,int_stack+4781350, 0.0, zero_stack, 1.0, int_stack+1321738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+606171,int_stack+605415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979345, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+607179,int_stack+606171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+980101, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2778370, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+608475,int_stack+607179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+981109, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4781350,int_stack+2195890,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2608837, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+4781350,int_stack+4776814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2821084, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4773790,int_stack+0,int_stack+4794328, 0.0, zero_stack, 1.0, int_stack+1342444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+1348324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+573285,int_stack+3171070,int_stack+4707640, 0.0, zero_stack, 1.0, int_stack+1361554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+611040,int_stack+610095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685495, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+612300,int_stack+611040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687385, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825620, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+613920,int_stack+612300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689905, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2914828, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+4706830,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1394926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+1402486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4875850,int_stack+4694410,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1420126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+616260,int_stack+615945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962705, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+616680,int_stack+616260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963020, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936540, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+617220,int_stack+616680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963440, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942595, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+618336,int_stack+617895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+966605, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+618924,int_stack+618336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967046, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+1078240,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2746870, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+619680,int_stack+618924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967634, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080004, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2752540, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2195890,int_stack+3175480, 0.0, zero_stack, 1.0, int_stack+1532266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+621213,int_stack+620625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972065, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+621997,int_stack+621213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972653, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2755186, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+623005,int_stack+621997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973437, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2756950, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2774842, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+3191608,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1545622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4707640,int_stack+4694410,int_stack+3178630, 0.0, zero_stack, 1.0, int_stack+1550032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+625021,int_stack+624265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979345, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+626029,int_stack+625021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+980101, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2778370, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+627325,int_stack+626029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+981109, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2608837, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2821084, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 0.0, zero_stack, 1.0, int_stack+1567714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+1573594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4919950,int_stack+4773790,int_stack+4707640, 0.0, zero_stack, 1.0, int_stack+1586824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+629890,int_stack+628945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685495, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+631150,int_stack+629890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687385, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825620, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+632770,int_stack+631150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689905, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+4706830,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1616308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1623868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4951450,int_stack+4694410,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+1641508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+635110,int_stack+634795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+635530,int_stack+635110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+636070,int_stack+635530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+637186,int_stack+636745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+966605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+637774,int_stack+637186, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+1078240,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2746870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4781350,int_stack+638530,int_stack+637774, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+4781350,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+4775113, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2752540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2195890,int_stack+4778200, 0.0, zero_stack, 1.0, int_stack+1753648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+640063,int_stack+639475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+640847,int_stack+640063, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4790800,int_stack+2421160,int_stack+1078240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2755186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4794328,int_stack+641855,int_stack+640847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4773790,int_stack+4794328,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2756950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4794328,int_stack+4773790,int_stack+4790800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2774842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+4794328,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1767004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4707640,int_stack+4694410,int_stack+4781350, 0.0, zero_stack, 1.0, int_stack+1771414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+643871,int_stack+643115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+644879,int_stack+643871, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+980101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2195890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2778370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+646175,int_stack+644879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+981109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4781350,int_stack+2195890,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2608837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+4781350,int_stack+4776814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2821084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4773790,int_stack+0,int_stack+4794328, 0.0, zero_stack, 1.0, int_stack+1789096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+1794976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+604785,int_stack+3171070,int_stack+4707640, 0.0, zero_stack, 1.0, int_stack+1808206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+648740,int_stack+647795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+650000,int_stack+648740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+651620,int_stack+650000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+4706830,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1841578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+1849138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4995550,int_stack+4694410,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+1866778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+653960,int_stack+653645, 0.0, zero_stack, 1.0, int_stack+962705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+654380,int_stack+653960, 0.0, zero_stack, 1.0, int_stack+963020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+936540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+654920,int_stack+654380, 0.0, zero_stack, 1.0, int_stack+963440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+942595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+656036,int_stack+655595, 0.0, zero_stack, 1.0, int_stack+966605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+656624,int_stack+656036, 0.0, zero_stack, 1.0, int_stack+967046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+1078240,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2746870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+657380,int_stack+656624, 0.0, zero_stack, 1.0, int_stack+967634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+1078240, 0.0, zero_stack, 1.0, int_stack+1080004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2195890,int_stack+2421160,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+2752540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2195890,int_stack+3175480, 0.0, zero_stack, 1.0, int_stack+1978918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+658913,int_stack+658325, 0.0, zero_stack, 1.0, int_stack+972065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+659697,int_stack+658913, 0.0, zero_stack, 1.0, int_stack+972653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+1078240, 0.0, zero_stack, 1.0, int_stack+2755186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+660705,int_stack+659697, 0.0, zero_stack, 1.0, int_stack+973437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160, 0.0, zero_stack, 1.0, int_stack+2756950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080, 0.0, zero_stack, 1.0, int_stack+2774842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+3191608,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+1992274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4707640,int_stack+4694410,int_stack+3178630, 0.0, zero_stack, 1.0, int_stack+1996684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2195890,int_stack+662721,int_stack+661965, 0.0, zero_stack, 1.0, int_stack+979345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+663729,int_stack+662721, 0.0, zero_stack, 1.0, int_stack+980101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2195890, 0.0, zero_stack, 1.0, int_stack+2778370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2195890,int_stack+665025,int_stack+663729, 0.0, zero_stack, 1.0, int_stack+981109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3178630,int_stack+2195890,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2608837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3178630,int_stack+3174094, 0.0, zero_stack, 1.0, int_stack+2821084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 0.0, zero_stack, 1.0, int_stack+2014366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+2020246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+5039650,int_stack+4773790,int_stack+4707640, 0.0, zero_stack, 1.0, int_stack+2033476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2606002,int_stack+667590,int_stack+666645, 0.0, zero_stack, 1.0, int_stack+685495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+668850,int_stack+667590, 0.0, zero_stack, 1.0, int_stack+687385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+2606002, 0.0, zero_stack, 1.0, int_stack+2825620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+670470,int_stack+668850, 0.0, zero_stack, 1.0, int_stack+689905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 0.0, zero_stack, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4706830,int_stack+4699270,int_stack+2695210, 0.0, zero_stack, 1.0, int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+403410,int_stack+4706830,int_stack+0, 0.0, zero_stack, 1.0, int_stack+2062960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+403410,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2070520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5071150,int_stack+4694410,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+2088160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+672810,int_stack+672495, 1.0, int_stack+962705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+673230,int_stack+672810, 1.0, int_stack+963020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 1.0, int_stack+936540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+673770,int_stack+673230, 1.0, int_stack+963440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 1.0, int_stack+942595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 1.0, int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+674886,int_stack+674445, 1.0, int_stack+966605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1078240,int_stack+675474,int_stack+674886, 1.0, int_stack+967046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1078240,int_stack+2744980, 1.0, int_stack+2746870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+676230,int_stack+675474, 1.0, int_stack+967634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+2744980,int_stack+1078240, 1.0, int_stack+1080004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+4773790, 1.0, int_stack+2752540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1078240,int_stack+2744980,int_stack+4778200, 0.0, zero_stack, 1.0, int_stack+2200300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+677763,int_stack+677175, 1.0, int_stack+972065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2752540,int_stack+678547,int_stack+677763, 1.0, int_stack+972653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2421160,int_stack+2752540,int_stack+2531158, 1.0, int_stack+2755186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4773790,int_stack+679555,int_stack+678547, 1.0, int_stack+973437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2752540, 1.0, int_stack+2756950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2752540,int_stack+4776814,int_stack+2421160, 1.0, int_stack+2774842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4773790,int_stack+2752540,int_stack+2744980, 0.0, zero_stack, 1.0, int_stack+2213656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+4694410,int_stack+4773790,int_stack+1078240, 0.0, zero_stack, 1.0, int_stack+2218066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+681571,int_stack+680815, 1.0, int_stack+979345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1080508,int_stack+682579,int_stack+681571, 1.0, int_stack+980101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1083532,int_stack+1080508,int_stack+1078240, 1.0, int_stack+2778370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1088068,int_stack+683875,int_stack+682579, 1.0, int_stack+981109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2774842,int_stack+1088068,int_stack+1080508, 1.0, int_stack+2608837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2774842,int_stack+1083532, 1.0, int_stack+2821084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1078240,int_stack+0,int_stack+2752540, 0.0, zero_stack, 1.0, int_stack+2235748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+1078240,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+2241628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+636285,int_stack+3171070,int_stack+4694410, 0.0, zero_stack, 1.0, int_stack+2254858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4694410,int_stack+688645,int_stack+686440, 1.0, int_stack+685495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4066930,int_stack+691525,int_stack+688645, 1.0, int_stack+687385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2695210,int_stack+4066930,int_stack+4694410, 1.0, int_stack+2825620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4694410,int_stack+693145,int_stack+691525, 1.0, int_stack+689905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4699270,int_stack+4694410,int_stack+4066930, 1.0, int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1034725,int_stack+4699270,int_stack+2695210, 1.0, int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4694410,int_stack+1034725,int_stack+0, 0.0, zero_stack, 1.0, int_stack+2288230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5115250,int_stack+4694410,int_stack+1078240, 0.0, zero_stack, 1.0, int_stack+2295790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5150530,int_stack+5115250,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2313430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+695485,int_stack+695170,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+695905,int_stack+695485,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+696445,int_stack+695905,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+697561,int_stack+697120,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+698149,int_stack+697561,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+698905,int_stack+698149,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+2531158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+3172393,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2744980,int_stack+3175480, 0.0, zero_stack, 1.0, int_stack+1147246, 1.0, int_stack+2749390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+700438,int_stack+699850,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+701222,int_stack+700438,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+2531158,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+702230,int_stack+701222,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5115250,int_stack+3191608,int_stack+2744980, 0.0, zero_stack, 1.0, int_stack+2438548, 1.0, int_stack+2760982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1078240,int_stack+5115250,int_stack+3178630, 0.0, zero_stack, 1.0, int_stack+2564422, 1.0, int_stack+2765392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+704246,int_stack+703490,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+705254,int_stack+704246,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2744980,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+706550,int_stack+705254,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+3171070,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+3174094,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 0.0, zero_stack, 1.0, int_stack+7560, 1.0, int_stack+2783074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+5115250, 0.0, zero_stack, 1.0, int_stack+2573872, 1.0, int_stack+2788954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+5115250,int_stack+4773790,int_stack+1078240, 0.0, zero_stack, 1.0, int_stack+2587102, 1.0, int_stack+2802184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+709115,int_stack+708170,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+710375,int_stack+709115,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1078240,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1078240,int_stack+711995,int_stack+710375,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1083100,int_stack+1078240,int_stack+5146750,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4694410,int_stack+1083100,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4703860,int_stack+4694410,int_stack+0, 0.0, zero_stack, 1.0, int_stack+2612050, 1.0, int_stack+2831668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+667785,int_stack+4703860,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2619610, 1.0, int_stack+2839228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5194630,int_stack+667785,int_stack+4773790, 0.0, zero_stack, 1.0, int_stack+2637250, 1.0, int_stack+2856868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+714335,int_stack+714020,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+714755,int_stack+714335,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+715295,int_stack+714755,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+716411,int_stack+715970,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+716999,int_stack+716411,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+2531158,int_stack+4773790,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4781350,int_stack+717755,int_stack+716999,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+4781350,int_stack+2531158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+4775113,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2744980,int_stack+4778200, 0.0, zero_stack, 2.0, int_stack+2749390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+719288,int_stack+718700,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+720072,int_stack+719288,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4790800,int_stack+2421160,int_stack+2531158,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4794328,int_stack+721080,int_stack+720072,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4773790,int_stack+4794328,int_stack+2421160,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4794328,int_stack+4773790,int_stack+4790800,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+667785,int_stack+4794328,int_stack+2744980, 0.0, zero_stack, 2.0, int_stack+2760982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1078240,int_stack+667785,int_stack+4781350, 0.0, zero_stack, 2.0, int_stack+2765392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+723096,int_stack+722340,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+724104,int_stack+723096,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2744980,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+725400,int_stack+724104,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+4773790,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+4776814,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4773790,int_stack+0,int_stack+4794328, 0.0, zero_stack, 2.0, int_stack+2783074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+667785, 0.0, zero_stack, 2.0, int_stack+2788954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+667785,int_stack+3171070,int_stack+1078240, 0.0, zero_stack, 2.0, int_stack+2802184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1078240,int_stack+727965,int_stack+727020,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+729225,int_stack+727965,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1078240,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1078240,int_stack+730845,int_stack+729225,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1083100,int_stack+1078240,int_stack+5146750,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+699285,int_stack+1083100,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+708735,int_stack+699285,int_stack+0, 0.0, zero_stack, 2.0, int_stack+2831668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4694410,int_stack+708735,int_stack+4773790, 0.0, zero_stack, 2.0, int_stack+2839228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5238730,int_stack+4694410,int_stack+3171070, 0.0, zero_stack, 2.0, int_stack+2856868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+735135,int_stack+734820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996505,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+735555,int_stack+735135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996820,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968390,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+736095,int_stack+735555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+997240,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974445,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2964598,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+739941,int_stack+739500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003135,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+740529,int_stack+739941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003576,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2966488,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+741285,int_stack+740529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004164,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2972158,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2973922,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2744980,int_stack+3175480, 1.0, int_stack+1047055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+746458,int_stack+745870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012235,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+747242,int_stack+746458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012823,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2976568,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+748250,int_stack+747242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1013607,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2978332,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2996224,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4694410,int_stack+3191608,int_stack+2744980, 1.0, int_stack+1064380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1078240,int_stack+4694410,int_stack+3178630, 1.0, int_stack+1068790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+754946,int_stack+754190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019515,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+755954,int_stack+754946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1020271,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424688,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+757250,int_stack+755954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021279,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2426956,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+3174094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429980,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 1.0, int_stack+1097140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+4694410, 1.0, int_stack+1103020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4694410,int_stack+4773790,int_stack+1078240, 1.0, int_stack+1116250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725910,int_stack+759815,int_stack+758870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921180,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+761075,int_stack+759815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923070,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+4725910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037762,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2606002,int_stack+762695,int_stack+761075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925590,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3188710,int_stack+2606002,int_stack+5146750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2434516,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+699285,int_stack+3188710,int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13440,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+708735,int_stack+699285,int_stack+0, 1.0, int_stack+1157182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1034725,int_stack+708735,int_stack+3171070, 1.0, int_stack+1164742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+699285,int_stack+1034725,int_stack+4773790, 1.0, int_stack+1182382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+766985,int_stack+766670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996505, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+767405,int_stack+766985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996820, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968390, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+767945,int_stack+767405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+997240, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974445, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2964598, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+771791,int_stack+771350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003135, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+772379,int_stack+771791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003576, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+2531158,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2966488, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4781350,int_stack+773135,int_stack+772379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004164, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+4781350,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2972158, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+4775113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2973922, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2744980,int_stack+4778200, 1.0, int_stack+1303972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+778308,int_stack+777720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012235, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+779092,int_stack+778308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012823, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4790800,int_stack+2421160,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2976568, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4794328,int_stack+780100,int_stack+779092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1013607, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4773790,int_stack+4794328,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2978332, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4794328,int_stack+4773790,int_stack+4790800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2996224, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1034725,int_stack+4794328,int_stack+2744980, 1.0, int_stack+1317328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1047955,int_stack+1034725,int_stack+4781350, 1.0, int_stack+1321738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+786796,int_stack+786040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019515, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+787804,int_stack+786796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1020271, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+789100,int_stack+787804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021279, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2426956, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+4776814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429980, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4773790,int_stack+0,int_stack+4794328, 1.0, int_stack+1342444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+1034725, 1.0, int_stack+1348324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1066855,int_stack+3171070,int_stack+1047955, 1.0, int_stack+1361554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1034725,int_stack+791665,int_stack+790720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921180, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+792925,int_stack+791665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923070, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1034725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037762, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1034725,int_stack+794545,int_stack+792925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925590, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1039585,int_stack+1034725,int_stack+5146750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2434516, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1047145,int_stack+1039585,int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13440, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1098355,int_stack+1047145,int_stack+0, 1.0, int_stack+1394926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+743385,int_stack+1098355,int_stack+4773790, 1.0, int_stack+1402486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1098355,int_stack+743385,int_stack+3171070, 1.0, int_stack+1420126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+798835,int_stack+798520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996505, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+799255,int_stack+798835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996820, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968390, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+799795,int_stack+799255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+997240, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974445, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2964598, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+803641,int_stack+803200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003135, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+804229,int_stack+803641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003576, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2966488, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+804985,int_stack+804229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004164, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2972158, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+3172393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2973922, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2744980,int_stack+3175480, 1.0, int_stack+1532266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+810158,int_stack+809570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012235, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+810942,int_stack+810158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012823, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2976568, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+811950,int_stack+810942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1013607, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2978332, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2996224, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+743385,int_stack+3191608,int_stack+2744980, 1.0, int_stack+1545622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+756615,int_stack+743385,int_stack+3178630, 1.0, int_stack+1550032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+818646,int_stack+817890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019515, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+819654,int_stack+818646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1020271, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+820950,int_stack+819654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021279, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+3171070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2426956, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+3174094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429980, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 1.0, int_stack+1567714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+743385, 1.0, int_stack+1573594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+775515,int_stack+4773790,int_stack+756615, 1.0, int_stack+1586824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+743385,int_stack+823515,int_stack+822570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921180, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+824775,int_stack+823515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923070, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+743385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037762, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+743385,int_stack+826395,int_stack+824775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925590, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+748245,int_stack+743385,int_stack+5146750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2434516, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+755805,int_stack+748245,int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13440, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+807015,int_stack+755805,int_stack+0, 1.0, int_stack+1616308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1150396,int_stack+807015,int_stack+3171070, 1.0, int_stack+1623868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1527856,int_stack+1150396,int_stack+4773790, 1.0, int_stack+1641508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+830685,int_stack+830370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+831105,int_stack+830685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+831645,int_stack+831105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+997240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2964598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+835491,int_stack+835050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+836079,int_stack+835491, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+2531158,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2966488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4781350,int_stack+836835,int_stack+836079, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+4781350,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2972158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+4775113, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2973922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2744980,int_stack+4778200, 1.0, int_stack+1753648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+842008,int_stack+841420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+842792,int_stack+842008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4790800,int_stack+2421160,int_stack+2531158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2976568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4794328,int_stack+843800,int_stack+842792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1013607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4773790,int_stack+4794328,int_stack+2421160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2978332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4794328,int_stack+4773790,int_stack+4790800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2996224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1150396,int_stack+4794328,int_stack+2744980, 1.0, int_stack+1767004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1163626,int_stack+1150396,int_stack+4781350, 1.0, int_stack+1771414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+850496,int_stack+849740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+851504,int_stack+850496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1020271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4776814,int_stack+4773790,int_stack+2744980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+852800,int_stack+851504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+4773790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2426956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+4776814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4773790,int_stack+0,int_stack+4794328, 1.0, int_stack+1789096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+1150396, 1.0, int_stack+1794976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+807015,int_stack+3171070,int_stack+1163626, 1.0, int_stack+1808206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1150396,int_stack+855365,int_stack+854420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+856625,int_stack+855365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1150396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1150396,int_stack+858245,int_stack+856625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1155256,int_stack+1150396,int_stack+5146750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2434516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1162816,int_stack+1155256,int_stack+2914828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1172266,int_stack+1162816,int_stack+0, 1.0, int_stack+1841578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1749238,int_stack+1172266,int_stack+4773790, 1.0, int_stack+1849138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1150396,int_stack+1749238,int_stack+3171070, 1.0, int_stack+1866778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+862535,int_stack+862220, 0.0, zero_stack, 1.0, int_stack+996505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+862955,int_stack+862535, 0.0, zero_stack, 1.0, int_stack+996820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+1014615,int_stack+1004920, 0.0, zero_stack, 1.0, int_stack+968390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+863495,int_stack+862955, 0.0, zero_stack, 1.0, int_stack+997240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3172960,int_stack+1022575,int_stack+1014615, 0.0, zero_stack, 1.0, int_stack+974445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3175480,int_stack+3172960,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2964598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+867341,int_stack+866900, 0.0, zero_stack, 1.0, int_stack+1003135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+867929,int_stack+867341, 0.0, zero_stack, 1.0, int_stack+1003576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2966488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3178630,int_stack+868685,int_stack+867929, 0.0, zero_stack, 1.0, int_stack+1004164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+3178630,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+2972158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2744980,int_stack+2421160,int_stack+3172393, 0.0, zero_stack, 1.0, int_stack+2973922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3178630,int_stack+2744980,int_stack+3175480, 1.0, int_stack+1978918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+873858,int_stack+873270, 0.0, zero_stack, 1.0, int_stack+1012235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421160,int_stack+874642,int_stack+873858, 0.0, zero_stack, 1.0, int_stack+1012823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3188080,int_stack+2421160,int_stack+2531158, 0.0, zero_stack, 1.0, int_stack+2976568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3191608,int_stack+875650,int_stack+874642, 0.0, zero_stack, 1.0, int_stack+1013607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+3191608,int_stack+2421160, 0.0, zero_stack, 1.0, int_stack+2978332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3191608,int_stack+3171070,int_stack+3188080, 0.0, zero_stack, 1.0, int_stack+2996224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1749238,int_stack+3191608,int_stack+2744980, 1.0, int_stack+1992274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1762468,int_stack+1749238,int_stack+3178630, 1.0, int_stack+1996684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2744980,int_stack+882346,int_stack+881590, 0.0, zero_stack, 1.0, int_stack+1019515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+883354,int_stack+882346, 0.0, zero_stack, 1.0, int_stack+1020271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2744980, 0.0, zero_stack, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2744980,int_stack+884650,int_stack+883354, 0.0, zero_stack, 1.0, int_stack+1021279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2744980,int_stack+3171070, 0.0, zero_stack, 1.0, int_stack+2426956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+3174094, 0.0, zero_stack, 1.0, int_stack+2429980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3171070,int_stack+0,int_stack+3191608, 1.0, int_stack+2014366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+3171070,int_stack+1749238, 1.0, int_stack+2020246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1781368,int_stack+4773790,int_stack+1762468, 1.0, int_stack+2033476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1749238,int_stack+887215,int_stack+886270, 0.0, zero_stack, 1.0, int_stack+921180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+888475,int_stack+887215, 0.0, zero_stack, 1.0, int_stack+923070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1749238, 0.0, zero_stack, 1.0, int_stack+3037762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1749238,int_stack+890095,int_stack+888475, 0.0, zero_stack, 1.0, int_stack+925590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1754098,int_stack+1749238,int_stack+5146750, 0.0, zero_stack, 1.0, int_stack+2434516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1761658,int_stack+1754098,int_stack+2914828, 0.0, zero_stack, 1.0, int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1812868,int_stack+1761658,int_stack+0, 1.0, int_stack+2062960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1835548,int_stack+1812868,int_stack+3171070, 1.0, int_stack+2070520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+838515,int_stack+1835548,int_stack+4773790, 1.0, int_stack+2088160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1004920,int_stack+894385,int_stack+894070, 1.0, int_stack+996505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1014615,int_stack+894805,int_stack+894385, 1.0, int_stack+996820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+1014615,int_stack+1004920, 1.0, int_stack+968390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022575,int_stack+895345,int_stack+894805, 1.0, int_stack+997240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4775680,int_stack+1022575,int_stack+1014615, 1.0, int_stack+974445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4778200,int_stack+4775680,int_stack+4773790, 1.0, int_stack+2964598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2964598,int_stack+899191,int_stack+898750, 1.0, int_stack+1003135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+899779,int_stack+899191, 1.0, int_stack+1003576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4773790,int_stack+2531158,int_stack+2964598, 1.0, int_stack+2966488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2964598,int_stack+900535,int_stack+899779, 1.0, int_stack+1004164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2421160,int_stack+2964598,int_stack+2531158, 1.0, int_stack+2972158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2964598,int_stack+2421160,int_stack+4773790, 1.0, int_stack+2973922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4781350,int_stack+2964598,int_stack+4778200, 1.0, int_stack+2200300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+905708,int_stack+905120, 1.0, int_stack+1012235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4773790,int_stack+906492,int_stack+905708, 1.0, int_stack+1012823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2421160,int_stack+4773790,int_stack+2531158, 1.0, int_stack+2976568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4776142,int_stack+907500,int_stack+906492, 1.0, int_stack+1013607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2972158,int_stack+4776142,int_stack+4773790, 1.0, int_stack+2978332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4773790,int_stack+2972158,int_stack+2421160, 1.0, int_stack+2996224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3171070,int_stack+4773790,int_stack+2964598, 1.0, int_stack+2213656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1812868,int_stack+3171070,int_stack+4781350, 1.0, int_stack+2218066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2964598,int_stack+917256,int_stack+916500, 1.0, int_stack+1019515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2996224,int_stack+918264,int_stack+917256, 1.0, int_stack+1020271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2972158,int_stack+2996224,int_stack+2964598, 1.0, int_stack+2424688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2964598,int_stack+919560,int_stack+918264, 1.0, int_stack+1021279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2606002,int_stack+2964598,int_stack+2996224, 1.0, int_stack+2426956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+2606002,int_stack+2972158, 1.0, int_stack+2429980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4779670,int_stack+0,int_stack+4773790, 1.0, int_stack+2235748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1831768,int_stack+4779670,int_stack+3171070, 1.0, int_stack+2241628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1858228,int_stack+1831768,int_stack+1812868, 1.0, int_stack+2254858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1812868,int_stack+924330,int_stack+922125, 1.0, int_stack+921180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+927210,int_stack+924330, 1.0, int_stack+923070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+1812868, 1.0, int_stack+3037762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3037762,int_stack+928830,int_stack+927210, 1.0, int_stack+925590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1812868,int_stack+3037762,int_stack+5146750, 1.0, int_stack+2434516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1820428,int_stack+1812868,int_stack+2914828, 1.0, int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3171070,int_stack+1820428,int_stack+0, 1.0, int_stack+2288230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+882615,int_stack+3171070,int_stack+4779670, 1.0, int_stack+2295790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2195890,int_stack+882615,int_stack+1831768, 1.0, int_stack+2313430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+882615,int_stack+933120,int_stack+932805,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+883560,int_stack+933540,int_stack+933120,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+884820,int_stack+883560,int_stack+882615,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+886710,int_stack+934080,int_stack+933540,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+888330,int_stack+886710,int_stack+883560,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+890850,int_stack+888330,int_stack+884820,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+882615,int_stack+937926,int_stack+937485,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+938514,int_stack+937926,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+883938,int_stack+2531158,int_stack+882615,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+886584,int_stack+939270,int_stack+938514,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2996224,int_stack+886584,int_stack+2531158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2964598,int_stack+2996224,int_stack+883938,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+894000,int_stack+2964598,int_stack+890850, 1.0, int_stack+1147246, 0.0, zero_stack, 1.0, int_stack+2969008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+944443,int_stack+943855,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2996224,int_stack+945227,int_stack+944443,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+882615,int_stack+2996224,int_stack+2531158,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+886143,int_stack+946235,int_stack+945227,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+889167,int_stack+886143,int_stack+2996224,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+903450,int_stack+889167,int_stack+882615,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+909330,int_stack+903450,int_stack+2964598, 1.0, int_stack+2438548, 0.0, zero_stack, 1.0, int_stack+2982364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+922560,int_stack+909330,int_stack+894000, 1.0, int_stack+2564422, 0.0, zero_stack, 1.0, int_stack+2986774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2564422,int_stack+952931,int_stack+952175,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2566690,int_stack+953939,int_stack+952931,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+882615,int_stack+2566690,int_stack+2564422,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2569714,int_stack+955235,int_stack+953939,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3037762,int_stack+2569714,int_stack+2566690,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+3037762,int_stack+882615,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+882615,int_stack+0,int_stack+903450, 1.0, int_stack+7560, 0.0, zero_stack, 1.0, int_stack+2999752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+882615,int_stack+909330, 1.0, int_stack+2573872, 0.0, zero_stack, 1.0, int_stack+3005632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1812868,int_stack+3171070,int_stack+922560, 1.0, int_stack+2587102, 0.0, zero_stack, 1.0, int_stack+3018862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+957800,int_stack+956855,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+959060,int_stack+957800,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+7560,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7560,int_stack+960680,int_stack+959060,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+900255,int_stack+7560,int_stack+5146750,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7560,int_stack+900255,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+900255,int_stack+7560,int_stack+0, 1.0, int_stack+2612050, 0.0, zero_stack, 1.0, int_stack+3043810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+922935,int_stack+900255,int_stack+882615, 1.0, int_stack+2619610, 0.0, zero_stack, 1.0, int_stack+3051370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2564422,int_stack+922935,int_stack+3171070, 1.0, int_stack+2637250, 0.0, zero_stack, 1.0, int_stack+3069010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+964970,int_stack+964655,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3172015,int_stack+965390,int_stack+964970,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3173275,int_stack+3172015,int_stack+3171070,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3175165,int_stack+965930,int_stack+965390,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3176785,int_stack+3175165,int_stack+3172015,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3179305,int_stack+3176785,int_stack+3173275,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3171070,int_stack+969776,int_stack+969335,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+970364,int_stack+969776,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3172393,int_stack+2531158,int_stack+3171070,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3175039,int_stack+971120,int_stack+970364,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2996224,int_stack+3175039,int_stack+2531158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2964598,int_stack+2996224,int_stack+3172393,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3182455,int_stack+2964598,int_stack+3179305, 1.0, int_stack+2749390, 1.0, int_stack+2969008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+976293,int_stack+975705,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2996224,int_stack+977077,int_stack+976293,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3171070,int_stack+2996224,int_stack+2531158,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3174598,int_stack+978085,int_stack+977077,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3177622,int_stack+3174598,int_stack+2996224,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+882615,int_stack+3177622,int_stack+3171070,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+888495,int_stack+882615,int_stack+2964598, 1.0, int_stack+2760982, 1.0, int_stack+2982364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+901725,int_stack+888495,int_stack+3182455, 1.0, int_stack+2765392, 1.0, int_stack+2986774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2964598,int_stack+984781,int_stack+984025,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3171070,int_stack+985789,int_stack+984781,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3174094,int_stack+3171070,int_stack+2964598,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2964598,int_stack+987085,int_stack+985789,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3037762,int_stack+2964598,int_stack+3171070,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3178630,int_stack+3037762,int_stack+3174094,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+920625,int_stack+3178630,int_stack+882615, 1.0, int_stack+2783074, 1.0, int_stack+2999752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4773790,int_stack+920625,int_stack+888495, 1.0, int_stack+2788954, 1.0, int_stack+3005632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+938265,int_stack+4773790,int_stack+901725, 1.0, int_stack+2802184, 1.0, int_stack+3018862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+882615,int_stack+989650,int_stack+988705,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+990910,int_stack+989650,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+882615,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+882615,int_stack+992530,int_stack+990910,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3171070,int_stack+882615,int_stack+5146750,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+882615,int_stack+3171070,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+892065,int_stack+882615,int_stack+3178630, 1.0, int_stack+2831668, 1.0, int_stack+3043810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2608522,int_stack+892065,int_stack+920625, 1.0, int_stack+2839228, 1.0, int_stack+3051370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+882615,int_stack+2608522,int_stack+4773790, 1.0, int_stack+2856868, 1.0, int_stack+3069010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+998770,int_stack+998455,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4774735,int_stack+999190,int_stack+998770,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4775995,int_stack+4774735,int_stack+4773790,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4777885,int_stack+999730,int_stack+999190,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4779505,int_stack+4777885,int_stack+4774735,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4782025,int_stack+4779505,int_stack+4775995,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4773790,int_stack+1006306,int_stack+1005865,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2531158,int_stack+1006894,int_stack+1006306,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4775113,int_stack+2531158,int_stack+4773790,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4777759,int_stack+1007650,int_stack+1006894,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2996224,int_stack+4777759,int_stack+2531158,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2964598,int_stack+2996224,int_stack+4775113,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+4785175,int_stack+2964598,int_stack+4782025, 2.0, int_stack+2969008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2531158,int_stack+1016463,int_stack+1015875,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2969008,int_stack+1017247,int_stack+1016463,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2996224,int_stack+2969008,int_stack+2531158,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2971360,int_stack+1018255,int_stack+1017247,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2974384,int_stack+2971360,int_stack+2969008,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4773790,int_stack+2974384,int_stack+2996224,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2969008,int_stack+4773790,int_stack+2964598, 2.0, int_stack+2982364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2608522,int_stack+2969008,int_stack+4785175, 2.0, int_stack+2986774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2964598,int_stack+1024951,int_stack+1024195,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2982238,int_stack+1025959,int_stack+1024951,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2985262,int_stack+2982238,int_stack+2964598,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2964598,int_stack+1027255,int_stack+1025959,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3037762,int_stack+2964598,int_stack+2982238,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2989798,int_stack+3037762,int_stack+2985262,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4779670,int_stack+2989798,int_stack+4773790, 2.0, int_stack+2999752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3171070,int_stack+4779670,int_stack+2969008, 2.0, int_stack+3005632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2627422,int_stack+3171070,int_stack+2608522, 2.0, int_stack+3018862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2608522,int_stack+1029820,int_stack+1028875,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5146750,int_stack+1031080,int_stack+1029820,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2914828,int_stack+5146750,int_stack+2608522,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2608522,int_stack+1032700,int_stack+1031080,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2613382,int_stack+2608522,int_stack+5146750,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2964598,int_stack+2613382,int_stack+2914828,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2997358,int_stack+2964598,int_stack+2989798, 2.0, int_stack+3043810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+969765,int_stack+2997358,int_stack+4779670, 2.0, int_stack+3051370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2964598,int_stack+969765,int_stack+3171070, 2.0, int_stack+3069010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+969765,int_stack+1255462,int_stack+1208842,210);
     Libderiv->ABCD[11] = int_stack + 969765;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1017015,int_stack+1483756,int_stack+1446586,210);
     Libderiv->ABCD[10] = int_stack + 1017015;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3008698,int_stack+1705138,int_stack+1667968,210);
     Libderiv->ABCD[9] = int_stack + 3008698;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+2744980,int_stack+1930408,int_stack+1893238,210);
     Libderiv->ABCD[8] = int_stack + 2744980;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+2792230,int_stack+2151790,int_stack+2114620,210);
     Libderiv->ABCD[7] = int_stack + 2792230;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+2239990,int_stack+2377060,int_stack+2339890,210);
     Libderiv->ABCD[6] = int_stack + 2239990;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2287240,int_stack+2700880,int_stack+2663710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2532922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 2287240;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2695210,int_stack+2920498,int_stack+2883328, 0.0, zero_stack, 1.0, int_stack+2532922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 2695210;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2914828,int_stack+3126970,int_stack+3095470, 1.0, int_stack+2532922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 2914828;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3126970,int_stack+2442958,int_stack+3197530,210);
     Libderiv->ABCD[155] = int_stack + 3126970;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3174220,int_stack+3260530,int_stack+3229030,210);
     Libderiv->ABCD[143] = int_stack + 3174220;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3221470,int_stack+2487058,int_stack+3304630,210);
     Libderiv->ABCD[142] = int_stack + 3221470;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3268720,int_stack+50610,int_stack+19110,210);
     Libderiv->ABCD[131] = int_stack + 3268720;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+0,int_stack+3367630,int_stack+3336130,210);
     Libderiv->ABCD[130] = int_stack + 0;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3315970,int_stack+3411730,int_stack+94710,210);
     Libderiv->ABCD[129] = int_stack + 3315970;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3363220,int_stack+3564190,int_stack+3497410,210);
     Libderiv->ABCD[119] = int_stack + 3363220;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+47250,int_stack+126210,int_stack+3455830,210);
     Libderiv->ABCD[118] = int_stack + 47250;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3410470,int_stack+3676330,int_stack+3644830,210);
     Libderiv->ABCD[117] = int_stack + 3410470;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3457720,int_stack+3720430,int_stack+170310,210);
     Libderiv->ABCD[116] = int_stack + 3457720;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+94500,int_stack+3796030,int_stack+3764530,210);
     Libderiv->ABCD[107] = int_stack + 94500;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+141750,int_stack+201810,int_stack+3608290,210);
     Libderiv->ABCD[106] = int_stack + 141750;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+189000,int_stack+3947230,int_stack+3880450,210);
     Libderiv->ABCD[105] = int_stack + 189000;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+2371390,int_stack+3991330,int_stack+245910,210);
     Libderiv->ABCD[104] = int_stack + 2371390;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+2418640,int_stack+4070710,int_stack+3528910,210);
     Libderiv->ABCD[103] = int_stack + 2418640;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3504970,int_stack+4114810,int_stack+277410,210);
     Libderiv->ABCD[95] = int_stack + 3504970;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3552220,int_stack+4158910,int_stack+3911950,210);
     Libderiv->ABCD[94] = int_stack + 3552220;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3599470,int_stack+4203010,int_stack+308910,210);
     Libderiv->ABCD[93] = int_stack + 3599470;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3646720,int_stack+4247110,int_stack+340410,210);
     Libderiv->ABCD[92] = int_stack + 3646720;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3693970,int_stack+4291210,int_stack+371910,210);
     Libderiv->ABCD[91] = int_stack + 3693970;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3741220,int_stack+4366810,int_stack+4335310,210);
     Libderiv->ABCD[90] = int_stack + 3741220;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3788470,int_stack+4410910,int_stack+4035430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1208842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[47] = int_stack + 3788470;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+236250,int_stack+4455010,int_stack+434685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[46] = int_stack + 236250;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+283500,int_stack+4530610,int_stack+4499110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[45] = int_stack + 283500;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+330750,int_stack+4574710,int_stack+466185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1893238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[44] = int_stack + 330750;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+378000,int_stack+4618810,int_stack+497685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2114620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[43] = int_stack + 378000;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+425250,int_stack+4729690,int_stack+4662910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2339890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[42] = int_stack + 425250;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+472500,int_stack+529185,int_stack+3840130, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2663710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[38] = int_stack + 472500;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3835720,int_stack+4831750,int_stack+4800250, 0.0, zero_stack, 1.0, int_stack+1208842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[35] = int_stack + 3835720;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3882970,int_stack+4875850,int_stack+573285, 0.0, zero_stack, 1.0, int_stack+1446586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[34] = int_stack + 3882970;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3930220,int_stack+4951450,int_stack+4919950, 0.0, zero_stack, 1.0, int_stack+1667968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[33] = int_stack + 3930220;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3977470,int_stack+4995550,int_stack+604785, 0.0, zero_stack, 1.0, int_stack+1893238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[32] = int_stack + 3977470;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4024720,int_stack+5071150,int_stack+5039650, 0.0, zero_stack, 1.0, int_stack+2114620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[31] = int_stack + 4024720;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4071970,int_stack+5150530,int_stack+636285, 0.0, zero_stack, 1.0, int_stack+2339890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[30] = int_stack + 4071970;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4119220,int_stack+5194630,int_stack+5115250, 0.0, zero_stack, 1.0, int_stack+2663710, 1.0, int_stack+2883328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[26] = int_stack + 4119220;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4166470,int_stack+5238730,int_stack+667785, 0.0, zero_stack, 2.0, int_stack+2883328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[25] = int_stack + 4166470;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4213720,int_stack+699285,int_stack+4694410, 1.0, int_stack+1208842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[23] = int_stack + 4213720;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4260970,int_stack+1098355,int_stack+1066855, 1.0, int_stack+1446586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[22] = int_stack + 4260970;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4308220,int_stack+1527856,int_stack+775515, 1.0, int_stack+1667968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[21] = int_stack + 4308220;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4355470,int_stack+1150396,int_stack+807015, 1.0, int_stack+1893238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[20] = int_stack + 4355470;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4402720,int_stack+838515,int_stack+1781368, 1.0, int_stack+2114620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[19] = int_stack + 4402720;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4449970,int_stack+2195890,int_stack+1858228, 1.0, int_stack+2339890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[18] = int_stack + 4449970;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4497220,int_stack+2564422,int_stack+1812868, 1.0, int_stack+2663710, 0.0, zero_stack, 1.0, int_stack+3095470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[14] = int_stack + 4497220;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4544470,int_stack+882615,int_stack+938265, 1.0, int_stack+2883328, 1.0, int_stack+3095470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[13] = int_stack + 4544470;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4591720,int_stack+2964598,int_stack+2627422, 2.0, int_stack+3095470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[12] = int_stack + 4591720;

}
