/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gpgf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|gf) integrals */

void d12hrr_order_gpgf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][7][11] = int_stack + 0;
 Libderiv->deriv_classes[5][7][10] = int_stack + 756;
 Libderiv->deriv_classes[5][7][9] = int_stack + 1512;
 Libderiv->deriv_classes[5][7][8] = int_stack + 2268;
 Libderiv->deriv_classes[5][7][7] = int_stack + 3024;
 Libderiv->dvrr_classes[5][6] = int_stack + 3780;
 Libderiv->deriv_classes[5][7][6] = int_stack + 4368;
 Libderiv->deriv_classes[5][7][2] = int_stack + 5124;
 Libderiv->deriv_classes[5][7][1] = int_stack + 5880;
 Libderiv->dvrr_classes[4][7] = int_stack + 6636;
 Libderiv->deriv_classes[5][7][0] = int_stack + 7176;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 7932;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 8157;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 8472;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 8892;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 9432;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 9747;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 10188;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 10776;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 11532;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 11757;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 12072;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 12492;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 13032;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 13347;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 13788;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 14376;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 15132;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 15357;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 15672;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 16092;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 16632;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 16947;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 17388;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 17976;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 18732;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 18957;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 19272;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 19692;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 20232;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 20547;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 20988;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 21576;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 22332;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 22557;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 22872;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 23292;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 23832;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 24147;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 24588;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 25176;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 25932;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 26157;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 26472;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 26892;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 27432;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 27747;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 28188;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 28776;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 29532;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 29757;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 30072;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 30492;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 31032;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 31347;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 31788;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 32376;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 33132;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 33357;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 33672;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 34092;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 34632;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 34947;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 35388;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 35976;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 36732;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 36957;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 37272;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 37692;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 38232;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 38547;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 38988;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 39576;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 40332;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 40557;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 40872;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 41292;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 41832;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 42147;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 42588;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 43176;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 43932;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 44157;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 44472;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 44892;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 45432;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 45747;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 46188;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 46776;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 47532;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 47757;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 48072;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 48492;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 49032;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 49347;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 49788;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 50376;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 51132;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 51357;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 51672;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 52092;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 52632;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 52947;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 53388;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 53976;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 54732;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 54957;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 55272;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 55692;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 56232;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 56547;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 56988;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 57576;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 58332;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 58557;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 58872;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 59292;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 59832;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 60147;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 60588;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 61176;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 61932;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 62157;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 62472;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 62892;
 Libderiv->deriv_classes[5][4][11] = int_stack + 63432;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 63747;
 Libderiv->deriv_classes[5][5][11] = int_stack + 64062;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 64503;
 Libderiv->deriv_classes[5][6][11] = int_stack + 64944;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 65532;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 66120;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 66876;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 67101;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 67416;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 67836;
 Libderiv->deriv_classes[5][4][10] = int_stack + 68376;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 68691;
 Libderiv->deriv_classes[5][5][10] = int_stack + 69006;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 69447;
 Libderiv->deriv_classes[5][6][10] = int_stack + 69888;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 70476;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 71064;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 71820;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 72045;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 72360;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 72780;
 Libderiv->deriv_classes[5][4][9] = int_stack + 73320;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 73635;
 Libderiv->deriv_classes[5][5][9] = int_stack + 73950;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 74391;
 Libderiv->deriv_classes[5][6][9] = int_stack + 74832;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 75420;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 76008;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 76764;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 76989;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 77304;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 77724;
 Libderiv->deriv_classes[5][4][8] = int_stack + 78264;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 78579;
 Libderiv->deriv_classes[5][5][8] = int_stack + 78894;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 79335;
 Libderiv->deriv_classes[5][6][8] = int_stack + 79776;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 80364;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 80952;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 81708;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 81933;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 82248;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 82668;
 Libderiv->deriv_classes[5][4][7] = int_stack + 83208;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 83523;
 Libderiv->deriv_classes[5][5][7] = int_stack + 83838;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 84279;
 Libderiv->deriv_classes[5][6][7] = int_stack + 84720;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 85308;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 85896;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 86652;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 86877;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 87192;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 87612;
 Libderiv->dvrr_classes[5][4] = int_stack + 88152;
 Libderiv->deriv_classes[5][4][6] = int_stack + 88467;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 88782;
 Libderiv->dvrr_classes[5][5] = int_stack + 89097;
 Libderiv->deriv_classes[5][5][6] = int_stack + 89538;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 89979;
 Libderiv->deriv_classes[5][6][6] = int_stack + 90420;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 91008;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 91596;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 92352;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 92577;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 92892;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 93312;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 93852;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 94167;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 94608;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 95196;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 95952;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 96177;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 96492;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 96912;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 97452;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 97767;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 98208;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 98796;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 99552;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 99777;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 100092;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 100512;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 101052;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 101367;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 101808;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 102396;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 103152;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 103377;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 103692;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 104112;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 104652;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 104967;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 105408;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 105996;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 106752;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 106977;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 107292;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 107712;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 108252;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 108567;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 109008;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 109596;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 110352;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 110577;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 110892;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 111312;
 Libderiv->deriv_classes[5][4][2] = int_stack + 111852;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 112167;
 Libderiv->deriv_classes[5][5][2] = int_stack + 112482;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 112923;
 Libderiv->deriv_classes[5][6][2] = int_stack + 113364;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 113952;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 114540;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 115296;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 115521;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 115836;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 116256;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 116796;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 117111;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 117552;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 118140;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 118896;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 119121;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 119436;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 119856;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 120396;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 120711;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 121152;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 121740;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 122496;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 122721;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 123036;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 123456;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 123996;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 124311;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 124752;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 125340;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 126096;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 126321;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 126636;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 127056;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 127596;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 127911;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 128352;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 128940;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 129696;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 129921;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 130236;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 130656;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 131196;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 131511;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 131952;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 132540;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 133296;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 133521;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 133836;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 134256;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 134796;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 135111;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 135552;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 136140;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 136896;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 137121;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 137436;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 137856;
 Libderiv->deriv_classes[5][4][1] = int_stack + 138396;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 138711;
 Libderiv->deriv_classes[5][5][1] = int_stack + 139026;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 139467;
 Libderiv->deriv_classes[5][6][1] = int_stack + 139908;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 140496;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 141084;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 141840;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 142065;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 142380;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 142800;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 143340;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 143655;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 144096;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 144684;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 145440;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 145665;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 145980;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 146400;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 146940;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 147255;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 147696;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 148284;
 Libderiv->deriv_classes[4][4][11] = int_stack + 149040;
 Libderiv->deriv_classes[4][5][11] = int_stack + 149265;
 Libderiv->deriv_classes[4][6][11] = int_stack + 149580;
 Libderiv->deriv_classes[4][7][11] = int_stack + 150000;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 150540;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 150765;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 151080;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 151500;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 152040;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 152355;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 152796;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 153384;
 Libderiv->deriv_classes[4][4][10] = int_stack + 154140;
 Libderiv->deriv_classes[4][5][10] = int_stack + 154365;
 Libderiv->deriv_classes[4][6][10] = int_stack + 154680;
 Libderiv->deriv_classes[4][7][10] = int_stack + 155100;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 155640;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 155865;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 156180;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 156600;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 157140;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 157455;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 157896;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 158484;
 Libderiv->deriv_classes[4][4][9] = int_stack + 159240;
 Libderiv->deriv_classes[4][5][9] = int_stack + 159465;
 Libderiv->deriv_classes[4][6][9] = int_stack + 159780;
 Libderiv->deriv_classes[4][7][9] = int_stack + 160200;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 160740;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 160965;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 161280;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 161700;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 162240;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 162555;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 162996;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 163584;
 Libderiv->deriv_classes[4][4][8] = int_stack + 164340;
 Libderiv->deriv_classes[4][5][8] = int_stack + 164565;
 Libderiv->deriv_classes[4][6][8] = int_stack + 164880;
 Libderiv->deriv_classes[4][7][8] = int_stack + 165300;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 165840;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 166065;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 166380;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 166800;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 167340;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 167655;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 168096;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 168684;
 Libderiv->deriv_classes[4][4][7] = int_stack + 169440;
 Libderiv->deriv_classes[4][5][7] = int_stack + 169665;
 Libderiv->deriv_classes[4][6][7] = int_stack + 169980;
 Libderiv->deriv_classes[4][7][7] = int_stack + 170400;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 170940;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 171165;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 171480;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 171900;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 172440;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 172755;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 173196;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 173784;
 Libderiv->dvrr_classes[4][4] = int_stack + 174540;
 Libderiv->deriv_classes[4][4][6] = int_stack + 174765;
 Libderiv->dvrr_classes[4][5] = int_stack + 174990;
 Libderiv->deriv_classes[4][5][6] = int_stack + 175305;
 Libderiv->dvrr_classes[4][6] = int_stack + 175620;
 Libderiv->deriv_classes[4][6][6] = int_stack + 176040;
 Libderiv->deriv_classes[4][7][6] = int_stack + 176460;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 177000;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 177225;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 177540;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 177960;
 Libderiv->deriv_classes[5][4][0] = int_stack + 178500;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 178815;
 Libderiv->deriv_classes[5][5][0] = int_stack + 179130;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 179571;
 Libderiv->deriv_classes[5][6][0] = int_stack + 180012;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 180600;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 181188;
 Libderiv->deriv_classes[4][4][2] = int_stack + 181944;
 Libderiv->deriv_classes[4][5][2] = int_stack + 182169;
 Libderiv->deriv_classes[4][6][2] = int_stack + 182484;
 Libderiv->deriv_classes[4][7][2] = int_stack + 182904;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 183444;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 183669;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 183984;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 184404;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 184944;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 185259;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 185700;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 186288;
 Libderiv->deriv_classes[4][4][1] = int_stack + 187044;
 Libderiv->deriv_classes[4][5][1] = int_stack + 187269;
 Libderiv->deriv_classes[4][6][1] = int_stack + 187584;
 Libderiv->deriv_classes[4][7][1] = int_stack + 188004;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 188544;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 188769;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 189084;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 189504;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 190044;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 190359;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 190800;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 191388;
 Libderiv->deriv_classes[4][4][0] = int_stack + 192144;
 Libderiv->deriv_classes[4][5][0] = int_stack + 192369;
 Libderiv->deriv_classes[4][6][0] = int_stack + 192684;
 Libderiv->deriv_classes[4][7][0] = int_stack + 193104;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 193644;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 193869;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 194184;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 194604;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 195144;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 195459;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 195900;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 196488;
 memset(int_stack,0,1577952);

 Libderiv->dvrr_stack = int_stack + 440325;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gpgf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+197244,int_stack+174990,int_stack+174540,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+197919,int_stack+175620,int_stack+174990,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+198864,int_stack+197919,int_stack+197244,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+200214,int_stack+149265,int_stack+149040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174540,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200889,int_stack+149580,int_stack+149265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174990,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+201834,int_stack+200889,int_stack+200214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197244,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+203184,int_stack+150000,int_stack+149580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175620,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+204444,int_stack+203184,int_stack+200889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197919,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+206334,int_stack+204444,int_stack+201834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198864,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+203184,int_stack+89097,int_stack+88152,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+204129,int_stack+3780,int_stack+89097,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+208584,int_stack+204129,int_stack+203184,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+210474,int_stack+64062,int_stack+63432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88152,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211419,int_stack+64944,int_stack+64062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89097,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+212742,int_stack+211419,int_stack+210474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203184,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+214632,int_stack+0,int_stack+64944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+216396,int_stack+214632,int_stack+211419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204129,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+219042,int_stack+216396,int_stack+212742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+214632,int_stack+154365,int_stack+154140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174540, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+215307,int_stack+154680,int_stack+154365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174990, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+216252,int_stack+215307,int_stack+214632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197244, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+217602,int_stack+155100,int_stack+154680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175620, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+222192,int_stack+217602,int_stack+215307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197919, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+224082,int_stack+222192,int_stack+216252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198864, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+222192,int_stack+69006,int_stack+68376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88152, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+217602,int_stack+69888,int_stack+69006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89097, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+226332,int_stack+217602,int_stack+222192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203184, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+228222,int_stack+756,int_stack+69888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+229986,int_stack+228222,int_stack+217602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204129, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+232632,int_stack+229986,int_stack+226332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+228222,int_stack+159465,int_stack+159240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174540, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+223137,int_stack+159780,int_stack+159465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174990, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+228897,int_stack+223137,int_stack+228222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197244, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+230247,int_stack+160200,int_stack+159780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175620, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+235782,int_stack+230247,int_stack+223137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197919, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+230247,int_stack+235782,int_stack+228897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198864, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+235782,int_stack+73950,int_stack+73320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88152, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+74832,int_stack+73950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89097, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+236727,int_stack+0,int_stack+235782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203184, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+238617,int_stack+1512,int_stack+74832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+240381,int_stack+238617,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204129, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+243027,int_stack+240381,int_stack+236727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238617,int_stack+164565,int_stack+164340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1323,int_stack+164880,int_stack+164565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+239292,int_stack+1323,int_stack+238617, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+240642,int_stack+165300,int_stack+164880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+246177,int_stack+240642,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+240642,int_stack+246177,int_stack+239292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+246177,int_stack+78894,int_stack+78264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+247122,int_stack+79776,int_stack+78894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+248445,int_stack+247122,int_stack+246177, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+250335,int_stack+2268,int_stack+79776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+252099,int_stack+250335,int_stack+247122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+254745,int_stack+252099,int_stack+248445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+250335,int_stack+169665,int_stack+169440, 0.0, zero_stack, 1.0, int_stack+174540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+251010,int_stack+169980,int_stack+169665, 0.0, zero_stack, 1.0, int_stack+174990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+251955,int_stack+251010,int_stack+250335, 0.0, zero_stack, 1.0, int_stack+197244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+253305,int_stack+170400,int_stack+169980, 0.0, zero_stack, 1.0, int_stack+175620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+253305,int_stack+251010, 0.0, zero_stack, 1.0, int_stack+197919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+259785,int_stack+257895,int_stack+251955, 0.0, zero_stack, 1.0, int_stack+198864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+83838,int_stack+83208, 0.0, zero_stack, 1.0, int_stack+88152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+253305,int_stack+84720,int_stack+83838, 0.0, zero_stack, 1.0, int_stack+89097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262035,int_stack+253305,int_stack+257895, 0.0, zero_stack, 1.0, int_stack+203184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+263925,int_stack+3024,int_stack+84720, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+265689,int_stack+263925,int_stack+253305, 0.0, zero_stack, 1.0, int_stack+204129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+268335,int_stack+265689,int_stack+262035, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+263925,int_stack+175305,int_stack+174765, 1.0, int_stack+174540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258840,int_stack+176040,int_stack+175305, 1.0, int_stack+174990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+264600,int_stack+258840,int_stack+263925, 1.0, int_stack+197244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+265950,int_stack+176460,int_stack+176040, 1.0, int_stack+175620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+271485,int_stack+265950,int_stack+258840, 1.0, int_stack+197919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+265950,int_stack+271485,int_stack+264600, 1.0, int_stack+198864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+271485,int_stack+89538,int_stack+88467, 1.0, int_stack+88152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+272430,int_stack+90420,int_stack+89538, 1.0, int_stack+89097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+273753,int_stack+272430,int_stack+271485, 1.0, int_stack+203184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+275643,int_stack+4368,int_stack+90420, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2268,int_stack+275643,int_stack+272430, 1.0, int_stack+204129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+203184,int_stack+2268,int_stack+273753, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+208584,int_stack+6636,int_stack+175620,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2268,int_stack+208584,int_stack+197919,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+275643,int_stack+2268,int_stack+198864,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2268,int_stack+182169,int_stack+181944,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2943,int_stack+182484,int_stack+182169,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+208584,int_stack+2943,int_stack+2268,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+197244,int_stack+182904,int_stack+182484,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+277893,int_stack+197244,int_stack+2943,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+197244,int_stack+277893,int_stack+208584,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+277893,int_stack+112482,int_stack+111852,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+278838,int_stack+113364,int_stack+112482,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+280161,int_stack+278838,int_stack+277893,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+282051,int_stack+5124,int_stack+113364,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+283815,int_stack+282051,int_stack+278838,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+286461,int_stack+283815,int_stack+280161,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+282051,int_stack+187269,int_stack+187044,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+282726,int_stack+187584,int_stack+187269,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+283671,int_stack+282726,int_stack+282051,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+285021,int_stack+188004,int_stack+187584,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3888,int_stack+285021,int_stack+282726,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+289611,int_stack+3888,int_stack+283671,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3888,int_stack+139026,int_stack+138396,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+285021,int_stack+139908,int_stack+139026,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+291861,int_stack+285021,int_stack+3888,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+293751,int_stack+5880,int_stack+139908,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+295515,int_stack+293751,int_stack+285021,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+298161,int_stack+295515,int_stack+291861,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+293751,int_stack+192369,int_stack+192144,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+294426,int_stack+192684,int_stack+192369,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+295371,int_stack+294426,int_stack+293751,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+296721,int_stack+193104,int_stack+192684,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4833,int_stack+296721,int_stack+294426,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+301311,int_stack+4833,int_stack+295371,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+4833,int_stack+179130,int_stack+178500,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5778,int_stack+180012,int_stack+179130,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+303561,int_stack+5778,int_stack+4833,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+305451,int_stack+7176,int_stack+180012,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+307215,int_stack+305451,int_stack+5778,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+309861,int_stack+307215,int_stack+303561,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+8157,int_stack+7932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+149040,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+306126,int_stack+8472,int_stack+8157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+149265,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+307071,int_stack+306126,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+200214,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+308421,int_stack+8892,int_stack+8472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+149580,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7101,int_stack+308421,int_stack+306126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+200889,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+313011,int_stack+7101,int_stack+307071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+201834,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7101,int_stack+9747,int_stack+9432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+63432,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8046,int_stack+10188,int_stack+9747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+64062,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+8046,int_stack+7101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+210474,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+307341,int_stack+10776,int_stack+10188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+64944,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+307341,int_stack+8046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+211419,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+7101,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+212742,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+11757,int_stack+11532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149040, 1.0, int_stack+154140,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+306126,int_stack+12072,int_stack+11757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149265, 1.0, int_stack+154365,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+307071,int_stack+306126,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200214, 1.0, int_stack+214632,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+308421,int_stack+12492,int_stack+12072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149580, 1.0, int_stack+154680,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+308421,int_stack+306126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200889, 1.0, int_stack+215307,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+10251,int_stack+315261,int_stack+307071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201834, 1.0, int_stack+216252,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+13347,int_stack+13032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63432, 1.0, int_stack+68376,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+316206,int_stack+13788,int_stack+13347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64062, 1.0, int_stack+69006,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+316206,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210474, 1.0, int_stack+222192,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+307341,int_stack+14376,int_stack+13788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64944, 1.0, int_stack+69888,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+317529,int_stack+307341,int_stack+316206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211419, 1.0, int_stack+217602,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+320175,int_stack+317529,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212742, 1.0, int_stack+226332,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+15357,int_stack+15132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+154140, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+306126,int_stack+15672,int_stack+15357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+154365, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+307071,int_stack+306126,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+214632, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+308421,int_stack+16092,int_stack+15672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+154680, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+308421,int_stack+306126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+215307, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+317151,int_stack+315261,int_stack+307071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+216252, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+16947,int_stack+16632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68376, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+305451,int_stack+17388,int_stack+16947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69006, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+306774,int_stack+305451,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+222192, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315261,int_stack+17976,int_stack+17388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69888, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12501,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+217602, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+15147,int_stack+12501,int_stack+306774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+226332, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12501,int_stack+18957,int_stack+18732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149040, 0.0, zero_stack, 1.0, int_stack+159240,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13176,int_stack+19272,int_stack+18957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149265, 0.0, zero_stack, 1.0, int_stack+159465,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+13176,int_stack+12501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200214, 0.0, zero_stack, 1.0, int_stack+228222,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+306801,int_stack+19692,int_stack+19272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149580, 0.0, zero_stack, 1.0, int_stack+159780,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+306801,int_stack+13176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200889, 0.0, zero_stack, 1.0, int_stack+223137,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+306801,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201834, 0.0, zero_stack, 1.0, int_stack+228897,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+20547,int_stack+20232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63432, 0.0, zero_stack, 1.0, int_stack+73320,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+20988,int_stack+20547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64062, 0.0, zero_stack, 1.0, int_stack+73950,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12501,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210474, 0.0, zero_stack, 1.0, int_stack+235782,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18297,int_stack+21576,int_stack+20988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64944, 0.0, zero_stack, 1.0, int_stack+74832,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+323325,int_stack+18297,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211419, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+18297,int_stack+323325,int_stack+12501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212742, 0.0, zero_stack, 1.0, int_stack+236727,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12501,int_stack+22557,int_stack+22332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154140, 1.0, int_stack+159240, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13176,int_stack+22872,int_stack+22557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154365, 1.0, int_stack+159465, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+13176,int_stack+12501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214632, 1.0, int_stack+228222, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+323325,int_stack+23292,int_stack+22872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154680, 1.0, int_stack+159780, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+323325,int_stack+13176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215307, 1.0, int_stack+223137, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+323325,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216252, 1.0, int_stack+228897, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+24147,int_stack+23832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68376, 1.0, int_stack+73320, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+24588,int_stack+24147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69006, 1.0, int_stack+73950, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12501,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222192, 1.0, int_stack+235782, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21447,int_stack+25176,int_stack+24588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69888, 1.0, int_stack+74832, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23211,int_stack+21447,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217602, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+325575,int_stack+23211,int_stack+12501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226332, 1.0, int_stack+236727, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12501,int_stack+26157,int_stack+25932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+159240, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13176,int_stack+26472,int_stack+26157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+159465, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+13176,int_stack+12501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+228222, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315261,int_stack+26892,int_stack+26472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+159780, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21447,int_stack+315261,int_stack+13176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+223137, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12501,int_stack+21447,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+228897, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+27747,int_stack+27432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21447,int_stack+28188,int_stack+27747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73950, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+21447,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235782, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22770,int_stack+28776,int_stack+28188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24534,int_stack+22770,int_stack+21447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+328725,int_stack+24534,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+236727, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+29757,int_stack+29532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164340,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+30072,int_stack+29757, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164565,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238617,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21447,int_stack+30492,int_stack+30072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164880,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22707,int_stack+21447,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+24597,int_stack+22707,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201834, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239292,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+31347,int_stack+31032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78264,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21447,int_stack+31788,int_stack+31347, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78894,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+21447,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246177,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22770,int_stack+32376,int_stack+31788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79776,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26847,int_stack+22770,int_stack+21447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211419, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247122,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+21447,int_stack+26847,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248445,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+33357,int_stack+33132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154140, 0.0, zero_stack, 1.0, int_stack+164340, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+33672,int_stack+33357, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154365, 0.0, zero_stack, 1.0, int_stack+164565, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214632, 0.0, zero_stack, 1.0, int_stack+238617, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+26847,int_stack+34092,int_stack+33672, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154680, 0.0, zero_stack, 1.0, int_stack+164880, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28107,int_stack+26847,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215307, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29997,int_stack+28107,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216252, 0.0, zero_stack, 1.0, int_stack+239292, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+34947,int_stack+34632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68376, 0.0, zero_stack, 1.0, int_stack+78264, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26847,int_stack+35388,int_stack+34947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69006, 0.0, zero_stack, 1.0, int_stack+78894, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+26847,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222192, 0.0, zero_stack, 1.0, int_stack+246177, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28170,int_stack+35976,int_stack+35388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69888, 0.0, zero_stack, 1.0, int_stack+79776, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32247,int_stack+28170,int_stack+26847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217602, 0.0, zero_stack, 1.0, int_stack+247122, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+26847,int_stack+32247,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226332, 0.0, zero_stack, 1.0, int_stack+248445, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+36957,int_stack+36732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159240, 1.0, int_stack+164340, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+37272,int_stack+36957, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159465, 1.0, int_stack+164565, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228222, 1.0, int_stack+238617, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32247,int_stack+37692,int_stack+37272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159780, 1.0, int_stack+164880, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33507,int_stack+32247,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223137, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+35397,int_stack+33507,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228897, 1.0, int_stack+239292, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+38547,int_stack+38232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73320, 1.0, int_stack+78264, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32247,int_stack+38988,int_stack+38547, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73950, 1.0, int_stack+78894, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+32247,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235782, 1.0, int_stack+246177, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33570,int_stack+39576,int_stack+38988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74832, 1.0, int_stack+79776, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37647,int_stack+33570,int_stack+32247, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+247122, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+32247,int_stack+37647,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+236727, 1.0, int_stack+248445, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+40557,int_stack+40332, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+164340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+40872,int_stack+40557, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+164565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+238617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37647,int_stack+41292,int_stack+40872, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+164880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38907,int_stack+37647,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+331875,int_stack+38907,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+239292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+42147,int_stack+41832, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+78264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37647,int_stack+42588,int_stack+42147, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+78894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+37647,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+246177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38970,int_stack+43176,int_stack+42588, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+79776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40734,int_stack+38970,int_stack+37647, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+247122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+334125,int_stack+40734,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+248445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+44157,int_stack+43932, 0.0, zero_stack, 1.0, int_stack+149040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169440,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+44472,int_stack+44157, 0.0, zero_stack, 1.0, int_stack+149265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169665,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+200214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250335,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37647,int_stack+44892,int_stack+44472, 0.0, zero_stack, 1.0, int_stack+149580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169980,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38907,int_stack+37647,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+200889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251010,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+40797,int_stack+38907,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+201834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251955,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+45747,int_stack+45432, 0.0, zero_stack, 1.0, int_stack+63432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83208,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37647,int_stack+46188,int_stack+45747, 0.0, zero_stack, 1.0, int_stack+64062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83838,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+37647,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+210474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257895,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38970,int_stack+46776,int_stack+46188, 0.0, zero_stack, 1.0, int_stack+64944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84720,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+43047,int_stack+38970,int_stack+37647, 0.0, zero_stack, 1.0, int_stack+211419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253305,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+37647,int_stack+43047,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+212742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262035,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+47757,int_stack+47532, 0.0, zero_stack, 1.0, int_stack+154140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169440, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+48072,int_stack+47757, 0.0, zero_stack, 1.0, int_stack+154365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169665, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+214632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250335, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43047,int_stack+48492,int_stack+48072, 0.0, zero_stack, 1.0, int_stack+154680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169980, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+44307,int_stack+43047,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+215307, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251010, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+46197,int_stack+44307,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+216252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251955, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+49347,int_stack+49032, 0.0, zero_stack, 1.0, int_stack+68376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83208, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43047,int_stack+49788,int_stack+49347, 0.0, zero_stack, 1.0, int_stack+69006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83838, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+43047,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+222192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257895, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+44370,int_stack+50376,int_stack+49788, 0.0, zero_stack, 1.0, int_stack+69888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84720, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48447,int_stack+44370,int_stack+43047, 0.0, zero_stack, 1.0, int_stack+217602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253305, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+43047,int_stack+48447,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+226332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262035, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+51357,int_stack+51132, 0.0, zero_stack, 1.0, int_stack+159240, 0.0, zero_stack, 1.0, int_stack+169440, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+51672,int_stack+51357, 0.0, zero_stack, 1.0, int_stack+159465, 0.0, zero_stack, 1.0, int_stack+169665, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+228222, 0.0, zero_stack, 1.0, int_stack+250335, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48447,int_stack+52092,int_stack+51672, 0.0, zero_stack, 1.0, int_stack+159780, 0.0, zero_stack, 1.0, int_stack+169980, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49707,int_stack+48447,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+223137, 0.0, zero_stack, 1.0, int_stack+251010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+337275,int_stack+49707,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+228897, 0.0, zero_stack, 1.0, int_stack+251955, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+52947,int_stack+52632, 0.0, zero_stack, 1.0, int_stack+73320, 0.0, zero_stack, 1.0, int_stack+83208, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48447,int_stack+53388,int_stack+52947, 0.0, zero_stack, 1.0, int_stack+73950, 0.0, zero_stack, 1.0, int_stack+83838, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+48447,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+235782, 0.0, zero_stack, 1.0, int_stack+257895, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49770,int_stack+53976,int_stack+53388, 0.0, zero_stack, 1.0, int_stack+74832, 0.0, zero_stack, 1.0, int_stack+84720, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51534,int_stack+49770,int_stack+48447, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+253305, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+339525,int_stack+51534,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+236727, 0.0, zero_stack, 1.0, int_stack+262035, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+54957,int_stack+54732, 0.0, zero_stack, 1.0, int_stack+164340, 1.0, int_stack+169440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+55272,int_stack+54957, 0.0, zero_stack, 1.0, int_stack+164565, 1.0, int_stack+169665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+238617, 1.0, int_stack+250335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48447,int_stack+55692,int_stack+55272, 0.0, zero_stack, 1.0, int_stack+164880, 1.0, int_stack+169980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49707,int_stack+48447,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+1323, 1.0, int_stack+251010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+51597,int_stack+49707,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+239292, 1.0, int_stack+251955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+56547,int_stack+56232, 0.0, zero_stack, 1.0, int_stack+78264, 1.0, int_stack+83208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48447,int_stack+56988,int_stack+56547, 0.0, zero_stack, 1.0, int_stack+78894, 1.0, int_stack+83838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+48447,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+246177, 1.0, int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49770,int_stack+57576,int_stack+56988, 0.0, zero_stack, 1.0, int_stack+79776, 1.0, int_stack+84720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+53847,int_stack+49770,int_stack+48447, 0.0, zero_stack, 1.0, int_stack+247122, 1.0, int_stack+253305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+48447,int_stack+53847,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+248445, 1.0, int_stack+262035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+58557,int_stack+58332, 0.0, zero_stack, 2.0, int_stack+169440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+58872,int_stack+58557, 0.0, zero_stack, 2.0, int_stack+169665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 2.0, int_stack+250335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+53847,int_stack+59292,int_stack+58872, 0.0, zero_stack, 2.0, int_stack+169980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55107,int_stack+53847,int_stack+315936, 0.0, zero_stack, 2.0, int_stack+251010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+56997,int_stack+55107,int_stack+305451, 0.0, zero_stack, 2.0, int_stack+251955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+60147,int_stack+59832, 0.0, zero_stack, 2.0, int_stack+83208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53847,int_stack+60588,int_stack+60147, 0.0, zero_stack, 2.0, int_stack+83838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+53847,int_stack+305451, 0.0, zero_stack, 2.0, int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+55170,int_stack+61176,int_stack+60588, 0.0, zero_stack, 2.0, int_stack+84720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+59247,int_stack+55170,int_stack+53847, 0.0, zero_stack, 2.0, int_stack+253305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+53847,int_stack+59247,int_stack+315261, 0.0, zero_stack, 2.0, int_stack+262035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+62157,int_stack+61932, 1.0, int_stack+149040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174765,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+62472,int_stack+62157, 1.0, int_stack+149265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175305,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 1.0, int_stack+200214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263925,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59247,int_stack+62892,int_stack+62472, 1.0, int_stack+149580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176040,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60507,int_stack+59247,int_stack+315936, 1.0, int_stack+200889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258840,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+199494,int_stack+60507,int_stack+305451, 1.0, int_stack+201834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264600,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+64503,int_stack+63747, 1.0, int_stack+63432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88467,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+59247,int_stack+65532,int_stack+64503, 1.0, int_stack+64062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89538,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+59247,int_stack+305451, 1.0, int_stack+210474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271485,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+60570,int_stack+66120,int_stack+65532, 1.0, int_stack+64944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90420,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+62334,int_stack+60570,int_stack+59247, 1.0, int_stack+211419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272430,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+342675,int_stack+62334,int_stack+315261, 1.0, int_stack+212742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273753,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+67101,int_stack+66876, 1.0, int_stack+154140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174765, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+67416,int_stack+67101, 1.0, int_stack+154365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175305, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 1.0, int_stack+214632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263925, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59247,int_stack+67836,int_stack+67416, 1.0, int_stack+154680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176040, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60507,int_stack+59247,int_stack+315936, 1.0, int_stack+215307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258840, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+62397,int_stack+60507,int_stack+305451, 1.0, int_stack+216252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264600, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+69447,int_stack+68691, 1.0, int_stack+68376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88467, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+59247,int_stack+70476,int_stack+69447, 1.0, int_stack+69006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89538, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+59247,int_stack+305451, 1.0, int_stack+222192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271485, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+60570,int_stack+71064,int_stack+70476, 1.0, int_stack+69888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90420, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+64647,int_stack+60570,int_stack+59247, 1.0, int_stack+217602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272430, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+59247,int_stack+64647,int_stack+315261, 1.0, int_stack+226332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273753, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+226332,int_stack+72045,int_stack+71820, 1.0, int_stack+159240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174765, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222192,int_stack+72360,int_stack+72045, 1.0, int_stack+159465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175305, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+222192,int_stack+226332, 1.0, int_stack+228222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263925, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+226332,int_stack+72780,int_stack+72360, 1.0, int_stack+159780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176040, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+226332,int_stack+222192, 1.0, int_stack+223137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258840, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+226332,int_stack+315261,int_stack+305451, 1.0, int_stack+228897, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264600, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+74391,int_stack+73635, 1.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88467, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+75420,int_stack+74391, 1.0, int_stack+73950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89538, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+222192,int_stack+315261,int_stack+305451, 1.0, int_stack+235782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271485, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64647,int_stack+76008,int_stack+75420, 1.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90420, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66411,int_stack+64647,int_stack+315261, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272430, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+69057,int_stack+66411,int_stack+222192, 1.0, int_stack+236727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273753, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+222192,int_stack+76989,int_stack+76764, 1.0, int_stack+164340, 0.0, zero_stack, 1.0, int_stack+174765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222867,int_stack+77304,int_stack+76989, 1.0, int_stack+164565, 0.0, zero_stack, 1.0, int_stack+175305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+222867,int_stack+222192, 1.0, int_stack+238617, 0.0, zero_stack, 1.0, int_stack+263925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+77724,int_stack+77304, 1.0, int_stack+164880, 0.0, zero_stack, 1.0, int_stack+176040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+0,int_stack+222867, 1.0, int_stack+1323, 0.0, zero_stack, 1.0, int_stack+258840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+0,int_stack+315261,int_stack+305451, 1.0, int_stack+239292, 0.0, zero_stack, 1.0, int_stack+264600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+79335,int_stack+78579, 1.0, int_stack+78264, 0.0, zero_stack, 1.0, int_stack+88467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+80364,int_stack+79335, 1.0, int_stack+78894, 0.0, zero_stack, 1.0, int_stack+89538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+222192,int_stack+315261,int_stack+305451, 1.0, int_stack+246177, 0.0, zero_stack, 1.0, int_stack+271485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64647,int_stack+80952,int_stack+80364, 1.0, int_stack+79776, 0.0, zero_stack, 1.0, int_stack+90420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66411,int_stack+64647,int_stack+315261, 1.0, int_stack+247122, 0.0, zero_stack, 1.0, int_stack+272430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+235782,int_stack+66411,int_stack+222192, 1.0, int_stack+248445, 0.0, zero_stack, 1.0, int_stack+273753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+222192,int_stack+81933,int_stack+81708, 1.0, int_stack+169440, 1.0, int_stack+174765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222867,int_stack+82248,int_stack+81933, 1.0, int_stack+169665, 1.0, int_stack+175305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+222867,int_stack+222192, 1.0, int_stack+250335, 1.0, int_stack+263925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315261,int_stack+82668,int_stack+82248, 1.0, int_stack+169980, 1.0, int_stack+176040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+64647,int_stack+315261,int_stack+222867, 1.0, int_stack+251010, 1.0, int_stack+258840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+66537,int_stack+64647,int_stack+305451, 1.0, int_stack+251955, 1.0, int_stack+264600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+84279,int_stack+83523, 1.0, int_stack+83208, 1.0, int_stack+88467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64647,int_stack+85308,int_stack+84279, 1.0, int_stack+83838, 1.0, int_stack+89538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+64647,int_stack+305451, 1.0, int_stack+257895, 1.0, int_stack+271485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+222192,int_stack+85896,int_stack+85308, 1.0, int_stack+84720, 1.0, int_stack+90420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+246177,int_stack+222192,int_stack+64647, 1.0, int_stack+253305, 1.0, int_stack+272430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+248823,int_stack+246177,int_stack+315261, 1.0, int_stack+262035, 1.0, int_stack+273753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+262035,int_stack+86877,int_stack+86652, 2.0, int_stack+174765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+87192,int_stack+86877, 2.0, int_stack+175305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+257895,int_stack+262035, 2.0, int_stack+263925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262035,int_stack+87612,int_stack+87192, 2.0, int_stack+176040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+262035,int_stack+257895, 2.0, int_stack+258840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+262035,int_stack+315261,int_stack+305451, 2.0, int_stack+264600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+89979,int_stack+88782, 2.0, int_stack+88467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+91008,int_stack+89979, 2.0, int_stack+89538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 2.0, int_stack+271485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+246177,int_stack+91596,int_stack+91008, 2.0, int_stack+90420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+251973,int_stack+246177,int_stack+315261, 2.0, int_stack+272430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+72207,int_stack+251973,int_stack+257895, 2.0, int_stack+273753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+92577,int_stack+92352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181944,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+92892,int_stack+92577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182169,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+251973,int_stack+93312,int_stack+92892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182484,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+251973,int_stack+258570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+251973,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+94167,int_stack+93852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111852,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+94608,int_stack+94167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112482,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277893,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+246177,int_stack+95196,int_stack+94608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113364,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+271485,int_stack+246177,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278838,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+75357,int_stack+271485,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280161,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+96177,int_stack+95952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181944, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+96492,int_stack+96177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182169, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+271485,int_stack+96912,int_stack+96492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182484, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+271485,int_stack+258570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+271485,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+97767,int_stack+97452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111852, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+98208,int_stack+97767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112482, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277893, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+273735,int_stack+98796,int_stack+98208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113364, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+246177,int_stack+273735,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278838, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+78507,int_stack+246177,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280161, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+99777,int_stack+99552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181944, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+100092,int_stack+99777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182169, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+246177,int_stack+100512,int_stack+100092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182484, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+246177,int_stack+258570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+246177,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+101367,int_stack+101052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111852, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+101808,int_stack+101367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112482, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277893, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+273735,int_stack+102396,int_stack+101808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+81657,int_stack+273735,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278838, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+84303,int_stack+81657,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280161, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+103377,int_stack+103152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+103692,int_stack+103377, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+81657,int_stack+104112,int_stack+103692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+81657,int_stack+258570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+81657,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+104967,int_stack+104652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+105408,int_stack+104967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+273735,int_stack+105996,int_stack+105408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+87453,int_stack+273735,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+90099,int_stack+87453,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+106977,int_stack+106752, 0.0, zero_stack, 1.0, int_stack+181944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+107292,int_stack+106977, 0.0, zero_stack, 1.0, int_stack+182169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+87453,int_stack+107712,int_stack+107292, 0.0, zero_stack, 1.0, int_stack+182484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+87453,int_stack+258570, 0.0, zero_stack, 1.0, int_stack+2943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+87453,int_stack+315261,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+108567,int_stack+108252, 0.0, zero_stack, 1.0, int_stack+111852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+109008,int_stack+108567, 0.0, zero_stack, 1.0, int_stack+112482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+277893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+273735,int_stack+109596,int_stack+109008, 0.0, zero_stack, 1.0, int_stack+113364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93249,int_stack+273735,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+278838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+95895,int_stack+93249,int_stack+257895, 0.0, zero_stack, 1.0, int_stack+280161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+110577,int_stack+110352, 1.0, int_stack+181944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258570,int_stack+110892,int_stack+110577, 1.0, int_stack+182169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+258570,int_stack+257895, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93249,int_stack+111312,int_stack+110892, 1.0, int_stack+182484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+93249,int_stack+258570, 1.0, int_stack+2943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+93249,int_stack+315261,int_stack+305451, 1.0, int_stack+208584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+208584,int_stack+112923,int_stack+112167, 1.0, int_stack+111852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209529,int_stack+113952,int_stack+112923, 1.0, int_stack+112482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+209529,int_stack+208584, 1.0, int_stack+277893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210852,int_stack+114540,int_stack+113952, 1.0, int_stack+113364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+212616,int_stack+210852,int_stack+209529, 1.0, int_stack+278838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+208584,int_stack+212616,int_stack+315261, 1.0, int_stack+280161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+115521,int_stack+115296,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+115836,int_stack+115521,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+277893,int_stack+116256,int_stack+115836,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+277893,int_stack+315936,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+277893,int_stack+257895,int_stack+305451,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+117111,int_stack+116796,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+117552,int_stack+117111,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+118140,int_stack+117552,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+211734,int_stack+280143,int_stack+257895,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+214380,int_stack+211734,int_stack+315261,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+119121,int_stack+118896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187044,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+119436,int_stack+119121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187269,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282051,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+211734,int_stack+119856,int_stack+119436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187584,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+211734,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282726,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+211734,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283671,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+120711,int_stack+120396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138396,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+121152,int_stack+120711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139026,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+121740,int_stack+121152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139908,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+99045,int_stack+280143,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285021,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+101691,int_stack+99045,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291861,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+122721,int_stack+122496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187044, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+123036,int_stack+122721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187269, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282051, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+99045,int_stack+123456,int_stack+123036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187584, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+99045,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282726, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+99045,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283671, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+124311,int_stack+123996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138396, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+124752,int_stack+124311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139026, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+125340,int_stack+124752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139908, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+104841,int_stack+280143,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285021, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+107487,int_stack+104841,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291861, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+126321,int_stack+126096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187044, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+126636,int_stack+126321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187269, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282051, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+104841,int_stack+127056,int_stack+126636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187584, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+104841,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282726, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+104841,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283671, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+127911,int_stack+127596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138396, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+128352,int_stack+127911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139026, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+128940,int_stack+128352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139908, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110637,int_stack+280143,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285021, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+113283,int_stack+110637,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291861, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+129921,int_stack+129696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+130236,int_stack+129921, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+110637,int_stack+130656,int_stack+130236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+110637,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+110637,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+131511,int_stack+131196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+131952,int_stack+131511, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+132540,int_stack+131952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+116433,int_stack+280143,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+119079,int_stack+116433,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+133521,int_stack+133296, 0.0, zero_stack, 1.0, int_stack+187044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+133836,int_stack+133521, 0.0, zero_stack, 1.0, int_stack+187269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+282051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+116433,int_stack+134256,int_stack+133836, 0.0, zero_stack, 1.0, int_stack+187584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+116433,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+282726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+116433,int_stack+257895,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+283671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+135111,int_stack+134796, 0.0, zero_stack, 1.0, int_stack+138396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+135552,int_stack+135111, 0.0, zero_stack, 1.0, int_stack+139026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+136140,int_stack+135552, 0.0, zero_stack, 1.0, int_stack+139908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+122229,int_stack+280143,int_stack+257895, 0.0, zero_stack, 1.0, int_stack+285021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+124875,int_stack+122229,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+291861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+137121,int_stack+136896, 1.0, int_stack+187044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+137436,int_stack+137121, 1.0, int_stack+187269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 1.0, int_stack+282051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+122229,int_stack+137856,int_stack+137436, 1.0, int_stack+187584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+122229,int_stack+315936, 1.0, int_stack+282726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+122229,int_stack+257895,int_stack+305451, 1.0, int_stack+283671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+139467,int_stack+138711, 1.0, int_stack+138396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+140496,int_stack+139467, 1.0, int_stack+139026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 1.0, int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+280143,int_stack+141084,int_stack+140496, 1.0, int_stack+139908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+281907,int_stack+280143,int_stack+257895, 1.0, int_stack+285021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+128025,int_stack+281907,int_stack+315261, 1.0, int_stack+291861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+291861,int_stack+142065,int_stack+141840,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+292536,int_stack+142380,int_stack+142065,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+292536,int_stack+291861,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+315261,int_stack+142800,int_stack+142380,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+292536,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+280143,int_stack+257895,int_stack+305451,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+143655,int_stack+143340,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+144096,int_stack+143655,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+291861,int_stack+144684,int_stack+144096,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+282393,int_stack+291861,int_stack+257895,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+131175,int_stack+282393,int_stack+315261,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+145665,int_stack+145440,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+145980,int_stack+145665,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+282393,int_stack+146400,int_stack+145980,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+282393,int_stack+315936,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+282393,int_stack+257895,int_stack+305451,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+147255,int_stack+146940,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+147696,int_stack+147255,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+148284,int_stack+147696,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+134325,int_stack+284643,int_stack+257895,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+136971,int_stack+134325,int_stack+315261,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+150765,int_stack+150540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192144,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+151080,int_stack+150765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192369,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293751,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+134325,int_stack+151500,int_stack+151080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192684,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+134325,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294426,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+134325,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295371,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+152355,int_stack+152040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178500,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+152796,int_stack+152355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179130,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4833,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+153384,int_stack+152796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180012,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+140121,int_stack+284643,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5778,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+142767,int_stack+140121,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303561,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+155865,int_stack+155640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192144, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+156180,int_stack+155865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192369, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293751, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+140121,int_stack+156600,int_stack+156180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192684, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+140121,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294426, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+140121,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295371, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+157455,int_stack+157140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178500, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+157896,int_stack+157455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179130, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4833, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+158484,int_stack+157896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180012, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+145917,int_stack+284643,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5778, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+148563,int_stack+145917,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303561, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+160965,int_stack+160740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192144, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+161280,int_stack+160965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192369, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293751, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145917,int_stack+161700,int_stack+161280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192684, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+145917,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294426, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+145917,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295371, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+162555,int_stack+162240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178500, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+162996,int_stack+162555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179130, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4833, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+163584,int_stack+162996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180012, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+151713,int_stack+284643,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5778, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+154359,int_stack+151713,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303561, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+166065,int_stack+165840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+166380,int_stack+166065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+151713,int_stack+166800,int_stack+166380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+151713,int_stack+315936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+151713,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+167655,int_stack+167340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+168096,int_stack+167655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+168684,int_stack+168096, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+157509,int_stack+284643,int_stack+257895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+160155,int_stack+157509,int_stack+315261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+171165,int_stack+170940, 0.0, zero_stack, 1.0, int_stack+192144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+171480,int_stack+171165, 0.0, zero_stack, 1.0, int_stack+192369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+293751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+157509,int_stack+171900,int_stack+171480, 0.0, zero_stack, 1.0, int_stack+192684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+157509,int_stack+315936, 0.0, zero_stack, 1.0, int_stack+294426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+157509,int_stack+257895,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+295371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+172755,int_stack+172440, 0.0, zero_stack, 1.0, int_stack+178500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+173196,int_stack+172755, 0.0, zero_stack, 1.0, int_stack+179130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 0.0, zero_stack, 1.0, int_stack+4833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+173784,int_stack+173196, 0.0, zero_stack, 1.0, int_stack+180012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+163305,int_stack+284643,int_stack+257895, 0.0, zero_stack, 1.0, int_stack+5778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+165951,int_stack+163305,int_stack+315261, 0.0, zero_stack, 1.0, int_stack+303561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+177225,int_stack+177000, 1.0, int_stack+192144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+177540,int_stack+177225, 1.0, int_stack+192369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+305451,int_stack+315936,int_stack+315261, 1.0, int_stack+293751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+163305,int_stack+177960,int_stack+177540, 1.0, int_stack+192684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+163305,int_stack+315936, 1.0, int_stack+294426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+163305,int_stack+257895,int_stack+305451, 1.0, int_stack+295371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+305451,int_stack+179571,int_stack+178815, 1.0, int_stack+178500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+257895,int_stack+180600,int_stack+179571, 1.0, int_stack+179130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+257895,int_stack+305451, 1.0, int_stack+4833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+284643,int_stack+181188,int_stack+180600, 1.0, int_stack+180012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+291861,int_stack+284643,int_stack+257895, 1.0, int_stack+5778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+294507,int_stack+291861,int_stack+315261, 1.0, int_stack+303561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+303561,int_stack+183669,int_stack+183444,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+304236,int_stack+183984,int_stack+183669,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+305181,int_stack+304236,int_stack+303561,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+315261,int_stack+184404,int_stack+183984,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+257895,int_stack+315261,int_stack+304236,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+291861,int_stack+257895,int_stack+305181,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+257895,int_stack+185259,int_stack+184944,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+315261,int_stack+185700,int_stack+185259,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+64647,int_stack+315261,int_stack+257895,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+257895,int_stack+186288,int_stack+185700,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+303561,int_stack+257895,int_stack+315261,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+2250,int_stack+303561,int_stack+64647,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+64647,int_stack+188769,int_stack+188544,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+65322,int_stack+189084,int_stack+188769,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+303561,int_stack+65322,int_stack+64647,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+304911,int_stack+189504,int_stack+189084,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+315261,int_stack+304911,int_stack+65322,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+169101,int_stack+315261,int_stack+303561,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+303561,int_stack+190359,int_stack+190044,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+304506,int_stack+190800,int_stack+190359,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+304506,int_stack+303561,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+64647,int_stack+191388,int_stack+190800,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+171351,int_stack+64647,int_stack+304506,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+303561,int_stack+171351,int_stack+315261,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+315261,int_stack+193869,int_stack+193644,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+315936,int_stack+194184,int_stack+193869,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+171351,int_stack+315936,int_stack+315261,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+172701,int_stack+194604,int_stack+194184,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+64647,int_stack+172701,int_stack+315936,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+172701,int_stack+64647,int_stack+171351,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171351,int_stack+195459,int_stack+195144,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+64647,int_stack+195900,int_stack+195459,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+315261,int_stack+64647,int_stack+171351,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+174951,int_stack+196488,int_stack+195900,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+176715,int_stack+174951,int_stack+64647,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+179361,int_stack+176715,int_stack+315261,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+182511,int_stack+219042,int_stack+206334,150);
     Libderiv->ABCD[11] = int_stack + 182511;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+189261,int_stack+232632,int_stack+224082,150);
     Libderiv->ABCD[10] = int_stack + 189261;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+345825,int_stack+243027,int_stack+230247,150);
     Libderiv->ABCD[9] = int_stack + 345825;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+352575,int_stack+254745,int_stack+240642,150);
     Libderiv->ABCD[8] = int_stack + 352575;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+359325,int_stack+268335,int_stack+259785,150);
     Libderiv->ABCD[7] = int_stack + 359325;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+366075,int_stack+203184,int_stack+265950,150);
     Libderiv->ABCD[6] = int_stack + 366075;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+372825,int_stack+286461,int_stack+197244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[2] = int_stack + 372825;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+379575,int_stack+298161,int_stack+289611, 0.0, zero_stack, 1.0, int_stack+275643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[1] = int_stack + 379575;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+386325,int_stack+309861,int_stack+301311, 1.0, int_stack+275643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[0] = int_stack + 386325;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+393075,int_stack+7101,int_stack+313011,150);
     Libderiv->ABCD[155] = int_stack + 393075;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+309051,int_stack+320175,int_stack+10251,150);
     Libderiv->ABCD[143] = int_stack + 309051;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+5400,int_stack+15147,int_stack+317151,150);
     Libderiv->ABCD[142] = int_stack + 5400;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+315801,int_stack+18297,int_stack+306801,150);
     Libderiv->ABCD[131] = int_stack + 315801;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+399825,int_stack+325575,int_stack+323325,150);
     Libderiv->ABCD[130] = int_stack + 399825;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+406575,int_stack+328725,int_stack+12501,150);
     Libderiv->ABCD[129] = int_stack + 406575;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+12150,int_stack+21447,int_stack+24597,150);
     Libderiv->ABCD[119] = int_stack + 12150;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+18900,int_stack+26847,int_stack+29997,150);
     Libderiv->ABCD[118] = int_stack + 18900;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+322551,int_stack+32247,int_stack+35397,150);
     Libderiv->ABCD[117] = int_stack + 322551;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+25650,int_stack+334125,int_stack+331875,150);
     Libderiv->ABCD[116] = int_stack + 25650;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+329301,int_stack+37647,int_stack+40797,150);
     Libderiv->ABCD[107] = int_stack + 329301;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+32400,int_stack+43047,int_stack+46197,150);
     Libderiv->ABCD[106] = int_stack + 32400;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+39150,int_stack+339525,int_stack+337275,150);
     Libderiv->ABCD[105] = int_stack + 39150;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+413325,int_stack+48447,int_stack+51597,150);
     Libderiv->ABCD[104] = int_stack + 413325;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+45900,int_stack+53847,int_stack+56997,150);
     Libderiv->ABCD[103] = int_stack + 45900;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+420075,int_stack+342675,int_stack+199494,150);
     Libderiv->ABCD[95] = int_stack + 420075;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+199494,int_stack+59247,int_stack+62397,150);
     Libderiv->ABCD[94] = int_stack + 199494;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+52650,int_stack+69057,int_stack+226332,150);
     Libderiv->ABCD[93] = int_stack + 52650;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+59400,int_stack+235782,int_stack+0,150);
     Libderiv->ABCD[92] = int_stack + 59400;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+336051,int_stack+248823,int_stack+66537,150);
     Libderiv->ABCD[91] = int_stack + 336051;
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+232497,int_stack+72207,int_stack+262035,150);
     Libderiv->ABCD[90] = int_stack + 232497;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+66150,int_stack+75357,int_stack+251973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[47] = int_stack + 66150;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+248427,int_stack+78507,int_stack+271485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[46] = int_stack + 248427;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+72900,int_stack+84303,int_stack+246177, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[45] = int_stack + 72900;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+268200,int_stack+90099,int_stack+81657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[44] = int_stack + 268200;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+79650,int_stack+95895,int_stack+87453, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[43] = int_stack + 79650;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+86400,int_stack+208584,int_stack+93249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[42] = int_stack + 86400;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+426825,int_stack+214380,int_stack+277893, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+197244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[38] = int_stack + 426825;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+213984,int_stack+101691,int_stack+211734, 0.0, zero_stack, 1.0, int_stack+206334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[35] = int_stack + 213984;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+433575,int_stack+107487,int_stack+99045, 0.0, zero_stack, 1.0, int_stack+224082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[34] = int_stack + 433575;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+93150,int_stack+113283,int_stack+104841, 0.0, zero_stack, 1.0, int_stack+230247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[33] = int_stack + 93150;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+99900,int_stack+119079,int_stack+110637, 0.0, zero_stack, 1.0, int_stack+240642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[32] = int_stack + 99900;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+106650,int_stack+124875,int_stack+116433, 0.0, zero_stack, 1.0, int_stack+259785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[31] = int_stack + 106650;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+113400,int_stack+128025,int_stack+122229, 0.0, zero_stack, 1.0, int_stack+265950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[30] = int_stack + 113400;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+120150,int_stack+131175,int_stack+280143, 0.0, zero_stack, 1.0, int_stack+197244, 1.0, int_stack+289611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[26] = int_stack + 120150;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+126900,int_stack+136971,int_stack+282393, 0.0, zero_stack, 2.0, int_stack+289611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[25] = int_stack + 126900;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+274950,int_stack+142767,int_stack+134325, 1.0, int_stack+206334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[23] = int_stack + 274950;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+206244,int_stack+148563,int_stack+140121, 1.0, int_stack+224082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[22] = int_stack + 206244;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+220734,int_stack+154359,int_stack+145917, 1.0, int_stack+230247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[21] = int_stack + 220734;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+133650,int_stack+160155,int_stack+151713, 1.0, int_stack+240642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[20] = int_stack + 133650;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+140400,int_stack+165951,int_stack+157509, 1.0, int_stack+259785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[19] = int_stack + 140400;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+255177,int_stack+294507,int_stack+163305, 1.0, int_stack+265950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[18] = int_stack + 255177;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+294111,int_stack+2250,int_stack+291861, 1.0, int_stack+197244, 0.0, zero_stack, 1.0, int_stack+301311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[14] = int_stack + 294111;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+147150,int_stack+303561,int_stack+169101, 1.0, int_stack+289611, 1.0, int_stack+301311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[13] = int_stack + 147150;
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+153900,int_stack+179361,int_stack+172701, 2.0, int_stack+301311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[12] = int_stack + 153900;

}
