/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (00|hh) integrals */

void d12vrr_order_00hh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+15, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+3, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+56, dvrr_stack+9, dvrr_stack+50, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+66, dvrr_stack+21, dvrr_stack+56, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+81, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+96, dvrr_stack+81, dvrr_stack+66, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+31, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+117, dvrr_stack+15, dvrr_stack+34, dvrr_stack+0, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+127, dvrr_stack+117, dvrr_stack+40, dvrr_stack+15, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+142, dvrr_stack+127, dvrr_stack+81, dvrr_stack+117, dvrr_stack+40, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+3, dvrr_stack+31, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+50, dvrr_stack+34, dvrr_stack+6, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+163, dvrr_stack+56, dvrr_stack+40, dvrr_stack+9, dvrr_stack+50, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+178, dvrr_stack+66, dvrr_stack+163, dvrr_stack+21, dvrr_stack+56, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+199, dvrr_stack+96, dvrr_stack+178, dvrr_stack+81, dvrr_stack+66, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+227, dvrr_stack+142, dvrr_stack+96, dvrr_stack+127, dvrr_stack+81, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+255, dvrr_stack+227, dvrr_stack+199, dvrr_stack+142, dvrr_stack+96, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+81, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+84, dvrr_stack+81, dvrr_stack+0, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+84, dvrr_stack+15, dvrr_stack+81, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+291, dvrr_stack+21, dvrr_stack+117, dvrr_stack+84, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+306, dvrr_stack+291, dvrr_stack+127, dvrr_stack+21, dvrr_stack+117, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+327, dvrr_stack+306, dvrr_stack+142, dvrr_stack+291, dvrr_stack+127, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+355, dvrr_stack+327, dvrr_stack+227, dvrr_stack+306, dvrr_stack+142, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+90, dvrr_stack+31, dvrr_stack+0, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6, dvrr_stack+34, dvrr_stack+90, dvrr_stack+3, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+391, dvrr_stack+40, dvrr_stack+6, dvrr_stack+50, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+406, dvrr_stack+163, dvrr_stack+391, dvrr_stack+56, dvrr_stack+40, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+427, dvrr_stack+178, dvrr_stack+406, dvrr_stack+66, dvrr_stack+163, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+455, dvrr_stack+199, dvrr_stack+427, dvrr_stack+96, dvrr_stack+178, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+491, dvrr_stack+255, dvrr_stack+455, dvrr_stack+227, dvrr_stack+199, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+536, dvrr_stack+355, dvrr_stack+255, dvrr_stack+327, dvrr_stack+227, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+581, dvrr_stack+536, dvrr_stack+491, dvrr_stack+355, dvrr_stack+255, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+96, dvrr_stack+0, dvrr_stack+3, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+102, dvrr_stack+90, dvrr_stack+96, dvrr_stack+31, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+102, dvrr_stack+34, dvrr_stack+90, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+636, dvrr_stack+391, dvrr_stack+50, dvrr_stack+40, dvrr_stack+6, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+657, dvrr_stack+406, dvrr_stack+636, dvrr_stack+163, dvrr_stack+391, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+685, dvrr_stack+427, dvrr_stack+657, dvrr_stack+178, dvrr_stack+406, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+721, dvrr_stack+455, dvrr_stack+685, dvrr_stack+199, dvrr_stack+427, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+163, dvrr_stack+491, dvrr_stack+721, dvrr_stack+255, dvrr_stack+455, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+766, dvrr_stack+581, dvrr_stack+163, dvrr_stack+536, dvrr_stack+491, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+218, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+221, dvrr_stack+218, dvrr_stack+81, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+31, dvrr_stack+221, dvrr_stack+84, dvrr_stack+218, dvrr_stack+81, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+65, dvrr_stack+31, dvrr_stack+21, dvrr_stack+221, dvrr_stack+84, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+832, dvrr_stack+65, dvrr_stack+291, dvrr_stack+31, dvrr_stack+21, NULL);
 tmp = dvrr_stack + 832;
 target_ptr = Libderiv->dvrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+853, dvrr_stack+832, dvrr_stack+306, dvrr_stack+65, dvrr_stack+291, NULL);
 tmp = dvrr_stack + 853;
 target_ptr = Libderiv->dvrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+881, dvrr_stack+853, dvrr_stack+327, dvrr_stack+832, dvrr_stack+306, NULL);
 tmp = dvrr_stack + 881;
 target_ptr = Libderiv->dvrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+917, dvrr_stack+881, dvrr_stack+355, dvrr_stack+853, dvrr_stack+327, NULL);
 tmp = dvrr_stack + 917;
 target_ptr = Libderiv->dvrr_classes[0][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+962, dvrr_stack+917, dvrr_stack+536, dvrr_stack+881, dvrr_stack+355, NULL);
 tmp = dvrr_stack + 962;
 target_ptr = Libderiv->dvrr_classes[0][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1017, dvrr_stack+962, dvrr_stack+581, dvrr_stack+917, dvrr_stack+536, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1083, dvrr_stack+1017, dvrr_stack+766, NULL, NULL, dvrr_stack+581);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+1281,dvrr_stack+853,dvrr_stack+832,1);


 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+1344,dvrr_stack+881,dvrr_stack+853,1);


 /* compute (0 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+1428,dvrr_stack+1344,dvrr_stack+1281,1);


 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,21,dvrr_stack+1554, dvrr_stack+1428, dvrr_stack+832);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+1617,dvrr_stack+917,dvrr_stack+881,1);


 /* compute (0 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+1725,dvrr_stack+1617,dvrr_stack+1344,1);


 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,28,dvrr_stack+1893, dvrr_stack+1725, dvrr_stack+853);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1977,dvrr_stack+962,dvrr_stack+917,1);


 /* compute (0 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+2112,dvrr_stack+1977,dvrr_stack+1617,1);


 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,36,dvrr_stack+2328, dvrr_stack+2112, dvrr_stack+881);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+2436,dvrr_stack+1017,dvrr_stack+962,1);


 /* compute (0 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+2601,dvrr_stack+2436,dvrr_stack+1977,1);


 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,45,dvrr_stack+2871, dvrr_stack+2601, dvrr_stack+917);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+3006, dvrr_stack+1017, dvrr_stack+766, dvrr_stack+962, dvrr_stack+581, NULL);

 /* compute (0 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+3084,dvrr_stack+3006,dvrr_stack+1017,1);


 /* compute (0 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+3282,dvrr_stack+3084,dvrr_stack+2436,1);


 /* compute (0 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,55,dvrr_stack+3612, dvrr_stack+3282, dvrr_stack+962);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+218, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+221, dvrr_stack+3, dvrr_stack+218, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+80, dvrr_stack+96, dvrr_stack+221, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3777, dvrr_stack+102, dvrr_stack+80, dvrr_stack+90, dvrr_stack+96, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+80, dvrr_stack+50, dvrr_stack+3777, dvrr_stack+6, dvrr_stack+102, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3777, dvrr_stack+636, dvrr_stack+80, dvrr_stack+391, dvrr_stack+50, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+80, dvrr_stack+657, dvrr_stack+3777, dvrr_stack+406, dvrr_stack+636, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3777, dvrr_stack+685, dvrr_stack+80, dvrr_stack+427, dvrr_stack+657, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3822, dvrr_stack+721, dvrr_stack+3777, dvrr_stack+455, dvrr_stack+685, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+636, dvrr_stack+163, dvrr_stack+3822, dvrr_stack+491, dvrr_stack+721, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+3777, dvrr_stack+766, dvrr_stack+636, dvrr_stack+581, dvrr_stack+163, NULL);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+3855, dvrr_stack+3006, dvrr_stack+3777, dvrr_stack+1017, dvrr_stack+766, NULL);

 /* compute (0 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+3946,dvrr_stack+3855,dvrr_stack+3006,1);


 /* compute (0 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+4180,dvrr_stack+3946,dvrr_stack+3084,1);


 /* compute (0 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,66,dvrr_stack+4576, dvrr_stack+4180, dvrr_stack+1017);

 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,21,dvrr_stack+4774, dvrr_stack+1428, dvrr_stack+832);

 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,28,dvrr_stack+4837, dvrr_stack+1725, dvrr_stack+853);

 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,36,dvrr_stack+4921, dvrr_stack+2112, dvrr_stack+881);

 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,45,dvrr_stack+5029, dvrr_stack+2601, dvrr_stack+917);

 /* compute (0 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,55,dvrr_stack+5164, dvrr_stack+3282, dvrr_stack+962);

 /* compute (0 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,66,dvrr_stack+5329, dvrr_stack+4180, dvrr_stack+1017);

 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,21,dvrr_stack+5527, dvrr_stack+1428, dvrr_stack+832);

 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,28,dvrr_stack+1428, dvrr_stack+1725, dvrr_stack+853);

 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,36,dvrr_stack+1725, dvrr_stack+2112, dvrr_stack+881);

 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,45,dvrr_stack+2112, dvrr_stack+2601, dvrr_stack+917);

 /* compute (0 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,55,dvrr_stack+2601, dvrr_stack+3282, dvrr_stack+962);

 /* compute (0 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,66,dvrr_stack+3282, dvrr_stack+4180, dvrr_stack+1017);

 /* compute (0 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+4180,dvrr_stack+832,dvrr_stack+65,1);


 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,15,dvrr_stack+4225, dvrr_stack+4180, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+4240, dvrr_stack+1344, NULL);
 tmp = dvrr_stack + 4240;
 target_ptr = Libderiv->deriv_classes[0][6][11];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+0, dvrr_stack+1281, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[0][5][11];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+4268, dvrr_stack+1617, NULL);
 tmp = dvrr_stack + 4268;
 target_ptr = Libderiv->deriv_classes[0][7][11];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+4304, dvrr_stack+1977, NULL);
 tmp = dvrr_stack + 4304;
 target_ptr = Libderiv->deriv_classes[0][8][11];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+4349, dvrr_stack+2436, NULL);
 tmp = dvrr_stack + 4349;
 target_ptr = Libderiv->deriv_classes[0][9][11];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,66,dvrr_stack+4404, dvrr_stack+3084, NULL);
 tmp = dvrr_stack + 4404;
 target_ptr = Libderiv->deriv_classes[0][10][11];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,78,dvrr_stack+4470, dvrr_stack+3946, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,15,dvrr_stack+4548, dvrr_stack+4180, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+3480, dvrr_stack+1344, NULL);
 tmp = dvrr_stack + 3480;
 target_ptr = Libderiv->deriv_classes[0][6][10];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+3508, dvrr_stack+1281, NULL);
 tmp = dvrr_stack + 3508;
 target_ptr = Libderiv->deriv_classes[0][5][10];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+3529, dvrr_stack+1617, NULL);
 tmp = dvrr_stack + 3529;
 target_ptr = Libderiv->deriv_classes[0][7][10];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+3565, dvrr_stack+1977, NULL);
 tmp = dvrr_stack + 3565;
 target_ptr = Libderiv->deriv_classes[0][8][10];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+2766, dvrr_stack+2436, NULL);
 tmp = dvrr_stack + 2766;
 target_ptr = Libderiv->deriv_classes[0][9][10];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,66,dvrr_stack+2247, dvrr_stack+3084, NULL);
 tmp = dvrr_stack + 2247;
 target_ptr = Libderiv->deriv_classes[0][10][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,78,dvrr_stack+5590, dvrr_stack+3946, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,15,dvrr_stack+2313, dvrr_stack+4180, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+4180, dvrr_stack+1344, NULL);
 tmp = dvrr_stack + 4180;
 target_ptr = Libderiv->deriv_classes[0][6][9];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+1344, dvrr_stack+1281, NULL);
 tmp = dvrr_stack + 1344;
 target_ptr = Libderiv->deriv_classes[0][5][9];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+1281, dvrr_stack+1617, NULL);
 tmp = dvrr_stack + 1281;
 target_ptr = Libderiv->deriv_classes[0][7][9];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+1617, dvrr_stack+1977, NULL);
 tmp = dvrr_stack + 1617;
 target_ptr = Libderiv->deriv_classes[0][8][9];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+1977, dvrr_stack+2436, NULL);
 tmp = dvrr_stack + 1977;
 target_ptr = Libderiv->deriv_classes[0][9][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,66,dvrr_stack+2436, dvrr_stack+3084, NULL);
 tmp = dvrr_stack + 2436;
 target_ptr = Libderiv->deriv_classes[0][10][9];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,78,dvrr_stack+3084, dvrr_stack+3946, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,1,1,dvrr_stack+3946, dvrr_stack+832, dvrr_stack+31);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+3961, dvrr_stack+881, dvrr_stack+832);
 tmp = dvrr_stack + 3961;
 target_ptr = Libderiv->deriv_classes[0][6][8];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+3989, dvrr_stack+853, dvrr_stack+65);
 tmp = dvrr_stack + 3989;
 target_ptr = Libderiv->deriv_classes[0][5][8];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+4010, dvrr_stack+917, dvrr_stack+853);
 tmp = dvrr_stack + 4010;
 target_ptr = Libderiv->deriv_classes[0][7][8];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+4046, dvrr_stack+962, dvrr_stack+881);
 tmp = dvrr_stack + 4046;
 target_ptr = Libderiv->deriv_classes[0][8][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+4091, dvrr_stack+1017, dvrr_stack+917);
 tmp = dvrr_stack + 4091;
 target_ptr = Libderiv->deriv_classes[0][9][8];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+3162, dvrr_stack+3006, dvrr_stack+962);
 tmp = dvrr_stack + 3162;
 target_ptr = Libderiv->deriv_classes[0][10][8];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,1,1,dvrr_stack+2502, dvrr_stack+3855, dvrr_stack+1017);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,1,1,dvrr_stack+4146, dvrr_stack+832, dvrr_stack+31);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+3228, dvrr_stack+881, dvrr_stack+832);
 tmp = dvrr_stack + 3228;
 target_ptr = Libderiv->deriv_classes[0][6][7];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2580, dvrr_stack+853, dvrr_stack+65);
 tmp = dvrr_stack + 2580;
 target_ptr = Libderiv->deriv_classes[0][5][7];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2032, dvrr_stack+917, dvrr_stack+853);
 tmp = dvrr_stack + 2032;
 target_ptr = Libderiv->deriv_classes[0][7][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+1662, dvrr_stack+962, dvrr_stack+881);
 tmp = dvrr_stack + 1662;
 target_ptr = Libderiv->deriv_classes[0][8][7];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+1365, dvrr_stack+1017, dvrr_stack+917);
 tmp = dvrr_stack + 1365;
 target_ptr = Libderiv->deriv_classes[0][9][7];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+5668, dvrr_stack+3006, dvrr_stack+962);
 tmp = dvrr_stack + 5668;
 target_ptr = Libderiv->deriv_classes[0][10][7];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,1,1,dvrr_stack+5734, dvrr_stack+3855, dvrr_stack+1017);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,1,1,dvrr_stack+4161, dvrr_stack+832, dvrr_stack+31);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+31, dvrr_stack+881, dvrr_stack+832);
 tmp = dvrr_stack + 31;
 target_ptr = Libderiv->deriv_classes[0][6][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+3256, dvrr_stack+853, dvrr_stack+65);
 tmp = dvrr_stack + 3256;
 target_ptr = Libderiv->deriv_classes[0][5][6];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+2068, dvrr_stack+917, dvrr_stack+853);
 tmp = dvrr_stack + 2068;
 target_ptr = Libderiv->deriv_classes[0][7][6];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+2821, dvrr_stack+962, dvrr_stack+881);
 tmp = dvrr_stack + 2821;
 target_ptr = Libderiv->deriv_classes[0][8][6];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+1833, dvrr_stack+1017, dvrr_stack+917);
 tmp = dvrr_stack + 1833;
 target_ptr = Libderiv->deriv_classes[0][9][6];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+5812, dvrr_stack+3006, dvrr_stack+962);
 tmp = dvrr_stack + 5812;
 target_ptr = Libderiv->deriv_classes[0][10][6];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,1,1,dvrr_stack+5878, dvrr_stack+3855, dvrr_stack+1017);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+3855, dvrr_stack+832, dvrr_stack+306, NULL, NULL, dvrr_stack+291);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+391, dvrr_stack+853, dvrr_stack+327, NULL, NULL, dvrr_stack+306);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+5956,dvrr_stack+391,dvrr_stack+3855,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+6145, dvrr_stack+5956, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6208, dvrr_stack+881, dvrr_stack+355, NULL, NULL, dvrr_stack+327);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+6316,dvrr_stack+6208,dvrr_stack+391,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+6568, dvrr_stack+6316, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6652, dvrr_stack+917, dvrr_stack+536, NULL, NULL, dvrr_stack+355);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+6787,dvrr_stack+6652,dvrr_stack+6208,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+7111, dvrr_stack+6787, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7219, dvrr_stack+962, dvrr_stack+581, NULL, NULL, dvrr_stack+536);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+7384,dvrr_stack+7219,dvrr_stack+6652,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+7789, dvrr_stack+7384, NULL);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+7924,dvrr_stack+1083,dvrr_stack+7219,3);


 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+8419, dvrr_stack+7924, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+8584, dvrr_stack+3006, dvrr_stack+3777, NULL, NULL, dvrr_stack+766);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+8818,dvrr_stack+8584,dvrr_stack+1083,3);


 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+9412, dvrr_stack+8818, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+3777, dvrr_stack+5956, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+9610, dvrr_stack+6316, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+9694, dvrr_stack+6787, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+9802, dvrr_stack+7384, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+9937, dvrr_stack+7924, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+10102, dvrr_stack+8818, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+3006, dvrr_stack+5956, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+5956, dvrr_stack+6316, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+6316, dvrr_stack+6787, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+6787, dvrr_stack+7384, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+7384, dvrr_stack+7924, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+7924, dvrr_stack+8818, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8818, dvrr_stack+65, dvrr_stack+291, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+8863, dvrr_stack+391, dvrr_stack+8818);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+8926, dvrr_stack+6208, dvrr_stack+3855);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+9010, dvrr_stack+6652, dvrr_stack+391);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+9118, dvrr_stack+7219, dvrr_stack+6208);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+8122, dvrr_stack+1083, dvrr_stack+6652);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+7549, dvrr_stack+8584, dvrr_stack+7219);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+9253, dvrr_stack+391, dvrr_stack+8818);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+9316, dvrr_stack+6208, dvrr_stack+3855);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+8287, dvrr_stack+6652, dvrr_stack+391);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+6922, dvrr_stack+7219, dvrr_stack+6208);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+10300, dvrr_stack+1083, dvrr_stack+6652);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+10465, dvrr_stack+8584, dvrr_stack+7219);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+6424, dvrr_stack+391, dvrr_stack+8818);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+6040, dvrr_stack+6208, dvrr_stack+3855);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+10663, dvrr_stack+6652, dvrr_stack+391);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+10771, dvrr_stack+7219, dvrr_stack+6208);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+10906, dvrr_stack+1083, dvrr_stack+6652);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+11071, dvrr_stack+8584, dvrr_stack+7219);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8584, dvrr_stack+291, dvrr_stack+127, NULL, NULL, dvrr_stack+117);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+8629, dvrr_stack+306, dvrr_stack+142, NULL, NULL, dvrr_stack+127);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+8692, dvrr_stack+3855, dvrr_stack+8629, dvrr_stack+832, dvrr_stack+306, dvrr_stack+8584);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+6487, dvrr_stack+8692, dvrr_stack+832);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+11269, dvrr_stack+327, dvrr_stack+227, NULL, NULL, dvrr_stack+142);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+11353, dvrr_stack+391, dvrr_stack+11269, dvrr_stack+853, dvrr_stack+327, dvrr_stack+8629);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+8584, dvrr_stack+11353, dvrr_stack+853);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11521, dvrr_stack+355, dvrr_stack+255, NULL, NULL, dvrr_stack+227);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11629, dvrr_stack+6208, dvrr_stack+11521, dvrr_stack+881, dvrr_stack+355, dvrr_stack+11269);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+11845, dvrr_stack+11629, dvrr_stack+881);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11953, dvrr_stack+536, dvrr_stack+491, NULL, NULL, dvrr_stack+255);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12088, dvrr_stack+6652, dvrr_stack+11953, dvrr_stack+917, dvrr_stack+536, dvrr_stack+11521);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+12358, dvrr_stack+12088, dvrr_stack+917);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+581, dvrr_stack+163, NULL, NULL, dvrr_stack+491);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12658, dvrr_stack+7219, dvrr_stack+12493, dvrr_stack+962, dvrr_stack+581, dvrr_stack+11953);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+218, dvrr_stack+12658, dvrr_stack+962);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12988, dvrr_stack+766, dvrr_stack+636, NULL, NULL, dvrr_stack+163);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+13186, dvrr_stack+1083, dvrr_stack+12988, dvrr_stack+1017, dvrr_stack+766, dvrr_stack+12493);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+12988, dvrr_stack+13186, dvrr_stack+1017);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+12493, dvrr_stack+8692, dvrr_stack+832);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+11269, dvrr_stack+11353, dvrr_stack+853);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+11521, dvrr_stack+11629, dvrr_stack+881);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+11953, dvrr_stack+12088, dvrr_stack+917);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+13582, dvrr_stack+12658, dvrr_stack+962);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+13747, dvrr_stack+13186, dvrr_stack+1017);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+12556, dvrr_stack+8692, dvrr_stack+832);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+8668, dvrr_stack+11353, dvrr_stack+853);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+11353, dvrr_stack+11629, dvrr_stack+881);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+11629, dvrr_stack+12088, dvrr_stack+917);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+12088, dvrr_stack+12658, dvrr_stack+962);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+12619, dvrr_stack+13186, dvrr_stack+1017);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+13186, dvrr_stack+1083, NULL);
 tmp = dvrr_stack + 13186;
 target_ptr = Libderiv->deriv_classes[0][10][2];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+13252, dvrr_stack+1083, NULL);
 tmp = dvrr_stack + 13252;
 target_ptr = Libderiv->deriv_classes[0][10][1];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+13318, dvrr_stack+1083, NULL);
 tmp = dvrr_stack + 13318;
 target_ptr = Libderiv->deriv_classes[0][10][0];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,21,dvrr_stack+6124, dvrr_stack+1554, NULL);
 tmp = dvrr_stack + 6124;
 target_ptr = Libderiv->deriv2_classes[0][5][143];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,28,dvrr_stack+3918, dvrr_stack+1893, NULL);
 tmp = dvrr_stack + 3918;
 target_ptr = Libderiv->deriv2_classes[0][6][143];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,36,dvrr_stack+13384, dvrr_stack+2328, NULL);
 tmp = dvrr_stack + 13384;
 target_ptr = Libderiv->deriv2_classes[0][7][143];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,45,dvrr_stack+13420, dvrr_stack+2871, NULL);
 tmp = dvrr_stack + 13420;
 target_ptr = Libderiv->deriv2_classes[0][8][143];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,55,dvrr_stack+13465, dvrr_stack+3612, NULL);
 tmp = dvrr_stack + 13465;
 target_ptr = Libderiv->deriv2_classes[0][9][143];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,66,dvrr_stack+12253, dvrr_stack+4576, NULL);
 tmp = dvrr_stack + 12253;
 target_ptr = Libderiv->deriv2_classes[0][10][143];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,21,dvrr_stack+13520, dvrr_stack+1554, NULL);
 tmp = dvrr_stack + 13520;
 target_ptr = Libderiv->deriv2_classes[0][5][131];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,28,dvrr_stack+13541, dvrr_stack+1893, NULL);
 tmp = dvrr_stack + 13541;
 target_ptr = Libderiv->deriv2_classes[0][6][131];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,36,dvrr_stack+12319, dvrr_stack+2328, NULL);
 tmp = dvrr_stack + 12319;
 target_ptr = Libderiv->deriv2_classes[0][7][131];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,45,dvrr_stack+11764, dvrr_stack+2871, NULL);
 tmp = dvrr_stack + 11764;
 target_ptr = Libderiv->deriv2_classes[0][8][131];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,55,dvrr_stack+11461, dvrr_stack+3612, NULL);
 tmp = dvrr_stack + 11461;
 target_ptr = Libderiv->deriv2_classes[0][9][131];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,66,dvrr_stack+12817, dvrr_stack+4576, NULL);
 tmp = dvrr_stack + 12817;
 target_ptr = Libderiv->deriv2_classes[0][10][131];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+11809, dvrr_stack+4774, NULL);
 tmp = dvrr_stack + 11809;
 target_ptr = Libderiv->deriv2_classes[0][5][130];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+12883, dvrr_stack+4837, NULL);
 tmp = dvrr_stack + 12883;
 target_ptr = Libderiv->deriv2_classes[0][6][130];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+12911, dvrr_stack+4921, NULL);
 tmp = dvrr_stack + 12911;
 target_ptr = Libderiv->deriv2_classes[0][7][130];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+8752, dvrr_stack+5029, NULL);
 tmp = dvrr_stack + 8752;
 target_ptr = Libderiv->deriv2_classes[0][8][130];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+8797, dvrr_stack+5164, NULL);
 tmp = dvrr_stack + 8797;
 target_ptr = Libderiv->deriv2_classes[0][9][130];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,66,dvrr_stack+59, dvrr_stack+5329, NULL);
 tmp = dvrr_stack + 59;
 target_ptr = Libderiv->deriv2_classes[0][10][130];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,21,dvrr_stack+12947, dvrr_stack+1554, NULL);
 tmp = dvrr_stack + 12947;
 target_ptr = Libderiv->deriv2_classes[0][5][119];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,28,dvrr_stack+7747, dvrr_stack+1893, NULL);
 tmp = dvrr_stack + 7747;
 target_ptr = Libderiv->deriv2_classes[0][6][119];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,36,dvrr_stack+7057, dvrr_stack+2328, NULL);
 tmp = dvrr_stack + 7057;
 target_ptr = Libderiv->deriv2_classes[0][7][119];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,45,dvrr_stack+2328, dvrr_stack+2871, NULL);
 tmp = dvrr_stack + 2328;
 target_ptr = Libderiv->deriv2_classes[0][8][119];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,55,dvrr_stack+2373, dvrr_stack+3612, NULL);
 tmp = dvrr_stack + 2373;
 target_ptr = Libderiv->deriv2_classes[0][9][119];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,66,dvrr_stack+125, dvrr_stack+4576, NULL);
 tmp = dvrr_stack + 125;
 target_ptr = Libderiv->deriv2_classes[0][10][119];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+8395, dvrr_stack+4774, NULL);
 tmp = dvrr_stack + 8395;
 target_ptr = Libderiv->deriv2_classes[0][5][118];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+4563, dvrr_stack+4837, NULL);
 tmp = dvrr_stack + 4563;
 target_ptr = Libderiv->deriv2_classes[0][6][118];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+4591, dvrr_stack+4921, NULL);
 tmp = dvrr_stack + 4591;
 target_ptr = Libderiv->deriv2_classes[0][7][118];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+4627, dvrr_stack+5029, NULL);
 tmp = dvrr_stack + 4627;
 target_ptr = Libderiv->deriv2_classes[0][8][118];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+4672, dvrr_stack+5164, NULL);
 tmp = dvrr_stack + 4672;
 target_ptr = Libderiv->deriv2_classes[0][9][118];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,66,dvrr_stack+4727, dvrr_stack+5329, NULL);
 tmp = dvrr_stack + 4727;
 target_ptr = Libderiv->deriv2_classes[0][10][118];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+191, dvrr_stack+5527, NULL);
 tmp = dvrr_stack + 191;
 target_ptr = Libderiv->deriv2_classes[0][5][117];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+4793, dvrr_stack+1428, NULL);
 tmp = dvrr_stack + 4793;
 target_ptr = Libderiv->deriv2_classes[0][6][117];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+1420, dvrr_stack+1725, NULL);
 tmp = dvrr_stack + 1420;
 target_ptr = Libderiv->deriv2_classes[0][7][117];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+1707, dvrr_stack+2112, NULL);
 tmp = dvrr_stack + 1707;
 target_ptr = Libderiv->deriv2_classes[0][8][117];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+2104, dvrr_stack+2601, NULL);
 tmp = dvrr_stack + 2104;
 target_ptr = Libderiv->deriv2_classes[0][9][117];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,66,dvrr_stack+2601, dvrr_stack+3282, NULL);
 tmp = dvrr_stack + 2601;
 target_ptr = Libderiv->deriv2_classes[0][10][117];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+2667, dvrr_stack+4240, dvrr_stack+4225);
 tmp = dvrr_stack + 2667;
 target_ptr = Libderiv->deriv2_classes[0][5][107];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+2688, dvrr_stack+4268, dvrr_stack+0);
 tmp = dvrr_stack + 2688;
 target_ptr = Libderiv->deriv2_classes[0][6][107];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+2716, dvrr_stack+4304, dvrr_stack+4240);
 tmp = dvrr_stack + 2716;
 target_ptr = Libderiv->deriv2_classes[0][7][107];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+3277, dvrr_stack+4349, dvrr_stack+4268);
 tmp = dvrr_stack + 3277;
 target_ptr = Libderiv->deriv2_classes[0][8][107];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+3322, dvrr_stack+4404, dvrr_stack+4304);
 tmp = dvrr_stack + 3322;
 target_ptr = Libderiv->deriv2_classes[0][9][107];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+3377, dvrr_stack+4470, dvrr_stack+4349);
 tmp = dvrr_stack + 3377;
 target_ptr = Libderiv->deriv2_classes[0][10][107];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+3443, dvrr_stack+3480, dvrr_stack+4548);
 tmp = dvrr_stack + 3443;
 target_ptr = Libderiv->deriv2_classes[0][5][106];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+2159, dvrr_stack+3529, dvrr_stack+3508);
 tmp = dvrr_stack + 2159;
 target_ptr = Libderiv->deriv2_classes[0][6][106];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+2187, dvrr_stack+3565, dvrr_stack+3480);
 tmp = dvrr_stack + 2187;
 target_ptr = Libderiv->deriv2_classes[0][7][106];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+1752, dvrr_stack+2766, dvrr_stack+3529);
 tmp = dvrr_stack + 1752;
 target_ptr = Libderiv->deriv2_classes[0][8][106];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+1456, dvrr_stack+2247, dvrr_stack+3565);
 tmp = dvrr_stack + 1456;
 target_ptr = Libderiv->deriv2_classes[0][9][106];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+1511, dvrr_stack+5590, dvrr_stack+2766);
 tmp = dvrr_stack + 1511;
 target_ptr = Libderiv->deriv2_classes[0][10][106];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+2223, dvrr_stack+4180, dvrr_stack+2313);
 tmp = dvrr_stack + 2223;
 target_ptr = Libderiv->deriv2_classes[0][5][105];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+1797, dvrr_stack+1281, dvrr_stack+1344);
 tmp = dvrr_stack + 1797;
 target_ptr = Libderiv->deriv2_classes[0][6][105];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+1577, dvrr_stack+1617, dvrr_stack+4180);
 tmp = dvrr_stack + 1577;
 target_ptr = Libderiv->deriv2_classes[0][7][105];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+4821, dvrr_stack+1977, dvrr_stack+1281);
 tmp = dvrr_stack + 4821;
 target_ptr = Libderiv->deriv2_classes[0][8][105];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+4866, dvrr_stack+2436, dvrr_stack+1617);
 tmp = dvrr_stack + 4866;
 target_ptr = Libderiv->deriv2_classes[0][9][105];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+4921, dvrr_stack+3084, dvrr_stack+1977);
 tmp = dvrr_stack + 4921;
 target_ptr = Libderiv->deriv2_classes[0][10][105];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+1317, dvrr_stack+3961, dvrr_stack+3946);
 tmp = dvrr_stack + 1317;
 target_ptr = Libderiv->deriv2_classes[0][5][104];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+4987, dvrr_stack+4010, dvrr_stack+3989);
 tmp = dvrr_stack + 4987;
 target_ptr = Libderiv->deriv2_classes[0][6][104];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+5015, dvrr_stack+4046, dvrr_stack+3961);
 tmp = dvrr_stack + 5015;
 target_ptr = Libderiv->deriv2_classes[0][7][104];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+5051, dvrr_stack+4091, dvrr_stack+4010);
 tmp = dvrr_stack + 5051;
 target_ptr = Libderiv->deriv2_classes[0][8][104];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+5096, dvrr_stack+3162, dvrr_stack+4046);
 tmp = dvrr_stack + 5096;
 target_ptr = Libderiv->deriv2_classes[0][9][104];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+5151, dvrr_stack+2502, dvrr_stack+4091);
 tmp = dvrr_stack + 5151;
 target_ptr = Libderiv->deriv2_classes[0][10][104];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+5217, dvrr_stack+4240, dvrr_stack+4225);
 tmp = dvrr_stack + 5217;
 target_ptr = Libderiv->deriv2_classes[0][5][95];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+5238, dvrr_stack+4268, dvrr_stack+0);
 tmp = dvrr_stack + 5238;
 target_ptr = Libderiv->deriv2_classes[0][6][95];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+5266, dvrr_stack+4304, dvrr_stack+4240);
 tmp = dvrr_stack + 5266;
 target_ptr = Libderiv->deriv2_classes[0][7][95];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+5302, dvrr_stack+4349, dvrr_stack+4268);
 tmp = dvrr_stack + 5302;
 target_ptr = Libderiv->deriv2_classes[0][8][95];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+5347, dvrr_stack+4404, dvrr_stack+4304);
 tmp = dvrr_stack + 5347;
 target_ptr = Libderiv->deriv2_classes[0][9][95];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+5402, dvrr_stack+4470, dvrr_stack+4349);
 tmp = dvrr_stack + 5402;
 target_ptr = Libderiv->deriv2_classes[0][10][95];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+5468, dvrr_stack+3480, dvrr_stack+4548);
 tmp = dvrr_stack + 5468;
 target_ptr = Libderiv->deriv2_classes[0][5][94];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+5489, dvrr_stack+3529, dvrr_stack+3508);
 tmp = dvrr_stack + 5489;
 target_ptr = Libderiv->deriv2_classes[0][6][94];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+5517, dvrr_stack+3565, dvrr_stack+3480);
 tmp = dvrr_stack + 5517;
 target_ptr = Libderiv->deriv2_classes[0][7][94];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+3610, dvrr_stack+2766, dvrr_stack+3529);
 tmp = dvrr_stack + 3610;
 target_ptr = Libderiv->deriv2_classes[0][8][94];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+3655, dvrr_stack+2247, dvrr_stack+3565);
 tmp = dvrr_stack + 3655;
 target_ptr = Libderiv->deriv2_classes[0][9][94];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+3710, dvrr_stack+5590, dvrr_stack+2766);
 tmp = dvrr_stack + 3710;
 target_ptr = Libderiv->deriv2_classes[0][10][94];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+5553, dvrr_stack+4180, dvrr_stack+2313);
 tmp = dvrr_stack + 5553;
 target_ptr = Libderiv->deriv2_classes[0][5][93];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+2866, dvrr_stack+1281, dvrr_stack+1344);
 tmp = dvrr_stack + 2866;
 target_ptr = Libderiv->deriv2_classes[0][6][93];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2894, dvrr_stack+1617, dvrr_stack+4180);
 tmp = dvrr_stack + 2894;
 target_ptr = Libderiv->deriv2_classes[0][7][93];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+2930, dvrr_stack+1977, dvrr_stack+1281);
 tmp = dvrr_stack + 2930;
 target_ptr = Libderiv->deriv2_classes[0][8][93];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+1888, dvrr_stack+2436, dvrr_stack+1617);
 tmp = dvrr_stack + 1888;
 target_ptr = Libderiv->deriv2_classes[0][9][93];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+475, dvrr_stack+3084, dvrr_stack+1977);
 tmp = dvrr_stack + 475;
 target_ptr = Libderiv->deriv2_classes[0][10][93];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2975, dvrr_stack+3961, dvrr_stack+3946);
 tmp = dvrr_stack + 2975;
 target_ptr = Libderiv->deriv2_classes[0][5][92];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+1943, dvrr_stack+4010, dvrr_stack+3989);
 tmp = dvrr_stack + 1943;
 target_ptr = Libderiv->deriv2_classes[0][6][92];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+13945, dvrr_stack+4046, dvrr_stack+3961);
 tmp = dvrr_stack + 13945;
 target_ptr = Libderiv->deriv2_classes[0][7][92];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+541, dvrr_stack+4091, dvrr_stack+4010);
 tmp = dvrr_stack + 541;
 target_ptr = Libderiv->deriv2_classes[0][8][92];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+586, dvrr_stack+3162, dvrr_stack+4046);
 tmp = dvrr_stack + 586;
 target_ptr = Libderiv->deriv2_classes[0][9][92];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+641, dvrr_stack+2502, dvrr_stack+4091);
 tmp = dvrr_stack + 641;
 target_ptr = Libderiv->deriv2_classes[0][10][92];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+707, dvrr_stack+3228, dvrr_stack+4146);
 tmp = dvrr_stack + 707;
 target_ptr = Libderiv->deriv2_classes[0][5][91];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+728, dvrr_stack+2032, dvrr_stack+2580);
 tmp = dvrr_stack + 728;
 target_ptr = Libderiv->deriv2_classes[0][6][91];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+756, dvrr_stack+1662, dvrr_stack+3228);
 tmp = dvrr_stack + 756;
 target_ptr = Libderiv->deriv2_classes[0][7][91];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+792, dvrr_stack+1365, dvrr_stack+2032);
 tmp = dvrr_stack + 792;
 target_ptr = Libderiv->deriv2_classes[0][8][91];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+837, dvrr_stack+5668, dvrr_stack+1662);
 tmp = dvrr_stack + 837;
 target_ptr = Libderiv->deriv2_classes[0][9][91];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+892, dvrr_stack+5734, dvrr_stack+1365);
 tmp = dvrr_stack + 892;
 target_ptr = Libderiv->deriv2_classes[0][10][91];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+958, dvrr_stack+4240, dvrr_stack+4225);
 tmp = dvrr_stack + 958;
 target_ptr = Libderiv->deriv2_classes[0][5][83];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+4208, dvrr_stack+4268, dvrr_stack+0);
 tmp = dvrr_stack + 4208;
 target_ptr = Libderiv->deriv2_classes[0][6][83];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+979, dvrr_stack+4304, dvrr_stack+4240);
 tmp = dvrr_stack + 979;
 target_ptr = Libderiv->deriv2_classes[0][7][83];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+1015, dvrr_stack+4349, dvrr_stack+4268);
 tmp = dvrr_stack + 1015;
 target_ptr = Libderiv->deriv2_classes[0][8][83];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+4236, dvrr_stack+4404, dvrr_stack+4304);
 tmp = dvrr_stack + 4236;
 target_ptr = Libderiv->deriv2_classes[0][9][83];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+4404, dvrr_stack+4470, dvrr_stack+4349);
 tmp = dvrr_stack + 4404;
 target_ptr = Libderiv->deriv2_classes[0][10][83];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+4470, dvrr_stack+3480, dvrr_stack+4548);
 tmp = dvrr_stack + 4470;
 target_ptr = Libderiv->deriv2_classes[0][5][82];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+4491, dvrr_stack+3529, dvrr_stack+3508);
 tmp = dvrr_stack + 4491;
 target_ptr = Libderiv->deriv2_classes[0][6][82];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+4519, dvrr_stack+3565, dvrr_stack+3480);
 tmp = dvrr_stack + 4519;
 target_ptr = Libderiv->deriv2_classes[0][7][82];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3464, dvrr_stack+2766, dvrr_stack+3529);
 tmp = dvrr_stack + 3464;
 target_ptr = Libderiv->deriv2_classes[0][8][82];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+3509, dvrr_stack+2247, dvrr_stack+3565);
 tmp = dvrr_stack + 3509;
 target_ptr = Libderiv->deriv2_classes[0][9][82];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+2244, dvrr_stack+5590, dvrr_stack+2766);
 tmp = dvrr_stack + 2244;
 target_ptr = Libderiv->deriv2_classes[0][10][82];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+0, dvrr_stack+4180, dvrr_stack+2313);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[0][5][81];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+2752, dvrr_stack+1281, dvrr_stack+1344);
 tmp = dvrr_stack + 2752;
 target_ptr = Libderiv->deriv2_classes[0][6][81];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+2780, dvrr_stack+1617, dvrr_stack+4180);
 tmp = dvrr_stack + 2780;
 target_ptr = Libderiv->deriv2_classes[0][7][81];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3564, dvrr_stack+1977, dvrr_stack+1281);
 tmp = dvrr_stack + 3564;
 target_ptr = Libderiv->deriv2_classes[0][8][81];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+4291, dvrr_stack+2436, dvrr_stack+1617);
 tmp = dvrr_stack + 4291;
 target_ptr = Libderiv->deriv2_classes[0][9][81];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+2428, dvrr_stack+3084, dvrr_stack+1977);
 tmp = dvrr_stack + 2428;
 target_ptr = Libderiv->deriv2_classes[0][10][81];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+3069, dvrr_stack+3961, dvrr_stack+3946);
 tmp = dvrr_stack + 3069;
 target_ptr = Libderiv->deriv2_classes[0][5][80];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+3090, dvrr_stack+4010, dvrr_stack+3989);
 tmp = dvrr_stack + 3090;
 target_ptr = Libderiv->deriv2_classes[0][6][80];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+3118, dvrr_stack+4046, dvrr_stack+3961);
 tmp = dvrr_stack + 3118;
 target_ptr = Libderiv->deriv2_classes[0][7][80];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3946, dvrr_stack+4091, dvrr_stack+4010);
 tmp = dvrr_stack + 3946;
 target_ptr = Libderiv->deriv2_classes[0][8][80];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+3991, dvrr_stack+3162, dvrr_stack+4046);
 tmp = dvrr_stack + 3991;
 target_ptr = Libderiv->deriv2_classes[0][9][80];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+3154, dvrr_stack+2502, dvrr_stack+4091);
 tmp = dvrr_stack + 3154;
 target_ptr = Libderiv->deriv2_classes[0][10][80];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+4046, dvrr_stack+3228, dvrr_stack+4146);
 tmp = dvrr_stack + 4046;
 target_ptr = Libderiv->deriv2_classes[0][5][79];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+4067, dvrr_stack+2032, dvrr_stack+2580);
 tmp = dvrr_stack + 4067;
 target_ptr = Libderiv->deriv2_classes[0][6][79];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+4095, dvrr_stack+1662, dvrr_stack+3228);
 tmp = dvrr_stack + 4095;
 target_ptr = Libderiv->deriv2_classes[0][7][79];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+2494, dvrr_stack+1365, dvrr_stack+2032);
 tmp = dvrr_stack + 2494;
 target_ptr = Libderiv->deriv2_classes[0][8][79];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+2539, dvrr_stack+5668, dvrr_stack+1662);
 tmp = dvrr_stack + 2539;
 target_ptr = Libderiv->deriv2_classes[0][9][79];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+1613, dvrr_stack+5734, dvrr_stack+1365);
 tmp = dvrr_stack + 1613;
 target_ptr = Libderiv->deriv2_classes[0][10][79];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+4131, dvrr_stack+31, dvrr_stack+4161);
 tmp = dvrr_stack + 4131;
 target_ptr = Libderiv->deriv2_classes[0][5][78];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+1679, dvrr_stack+2068, dvrr_stack+3256);
 tmp = dvrr_stack + 1679;
 target_ptr = Libderiv->deriv2_classes[0][6][78];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+4152, dvrr_stack+2821, dvrr_stack+31);
 tmp = dvrr_stack + 4152;
 target_ptr = Libderiv->deriv2_classes[0][7][78];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3220, dvrr_stack+1833, dvrr_stack+2068);
 tmp = dvrr_stack + 3220;
 target_ptr = Libderiv->deriv2_classes[0][8][78];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+1338, dvrr_stack+5812, dvrr_stack+2821);
 tmp = dvrr_stack + 1338;
 target_ptr = Libderiv->deriv2_classes[0][9][78];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+5574, dvrr_stack+5878, dvrr_stack+1833);
 tmp = dvrr_stack + 5574;
 target_ptr = Libderiv->deriv2_classes[0][10][78];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,21,dvrr_stack+21, dvrr_stack+6145, NULL);
 tmp = dvrr_stack + 21;
 target_ptr = Libderiv->deriv2_classes[0][5][35];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,28,dvrr_stack+2816, dvrr_stack+6568, NULL);
 tmp = dvrr_stack + 2816;
 target_ptr = Libderiv->deriv2_classes[0][6][35];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,36,dvrr_stack+1825, dvrr_stack+7111, NULL);
 tmp = dvrr_stack + 1825;
 target_ptr = Libderiv->deriv2_classes[0][7][35];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,45,dvrr_stack+4346, dvrr_stack+7789, NULL);
 tmp = dvrr_stack + 4346;
 target_ptr = Libderiv->deriv2_classes[0][8][35];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,55,dvrr_stack+5640, dvrr_stack+8419, NULL);
 tmp = dvrr_stack + 5640;
 target_ptr = Libderiv->deriv2_classes[0][9][35];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,66,dvrr_stack+5695, dvrr_stack+9412, NULL);
 tmp = dvrr_stack + 5695;
 target_ptr = Libderiv->deriv2_classes[0][10][35];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+2844, dvrr_stack+3777, NULL);
 tmp = dvrr_stack + 2844;
 target_ptr = Libderiv->deriv2_classes[0][5][34];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+5761, dvrr_stack+9610, NULL);
 tmp = dvrr_stack + 5761;
 target_ptr = Libderiv->deriv2_classes[0][6][34];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+5789, dvrr_stack+9694, NULL);
 tmp = dvrr_stack + 5789;
 target_ptr = Libderiv->deriv2_classes[0][7][34];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+5825, dvrr_stack+9802, NULL);
 tmp = dvrr_stack + 5825;
 target_ptr = Libderiv->deriv2_classes[0][8][34];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+5870, dvrr_stack+9937, NULL);
 tmp = dvrr_stack + 5870;
 target_ptr = Libderiv->deriv2_classes[0][9][34];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+1971, dvrr_stack+10102, NULL);
 tmp = dvrr_stack + 1971;
 target_ptr = Libderiv->deriv2_classes[0][10][34];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+1861, dvrr_stack+3006, NULL);
 tmp = dvrr_stack + 1861;
 target_ptr = Libderiv->deriv2_classes[0][5][33];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+5925, dvrr_stack+5956, NULL);
 tmp = dvrr_stack + 5925;
 target_ptr = Libderiv->deriv2_classes[0][6][33];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+2037, dvrr_stack+6316, NULL);
 tmp = dvrr_stack + 2037;
 target_ptr = Libderiv->deriv2_classes[0][7][33];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+1060, dvrr_stack+6787, NULL);
 tmp = dvrr_stack + 1060;
 target_ptr = Libderiv->deriv2_classes[0][8][33];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+1105, dvrr_stack+7384, NULL);
 tmp = dvrr_stack + 1105;
 target_ptr = Libderiv->deriv2_classes[0][9][33];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+1160, dvrr_stack+7924, NULL);
 tmp = dvrr_stack + 1160;
 target_ptr = Libderiv->deriv2_classes[0][10][33];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+1393, dvrr_stack+8863, NULL);
 tmp = dvrr_stack + 1393;
 target_ptr = Libderiv->deriv2_classes[0][5][32];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+2073, dvrr_stack+8926, NULL);
 tmp = dvrr_stack + 2073;
 target_ptr = Libderiv->deriv2_classes[0][6][32];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+1226, dvrr_stack+9010, NULL);
 tmp = dvrr_stack + 1226;
 target_ptr = Libderiv->deriv2_classes[0][7][32];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+1262, dvrr_stack+9118, NULL);
 tmp = dvrr_stack + 1262;
 target_ptr = Libderiv->deriv2_classes[0][8][32];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+13981, dvrr_stack+8122, NULL);
 tmp = dvrr_stack + 13981;
 target_ptr = Libderiv->deriv2_classes[0][9][32];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+14036, dvrr_stack+7549, NULL);
 tmp = dvrr_stack + 14036;
 target_ptr = Libderiv->deriv2_classes[0][10][32];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+14102, dvrr_stack+9253, NULL);
 tmp = dvrr_stack + 14102;
 target_ptr = Libderiv->deriv2_classes[0][5][31];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+14123, dvrr_stack+9316, NULL);
 tmp = dvrr_stack + 14123;
 target_ptr = Libderiv->deriv2_classes[0][6][31];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+14151, dvrr_stack+8287, NULL);
 tmp = dvrr_stack + 14151;
 target_ptr = Libderiv->deriv2_classes[0][7][31];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+14187, dvrr_stack+6922, NULL);
 tmp = dvrr_stack + 14187;
 target_ptr = Libderiv->deriv2_classes[0][8][31];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+14232, dvrr_stack+10300, NULL);
 tmp = dvrr_stack + 14232;
 target_ptr = Libderiv->deriv2_classes[0][9][31];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+14287, dvrr_stack+10465, NULL);
 tmp = dvrr_stack + 14287;
 target_ptr = Libderiv->deriv2_classes[0][10][31];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+14353, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 14353;
 target_ptr = Libderiv->deriv_classes[0][5][2];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+14374, dvrr_stack+6424, NULL);
 tmp = dvrr_stack + 14374;
 target_ptr = Libderiv->deriv2_classes[0][5][30];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+14395, dvrr_stack+391, NULL);
 tmp = dvrr_stack + 14395;
 target_ptr = Libderiv->deriv_classes[0][6][2];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+14423, dvrr_stack+6040, NULL);
 tmp = dvrr_stack + 14423;
 target_ptr = Libderiv->deriv2_classes[0][6][30];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+14451, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 14451;
 target_ptr = Libderiv->deriv_classes[0][7][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+14487, dvrr_stack+10663, NULL);
 tmp = dvrr_stack + 14487;
 target_ptr = Libderiv->deriv2_classes[0][7][30];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+14523, dvrr_stack+6652, NULL);
 tmp = dvrr_stack + 14523;
 target_ptr = Libderiv->deriv_classes[0][8][2];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+14568, dvrr_stack+10771, NULL);
 tmp = dvrr_stack + 14568;
 target_ptr = Libderiv->deriv2_classes[0][8][30];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+14613, dvrr_stack+7219, NULL);
 tmp = dvrr_stack + 14613;
 target_ptr = Libderiv->deriv_classes[0][9][2];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+14668, dvrr_stack+10906, NULL);
 tmp = dvrr_stack + 14668;
 target_ptr = Libderiv->deriv2_classes[0][9][30];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+14723, dvrr_stack+11071, NULL);
 tmp = dvrr_stack + 14723;
 target_ptr = Libderiv->deriv2_classes[0][10][30];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+14789, dvrr_stack+6487, NULL);
 tmp = dvrr_stack + 14789;
 target_ptr = Libderiv->deriv2_classes[0][5][26];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+14810, dvrr_stack+8584, NULL);
 tmp = dvrr_stack + 14810;
 target_ptr = Libderiv->deriv2_classes[0][6][26];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+14838, dvrr_stack+11845, NULL);
 tmp = dvrr_stack + 14838;
 target_ptr = Libderiv->deriv2_classes[0][7][26];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+14874, dvrr_stack+12358, NULL);
 tmp = dvrr_stack + 14874;
 target_ptr = Libderiv->deriv2_classes[0][8][26];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+14919, dvrr_stack+218, NULL);
 tmp = dvrr_stack + 14919;
 target_ptr = Libderiv->deriv2_classes[0][9][26];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+14974, dvrr_stack+12988, NULL);
 tmp = dvrr_stack + 14974;
 target_ptr = Libderiv->deriv2_classes[0][10][26];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,21,dvrr_stack+15040, dvrr_stack+6145, NULL);
 tmp = dvrr_stack + 15040;
 target_ptr = Libderiv->deriv2_classes[0][5][23];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,28,dvrr_stack+15061, dvrr_stack+6568, NULL);
 tmp = dvrr_stack + 15061;
 target_ptr = Libderiv->deriv2_classes[0][6][23];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,36,dvrr_stack+15089, dvrr_stack+7111, NULL);
 tmp = dvrr_stack + 15089;
 target_ptr = Libderiv->deriv2_classes[0][7][23];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,45,dvrr_stack+15125, dvrr_stack+7789, NULL);
 tmp = dvrr_stack + 15125;
 target_ptr = Libderiv->deriv2_classes[0][8][23];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,55,dvrr_stack+15170, dvrr_stack+8419, NULL);
 tmp = dvrr_stack + 15170;
 target_ptr = Libderiv->deriv2_classes[0][9][23];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,66,dvrr_stack+15225, dvrr_stack+9412, NULL);
 tmp = dvrr_stack + 15225;
 target_ptr = Libderiv->deriv2_classes[0][10][23];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+15291, dvrr_stack+3777, NULL);
 tmp = dvrr_stack + 15291;
 target_ptr = Libderiv->deriv2_classes[0][5][22];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+15312, dvrr_stack+9610, NULL);
 tmp = dvrr_stack + 15312;
 target_ptr = Libderiv->deriv2_classes[0][6][22];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+15340, dvrr_stack+9694, NULL);
 tmp = dvrr_stack + 15340;
 target_ptr = Libderiv->deriv2_classes[0][7][22];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+15376, dvrr_stack+9802, NULL);
 tmp = dvrr_stack + 15376;
 target_ptr = Libderiv->deriv2_classes[0][8][22];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+15421, dvrr_stack+9937, NULL);
 tmp = dvrr_stack + 15421;
 target_ptr = Libderiv->deriv2_classes[0][9][22];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+15476, dvrr_stack+10102, NULL);
 tmp = dvrr_stack + 15476;
 target_ptr = Libderiv->deriv2_classes[0][10][22];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+15542, dvrr_stack+3006, NULL);
 tmp = dvrr_stack + 15542;
 target_ptr = Libderiv->deriv2_classes[0][5][21];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+15563, dvrr_stack+5956, NULL);
 tmp = dvrr_stack + 15563;
 target_ptr = Libderiv->deriv2_classes[0][6][21];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+15591, dvrr_stack+6316, NULL);
 tmp = dvrr_stack + 15591;
 target_ptr = Libderiv->deriv2_classes[0][7][21];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+15627, dvrr_stack+6787, NULL);
 tmp = dvrr_stack + 15627;
 target_ptr = Libderiv->deriv2_classes[0][8][21];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+15672, dvrr_stack+7384, NULL);
 tmp = dvrr_stack + 15672;
 target_ptr = Libderiv->deriv2_classes[0][9][21];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+15727, dvrr_stack+7924, NULL);
 tmp = dvrr_stack + 15727;
 target_ptr = Libderiv->deriv2_classes[0][10][21];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+15793, dvrr_stack+8863, NULL);
 tmp = dvrr_stack + 15793;
 target_ptr = Libderiv->deriv2_classes[0][5][20];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+15814, dvrr_stack+8926, NULL);
 tmp = dvrr_stack + 15814;
 target_ptr = Libderiv->deriv2_classes[0][6][20];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+15842, dvrr_stack+9010, NULL);
 tmp = dvrr_stack + 15842;
 target_ptr = Libderiv->deriv2_classes[0][7][20];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+15878, dvrr_stack+9118, NULL);
 tmp = dvrr_stack + 15878;
 target_ptr = Libderiv->deriv2_classes[0][8][20];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+15923, dvrr_stack+8122, NULL);
 tmp = dvrr_stack + 15923;
 target_ptr = Libderiv->deriv2_classes[0][9][20];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+15978, dvrr_stack+7549, NULL);
 tmp = dvrr_stack + 15978;
 target_ptr = Libderiv->deriv2_classes[0][10][20];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+16044, dvrr_stack+9253, NULL);
 tmp = dvrr_stack + 16044;
 target_ptr = Libderiv->deriv2_classes[0][5][19];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+16065, dvrr_stack+9316, NULL);
 tmp = dvrr_stack + 16065;
 target_ptr = Libderiv->deriv2_classes[0][6][19];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+16093, dvrr_stack+8287, NULL);
 tmp = dvrr_stack + 16093;
 target_ptr = Libderiv->deriv2_classes[0][7][19];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+16129, dvrr_stack+6922, NULL);
 tmp = dvrr_stack + 16129;
 target_ptr = Libderiv->deriv2_classes[0][8][19];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+16174, dvrr_stack+10300, NULL);
 tmp = dvrr_stack + 16174;
 target_ptr = Libderiv->deriv2_classes[0][9][19];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+16229, dvrr_stack+10465, NULL);
 tmp = dvrr_stack + 16229;
 target_ptr = Libderiv->deriv2_classes[0][10][19];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+16295, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 16295;
 target_ptr = Libderiv->deriv_classes[0][5][1];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+16316, dvrr_stack+6424, NULL);
 tmp = dvrr_stack + 16316;
 target_ptr = Libderiv->deriv2_classes[0][5][18];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+16337, dvrr_stack+391, NULL);
 tmp = dvrr_stack + 16337;
 target_ptr = Libderiv->deriv_classes[0][6][1];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+16365, dvrr_stack+6040, NULL);
 tmp = dvrr_stack + 16365;
 target_ptr = Libderiv->deriv2_classes[0][6][18];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+16393, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 16393;
 target_ptr = Libderiv->deriv_classes[0][7][1];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+16429, dvrr_stack+10663, NULL);
 tmp = dvrr_stack + 16429;
 target_ptr = Libderiv->deriv2_classes[0][7][18];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+16465, dvrr_stack+6652, NULL);
 tmp = dvrr_stack + 16465;
 target_ptr = Libderiv->deriv_classes[0][8][1];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+16510, dvrr_stack+10771, NULL);
 tmp = dvrr_stack + 16510;
 target_ptr = Libderiv->deriv2_classes[0][8][18];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+16555, dvrr_stack+7219, NULL);
 tmp = dvrr_stack + 16555;
 target_ptr = Libderiv->deriv_classes[0][9][1];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+16610, dvrr_stack+10906, NULL);
 tmp = dvrr_stack + 16610;
 target_ptr = Libderiv->deriv2_classes[0][9][18];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+16665, dvrr_stack+11071, NULL);
 tmp = dvrr_stack + 16665;
 target_ptr = Libderiv->deriv2_classes[0][10][18];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+16731, dvrr_stack+6487, NULL);
 tmp = dvrr_stack + 16731;
 target_ptr = Libderiv->deriv2_classes[0][5][14];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+16752, dvrr_stack+8584, NULL);
 tmp = dvrr_stack + 16752;
 target_ptr = Libderiv->deriv2_classes[0][6][14];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+16780, dvrr_stack+11845, NULL);
 tmp = dvrr_stack + 16780;
 target_ptr = Libderiv->deriv2_classes[0][7][14];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+16816, dvrr_stack+12358, NULL);
 tmp = dvrr_stack + 16816;
 target_ptr = Libderiv->deriv2_classes[0][8][14];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+16861, dvrr_stack+218, NULL);
 tmp = dvrr_stack + 16861;
 target_ptr = Libderiv->deriv2_classes[0][9][14];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+16916, dvrr_stack+12988, NULL);
 tmp = dvrr_stack + 16916;
 target_ptr = Libderiv->deriv2_classes[0][10][14];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+16982, dvrr_stack+12493, NULL);
 tmp = dvrr_stack + 16982;
 target_ptr = Libderiv->deriv2_classes[0][5][13];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+17003, dvrr_stack+11269, NULL);
 tmp = dvrr_stack + 17003;
 target_ptr = Libderiv->deriv2_classes[0][6][13];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+17031, dvrr_stack+11521, NULL);
 tmp = dvrr_stack + 17031;
 target_ptr = Libderiv->deriv2_classes[0][7][13];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+17067, dvrr_stack+11953, NULL);
 tmp = dvrr_stack + 17067;
 target_ptr = Libderiv->deriv2_classes[0][8][13];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+17112, dvrr_stack+13582, NULL);
 tmp = dvrr_stack + 17112;
 target_ptr = Libderiv->deriv2_classes[0][9][13];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+17167, dvrr_stack+13747, NULL);
 tmp = dvrr_stack + 17167;
 target_ptr = Libderiv->deriv2_classes[0][10][13];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,21,dvrr_stack+17233, dvrr_stack+6145, NULL);
 tmp = dvrr_stack + 17233;
 target_ptr = Libderiv->deriv2_classes[0][5][11];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,28,dvrr_stack+6145, dvrr_stack+6568, NULL);
 tmp = dvrr_stack + 6145;
 target_ptr = Libderiv->deriv2_classes[0][6][11];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,36,dvrr_stack+6550, dvrr_stack+7111, NULL);
 tmp = dvrr_stack + 6550;
 target_ptr = Libderiv->deriv2_classes[0][7][11];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,45,dvrr_stack+7093, dvrr_stack+7789, NULL);
 tmp = dvrr_stack + 7093;
 target_ptr = Libderiv->deriv2_classes[0][8][11];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,55,dvrr_stack+7775, dvrr_stack+8419, NULL);
 tmp = dvrr_stack + 7775;
 target_ptr = Libderiv->deriv2_classes[0][9][11];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,66,dvrr_stack+6586, dvrr_stack+9412, NULL);
 tmp = dvrr_stack + 6586;
 target_ptr = Libderiv->deriv2_classes[0][10][11];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+6173, dvrr_stack+3777, NULL);
 tmp = dvrr_stack + 6173;
 target_ptr = Libderiv->deriv2_classes[0][5][10];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+9400, dvrr_stack+9610, NULL);
 tmp = dvrr_stack + 9400;
 target_ptr = Libderiv->deriv2_classes[0][6][10];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+9428, dvrr_stack+9694, NULL);
 tmp = dvrr_stack + 9428;
 target_ptr = Libderiv->deriv2_classes[0][7][10];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+9464, dvrr_stack+9802, NULL);
 tmp = dvrr_stack + 9464;
 target_ptr = Libderiv->deriv2_classes[0][8][10];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+9509, dvrr_stack+9937, NULL);
 tmp = dvrr_stack + 9509;
 target_ptr = Libderiv->deriv2_classes[0][9][10];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+9564, dvrr_stack+10102, NULL);
 tmp = dvrr_stack + 9564;
 target_ptr = Libderiv->deriv2_classes[0][10][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+9630, dvrr_stack+3006, NULL);
 tmp = dvrr_stack + 9630;
 target_ptr = Libderiv->deriv2_classes[0][5][9];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+9651, dvrr_stack+5956, NULL);
 tmp = dvrr_stack + 9651;
 target_ptr = Libderiv->deriv2_classes[0][6][9];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+9679, dvrr_stack+6316, NULL);
 tmp = dvrr_stack + 9679;
 target_ptr = Libderiv->deriv2_classes[0][7][9];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+6316, dvrr_stack+6787, NULL);
 tmp = dvrr_stack + 6316;
 target_ptr = Libderiv->deriv2_classes[0][8][9];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+6787, dvrr_stack+7384, NULL);
 tmp = dvrr_stack + 6787;
 target_ptr = Libderiv->deriv2_classes[0][9][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+7384, dvrr_stack+7924, NULL);
 tmp = dvrr_stack + 7384;
 target_ptr = Libderiv->deriv2_classes[0][10][9];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+7450, dvrr_stack+8863, NULL);
 tmp = dvrr_stack + 7450;
 target_ptr = Libderiv->deriv2_classes[0][5][8];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+7471, dvrr_stack+8926, NULL);
 tmp = dvrr_stack + 7471;
 target_ptr = Libderiv->deriv2_classes[0][6][8];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+7499, dvrr_stack+9010, NULL);
 tmp = dvrr_stack + 7499;
 target_ptr = Libderiv->deriv2_classes[0][7][8];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+6842, dvrr_stack+9118, NULL);
 tmp = dvrr_stack + 6842;
 target_ptr = Libderiv->deriv2_classes[0][8][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+6361, dvrr_stack+8122, NULL);
 tmp = dvrr_stack + 6361;
 target_ptr = Libderiv->deriv2_classes[0][9][8];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+8852, dvrr_stack+7549, NULL);
 tmp = dvrr_stack + 8852;
 target_ptr = Libderiv->deriv2_classes[0][10][8];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+7535, dvrr_stack+9253, NULL);
 tmp = dvrr_stack + 7535;
 target_ptr = Libderiv->deriv2_classes[0][5][7];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+7556, dvrr_stack+9316, NULL);
 tmp = dvrr_stack + 7556;
 target_ptr = Libderiv->deriv2_classes[0][6][7];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+7584, dvrr_stack+8287, NULL);
 tmp = dvrr_stack + 7584;
 target_ptr = Libderiv->deriv2_classes[0][7][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+7620, dvrr_stack+6922, NULL);
 tmp = dvrr_stack + 7620;
 target_ptr = Libderiv->deriv2_classes[0][8][7];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+7665, dvrr_stack+10300, NULL);
 tmp = dvrr_stack + 7665;
 target_ptr = Libderiv->deriv2_classes[0][9][7];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+6887, dvrr_stack+10465, NULL);
 tmp = dvrr_stack + 6887;
 target_ptr = Libderiv->deriv2_classes[0][10][7];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+7720, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 7720;
 target_ptr = Libderiv->deriv_classes[0][5][0];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+6953, dvrr_stack+6424, NULL);
 tmp = dvrr_stack + 6953;
 target_ptr = Libderiv->deriv2_classes[0][5][6];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+6974, dvrr_stack+391, NULL);
 tmp = dvrr_stack + 6974;
 target_ptr = Libderiv->deriv_classes[0][6][0];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+7002, dvrr_stack+6040, NULL);
 tmp = dvrr_stack + 7002;
 target_ptr = Libderiv->deriv2_classes[0][6][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+6416, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 6416;
 target_ptr = Libderiv->deriv_classes[0][7][0];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+6194, dvrr_stack+10663, NULL);
 tmp = dvrr_stack + 6194;
 target_ptr = Libderiv->deriv2_classes[0][7][6];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+6230, dvrr_stack+6652, NULL);
 tmp = dvrr_stack + 6230;
 target_ptr = Libderiv->deriv_classes[0][8][0];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+6652, dvrr_stack+10771, NULL);
 tmp = dvrr_stack + 6652;
 target_ptr = Libderiv->deriv2_classes[0][8][6];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+6697, dvrr_stack+7219, NULL);
 tmp = dvrr_stack + 6697;
 target_ptr = Libderiv->deriv_classes[0][9][0];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+8918, dvrr_stack+10906, NULL);
 tmp = dvrr_stack + 8918;
 target_ptr = Libderiv->deriv2_classes[0][9][6];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+8973, dvrr_stack+11071, NULL);
 tmp = dvrr_stack + 8973;
 target_ptr = Libderiv->deriv2_classes[0][10][6];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+6752, dvrr_stack+6487, NULL);
 tmp = dvrr_stack + 6752;
 target_ptr = Libderiv->deriv2_classes[0][5][2];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+6452, dvrr_stack+8584, NULL);
 tmp = dvrr_stack + 6452;
 target_ptr = Libderiv->deriv2_classes[0][6][2];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+6480, dvrr_stack+11845, NULL);
 tmp = dvrr_stack + 6480;
 target_ptr = Libderiv->deriv2_classes[0][7][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+11830, dvrr_stack+12358, NULL);
 tmp = dvrr_stack + 11830;
 target_ptr = Libderiv->deriv2_classes[0][8][2];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+12355, dvrr_stack+218, NULL);
 tmp = dvrr_stack + 12355;
 target_ptr = Libderiv->deriv2_classes[0][9][2];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+12410, dvrr_stack+12988, NULL);
 tmp = dvrr_stack + 12410;
 target_ptr = Libderiv->deriv2_classes[0][10][2];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+7030, dvrr_stack+12493, NULL);
 tmp = dvrr_stack + 7030;
 target_ptr = Libderiv->deriv2_classes[0][5][1];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+6516, dvrr_stack+11269, NULL);
 tmp = dvrr_stack + 6516;
 target_ptr = Libderiv->deriv2_classes[0][6][1];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+6275, dvrr_stack+11521, NULL);
 tmp = dvrr_stack + 6275;
 target_ptr = Libderiv->deriv2_classes[0][7][1];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+12476, dvrr_stack+11953, NULL);
 tmp = dvrr_stack + 12476;
 target_ptr = Libderiv->deriv2_classes[0][8][1];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+11875, dvrr_stack+13582, NULL);
 tmp = dvrr_stack + 11875;
 target_ptr = Libderiv->deriv2_classes[0][9][1];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+13569, dvrr_stack+13747, NULL);
 tmp = dvrr_stack + 13569;
 target_ptr = Libderiv->deriv2_classes[0][10][1];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+13635, dvrr_stack+12556, NULL);
 tmp = dvrr_stack + 13635;
 target_ptr = Libderiv->deriv2_classes[0][5][0];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+13656, dvrr_stack+8668, NULL);
 tmp = dvrr_stack + 13656;
 target_ptr = Libderiv->deriv2_classes[0][6][0];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+13684, dvrr_stack+11353, NULL);
 tmp = dvrr_stack + 13684;
 target_ptr = Libderiv->deriv2_classes[0][7][0];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+13720, dvrr_stack+11629, NULL);
 tmp = dvrr_stack + 13720;
 target_ptr = Libderiv->deriv2_classes[0][8][0];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+13765, dvrr_stack+12088, NULL);
 tmp = dvrr_stack + 13765;
 target_ptr = Libderiv->deriv2_classes[0][9][0];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+13820, dvrr_stack+12619, NULL);
 tmp = dvrr_stack + 13820;
 target_ptr = Libderiv->deriv2_classes[0][10][0];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];


}

