/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hg|hh) integrals */

void d12vrr_order_hghh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+873, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+210, dvrr_stack+873, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+213, dvrr_stack+876, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+892, dvrr_stack+219, dvrr_stack+882, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+907, dvrr_stack+509, dvrr_stack+892, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+952, dvrr_stack+524, dvrr_stack+907, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1042, dvrr_stack+614, dvrr_stack+952, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1192, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1342, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1588, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1609, dvrr_stack+1588, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1672, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1693, dvrr_stack+1672, dvrr_stack+1588, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1756, dvrr_stack+509, dvrr_stack+892, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1777, dvrr_stack+1567, dvrr_stack+1756, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1840, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1966, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2092, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2302, dvrr_stack+593, dvrr_stack+1672, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2365, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2491, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2302, dvrr_stack+873, dvrr_stack+704, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+210, dvrr_stack+873, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2318, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2333, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+219, dvrr_stack+882, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2701, dvrr_stack+1756, dvrr_stack+2333, NULL, NULL, dvrr_stack+892);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2764, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+907);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2890, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+952);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3100, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1042);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3415, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+1192);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3730, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+1342);
 tmp = dvrr_stack + 3730;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2382, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4171, dvrr_stack+2382, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2410, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4255, dvrr_stack+2410, dvrr_stack+2382, NULL, NULL, dvrr_stack+1588);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+479, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+509, dvrr_stack+892, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4339, dvrr_stack+2354, dvrr_stack+479, NULL, NULL, dvrr_stack+1756);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4423, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1777);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4591, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1609);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4759, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+1840);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+1609, dvrr_stack+2410, NULL, NULL, dvrr_stack+1672);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+1693);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5291, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1966);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1966, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1969, dvrr_stack+704, dvrr_stack+1966, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1975, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+873, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+876, dvrr_stack+2302, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2021, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+892, dvrr_stack+2318, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+479, dvrr_stack+2021, NULL, NULL, dvrr_stack+2333);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5571, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+2701);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5739, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2764);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6019, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+2890);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6439, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+2092);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6859, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+3100);
 tmp = dvrr_stack + 6859;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+7447,dvrr_stack+6859,dvrr_stack+3730,21);


 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+1567, dvrr_stack+1756, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5159, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1588, dvrr_stack+1567, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+5159, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5195, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1672, dvrr_stack+1588, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8878, dvrr_stack+5195, dvrr_stack+5159, NULL, NULL, dvrr_stack+2382);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+1756, dvrr_stack+2333, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8986, dvrr_stack+5123, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9094, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+4339);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9310, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+4171);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9526, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+4423);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+593, dvrr_stack+1672, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+4171, dvrr_stack+5195, NULL, NULL, dvrr_stack+2410);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+4255);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10102, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4591);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4591, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1603, dvrr_stack+1966, dvrr_stack+4591, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4594, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+704, dvrr_stack+1966, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4604, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+2302, dvrr_stack+1969, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+2308, dvrr_stack+1975, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+2318, dvrr_stack+1985, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+2333, dvrr_stack+2000, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+1567, dvrr_stack+4647, NULL, NULL, dvrr_stack+2021);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+5039);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10678, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5571);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11038, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+5739);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11578, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+4759);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12118, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+6019);
 tmp = dvrr_stack + 12118;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+12874,dvrr_stack+12118,dvrr_stack+6859,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+14638,dvrr_stack+12874,dvrr_stack+7447,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+17284, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+2354, dvrr_stack+479, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9931, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+2382, dvrr_stack+2354, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+9931, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9976, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+2410, dvrr_stack+2382, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+9976, dvrr_stack+9931, NULL, NULL, dvrr_stack+5159);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+479, dvrr_stack+2021, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18877, dvrr_stack+9886, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19012, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+8986);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19282, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+8770);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19552, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9094);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+1609, dvrr_stack+2410, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+8770, dvrr_stack+9976, NULL, NULL, dvrr_stack+5195);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+8878);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20407, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+9310);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9313, dvrr_stack+4591, dvrr_stack+9310, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+9319, dvrr_stack+1603, dvrr_stack+9313, dvrr_stack+1966, dvrr_stack+4591, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+9329, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+1969, dvrr_stack+1603, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9344, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+1975, dvrr_stack+4594, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+1985, dvrr_stack+4604, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9365, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2021, dvrr_stack+4619, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+2354, dvrr_stack+9401, NULL, NULL, dvrr_stack+4647);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+1637);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21127, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+10462);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21577, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+10678);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22252, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+9526);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22927, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+11038);
 tmp = dvrr_stack + 22927;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+23872,dvrr_stack+22927,dvrr_stack+12118,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+26140,dvrr_stack+23872,dvrr_stack+12874,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+29668, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+5123, dvrr_stack+1567, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20192, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+5159, dvrr_stack+5123, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20192, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20247, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+5195, dvrr_stack+5159, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+20247, dvrr_stack+20192, NULL, NULL, dvrr_stack+9931);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+1567, dvrr_stack+4647, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+20137, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31762, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+18877);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32092, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+19012);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+4171, dvrr_stack+5195, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+20247, NULL, NULL, dvrr_stack+9976);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+18742);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33302, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+19282);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8980, dvrr_stack+9310, dvrr_stack+19282, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19285, dvrr_stack+9313, dvrr_stack+8980, dvrr_stack+4591, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19295, dvrr_stack+9319, dvrr_stack+19285, dvrr_stack+1603, dvrr_stack+9313, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19310, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+4594, dvrr_stack+9319, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19331, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+4604, dvrr_stack+9329, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+593, dvrr_stack+9344, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+4647, dvrr_stack+9365, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+5123, dvrr_stack+19440, NULL, NULL, dvrr_stack+9401);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+20002);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34182, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20857);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34732, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+21127);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35557, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+19552);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36382, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+21577);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37537,dvrr_stack+36382,dvrr_stack+22927,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+40372,dvrr_stack+37537,dvrr_stack+23872,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+44908, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+9886, dvrr_stack+2354, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33038, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+9931, dvrr_stack+9886, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+33038, dvrr_stack+32972, NULL, NULL, dvrr_stack+20137);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+9976, dvrr_stack+9931, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+18662, dvrr_stack+33038, NULL, NULL, dvrr_stack+20192);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+2354, dvrr_stack+9401, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+32972, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47572, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+31597);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47968, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+8815);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48364, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+31762);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+8770, dvrr_stack+9976, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+8815, dvrr_stack+18662, NULL, NULL, dvrr_stack+20247);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49618, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+32092);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4336, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32092, dvrr_stack+19282, dvrr_stack+4336, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32098, dvrr_stack+8980, dvrr_stack+32092, dvrr_stack+9310, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32108, dvrr_stack+19285, dvrr_stack+32098, dvrr_stack+9313, dvrr_stack+8980, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32123, dvrr_stack+19295, dvrr_stack+32108, dvrr_stack+9319, dvrr_stack+19285, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+32144, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+9329, dvrr_stack+19295, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+9344, dvrr_stack+19310, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+1609, dvrr_stack+19331, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32208, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+9365, dvrr_stack+19359, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+9401, dvrr_stack+19395, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+9886, dvrr_stack+32263, NULL, NULL, dvrr_stack+19440);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50674, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33852);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51334, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+34182);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+52324, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+32422);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+53314, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+34732);
 tmp = dvrr_stack + 53314;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+54700,dvrr_stack+53314,dvrr_stack+36382,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+58165,dvrr_stack+54700,dvrr_stack+37537,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+63835, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+20137, dvrr_stack+5123, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+20192, dvrr_stack+20137, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49378, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+32972);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+20247, dvrr_stack+20192, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+32329, dvrr_stack+49300, NULL, NULL, dvrr_stack+33038);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+5123, dvrr_stack+19440, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66904, dvrr_stack+49222, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67138, dvrr_stack+49378, dvrr_stack+66904, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+47374);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67606, dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+32329, dvrr_stack+49300, dvrr_stack+33104);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68074, dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+47572);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+18607, dvrr_stack+20247, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+33104, dvrr_stack+32329, NULL, NULL, dvrr_stack+18662);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+68854, dvrr_stack+66670, dvrr_stack+33104, dvrr_stack+32329, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69556, dvrr_stack+69088, dvrr_stack+67606, dvrr_stack+68854, dvrr_stack+66670, dvrr_stack+47968);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+49612, dvrr_stack+4336, dvrr_stack+9310, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+47968, dvrr_stack+32092, dvrr_stack+49612, dvrr_stack+19282, dvrr_stack+4336, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32407, dvrr_stack+32098, dvrr_stack+47968, dvrr_stack+8980, dvrr_stack+32092, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47978, dvrr_stack+32108, dvrr_stack+32407, dvrr_stack+19285, dvrr_stack+32098, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+47999, dvrr_stack+32123, dvrr_stack+47978, dvrr_stack+19295, dvrr_stack+32108, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48027, dvrr_stack+32144, dvrr_stack+47999, dvrr_stack+19310, dvrr_stack+32123, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48063, dvrr_stack+32172, dvrr_stack+48027, dvrr_stack+19331, dvrr_stack+32144, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+48063, dvrr_stack+19359, dvrr_stack+32172, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48108, dvrr_stack+32208, dvrr_stack+18607, dvrr_stack+19395, dvrr_stack+8770, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48174, dvrr_stack+32263, dvrr_stack+48108, dvrr_stack+19440, dvrr_stack+32208, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+20137, dvrr_stack+48174, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70336, dvrr_stack+66904, dvrr_stack+68854, dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+49024);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70804, dvrr_stack+67138, dvrr_stack+70336, dvrr_stack+49378, dvrr_stack+66904, dvrr_stack+50278);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+71584, dvrr_stack+68074, dvrr_stack+70804, dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+50674);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72754, dvrr_stack+69556, dvrr_stack+68074, dvrr_stack+69088, dvrr_stack+67606, dvrr_stack+48364);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+73924, dvrr_stack+72754, dvrr_stack+71584, dvrr_stack+69556, dvrr_stack+68074, dvrr_stack+51334);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+75562,dvrr_stack+73924,dvrr_stack+53314,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+79720,dvrr_stack+75562,dvrr_stack+54700,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+86650, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+32972, dvrr_stack+9886, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+33038, dvrr_stack+32972, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69270, dvrr_stack+69179, dvrr_stack+69088, NULL, NULL, dvrr_stack+49222);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69543, dvrr_stack+32329, dvrr_stack+49300, dvrr_stack+18662, dvrr_stack+33038, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69634, dvrr_stack+69543, dvrr_stack+69179, NULL, NULL, dvrr_stack+49300);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+20137, dvrr_stack+48174, dvrr_stack+9886, dvrr_stack+32263, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69907, dvrr_stack+69088, dvrr_stack+49222, NULL, NULL, dvrr_stack+20137);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+90115, dvrr_stack+69270, dvrr_stack+69907, dvrr_stack+69179, dvrr_stack+69088, dvrr_stack+66904);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+90661, dvrr_stack+69634, dvrr_stack+69270, dvrr_stack+69543, dvrr_stack+69179, dvrr_stack+49378);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+91207, dvrr_stack+90661, dvrr_stack+90115, dvrr_stack+69634, dvrr_stack+69270, dvrr_stack+67138);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+33104, dvrr_stack+32329, dvrr_stack+8815, dvrr_stack+18662, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49313, dvrr_stack+69179, dvrr_stack+69543, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+92117, dvrr_stack+49313, dvrr_stack+69634, dvrr_stack+69179, dvrr_stack+69543, dvrr_stack+66670);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+92663, dvrr_stack+92117, dvrr_stack+90661, dvrr_stack+49313, dvrr_stack+69634, dvrr_stack+67606);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+67606, dvrr_stack+9310, dvrr_stack+19282, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+67612, dvrr_stack+49612, dvrr_stack+67606, dvrr_stack+4336, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+67622, dvrr_stack+47968, dvrr_stack+67612, dvrr_stack+32092, dvrr_stack+49612, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+67637, dvrr_stack+32407, dvrr_stack+67622, dvrr_stack+32098, dvrr_stack+47968, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+67658, dvrr_stack+47978, dvrr_stack+67637, dvrr_stack+32108, dvrr_stack+32407, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67686, dvrr_stack+47999, dvrr_stack+67658, dvrr_stack+32123, dvrr_stack+47978, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+67722, dvrr_stack+48027, dvrr_stack+67686, dvrr_stack+32144, dvrr_stack+47999, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67767, dvrr_stack+48063, dvrr_stack+67722, dvrr_stack+32172, dvrr_stack+48027, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67822, dvrr_stack+18607, dvrr_stack+67767, dvrr_stack+8770, dvrr_stack+48063, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+48108, dvrr_stack+67822, dvrr_stack+32208, dvrr_stack+18607, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+48174, dvrr_stack+32329, dvrr_stack+32263, dvrr_stack+48108, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49313, dvrr_stack+49222, dvrr_stack+69179, NULL, NULL, dvrr_stack+48174);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+93573, dvrr_stack+69907, dvrr_stack+49313, dvrr_stack+69088, dvrr_stack+49222, dvrr_stack+68854);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+94119, dvrr_stack+90115, dvrr_stack+93573, dvrr_stack+69270, dvrr_stack+69907, dvrr_stack+70336);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+95029, dvrr_stack+91207, dvrr_stack+94119, dvrr_stack+90661, dvrr_stack+90115, dvrr_stack+70804);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+96394, dvrr_stack+92663, dvrr_stack+91207, dvrr_stack+92117, dvrr_stack+90661, dvrr_stack+68074);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+97759, dvrr_stack+96394, dvrr_stack+95029, dvrr_stack+92663, dvrr_stack+91207, dvrr_stack+71584);

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+99670,dvrr_stack+97759,dvrr_stack+73924,21);


 /* compute (5 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+104584,dvrr_stack+99670,dvrr_stack+75562,21);


 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1386,dvrr_stack+112900, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+4336, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+90661, dvrr_stack+6, dvrr_stack+569, dvrr_stack+3, dvrr_stack+0, dvrr_stack+4336);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+90679, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+90697, dvrr_stack+39, dvrr_stack+90679, dvrr_stack+15, dvrr_stack+33, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+90733, dvrr_stack+75, dvrr_stack+90697, dvrr_stack+57, dvrr_stack+39, dvrr_stack+90661);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+90793, dvrr_stack+219, dvrr_stack+882, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+90823, dvrr_stack+229, dvrr_stack+90793, dvrr_stack+111, dvrr_stack+219, dvrr_stack+90679);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+90883, dvrr_stack+259, dvrr_stack+90823, dvrr_stack+131, dvrr_stack+229, dvrr_stack+90697);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+9952, dvrr_stack+379, dvrr_stack+90883, dvrr_stack+319, dvrr_stack+259, dvrr_stack+90733);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+90983, dvrr_stack+892, dvrr_stack+2318, NULL, NULL, dvrr_stack+882);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+91028, dvrr_stack+907, dvrr_stack+90983, dvrr_stack+509, dvrr_stack+892, dvrr_stack+90793);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+92117, dvrr_stack+952, dvrr_stack+91028, dvrr_stack+524, dvrr_stack+907, dvrr_stack+90823);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+92267, dvrr_stack+1042, dvrr_stack+92117, dvrr_stack+614, dvrr_stack+952, dvrr_stack+90883);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+92492, dvrr_stack+1342, dvrr_stack+92267, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+9952);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2333, dvrr_stack+2000, NULL, NULL, dvrr_stack+2318);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+92807, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+90983);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+92933, dvrr_stack+2764, dvrr_stack+92807, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+91028);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+93143, dvrr_stack+2890, dvrr_stack+92933, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+92117);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+69270, dvrr_stack+3100, dvrr_stack+93143, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+92267);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+117058, dvrr_stack+3730, dvrr_stack+69270, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+92492);
 tmp = dvrr_stack + 117058;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+91118, dvrr_stack+2021, dvrr_stack+4619, NULL, NULL, dvrr_stack+2000);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+69711, dvrr_stack+5039, dvrr_stack+91118, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+32972, dvrr_stack+5571, dvrr_stack+69711, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+92807);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+117646, dvrr_stack+5739, dvrr_stack+32972, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+92933);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+118066, dvrr_stack+6019, dvrr_stack+117646, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+93143);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+118654, dvrr_stack+6859, dvrr_stack+118066, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+69270);
 tmp = dvrr_stack + 118654;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+119438,dvrr_stack+118654,dvrr_stack+117058,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4339, dvrr_stack+4647, dvrr_stack+9365, NULL, NULL, dvrr_stack+4619);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+91118);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121202, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+69711);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121562, dvrr_stack+10678, dvrr_stack+121202, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+32972);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122102, dvrr_stack+11038, dvrr_stack+121562, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+117646);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122858, dvrr_stack+12118, dvrr_stack+122102, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+118066);
 tmp = dvrr_stack + 122858;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+123866,dvrr_stack+122858,dvrr_stack+118654,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+126218,dvrr_stack+123866,dvrr_stack+119438,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+129746, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4447, dvrr_stack+9401, dvrr_stack+19395, NULL, NULL, dvrr_stack+9365);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+4339);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131510, dvrr_stack+20857, dvrr_stack+8815, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+66670);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131960, dvrr_stack+21127, dvrr_stack+131510, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+121202);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+132635, dvrr_stack+21577, dvrr_stack+131960, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+121562);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133580, dvrr_stack+22927, dvrr_stack+132635, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+122102);
 tmp = dvrr_stack + 133580;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+134840,dvrr_stack+133580,dvrr_stack+122858,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+137864,dvrr_stack+134840,dvrr_stack+123866,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+142568, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+19440, dvrr_stack+32208, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+4447);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+144920, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+8815);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+145470, dvrr_stack+34182, dvrr_stack+144920, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+131510);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+146295, dvrr_stack+34732, dvrr_stack+145470, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+131960);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+147450, dvrr_stack+36382, dvrr_stack+146295, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+132635);
 tmp = dvrr_stack + 147450;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+148990,dvrr_stack+147450,dvrr_stack+133580,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+152770,dvrr_stack+148990,dvrr_stack+134840,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+158818, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+32263, dvrr_stack+48108, NULL, NULL, dvrr_stack+32208);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+161842, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+18662);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+162502, dvrr_stack+50674, dvrr_stack+161842, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+144920);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+163492, dvrr_stack+51334, dvrr_stack+162502, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+145470);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+164878, dvrr_stack+53314, dvrr_stack+163492, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+146295);
 tmp = dvrr_stack + 164878;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+166726,dvrr_stack+164878,dvrr_stack+147450,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+171346,dvrr_stack+166726,dvrr_stack+148990,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+178906, dvrr_stack+171346, dvrr_stack+133580);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+48174, dvrr_stack+32329, NULL, NULL, dvrr_stack+48108);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+68854, dvrr_stack+47374, dvrr_stack+20137, dvrr_stack+48174, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182686, dvrr_stack+70336, dvrr_stack+31597, dvrr_stack+66904, dvrr_stack+68854, dvrr_stack+32422);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+183466, dvrr_stack+70804, dvrr_stack+182686, dvrr_stack+67138, dvrr_stack+70336, dvrr_stack+161842);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+184636, dvrr_stack+71584, dvrr_stack+183466, dvrr_stack+68074, dvrr_stack+70804, dvrr_stack+162502);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+186274, dvrr_stack+73924, dvrr_stack+184636, dvrr_stack+72754, dvrr_stack+71584, dvrr_stack+163492);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+188458,dvrr_stack+186274,dvrr_stack+164878,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+194002,dvrr_stack+188458,dvrr_stack+166726,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+203242, dvrr_stack+194002, dvrr_stack+147450);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+20137, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+19282, dvrr_stack+20137, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+67606, dvrr_stack+15, dvrr_stack+9310, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+20140, dvrr_stack+67612, dvrr_stack+111, dvrr_stack+49612, dvrr_stack+67606, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+20155, dvrr_stack+67622, dvrr_stack+20140, dvrr_stack+47968, dvrr_stack+67612, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+69879, dvrr_stack+67637, dvrr_stack+20155, dvrr_stack+32407, dvrr_stack+67622, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+67658, dvrr_stack+69879, dvrr_stack+47978, dvrr_stack+67637, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20176, dvrr_stack+67686, dvrr_stack+1567, dvrr_stack+47999, dvrr_stack+67658, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20221, dvrr_stack+67722, dvrr_stack+20176, dvrr_stack+48027, dvrr_stack+67686, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20276, dvrr_stack+67767, dvrr_stack+20221, dvrr_stack+48063, dvrr_stack+67722, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47608, dvrr_stack+67822, dvrr_stack+20276, dvrr_stack+18607, dvrr_stack+67767, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+69088, dvrr_stack+32329, dvrr_stack+47608, dvrr_stack+48108, dvrr_stack+67822, NULL);

 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+47686, dvrr_stack+69179, dvrr_stack+69088, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+49313, dvrr_stack+47686, dvrr_stack+49222, dvrr_stack+69179, dvrr_stack+47374);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+207862, dvrr_stack+93573, dvrr_stack+67888, dvrr_stack+69907, dvrr_stack+49313, dvrr_stack+31597);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+208772, dvrr_stack+94119, dvrr_stack+207862, dvrr_stack+90115, dvrr_stack+93573, dvrr_stack+182686);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+210137, dvrr_stack+95029, dvrr_stack+208772, dvrr_stack+91207, dvrr_stack+94119, dvrr_stack+183466);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+212048, dvrr_stack+97759, dvrr_stack+210137, dvrr_stack+96394, dvrr_stack+95029, dvrr_stack+184636);

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+214596,dvrr_stack+212048,dvrr_stack+186274,28);


 /* compute (6 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+221148,dvrr_stack+214596,dvrr_stack+188458,28);


 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1848,dvrr_stack+232236, dvrr_stack+221148, dvrr_stack+164878);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+96394, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+96397, dvrr_stack+4336, dvrr_stack+96394, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+4582, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+96403, dvrr_stack+569, dvrr_stack+4582, dvrr_stack+0, dvrr_stack+30, dvrr_stack+96394);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+90661, dvrr_stack+96403, dvrr_stack+6, dvrr_stack+569, dvrr_stack+96397);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+96421, dvrr_stack+213, dvrr_stack+876, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+96439, dvrr_stack+90679, dvrr_stack+96421, dvrr_stack+33, dvrr_stack+213, dvrr_stack+4582);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+96475, dvrr_stack+90697, dvrr_stack+96439, dvrr_stack+39, dvrr_stack+90679, dvrr_stack+96403);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+479, dvrr_stack+90733, dvrr_stack+96475, dvrr_stack+75, dvrr_stack+90697, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+96535, dvrr_stack+882, dvrr_stack+2308, NULL, NULL, dvrr_stack+876);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+96565, dvrr_stack+90793, dvrr_stack+96535, dvrr_stack+219, dvrr_stack+882, dvrr_stack+96421);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+96625, dvrr_stack+90823, dvrr_stack+96565, dvrr_stack+229, dvrr_stack+90793, dvrr_stack+96439);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+96725, dvrr_stack+90883, dvrr_stack+96625, dvrr_stack+259, dvrr_stack+90823, dvrr_stack+96475);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+96875, dvrr_stack+9952, dvrr_stack+96725, dvrr_stack+379, dvrr_stack+90883, dvrr_stack+479);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2318, dvrr_stack+1985, NULL, NULL, dvrr_stack+2308);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+97085, dvrr_stack+90983, dvrr_stack+219, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+96535);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+97175, dvrr_stack+91028, dvrr_stack+97085, dvrr_stack+907, dvrr_stack+90983, dvrr_stack+96565);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+97325, dvrr_stack+92117, dvrr_stack+97175, dvrr_stack+952, dvrr_stack+91028, dvrr_stack+96625);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+90115, dvrr_stack+92267, dvrr_stack+97325, dvrr_stack+1042, dvrr_stack+92117, dvrr_stack+96725);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+68434, dvrr_stack+92492, dvrr_stack+90115, dvrr_stack+1342, dvrr_stack+92267, dvrr_stack+96875);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+892, dvrr_stack+2000, dvrr_stack+593, NULL, NULL, dvrr_stack+1985);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+955, dvrr_stack+614, dvrr_stack+892, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+90430, dvrr_stack+92807, dvrr_stack+955, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+97085);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+69907, dvrr_stack+92933, dvrr_stack+90430, dvrr_stack+2764, dvrr_stack+92807, dvrr_stack+97175);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+91202, dvrr_stack+93143, dvrr_stack+69907, dvrr_stack+2890, dvrr_stack+92933, dvrr_stack+97325);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+66886, dvrr_stack+69270, dvrr_stack+91202, dvrr_stack+3100, dvrr_stack+93143, dvrr_stack+90115);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+48252, dvrr_stack+117058, dvrr_stack+66886, dvrr_stack+3730, dvrr_stack+69270, dvrr_stack+68434);
 tmp = dvrr_stack + 48252;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2701, dvrr_stack+4619, dvrr_stack+1609, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+91118, dvrr_stack+2701, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+892);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2021, dvrr_stack+69711, dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+91118, dvrr_stack+955);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+2785, dvrr_stack+32972, dvrr_stack+2021, dvrr_stack+5571, dvrr_stack+69711, dvrr_stack+90430);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+237780, dvrr_stack+117646, dvrr_stack+2785, dvrr_stack+5739, dvrr_stack+32972, dvrr_stack+69907);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+238368, dvrr_stack+118066, dvrr_stack+237780, dvrr_stack+6019, dvrr_stack+117646, dvrr_stack+91202);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+239152, dvrr_stack+118654, dvrr_stack+238368, dvrr_stack+6859, dvrr_stack+118066, dvrr_stack+66886);
 tmp = dvrr_stack + 239152;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+240160,dvrr_stack+239152,dvrr_stack+48252,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+9365, dvrr_stack+19359, NULL, NULL, dvrr_stack+1609);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5679, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2701);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+66670, dvrr_stack+5679, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+5123);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5895, dvrr_stack+121202, dvrr_stack+4647, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+2021);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242428, dvrr_stack+121562, dvrr_stack+5895, dvrr_stack+10678, dvrr_stack+121202, dvrr_stack+2785);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+243184, dvrr_stack+122102, dvrr_stack+242428, dvrr_stack+11038, dvrr_stack+121562, dvrr_stack+237780);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+244192, dvrr_stack+122858, dvrr_stack+243184, dvrr_stack+12118, dvrr_stack+122102, dvrr_stack+238368);
 tmp = dvrr_stack + 244192;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+245488,dvrr_stack+244192,dvrr_stack+239152,36);


 /* compute (7 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+248512,dvrr_stack+245488,dvrr_stack+240160,36);


 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+253048, dvrr_stack+248512, dvrr_stack+48252);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+19395, dvrr_stack+8770, NULL, NULL, dvrr_stack+19359);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10597, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+5571);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+8815, dvrr_stack+10597, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+5679);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10867, dvrr_stack+131510, dvrr_stack+9401, dvrr_stack+20857, dvrr_stack+8815, dvrr_stack+4647);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+255316, dvrr_stack+131960, dvrr_stack+10867, dvrr_stack+21127, dvrr_stack+131510, dvrr_stack+5895);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+256261, dvrr_stack+132635, dvrr_stack+255316, dvrr_stack+21577, dvrr_stack+131960, dvrr_stack+242428);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+257521, dvrr_stack+133580, dvrr_stack+256261, dvrr_stack+22927, dvrr_stack+132635, dvrr_stack+243184);
 tmp = dvrr_stack + 257521;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+259141,dvrr_stack+257521,dvrr_stack+244192,36);


 /* compute (7 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+263029,dvrr_stack+259141,dvrr_stack+245488,36);


 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+269077, dvrr_stack+263029, dvrr_stack+239152);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+32208, dvrr_stack+18607, NULL, NULL, dvrr_stack+8770);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21022, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+10462);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+18662, dvrr_stack+21022, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+10597);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21352, dvrr_stack+144920, dvrr_stack+19440, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+9401);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+272101, dvrr_stack+145470, dvrr_stack+21352, dvrr_stack+34182, dvrr_stack+144920, dvrr_stack+10867);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+273256, dvrr_stack+146295, dvrr_stack+272101, dvrr_stack+34732, dvrr_stack+145470, dvrr_stack+255316);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+274796, dvrr_stack+147450, dvrr_stack+273256, dvrr_stack+36382, dvrr_stack+146295, dvrr_stack+256261);
 tmp = dvrr_stack + 274796;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+276776,dvrr_stack+274796,dvrr_stack+257521,36);


 /* compute (7 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+281636,dvrr_stack+276776,dvrr_stack+259141,36);


 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1296,dvrr_stack+289412, dvrr_stack+281636, dvrr_stack+244192);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+48108, dvrr_stack+67822, NULL, NULL, dvrr_stack+18607);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34050, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+32263, dvrr_stack+48108, dvrr_stack+20857);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34446, dvrr_stack+32422, dvrr_stack+34050, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+21022);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+293300, dvrr_stack+161842, dvrr_stack+34446, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+19440);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+294290, dvrr_stack+162502, dvrr_stack+293300, dvrr_stack+50674, dvrr_stack+161842, dvrr_stack+21352);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+295676, dvrr_stack+163492, dvrr_stack+294290, dvrr_stack+51334, dvrr_stack+162502, dvrr_stack+272101);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+297524, dvrr_stack+164878, dvrr_stack+295676, dvrr_stack+53314, dvrr_stack+163492, dvrr_stack+273256);
 tmp = dvrr_stack + 297524;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+299900,dvrr_stack+297524,dvrr_stack+274796,36);


 /* compute (7 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+305840,dvrr_stack+299900,dvrr_stack+276776,36);


 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+315560, dvrr_stack+305840, dvrr_stack+257521);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+32329, dvrr_stack+47608, NULL, NULL, dvrr_stack+67822);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50512, dvrr_stack+47374, dvrr_stack+50278, dvrr_stack+48174, dvrr_stack+32329, dvrr_stack+33852);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50980, dvrr_stack+31597, dvrr_stack+50512, dvrr_stack+68854, dvrr_stack+47374, dvrr_stack+34050);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+320420, dvrr_stack+182686, dvrr_stack+50980, dvrr_stack+70336, dvrr_stack+31597, dvrr_stack+34446);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+321590, dvrr_stack+183466, dvrr_stack+320420, dvrr_stack+70804, dvrr_stack+182686, dvrr_stack+293300);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+323228, dvrr_stack+184636, dvrr_stack+321590, dvrr_stack+71584, dvrr_stack+183466, dvrr_stack+294290);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+325412, dvrr_stack+186274, dvrr_stack+323228, dvrr_stack+73924, dvrr_stack+184636, dvrr_stack+295676);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+328220,dvrr_stack+325412,dvrr_stack+297524,36);


 /* compute (7 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+335348,dvrr_stack+328220,dvrr_stack+299900,36);


 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+347228, dvrr_stack+335348, dvrr_stack+274796);

 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68854, dvrr_stack+20137, dvrr_stack+0, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+68860, dvrr_stack+15, dvrr_stack+68854, dvrr_stack+19282, dvrr_stack+20137, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32407, dvrr_stack+111, dvrr_stack+68860, dvrr_stack+67606, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+90640, dvrr_stack+20140, dvrr_stack+32407, dvrr_stack+67612, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+68870, dvrr_stack+20155, dvrr_stack+90640, dvrr_stack+67622, dvrr_stack+20140, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11542, dvrr_stack+69879, dvrr_stack+68870, dvrr_stack+67637, dvrr_stack+20155, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+68898, dvrr_stack+1567, dvrr_stack+11542, dvrr_stack+67658, dvrr_stack+69879, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+20176, dvrr_stack+68898, dvrr_stack+67686, dvrr_stack+1567, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+20221, dvrr_stack+264, dvrr_stack+67722, dvrr_stack+20176, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48174, dvrr_stack+20276, dvrr_stack+32263, dvrr_stack+67767, dvrr_stack+20221, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+68943, dvrr_stack+47608, dvrr_stack+48174, dvrr_stack+67822, dvrr_stack+20276, NULL);

 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51760, dvrr_stack+69088, dvrr_stack+68943, NULL, NULL, dvrr_stack+47608);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+70222, dvrr_stack+47686, dvrr_stack+51760, dvrr_stack+69179, dvrr_stack+69088, dvrr_stack+50278);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+70768, dvrr_stack+67888, dvrr_stack+70222, dvrr_stack+49313, dvrr_stack+47686, dvrr_stack+50512);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+353168, dvrr_stack+207862, dvrr_stack+70768, dvrr_stack+93573, dvrr_stack+67888, dvrr_stack+50980);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+354533, dvrr_stack+208772, dvrr_stack+353168, dvrr_stack+94119, dvrr_stack+207862, dvrr_stack+320420);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+356444, dvrr_stack+210137, dvrr_stack+354533, dvrr_stack+95029, dvrr_stack+208772, dvrr_stack+321590);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+358992, dvrr_stack+212048, dvrr_stack+356444, dvrr_stack+97759, dvrr_stack+210137, dvrr_stack+323228);

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+362268,dvrr_stack+358992,dvrr_stack+325412,36);


 /* compute (7 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+370692,dvrr_stack+362268,dvrr_stack+328220,36);


 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2376,dvrr_stack+384948, dvrr_stack+370692, dvrr_stack+297524);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+69179, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+69182, dvrr_stack+96394, dvrr_stack+69179, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+69188, dvrr_stack+96397, dvrr_stack+69182, dvrr_stack+4336, dvrr_stack+96394, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+69198, dvrr_stack+210, dvrr_stack+873, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+69207, dvrr_stack+4582, dvrr_stack+69198, dvrr_stack+30, dvrr_stack+210, dvrr_stack+69179);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+69225, dvrr_stack+96403, dvrr_stack+69207, dvrr_stack+569, dvrr_stack+4582, dvrr_stack+69182);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+69034, dvrr_stack+131, dvrr_stack+69225, dvrr_stack+90661, dvrr_stack+96403, dvrr_stack+69188);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+876, dvrr_stack+2302, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+52033, dvrr_stack+96421, dvrr_stack+30, dvrr_stack+213, dvrr_stack+876, dvrr_stack+69198);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+52069, dvrr_stack+96439, dvrr_stack+52033, dvrr_stack+90679, dvrr_stack+96421, dvrr_stack+69207);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+52129, dvrr_stack+96475, dvrr_stack+52069, dvrr_stack+90697, dvrr_stack+96439, dvrr_stack+69225);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+35106, dvrr_stack+479, dvrr_stack+52129, dvrr_stack+90733, dvrr_stack+96475, dvrr_stack+69034);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+90679, dvrr_stack+2308, dvrr_stack+1975, NULL, NULL, dvrr_stack+2302);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+52219, dvrr_stack+96535, dvrr_stack+90679, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+35232, dvrr_stack+96565, dvrr_stack+52219, dvrr_stack+90793, dvrr_stack+96535, dvrr_stack+52033);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+35332, dvrr_stack+96625, dvrr_stack+35232, dvrr_stack+90823, dvrr_stack+96565, dvrr_stack+52069);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+3205, dvrr_stack+96725, dvrr_stack+35332, dvrr_stack+90883, dvrr_stack+96625, dvrr_stack+52129);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+1637, dvrr_stack+96875, dvrr_stack+3205, dvrr_stack+9952, dvrr_stack+96725, dvrr_stack+35106);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+52279, dvrr_stack+1985, dvrr_stack+4604, NULL, NULL, dvrr_stack+1975);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+90793, dvrr_stack+219, dvrr_stack+52279, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+90679);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+2318, dvrr_stack+97085, dvrr_stack+90793, dvrr_stack+90983, dvrr_stack+219, dvrr_stack+52219);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+71678, dvrr_stack+97175, dvrr_stack+2318, dvrr_stack+91028, dvrr_stack+97085, dvrr_stack+35232);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+71903, dvrr_stack+97325, dvrr_stack+71678, dvrr_stack+92117, dvrr_stack+97175, dvrr_stack+35332);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+72218, dvrr_stack+90115, dvrr_stack+71903, dvrr_stack+92267, dvrr_stack+97325, dvrr_stack+3205);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+91643, dvrr_stack+68434, dvrr_stack+72218, dvrr_stack+92492, dvrr_stack+90115, dvrr_stack+1637);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+90883, dvrr_stack+593, dvrr_stack+9344, NULL, NULL, dvrr_stack+4604);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+90946, dvrr_stack+892, dvrr_stack+90883, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+52279);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+92183, dvrr_stack+955, dvrr_stack+90946, dvrr_stack+614, dvrr_stack+892, dvrr_stack+90793);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+93458, dvrr_stack+90430, dvrr_stack+92183, dvrr_stack+92807, dvrr_stack+955, dvrr_stack+2318);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+93773, dvrr_stack+69907, dvrr_stack+93458, dvrr_stack+92933, dvrr_stack+90430, dvrr_stack+71678);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+94214, dvrr_stack+91202, dvrr_stack+93773, dvrr_stack+93143, dvrr_stack+69907, dvrr_stack+71903);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+94802, dvrr_stack+66886, dvrr_stack+94214, dvrr_stack+69270, dvrr_stack+91202, dvrr_stack+72218);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+392076, dvrr_stack+48252, dvrr_stack+94802, dvrr_stack+117058, dvrr_stack+66886, dvrr_stack+91643);
 tmp = dvrr_stack + 392076;
 target_ptr = Libderiv->dvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+92807, dvrr_stack+1609, dvrr_stack+19331, NULL, NULL, dvrr_stack+9344);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+92891, dvrr_stack+2701, dvrr_stack+92807, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+90883);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+93059, dvrr_stack+5123, dvrr_stack+92891, dvrr_stack+91118, dvrr_stack+2701, dvrr_stack+90946);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+69255, dvrr_stack+2021, dvrr_stack+93059, dvrr_stack+69711, dvrr_stack+5123, dvrr_stack+92183);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+95558, dvrr_stack+2785, dvrr_stack+69255, dvrr_stack+32972, dvrr_stack+2021, dvrr_stack+93458);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+393021, dvrr_stack+237780, dvrr_stack+95558, dvrr_stack+117646, dvrr_stack+2785, dvrr_stack+93773);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+393805, dvrr_stack+238368, dvrr_stack+393021, dvrr_stack+118066, dvrr_stack+237780, dvrr_stack+94214);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+394813, dvrr_stack+239152, dvrr_stack+393805, dvrr_stack+118654, dvrr_stack+238368, dvrr_stack+94802);
 tmp = dvrr_stack + 394813;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+396073,dvrr_stack+394813,dvrr_stack+392076,45);


 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117646, dvrr_stack+19359, dvrr_stack+32172, NULL, NULL, dvrr_stack+19331);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117754, dvrr_stack+5571, dvrr_stack+117646, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+92807);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+117970, dvrr_stack+5679, dvrr_stack+117754, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+92891);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+49008, dvrr_stack+4647, dvrr_stack+117970, dvrr_stack+66670, dvrr_stack+5679, dvrr_stack+93059);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+398908, dvrr_stack+5895, dvrr_stack+49008, dvrr_stack+121202, dvrr_stack+4647, dvrr_stack+69255);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+399664, dvrr_stack+242428, dvrr_stack+398908, dvrr_stack+121562, dvrr_stack+5895, dvrr_stack+95558);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+400672, dvrr_stack+243184, dvrr_stack+399664, dvrr_stack+122102, dvrr_stack+242428, dvrr_stack+393021);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121202, dvrr_stack+244192, dvrr_stack+400672, dvrr_stack+122858, dvrr_stack+243184, dvrr_stack+393805);
 tmp = dvrr_stack + 121202;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+401968,dvrr_stack+121202,dvrr_stack+394813,45);


 /* compute (8 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+405748,dvrr_stack+401968,dvrr_stack+396073,45);


 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+411418, dvrr_stack+405748, dvrr_stack+392076);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+8770, dvrr_stack+48063, NULL, NULL, dvrr_stack+32172);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+118330, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+117646);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32818, dvrr_stack+10597, dvrr_stack+118330, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+117754);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+414253, dvrr_stack+9401, dvrr_stack+32818, dvrr_stack+8815, dvrr_stack+10597, dvrr_stack+117970);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+414928, dvrr_stack+10867, dvrr_stack+414253, dvrr_stack+131510, dvrr_stack+9401, dvrr_stack+49008);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+415873, dvrr_stack+255316, dvrr_stack+414928, dvrr_stack+131960, dvrr_stack+10867, dvrr_stack+398908);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+417133, dvrr_stack+256261, dvrr_stack+415873, dvrr_stack+132635, dvrr_stack+255316, dvrr_stack+399664);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131510, dvrr_stack+257521, dvrr_stack+417133, dvrr_stack+133580, dvrr_stack+256261, dvrr_stack+400672);
 tmp = dvrr_stack + 131510;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+418753,dvrr_stack+131510,dvrr_stack+121202,45);


 /* compute (8 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+423613,dvrr_stack+418753,dvrr_stack+401968,45);


 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+431173, dvrr_stack+423613, dvrr_stack+394813);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+67767, NULL, NULL, dvrr_stack+48063);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20857, dvrr_stack+4171, dvrr_stack+32208, dvrr_stack+18607, dvrr_stack+66670);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+434953, dvrr_stack+21022, dvrr_stack+8815, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+118330);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+435503, dvrr_stack+19440, dvrr_stack+434953, dvrr_stack+18662, dvrr_stack+21022, dvrr_stack+32818);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+436328, dvrr_stack+21352, dvrr_stack+435503, dvrr_stack+144920, dvrr_stack+19440, dvrr_stack+414253);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+437483, dvrr_stack+272101, dvrr_stack+436328, dvrr_stack+145470, dvrr_stack+21352, dvrr_stack+414928);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+439023, dvrr_stack+273256, dvrr_stack+437483, dvrr_stack+146295, dvrr_stack+272101, dvrr_stack+415873);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+144920, dvrr_stack+274796, dvrr_stack+439023, dvrr_stack+147450, dvrr_stack+273256, dvrr_stack+417133);
 tmp = dvrr_stack + 144920;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+441003,dvrr_stack+144920,dvrr_stack+131510,45);


 /* compute (8 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+447078,dvrr_stack+441003,dvrr_stack+418753,45);


 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+456798, dvrr_stack+447078, dvrr_stack+121202);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+67822, dvrr_stack+20276, NULL, NULL, dvrr_stack+67767);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18860, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+48108, dvrr_stack+67822, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+461658, dvrr_stack+34050, dvrr_stack+18860, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+8815);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+462318, dvrr_stack+34446, dvrr_stack+461658, dvrr_stack+32422, dvrr_stack+34050, dvrr_stack+434953);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+463308, dvrr_stack+293300, dvrr_stack+462318, dvrr_stack+161842, dvrr_stack+34446, dvrr_stack+435503);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+464694, dvrr_stack+294290, dvrr_stack+463308, dvrr_stack+162502, dvrr_stack+293300, dvrr_stack+436328);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+466542, dvrr_stack+295676, dvrr_stack+464694, dvrr_stack+163492, dvrr_stack+294290, dvrr_stack+437483);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+161842, dvrr_stack+297524, dvrr_stack+466542, dvrr_stack+164878, dvrr_stack+295676, dvrr_stack+439023);
 tmp = dvrr_stack + 161842;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+468918,dvrr_stack+161842,dvrr_stack+144920,45);


 /* compute (8 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+476343,dvrr_stack+468918,dvrr_stack+441003,45);


 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2025,dvrr_stack+488493, dvrr_stack+476343, dvrr_stack+131510);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+47608, dvrr_stack+48174, NULL, NULL, dvrr_stack+20276);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+494568, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+32329, dvrr_stack+47608, dvrr_stack+18662);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+495036, dvrr_stack+50512, dvrr_stack+494568, dvrr_stack+47374, dvrr_stack+50278, dvrr_stack+18860);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+495816, dvrr_stack+50980, dvrr_stack+495036, dvrr_stack+31597, dvrr_stack+50512, dvrr_stack+461658);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+496986, dvrr_stack+320420, dvrr_stack+495816, dvrr_stack+182686, dvrr_stack+50980, dvrr_stack+462318);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+498624, dvrr_stack+321590, dvrr_stack+496986, dvrr_stack+183466, dvrr_stack+320420, dvrr_stack+463308);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+500808, dvrr_stack+323228, dvrr_stack+498624, dvrr_stack+184636, dvrr_stack+321590, dvrr_stack+464694);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182686, dvrr_stack+325412, dvrr_stack+500808, dvrr_stack+186274, dvrr_stack+323228, dvrr_stack+466542);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+503616,dvrr_stack+182686,dvrr_stack+161842,45);


 /* compute (8 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+512526,dvrr_stack+503616,dvrr_stack+468918,45);


 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+527376, dvrr_stack+512526, dvrr_stack+144920);

 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+186196, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+186196, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+68854, dvrr_stack+213, dvrr_stack+20137, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+186199, dvrr_stack+68860, dvrr_stack+882, dvrr_stack+15, dvrr_stack+68854, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+32407, dvrr_stack+186199, dvrr_stack+111, dvrr_stack+68860, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+90640, dvrr_stack+2000, dvrr_stack+20140, dvrr_stack+32407, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122822, dvrr_stack+68870, dvrr_stack+4619, dvrr_stack+20155, dvrr_stack+90640, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133535, dvrr_stack+11542, dvrr_stack+122822, dvrr_stack+69879, dvrr_stack+68870, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+147395, dvrr_stack+68898, dvrr_stack+133535, dvrr_stack+1567, dvrr_stack+11542, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+164812, dvrr_stack+264, dvrr_stack+147395, dvrr_stack+20176, dvrr_stack+68898, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32329, dvrr_stack+32263, dvrr_stack+164812, dvrr_stack+20221, dvrr_stack+264, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+32656, dvrr_stack+48174, dvrr_stack+32329, dvrr_stack+20276, dvrr_stack+32263, NULL);

 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+68943, dvrr_stack+32656, NULL, NULL, dvrr_stack+48174);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+51760, dvrr_stack+47176, dvrr_stack+69088, dvrr_stack+68943, dvrr_stack+32422);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+534801, dvrr_stack+70222, dvrr_stack+31432, dvrr_stack+47686, dvrr_stack+51760, dvrr_stack+494568);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+535711, dvrr_stack+70768, dvrr_stack+534801, dvrr_stack+67888, dvrr_stack+70222, dvrr_stack+495036);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+537076, dvrr_stack+353168, dvrr_stack+535711, dvrr_stack+207862, dvrr_stack+70768, dvrr_stack+495816);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+538987, dvrr_stack+354533, dvrr_stack+537076, dvrr_stack+208772, dvrr_stack+353168, dvrr_stack+496986);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+541535, dvrr_stack+356444, dvrr_stack+538987, dvrr_stack+210137, dvrr_stack+354533, dvrr_stack+498624);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+207862, dvrr_stack+358992, dvrr_stack+541535, dvrr_stack+212048, dvrr_stack+356444, dvrr_stack+500808);

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+544811,dvrr_stack+207862,dvrr_stack+182686,45);


 /* compute (8 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+555341,dvrr_stack+544811,dvrr_stack+503616,45);


 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2970,dvrr_stack+573161, dvrr_stack+555341, dvrr_stack+161842);

 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+211957, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+15, dvrr_stack+69179, dvrr_stack+211957, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+111, dvrr_stack+69182, dvrr_stack+15, dvrr_stack+96394, dvrr_stack+69179, NULL);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+211960, dvrr_stack+69188, dvrr_stack+111, dvrr_stack+96397, dvrr_stack+69182, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+569, dvrr_stack+873, dvrr_stack+704, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+211975, dvrr_stack+69198, dvrr_stack+569, dvrr_stack+210, dvrr_stack+873, dvrr_stack+211957);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+211993, dvrr_stack+69207, dvrr_stack+211975, dvrr_stack+4582, dvrr_stack+69198, dvrr_stack+15);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+19395, dvrr_stack+69225, dvrr_stack+211993, dvrr_stack+96403, dvrr_stack+69207, dvrr_stack+111);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+67888, dvrr_stack+69034, dvrr_stack+19395, dvrr_stack+131, dvrr_stack+69225, dvrr_stack+211960);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+96403, dvrr_stack+2302, dvrr_stack+1969, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+9365, dvrr_stack+30, dvrr_stack+96403, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+569);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+186214, dvrr_stack+52033, dvrr_stack+9365, dvrr_stack+96421, dvrr_stack+30, dvrr_stack+211975);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+614, dvrr_stack+52069, dvrr_stack+186214, dvrr_stack+96439, dvrr_stack+52033, dvrr_stack+211993);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+67951, dvrr_stack+52129, dvrr_stack+614, dvrr_stack+96475, dvrr_stack+52069, dvrr_stack+19395);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+9145, dvrr_stack+35106, dvrr_stack+67951, dvrr_stack+479, dvrr_stack+52129, dvrr_stack+67888);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+96421, dvrr_stack+1975, dvrr_stack+4594, NULL, NULL, dvrr_stack+1969);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+96451, dvrr_stack+90679, dvrr_stack+96421, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+96403);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+69079, dvrr_stack+52219, dvrr_stack+96451, dvrr_stack+96535, dvrr_stack+90679, dvrr_stack+9365);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+68077, dvrr_stack+35232, dvrr_stack+69079, dvrr_stack+96565, dvrr_stack+52219, dvrr_stack+186214);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+47686, dvrr_stack+35332, dvrr_stack+68077, dvrr_stack+96625, dvrr_stack+35232, dvrr_stack+614);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+582071, dvrr_stack+3205, dvrr_stack+47686, dvrr_stack+96725, dvrr_stack+35332, dvrr_stack+67951);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+96511, dvrr_stack+1637, dvrr_stack+582071, dvrr_stack+96875, dvrr_stack+3205, dvrr_stack+9145);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+68227, dvrr_stack+4604, dvrr_stack+9329, NULL, NULL, dvrr_stack+4594);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+68272, dvrr_stack+52279, dvrr_stack+68227, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+96421);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+47449, dvrr_stack+90793, dvrr_stack+68272, dvrr_stack+219, dvrr_stack+52279, dvrr_stack+96451);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+4339, dvrr_stack+2318, dvrr_stack+47449, dvrr_stack+97085, dvrr_stack+90793, dvrr_stack+69079);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+582351, dvrr_stack+71678, dvrr_stack+4339, dvrr_stack+97175, dvrr_stack+2318, dvrr_stack+68077);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+582666, dvrr_stack+71903, dvrr_stack+582351, dvrr_stack+97325, dvrr_stack+71678, dvrr_stack+47686);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+97085, dvrr_stack+72218, dvrr_stack+582666, dvrr_stack+90115, dvrr_stack+71903, dvrr_stack+582071);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+583086, dvrr_stack+91643, dvrr_stack+97085, dvrr_stack+68434, dvrr_stack+72218, dvrr_stack+96511);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+90115, dvrr_stack+9344, dvrr_stack+19310, NULL, NULL, dvrr_stack+9329);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+90178, dvrr_stack+90883, dvrr_stack+90115, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+68227);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+69675, dvrr_stack+90946, dvrr_stack+90178, dvrr_stack+892, dvrr_stack+90883, dvrr_stack+68272);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+583761, dvrr_stack+92183, dvrr_stack+69675, dvrr_stack+955, dvrr_stack+90946, dvrr_stack+47449);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+584076, dvrr_stack+93458, dvrr_stack+583761, dvrr_stack+90430, dvrr_stack+92183, dvrr_stack+4339);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+584517, dvrr_stack+93773, dvrr_stack+584076, dvrr_stack+69907, dvrr_stack+93458, dvrr_stack+582351);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+585105, dvrr_stack+94214, dvrr_stack+584517, dvrr_stack+91202, dvrr_stack+93773, dvrr_stack+582666);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+585861, dvrr_stack+94802, dvrr_stack+585105, dvrr_stack+66886, dvrr_stack+94214, dvrr_stack+97085);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+586806, dvrr_stack+392076, dvrr_stack+585861, dvrr_stack+48252, dvrr_stack+94802, dvrr_stack+583086);
 tmp = dvrr_stack + 586806;
 target_ptr = Libderiv->dvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+892, dvrr_stack+19331, dvrr_stack+32144, NULL, NULL, dvrr_stack+19310);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+976, dvrr_stack+92807, dvrr_stack+892, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+90115);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+90304, dvrr_stack+92891, dvrr_stack+976, dvrr_stack+2701, dvrr_stack+92807, dvrr_stack+90178);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+66805, dvrr_stack+93059, dvrr_stack+90304, dvrr_stack+5123, dvrr_stack+92891, dvrr_stack+69675);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+587961, dvrr_stack+69255, dvrr_stack+66805, dvrr_stack+2021, dvrr_stack+93059, dvrr_stack+583761);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+588549, dvrr_stack+95558, dvrr_stack+587961, dvrr_stack+2785, dvrr_stack+69255, dvrr_stack+584076);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+589333, dvrr_stack+393021, dvrr_stack+588549, dvrr_stack+237780, dvrr_stack+95558, dvrr_stack+584517);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+590341, dvrr_stack+393805, dvrr_stack+589333, dvrr_stack+238368, dvrr_stack+393021, dvrr_stack+585105);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+591601, dvrr_stack+394813, dvrr_stack+590341, dvrr_stack+239152, dvrr_stack+393805, dvrr_stack+585861);
 tmp = dvrr_stack + 591601;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+593141,dvrr_stack+591601,dvrr_stack+586806,55);


 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237780, dvrr_stack+32172, dvrr_stack+48027, NULL, NULL, dvrr_stack+32144);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237888, dvrr_stack+117646, dvrr_stack+237780, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+892);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238104, dvrr_stack+117754, dvrr_stack+237888, dvrr_stack+5571, dvrr_stack+117646, dvrr_stack+976);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238464, dvrr_stack+117970, dvrr_stack+238104, dvrr_stack+5679, dvrr_stack+117754, dvrr_stack+90304);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+596606, dvrr_stack+49008, dvrr_stack+238464, dvrr_stack+4647, dvrr_stack+117970, dvrr_stack+66805);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+597362, dvrr_stack+398908, dvrr_stack+596606, dvrr_stack+5895, dvrr_stack+49008, dvrr_stack+587961);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+598370, dvrr_stack+399664, dvrr_stack+597362, dvrr_stack+242428, dvrr_stack+398908, dvrr_stack+588549);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+599666, dvrr_stack+400672, dvrr_stack+598370, dvrr_stack+243184, dvrr_stack+399664, dvrr_stack+589333);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+601286, dvrr_stack+121202, dvrr_stack+599666, dvrr_stack+244192, dvrr_stack+400672, dvrr_stack+590341);
 tmp = dvrr_stack + 601286;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+603266,dvrr_stack+601286,dvrr_stack+591601,55);


 /* compute (9 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+607886,dvrr_stack+603266,dvrr_stack+593141,55);


 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+614816, dvrr_stack+607886, dvrr_stack+586806);

 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242428, dvrr_stack+48063, dvrr_stack+67722, NULL, NULL, dvrr_stack+48027);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242563, dvrr_stack+66670, dvrr_stack+242428, dvrr_stack+8770, dvrr_stack+48063, dvrr_stack+237780);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242833, dvrr_stack+118330, dvrr_stack+242563, dvrr_stack+10462, dvrr_stack+66670, dvrr_stack+237888);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+243283, dvrr_stack+32818, dvrr_stack+242833, dvrr_stack+10597, dvrr_stack+118330, dvrr_stack+238104);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+618281, dvrr_stack+414253, dvrr_stack+243283, dvrr_stack+9401, dvrr_stack+32818, dvrr_stack+238464);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+619226, dvrr_stack+414928, dvrr_stack+618281, dvrr_stack+10867, dvrr_stack+414253, dvrr_stack+596606);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+620486, dvrr_stack+415873, dvrr_stack+619226, dvrr_stack+255316, dvrr_stack+414928, dvrr_stack+597362);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+622106, dvrr_stack+417133, dvrr_stack+620486, dvrr_stack+256261, dvrr_stack+415873, dvrr_stack+598370);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+624131, dvrr_stack+131510, dvrr_stack+622106, dvrr_stack+257521, dvrr_stack+417133, dvrr_stack+599666);
 tmp = dvrr_stack + 624131;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+626606,dvrr_stack+624131,dvrr_stack+601286,55);


 /* compute (9 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+632546,dvrr_stack+626606,dvrr_stack+603266,55);


 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+641786, dvrr_stack+632546, dvrr_stack+591601);

 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+255316, dvrr_stack+67767, dvrr_stack+20221, NULL, NULL, dvrr_stack+67722);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+255481, dvrr_stack+4171, dvrr_stack+255316, dvrr_stack+18607, dvrr_stack+67767, dvrr_stack+242428);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+255811, dvrr_stack+8815, dvrr_stack+255481, dvrr_stack+20857, dvrr_stack+4171, dvrr_stack+242563);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+256361, dvrr_stack+434953, dvrr_stack+255811, dvrr_stack+21022, dvrr_stack+8815, dvrr_stack+242833);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+646406, dvrr_stack+435503, dvrr_stack+256361, dvrr_stack+19440, dvrr_stack+434953, dvrr_stack+243283);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+647561, dvrr_stack+436328, dvrr_stack+646406, dvrr_stack+21352, dvrr_stack+435503, dvrr_stack+618281);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+649101, dvrr_stack+437483, dvrr_stack+647561, dvrr_stack+272101, dvrr_stack+436328, dvrr_stack+619226);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+651081, dvrr_stack+439023, dvrr_stack+649101, dvrr_stack+273256, dvrr_stack+437483, dvrr_stack+620486);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+653556, dvrr_stack+144920, dvrr_stack+651081, dvrr_stack+274796, dvrr_stack+439023, dvrr_stack+622106);
 tmp = dvrr_stack + 653556;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+656581,dvrr_stack+653556,dvrr_stack+624131,55);


 /* compute (9 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+664006,dvrr_stack+656581,dvrr_stack+626606,55);


 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+675886, dvrr_stack+664006, dvrr_stack+601286);

 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272101, dvrr_stack+20276, dvrr_stack+32263, NULL, NULL, dvrr_stack+20221);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272299, dvrr_stack+18662, dvrr_stack+272101, dvrr_stack+67822, dvrr_stack+20276, dvrr_stack+255316);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272695, dvrr_stack+18860, dvrr_stack+272299, dvrr_stack+33852, dvrr_stack+18662, dvrr_stack+255481);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+273355, dvrr_stack+461658, dvrr_stack+272695, dvrr_stack+34050, dvrr_stack+18860, dvrr_stack+255811);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+462318, dvrr_stack+273355, dvrr_stack+34446, dvrr_stack+461658, dvrr_stack+256361);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+681826, dvrr_stack+463308, dvrr_stack+20857, dvrr_stack+293300, dvrr_stack+462318, dvrr_stack+646406);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+683674, dvrr_stack+464694, dvrr_stack+681826, dvrr_stack+294290, dvrr_stack+463308, dvrr_stack+647561);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+686050, dvrr_stack+466542, dvrr_stack+683674, dvrr_stack+295676, dvrr_stack+464694, dvrr_stack+649101);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+293300, dvrr_stack+161842, dvrr_stack+686050, dvrr_stack+297524, dvrr_stack+466542, dvrr_stack+651081);

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+689020,dvrr_stack+293300,dvrr_stack+653556,55);


 /* compute (9 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+698095,dvrr_stack+689020,dvrr_stack+656581,55);


 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+712945, dvrr_stack+698095, dvrr_stack+624131);

 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+243958, dvrr_stack+48174, dvrr_stack+32329, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+296930, dvrr_stack+32422, dvrr_stack+243958, dvrr_stack+47608, dvrr_stack+48174, dvrr_stack+272101);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+494568, dvrr_stack+296930, dvrr_stack+50278, dvrr_stack+32422, dvrr_stack+272299);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+720370, dvrr_stack+495036, dvrr_stack+33852, dvrr_stack+50512, dvrr_stack+494568, dvrr_stack+272695);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+721540, dvrr_stack+495816, dvrr_stack+720370, dvrr_stack+50980, dvrr_stack+495036, dvrr_stack+273355);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+723178, dvrr_stack+496986, dvrr_stack+721540, dvrr_stack+320420, dvrr_stack+495816, dvrr_stack+20857);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+725362, dvrr_stack+498624, dvrr_stack+723178, dvrr_stack+321590, dvrr_stack+496986, dvrr_stack+681826);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+728170, dvrr_stack+500808, dvrr_stack+725362, dvrr_stack+323228, dvrr_stack+498624, dvrr_stack+683674);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+320420, dvrr_stack+182686, dvrr_stack+728170, dvrr_stack+325412, dvrr_stack+500808, dvrr_stack+686050);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+731680,dvrr_stack+320420,dvrr_stack+293300,55);


 /* compute (9 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+742570,dvrr_stack+731680,dvrr_stack+689020,55);


 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3025,dvrr_stack+760720, dvrr_stack+742570, dvrr_stack+653556);

 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+186196, dvrr_stack+210, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, dvrr_stack+0, dvrr_stack+186196, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+68854, dvrr_stack+213, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+186199, dvrr_stack+1985, dvrr_stack+68860, dvrr_stack+882, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+32407, dvrr_stack+186199, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+90640, dvrr_stack+2000, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+122822, dvrr_stack+19359, dvrr_stack+68870, dvrr_stack+4619, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+133535, dvrr_stack+8770, dvrr_stack+11542, dvrr_stack+122822, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67822, dvrr_stack+147395, dvrr_stack+18607, dvrr_stack+68898, dvrr_stack+133535, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+4619, dvrr_stack+164812, dvrr_stack+67822, dvrr_stack+264, dvrr_stack+147395, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+4697, dvrr_stack+32329, dvrr_stack+4619, dvrr_stack+32263, dvrr_stack+164812, NULL);

 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+4788, dvrr_stack+32656, dvrr_stack+4697, NULL, NULL, dvrr_stack+32329);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+324710, dvrr_stack+47176, dvrr_stack+4788, dvrr_stack+68943, dvrr_stack+32656, dvrr_stack+243958);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+31432, dvrr_stack+324710, dvrr_stack+51760, dvrr_stack+47176, dvrr_stack+296930);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+769795, dvrr_stack+534801, dvrr_stack+50278, dvrr_stack+70222, dvrr_stack+31432, dvrr_stack+33852);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+771160, dvrr_stack+535711, dvrr_stack+769795, dvrr_stack+70768, dvrr_stack+534801, dvrr_stack+720370);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+773071, dvrr_stack+537076, dvrr_stack+771160, dvrr_stack+353168, dvrr_stack+535711, dvrr_stack+721540);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+769795, dvrr_stack+538987, dvrr_stack+773071, dvrr_stack+354533, dvrr_stack+537076, dvrr_stack+723178);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+534801, dvrr_stack+541535, dvrr_stack+769795, dvrr_stack+356444, dvrr_stack+538987, dvrr_stack+725362);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+769795, dvrr_stack+207862, dvrr_stack+534801, dvrr_stack+358992, dvrr_stack+541535, dvrr_stack+728170);

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+774800,dvrr_stack+769795,dvrr_stack+320420,55);


 /* compute (9 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+787670,dvrr_stack+774800,dvrr_stack+731680,55);


 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,3630,dvrr_stack+809450, dvrr_stack+787670, dvrr_stack+293300);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+534801, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+536124, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+537888, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+540156, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+353168, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1386,dvrr_stack+820340, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+542991, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+356633, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+824498, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+827522, dvrr_stack+171346, dvrr_stack+133580);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+831302, dvrr_stack+194002, dvrr_stack+147450);

 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1848,dvrr_stack+835922, dvrr_stack+221148, dvrr_stack+164878);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+841466, dvrr_stack+248512, dvrr_stack+48252);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+843734, dvrr_stack+263029, dvrr_stack+239152);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1296,dvrr_stack+846758, dvrr_stack+281636, dvrr_stack+244192);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+850646, dvrr_stack+305840, dvrr_stack+257521);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+855506, dvrr_stack+335348, dvrr_stack+274796);

 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2376,dvrr_stack+861446, dvrr_stack+370692, dvrr_stack+297524);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+868574, dvrr_stack+405748, dvrr_stack+392076);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+871409, dvrr_stack+423613, dvrr_stack+394813);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+875189, dvrr_stack+447078, dvrr_stack+121202);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2025,dvrr_stack+880049, dvrr_stack+476343, dvrr_stack+131510);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+886124, dvrr_stack+512526, dvrr_stack+144920);

 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2970,dvrr_stack+893549, dvrr_stack+555341, dvrr_stack+161842);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+902459, dvrr_stack+607886, dvrr_stack+586806);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+905924, dvrr_stack+632546, dvrr_stack+591601);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+910544, dvrr_stack+664006, dvrr_stack+601286);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+916484, dvrr_stack+698095, dvrr_stack+624131);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3025,dvrr_stack+923909, dvrr_stack+742570, dvrr_stack+653556);

 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,3630,dvrr_stack+932984, dvrr_stack+787670, dvrr_stack+293300);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+50278, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+14638, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+26140, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+40372, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+58165, dvrr_stack+79720, dvrr_stack+36382);

 /* compute (5 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1386,dvrr_stack+79720, dvrr_stack+104584, dvrr_stack+53314);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+104584, dvrr_stack+126218, dvrr_stack+117058);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+126218, dvrr_stack+137864, dvrr_stack+118654);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+137864, dvrr_stack+152770, dvrr_stack+122858);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+152770, dvrr_stack+171346, dvrr_stack+133580);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+171346, dvrr_stack+194002, dvrr_stack+147450);

 /* compute (6 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1848,dvrr_stack+194002, dvrr_stack+221148, dvrr_stack+164878);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+156550, dvrr_stack+248512, dvrr_stack+48252);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+248512, dvrr_stack+263029, dvrr_stack+239152);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1296,dvrr_stack+263029, dvrr_stack+281636, dvrr_stack+244192);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+281636, dvrr_stack+305840, dvrr_stack+257521);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+305840, dvrr_stack+335348, dvrr_stack+274796);

 /* compute (7 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2376,dvrr_stack+335348, dvrr_stack+370692, dvrr_stack+297524);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+370692, dvrr_stack+405748, dvrr_stack+392076);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+311780, dvrr_stack+423613, dvrr_stack+394813);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+423613, dvrr_stack+447078, dvrr_stack+121202);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2025,dvrr_stack+447078, dvrr_stack+476343, dvrr_stack+131510);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+476343, dvrr_stack+512526, dvrr_stack+144920);

 /* compute (8 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2970,dvrr_stack+512526, dvrr_stack+555341, dvrr_stack+161842);

 /* compute (9 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+555341, dvrr_stack+607886, dvrr_stack+586806);

 /* compute (9 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+607886, dvrr_stack+632546, dvrr_stack+591601);

 /* compute (9 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+521436, dvrr_stack+664006, dvrr_stack+601286);

 /* compute (9 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+664006, dvrr_stack+698095, dvrr_stack+624131);

 /* compute (9 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3025,dvrr_stack+698095, dvrr_stack+742570, dvrr_stack+653556);

 /* compute (9 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,3630,dvrr_stack+742570, dvrr_stack+787670, dvrr_stack+293300);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+186196, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+787670, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+122822, dvrr_stack+787670, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+787688, dvrr_stack+122822, dvrr_stack+75, dvrr_stack+787670, dvrr_stack+57, dvrr_stack+186196);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+787748, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+787778, dvrr_stack+787748, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+787670);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+787838, dvrr_stack+787778, dvrr_stack+319, dvrr_stack+787748, dvrr_stack+180, dvrr_stack+122822);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+787938, dvrr_stack+787838, dvrr_stack+379, dvrr_stack+787778, dvrr_stack+319, dvrr_stack+787688);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+133535, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+170, dvrr_stack+133535, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+787748);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+788088, dvrr_stack+170, dvrr_stack+783, dvrr_stack+133535, dvrr_stack+738, dvrr_stack+787778);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+788238, dvrr_stack+788088, dvrr_stack+1192, dvrr_stack+170, dvrr_stack+783, dvrr_stack+787838);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+788463, dvrr_stack+788238, dvrr_stack+1342, dvrr_stack+788088, dvrr_stack+1192, dvrr_stack+787938);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+788778,dvrr_stack+3730,dvrr_stack+788463,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+789723, dvrr_stack+788778, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+790038, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 790038;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+790626, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 790626;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+791067, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 791067;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+791823, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 791823;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+792768, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 792768;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+793923, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 793923;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+795309, dvrr_stack+99670, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+4336, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+788088, dvrr_stack+186196, dvrr_stack+90661, dvrr_stack+22243, dvrr_stack+6, dvrr_stack+24);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+788118, dvrr_stack+787688, dvrr_stack+90733, dvrr_stack+122822, dvrr_stack+75, dvrr_stack+788088);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+796947, dvrr_stack+787938, dvrr_stack+9952, dvrr_stack+787838, dvrr_stack+379, dvrr_stack+788118);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+797157, dvrr_stack+788463, dvrr_stack+92492, dvrr_stack+788238, dvrr_stack+1342, dvrr_stack+796947);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+28408,dvrr_stack+117058,dvrr_stack+797157,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+797577, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+797997, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 797997;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+798781, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 798781;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+799369, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 799369;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+800377, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 800377;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+801637, dvrr_stack+166726, NULL);
 tmp = dvrr_stack + 801637;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+803177, dvrr_stack+188458, NULL);
 tmp = dvrr_stack + 803177;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+805025, dvrr_stack+214596, NULL);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+2308, dvrr_stack+24, dvrr_stack+96397, dvrr_stack+0, dvrr_stack+4336, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+133535, dvrr_stack+788088, dvrr_stack+131, dvrr_stack+186196, dvrr_stack+90661, dvrr_stack+2308);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+297398, dvrr_stack+788118, dvrr_stack+479, dvrr_stack+787688, dvrr_stack+90733, dvrr_stack+133535);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+807209, dvrr_stack+796947, dvrr_stack+96875, dvrr_stack+787938, dvrr_stack+9952, dvrr_stack+297398);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+807489, dvrr_stack+797157, dvrr_stack+68434, dvrr_stack+788463, dvrr_stack+92492, dvrr_stack+807209);

 /* compute (7 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+753460,dvrr_stack+48252,dvrr_stack+807489,36);


 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+808029, dvrr_stack+753460, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+755080, dvrr_stack+245488, NULL);
 tmp = dvrr_stack + 755080;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+808569, dvrr_stack+240160, NULL);
 tmp = dvrr_stack + 808569;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+756088, dvrr_stack+259141, NULL);
 tmp = dvrr_stack + 756088;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+757384, dvrr_stack+276776, NULL);
 tmp = dvrr_stack + 757384;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+707170, dvrr_stack+299900, NULL);
 tmp = dvrr_stack + 707170;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+709150, dvrr_stack+328220, NULL);
 tmp = dvrr_stack + 709150;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+671431, dvrr_stack+362268, NULL);

 /* compute (4 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+32407, dvrr_stack+2308, dvrr_stack+69188, dvrr_stack+24, dvrr_stack+96397, NULL);

 /* compute (5 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+48, dvrr_stack+133535, dvrr_stack+69034, dvrr_stack+788088, dvrr_stack+131, dvrr_stack+32407);

 /* compute (6 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+759004, dvrr_stack+297398, dvrr_stack+35106, dvrr_stack+788118, dvrr_stack+479, dvrr_stack+48);

 /* compute (7 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+759172, dvrr_stack+807209, dvrr_stack+1637, dvrr_stack+796947, dvrr_stack+96875, dvrr_stack+759004);

 /* compute (8 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+759532, dvrr_stack+807489, dvrr_stack+91643, dvrr_stack+797157, dvrr_stack+68434, dvrr_stack+759172);

 /* compute (8 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+632546,dvrr_stack+392076,dvrr_stack+759532,45);


 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+711526, dvrr_stack+632546, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+674239, dvrr_stack+401968, NULL);
 tmp = dvrr_stack + 674239;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+634571, dvrr_stack+396073, NULL);
 tmp = dvrr_stack + 634571;
 target_ptr = Libderiv->deriv_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+635516, dvrr_stack+418753, NULL);
 tmp = dvrr_stack + 635516;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+637136, dvrr_stack+441003, NULL);
 tmp = dvrr_stack + 637136;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+639161, dvrr_stack+468918, NULL);
 tmp = dvrr_stack + 639161;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+558806, dvrr_stack+503616, NULL);
 tmp = dvrr_stack + 558806;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+561776, dvrr_stack+544811, NULL);

 /* compute (5 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+131, dvrr_stack+32407, dvrr_stack+211960, dvrr_stack+2308, dvrr_stack+69188, NULL);

 /* compute (6 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+90709, dvrr_stack+48, dvrr_stack+67888, dvrr_stack+133535, dvrr_stack+69034, dvrr_stack+131);

 /* compute (7 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+759004, dvrr_stack+9145, dvrr_stack+297398, dvrr_stack+35106, dvrr_stack+90709);

 /* compute (8 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+760207, dvrr_stack+759172, dvrr_stack+96511, dvrr_stack+807209, dvrr_stack+1637, dvrr_stack+319);

 /* compute (9 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+612506, dvrr_stack+759532, dvrr_stack+583086, dvrr_stack+807489, dvrr_stack+91643, dvrr_stack+760207);

 /* compute (9 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+565286,dvrr_stack+586806,dvrr_stack+612506,55);


 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+613331, dvrr_stack+565286, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+567761, dvrr_stack+603266, NULL);
 tmp = dvrr_stack + 567761;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+569301, dvrr_stack+593141, NULL);
 tmp = dvrr_stack + 569301;
 target_ptr = Libderiv->deriv_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+570456, dvrr_stack+626606, NULL);
 tmp = dvrr_stack + 570456;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+483768, dvrr_stack+656581, NULL);
 tmp = dvrr_stack + 483768;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+453153, dvrr_stack+689020, NULL);
 tmp = dvrr_stack + 453153;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+405748, dvrr_stack+731680, NULL);
 tmp = dvrr_stack + 405748;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+373527, dvrr_stack+774800, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+712201, dvrr_stack+788778, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+614156, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 614156;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+572436, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 572436;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+486243, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 486243;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+486999, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 486999;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+428473, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 428473;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+429628, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 429628;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+409378, dvrr_stack+99670, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+712516, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+377817, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 377817;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+456178, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 456178;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+378601, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 378601;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+379609, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 379609;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+380869, dvrr_stack+166726, NULL);
 tmp = dvrr_stack + 380869;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+382409, dvrr_stack+188458, NULL);
 tmp = dvrr_stack + 382409;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+342476, dvrr_stack+214596, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+487944, dvrr_stack+753460, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+344660, dvrr_stack+245488, NULL);
 tmp = dvrr_stack + 344660;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+345668, dvrr_stack+240160, NULL);
 tmp = dvrr_stack + 345668;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+286496, dvrr_stack+259141, NULL);
 tmp = dvrr_stack + 286496;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+287792, dvrr_stack+276776, NULL);
 tmp = dvrr_stack + 287792;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+266917, dvrr_stack+299900, NULL);
 tmp = dvrr_stack + 266917;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+221148, dvrr_stack+328220, NULL);
 tmp = dvrr_stack + 221148;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+223524, dvrr_stack+362268, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+384257, dvrr_stack+632546, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+251536, dvrr_stack+401968, NULL);
 tmp = dvrr_stack + 251536;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+226332, dvrr_stack+396073, NULL);
 tmp = dvrr_stack + 226332;
 target_ptr = Libderiv->deriv_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+227277, dvrr_stack+418753, NULL);
 tmp = dvrr_stack + 227277;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+228897, dvrr_stack+441003, NULL);
 tmp = dvrr_stack + 228897;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+199546, dvrr_stack+468918, NULL);
 tmp = dvrr_stack + 199546;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+106348, dvrr_stack+503616, NULL);
 tmp = dvrr_stack + 106348;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+109318, dvrr_stack+544811, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+230922, dvrr_stack+565286, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+175966, dvrr_stack+603266, NULL);
 tmp = dvrr_stack + 175966;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+202021, dvrr_stack+593141, NULL);
 tmp = dvrr_stack + 202021;
 target_ptr = Libderiv->deriv_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+83878, dvrr_stack+626606, NULL);
 tmp = dvrr_stack + 83878;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+943874, dvrr_stack+656581, NULL);
 tmp = dvrr_stack + 943874;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+946349, dvrr_stack+689020, NULL);
 tmp = dvrr_stack + 946349;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+949374, dvrr_stack+731680, NULL);
 tmp = dvrr_stack + 949374;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+953004, dvrr_stack+774800, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+675499, dvrr_stack+788778, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+788778, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 788778;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+12874, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 12874;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+7447, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 7447;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+23872, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 23872;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+37537, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 37537;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+54700, dvrr_stack+75562, NULL);
 tmp = dvrr_stack + 54700;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+75562, dvrr_stack+99670, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+99670, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+28408, dvrr_stack+123866, NULL);
 tmp = dvrr_stack + 28408;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+123866, dvrr_stack+119438, NULL);
 tmp = dvrr_stack + 123866;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+119438, dvrr_stack+134840, NULL);
 tmp = dvrr_stack + 119438;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+134840, dvrr_stack+148990, NULL);
 tmp = dvrr_stack + 134840;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+148990, dvrr_stack+166726, NULL);
 tmp = dvrr_stack + 148990;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+166726, dvrr_stack+188458, NULL);
 tmp = dvrr_stack + 166726;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+188458, dvrr_stack+214596, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+214596, dvrr_stack+753460, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+753460, dvrr_stack+245488, NULL);
 tmp = dvrr_stack + 753460;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+120446, dvrr_stack+240160, NULL);
 tmp = dvrr_stack + 120446;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+240160, dvrr_stack+259141, NULL);
 tmp = dvrr_stack + 240160;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+259141, dvrr_stack+276776, NULL);
 tmp = dvrr_stack + 259141;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+276776, dvrr_stack+299900, NULL);
 tmp = dvrr_stack + 276776;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+299900, dvrr_stack+328220, NULL);
 tmp = dvrr_stack + 299900;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+328220, dvrr_stack+362268, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+362268, dvrr_stack+632546, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+632546, dvrr_stack+401968, NULL);
 tmp = dvrr_stack + 632546;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+401968, dvrr_stack+396073, NULL);
 tmp = dvrr_stack + 401968;
 target_ptr = Libderiv->deriv_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+396073, dvrr_stack+418753, NULL);
 tmp = dvrr_stack + 396073;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+418753, dvrr_stack+441003, NULL);
 tmp = dvrr_stack + 418753;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+441003, dvrr_stack+468918, NULL);
 tmp = dvrr_stack + 441003;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+468918, dvrr_stack+503616, NULL);
 tmp = dvrr_stack + 468918;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+503616, dvrr_stack+544811, NULL);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+507126, dvrr_stack+565286, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+565286, dvrr_stack+603266, NULL);
 tmp = dvrr_stack + 565286;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+603266, dvrr_stack+593141, NULL);
 tmp = dvrr_stack + 603266;
 target_ptr = Libderiv->deriv_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+593141, dvrr_stack+626606, NULL);
 tmp = dvrr_stack + 593141;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+626606, dvrr_stack+656581, NULL);
 tmp = dvrr_stack + 626606;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+656581, dvrr_stack+689020, NULL);
 tmp = dvrr_stack + 656581;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+689020, dvrr_stack+731680, NULL);
 tmp = dvrr_stack + 689020;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+731680, dvrr_stack+774800, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+4336, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+774800, dvrr_stack+4336, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+152, dvrr_stack+161, dvrr_stack+21, NULL, NULL, Data->F+3);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+774806, dvrr_stack+152, dvrr_stack+22243, dvrr_stack+161, dvrr_stack+21, dvrr_stack+4336);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+788208, dvrr_stack+774806, dvrr_stack+186196, dvrr_stack+152, dvrr_stack+22243, dvrr_stack+774800);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+774824, dvrr_stack+707, dvrr_stack+164, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+578, dvrr_stack+774824, dvrr_stack+787670, dvrr_stack+707, dvrr_stack+164, dvrr_stack+152);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+152, dvrr_stack+578, dvrr_stack+122822, dvrr_stack+774824, dvrr_stack+787670, dvrr_stack+774806);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+774842, dvrr_stack+152, dvrr_stack+787688, dvrr_stack+578, dvrr_stack+122822, dvrr_stack+788208);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+122822, dvrr_stack+121, dvrr_stack+713, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+774932, dvrr_stack+122822, dvrr_stack+787748, dvrr_stack+121, dvrr_stack+713, dvrr_stack+774824);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+707, dvrr_stack+774932, dvrr_stack+787778, dvrr_stack+122822, dvrr_stack+787748, dvrr_stack+578);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+641636, dvrr_stack+707, dvrr_stack+787838, dvrr_stack+774932, dvrr_stack+787778, dvrr_stack+152);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+774932, dvrr_stack+641636, dvrr_stack+787938, dvrr_stack+707, dvrr_stack+787838, dvrr_stack+774842);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+775142, dvrr_stack+3730, dvrr_stack+774932);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+775457, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 775457;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+776045, dvrr_stack+6859, dvrr_stack+788463);
 tmp = dvrr_stack + 776045;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+776486, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 776486;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+777242, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 777242;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+778187, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 778187;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+779342, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 779342;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+780728, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+121, dvrr_stack+774800, dvrr_stack+24, dvrr_stack+4336, dvrr_stack+0, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+707, dvrr_stack+788208, dvrr_stack+788088, dvrr_stack+774806, dvrr_stack+186196, dvrr_stack+121);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+782366, dvrr_stack+774842, dvrr_stack+788118, dvrr_stack+152, dvrr_stack+787688, dvrr_stack+707);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+782492, dvrr_stack+774932, dvrr_stack+796947, dvrr_stack+641636, dvrr_stack+787938, dvrr_stack+782366);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+782772, dvrr_stack+117058, dvrr_stack+782492);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+783192, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 783192;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+783976, dvrr_stack+118654, dvrr_stack+797157);
 tmp = dvrr_stack + 783976;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+784564, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 784564;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+785572, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 785572;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+735970, dvrr_stack+164878, dvrr_stack+133580);
 tmp = dvrr_stack + 735970;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+737510, dvrr_stack+186274, dvrr_stack+147450);
 tmp = dvrr_stack + 737510;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+739358, dvrr_stack+212048, dvrr_stack+164878);

 /* compute (4 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+121, dvrr_stack+2308, dvrr_stack+774800, dvrr_stack+24, NULL);

 /* compute (5 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+760657, dvrr_stack+707, dvrr_stack+133535, dvrr_stack+788208, dvrr_stack+788088, dvrr_stack+0);

 /* compute (6 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+786832, dvrr_stack+782366, dvrr_stack+297398, dvrr_stack+774842, dvrr_stack+788118, dvrr_stack+760657);

 /* compute (7 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+787000, dvrr_stack+782492, dvrr_stack+807209, dvrr_stack+774932, dvrr_stack+796947, dvrr_stack+786832);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,36,1,dvrr_stack+787360, dvrr_stack+48252, dvrr_stack+787000);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+741542, dvrr_stack+244192, dvrr_stack+48252);
 tmp = dvrr_stack + 741542;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+692650, dvrr_stack+239152, dvrr_stack+807489);
 tmp = dvrr_stack + 692650;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+693406, dvrr_stack+257521, dvrr_stack+239152);
 tmp = dvrr_stack + 693406;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+694702, dvrr_stack+274796, dvrr_stack+244192);
 tmp = dvrr_stack + 694702;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+659606, dvrr_stack+297524, dvrr_stack+257521);
 tmp = dvrr_stack + 659606;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+661586, dvrr_stack+325412, dvrr_stack+274796);
 tmp = dvrr_stack + 661586;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+629081, dvrr_stack+358992, dvrr_stack+297524);

 /* compute (5 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+796947, dvrr_stack+0, dvrr_stack+32407, dvrr_stack+121, dvrr_stack+2308, NULL);

 /* compute (6 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+796968, dvrr_stack+760657, dvrr_stack+48, dvrr_stack+707, dvrr_stack+133535, dvrr_stack+796947);

 /* compute (7 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+787900, dvrr_stack+786832, dvrr_stack+759004, dvrr_stack+782366, dvrr_stack+297398, dvrr_stack+796968);

 /* compute (8 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+696322, dvrr_stack+787000, dvrr_stack+759172, dvrr_stack+782492, dvrr_stack+807209, dvrr_stack+787900);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,45,1,dvrr_stack+696772, dvrr_stack+392076, dvrr_stack+696322);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+595121, dvrr_stack+121202, dvrr_stack+392076);
 tmp = dvrr_stack + 595121;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+604421, dvrr_stack+394813, dvrr_stack+759532);
 tmp = dvrr_stack + 604421;
 target_ptr = Libderiv->deriv_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+605366, dvrr_stack+131510, dvrr_stack+394813);
 tmp = dvrr_stack + 605366;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+507951, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 507951;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+509976, dvrr_stack+161842, dvrr_stack+131510);
 tmp = dvrr_stack + 509976;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+471888, dvrr_stack+182686, dvrr_stack+144920);
 tmp = dvrr_stack + 471888;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+443478, dvrr_stack+207862, dvrr_stack+161842);

 /* compute (6 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+1609, dvrr_stack+796947, dvrr_stack+131, dvrr_stack+0, dvrr_stack+32407, NULL);

 /* compute (7 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+807209, dvrr_stack+796968, dvrr_stack+90709, dvrr_stack+760657, dvrr_stack+48, dvrr_stack+1609);

 /* compute (8 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+697447, dvrr_stack+787900, dvrr_stack+319, dvrr_stack+786832, dvrr_stack+759004, dvrr_stack+807209);

 /* compute (9 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+631889, dvrr_stack+696322, dvrr_stack+760207, dvrr_stack+787000, dvrr_stack+759172, dvrr_stack+697447);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,55,1,dvrr_stack+606986, dvrr_stack+586806, dvrr_stack+631889);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+420778, dvrr_stack+601286, dvrr_stack+586806);
 tmp = dvrr_stack + 420778;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+474858, dvrr_stack+591601, dvrr_stack+612506);
 tmp = dvrr_stack + 474858;
 target_ptr = Libderiv->deriv_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+402913, dvrr_stack+624131, dvrr_stack+591601);
 tmp = dvrr_stack + 402913;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+362943, dvrr_stack+653556, dvrr_stack+601286);
 tmp = dvrr_stack + 362943;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+365418, dvrr_stack+293300, dvrr_stack+624131);
 tmp = dvrr_stack + 365418;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+331028, dvrr_stack+320420, dvrr_stack+653556);
 tmp = dvrr_stack + 331028;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+215136, dvrr_stack+769795, dvrr_stack+293300);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+697447, dvrr_stack+3730, dvrr_stack+774932);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+566826, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 566826;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+422318, dvrr_stack+6859, dvrr_stack+788463);
 tmp = dvrr_stack + 422318;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+422759, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 422759;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+397693, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 397693;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+368443, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 368443;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+302276, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 302276;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+303662, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+404893, dvrr_stack+117058, dvrr_stack+782492);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+369598, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 369598;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+633806, dvrr_stack+118654, dvrr_stack+797157);
 tmp = dvrr_stack + 633806;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+278756, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 278756;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+279764, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 279764;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+260761, dvrr_stack+164878, dvrr_stack+133580);
 tmp = dvrr_stack + 260761;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+245488, dvrr_stack+186274, dvrr_stack+147450);
 tmp = dvrr_stack + 245488;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+190642, dvrr_stack+212048, dvrr_stack+164878);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,36,1,dvrr_stack+305300, dvrr_stack+48252, dvrr_stack+787000);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+247336, dvrr_stack+244192, dvrr_stack+48252);
 tmp = dvrr_stack + 247336;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+241456, dvrr_stack+239152, dvrr_stack+807489);
 tmp = dvrr_stack + 241456;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+219426, dvrr_stack+257521, dvrr_stack+239152);
 tmp = dvrr_stack + 219426;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+168574, dvrr_stack+274796, dvrr_stack+244192);
 tmp = dvrr_stack + 168574;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+150530, dvrr_stack+297524, dvrr_stack+257521);
 tmp = dvrr_stack + 150530;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+100090, dvrr_stack+325412, dvrr_stack+274796);
 tmp = dvrr_stack + 100090;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+544755, dvrr_stack+358992, dvrr_stack+297524);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,45,1,dvrr_stack+334658, dvrr_stack+392076, dvrr_stack+696322);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+136100, dvrr_stack+121202, dvrr_stack+392076);
 tmp = dvrr_stack + 136100;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+192826, dvrr_stack+394813, dvrr_stack+759532);
 tmp = dvrr_stack + 192826;
 target_ptr = Libderiv->deriv_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+124454, dvrr_stack+131510, dvrr_stack+394813);
 tmp = dvrr_stack + 124454;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+102466, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 102466;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+77200, dvrr_stack+161842, dvrr_stack+131510);
 tmp = dvrr_stack + 77200;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+547563, dvrr_stack+182686, dvrr_stack+144920);
 tmp = dvrr_stack + 547563;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+550533, dvrr_stack+207862, dvrr_stack+161842);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,55,1,dvrr_stack+170194, dvrr_stack+586806, dvrr_stack+631889);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+56086, dvrr_stack+601286, dvrr_stack+586806);
 tmp = dvrr_stack + 56086;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+38692, dvrr_stack+591601, dvrr_stack+612506);
 tmp = dvrr_stack + 38692;
 target_ptr = Libderiv->deriv_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+61630, dvrr_stack+624131, dvrr_stack+591601);
 tmp = dvrr_stack + 61630;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+957294, dvrr_stack+653556, dvrr_stack+601286);
 tmp = dvrr_stack + 957294;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+959769, dvrr_stack+293300, dvrr_stack+624131);
 tmp = dvrr_stack + 959769;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+962794, dvrr_stack+320420, dvrr_stack+653556);
 tmp = dvrr_stack + 962794;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+966424, dvrr_stack+769795, dvrr_stack+293300);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+697762, dvrr_stack+3730, dvrr_stack+774932);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+281024, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 281024;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+262301, dvrr_stack+6859, dvrr_stack+788463);
 tmp = dvrr_stack + 262301;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+24817, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 24817;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+13315, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 13315;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+177506, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 177506;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+140888, dvrr_stack+73924, dvrr_stack+36382);
 tmp = dvrr_stack + 140888;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+73924, dvrr_stack+97759, dvrr_stack+53314);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+405313, dvrr_stack+117058, dvrr_stack+782492);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+346424, dvrr_stack+122858, dvrr_stack+117058);
 tmp = dvrr_stack + 346424;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+754468, dvrr_stack+118654, dvrr_stack+797157);
 tmp = dvrr_stack + 754468;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+128570, dvrr_stack+133580, dvrr_stack+118654);
 tmp = dvrr_stack + 128570;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+43207, dvrr_stack+147450, dvrr_stack+122858);
 tmp = dvrr_stack + 43207;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+97625, dvrr_stack+164878, dvrr_stack+133580);
 tmp = dvrr_stack + 97625;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+970714, dvrr_stack+186274, dvrr_stack+147450);
 tmp = dvrr_stack + 970714;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+186274, dvrr_stack+212048, dvrr_stack+164878);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,36,1,dvrr_stack+796947, dvrr_stack+48252, dvrr_stack+787000);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+554043, dvrr_stack+244192, dvrr_stack+48252);
 tmp = dvrr_stack + 554043;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+85858, dvrr_stack+239152, dvrr_stack+807489);
 tmp = dvrr_stack + 85858;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+212023, dvrr_stack+257521, dvrr_stack+239152);
 tmp = dvrr_stack + 212023;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+69885, dvrr_stack+274796, dvrr_stack+244192);
 tmp = dvrr_stack + 69885;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+972562, dvrr_stack+297524, dvrr_stack+257521);
 tmp = dvrr_stack + 972562;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+974542, dvrr_stack+325412, dvrr_stack+274796);
 tmp = dvrr_stack + 974542;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+324710, dvrr_stack+358992, dvrr_stack+297524);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,45,1,dvrr_stack+807209, dvrr_stack+392076, dvrr_stack+696322);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+358985, dvrr_stack+121202, dvrr_stack+392076);
 tmp = dvrr_stack + 358985;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+360245, dvrr_stack+394813, dvrr_stack+759532);
 tmp = dvrr_stack + 360245;
 target_ptr = Libderiv->deriv_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+976918, dvrr_stack+131510, dvrr_stack+394813);
 tmp = dvrr_stack + 976918;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+978538, dvrr_stack+144920, dvrr_stack+121202);
 tmp = dvrr_stack + 978538;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+980563, dvrr_stack+161842, dvrr_stack+131510);
 tmp = dvrr_stack + 980563;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+983038, dvrr_stack+182686, dvrr_stack+144920);
 tmp = dvrr_stack + 983038;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+986008, dvrr_stack+207862, dvrr_stack+161842);

 /* compute (9 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,55,1,dvrr_stack+207862, dvrr_stack+586806, dvrr_stack+631889);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+208687, dvrr_stack+601286, dvrr_stack+586806);
 tmp = dvrr_stack + 208687;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+210227, dvrr_stack+591601, dvrr_stack+612506);
 tmp = dvrr_stack + 210227;
 target_ptr = Libderiv->deriv_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+989518, dvrr_stack+624131, dvrr_stack+591601);
 tmp = dvrr_stack + 989518;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+991498, dvrr_stack+653556, dvrr_stack+601286);
 tmp = dvrr_stack + 991498;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+993973, dvrr_stack+293300, dvrr_stack+624131);
 tmp = dvrr_stack + 993973;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+996998, dvrr_stack+320420, dvrr_stack+653556);
 tmp = dvrr_stack + 996998;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+1000628, dvrr_stack+769795, dvrr_stack+293300);

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+769795,dvrr_stack+6439,dvrr_stack+3415,15);


 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+788463, dvrr_stack+769795, NULL);

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+770740,dvrr_stack+11578,dvrr_stack+6439,15);


 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+772000, dvrr_stack+770740, NULL);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+772420,dvrr_stack+22252,dvrr_stack+11578,15);


 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+774040, dvrr_stack+772420, NULL);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1004918,dvrr_stack+35557,dvrr_stack+22252,15);


 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+16402, dvrr_stack+1004918, NULL);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+1006943,dvrr_stack+52324,dvrr_stack+35557,15);


 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+361190, dvrr_stack+1006943, NULL);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+1009418,dvrr_stack+72754,dvrr_stack+52324,15);


 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+10462, dvrr_stack+1009418, NULL);

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+4336, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+774580, dvrr_stack+211957, dvrr_stack+4336, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+2308, dvrr_stack+15, dvrr_stack+774580, dvrr_stack+69179, dvrr_stack+211957, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+111, dvrr_stack+2308, dvrr_stack+69182, dvrr_stack+15, NULL);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+774586, dvrr_stack+211960, dvrr_stack+0, dvrr_stack+69188, dvrr_stack+111, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22243, dvrr_stack+704, dvrr_stack+1966, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+698077, dvrr_stack+569, dvrr_stack+22243, dvrr_stack+873, dvrr_stack+704, dvrr_stack+4336);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+774607, dvrr_stack+211975, dvrr_stack+698077, dvrr_stack+69198, dvrr_stack+569, dvrr_stack+774580);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+133535, dvrr_stack+211993, dvrr_stack+774607, dvrr_stack+69207, dvrr_stack+211975, dvrr_stack+2308);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+760657, dvrr_stack+19395, dvrr_stack+133535, dvrr_stack+69225, dvrr_stack+211993, dvrr_stack+0);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+774637, dvrr_stack+67888, dvrr_stack+760657, dvrr_stack+69034, dvrr_stack+19395, dvrr_stack+774586);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+186196, dvrr_stack+1969, dvrr_stack+1603, NULL, NULL, dvrr_stack+1966);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+578, dvrr_stack+96403, dvrr_stack+186196, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+22243);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+69179, dvrr_stack+9365, dvrr_stack+578, dvrr_stack+30, dvrr_stack+96403, dvrr_stack+698077);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+797487, dvrr_stack+186214, dvrr_stack+69179, dvrr_stack+52033, dvrr_stack+9365, dvrr_stack+774607);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+297398, dvrr_stack+614, dvrr_stack+797487, dvrr_stack+52069, dvrr_stack+186214, dvrr_stack+133535);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+248344, dvrr_stack+67951, dvrr_stack+297398, dvrr_stack+52129, dvrr_stack+614, dvrr_stack+760657);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+242212, dvrr_stack+9145, dvrr_stack+248344, dvrr_stack+35106, dvrr_stack+67951, dvrr_stack+774637);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+774721, dvrr_stack+4594, dvrr_stack+9319, NULL, NULL, dvrr_stack+1603);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+774751, dvrr_stack+96421, dvrr_stack+774721, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+186196);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+1975, dvrr_stack+96451, dvrr_stack+774751, dvrr_stack+90679, dvrr_stack+96421, dvrr_stack+578);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+641636, dvrr_stack+69079, dvrr_stack+1975, dvrr_stack+52219, dvrr_stack+96451, dvrr_stack+69179);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+2075, dvrr_stack+68077, dvrr_stack+641636, dvrr_stack+35232, dvrr_stack+69079, dvrr_stack+797487);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+774811, dvrr_stack+47686, dvrr_stack+2075, dvrr_stack+35332, dvrr_stack+68077, dvrr_stack+297398);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+631889, dvrr_stack+582071, dvrr_stack+774811, dvrr_stack+3205, dvrr_stack+47686, dvrr_stack+248344);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+696322, dvrr_stack+96511, dvrr_stack+631889, dvrr_stack+1637, dvrr_stack+582071, dvrr_stack+242212);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+79675, dvrr_stack+9329, dvrr_stack+19295, NULL, NULL, dvrr_stack+9319);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+446988, dvrr_stack+68227, dvrr_stack+79675, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+774721);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+632249, dvrr_stack+68272, dvrr_stack+446988, dvrr_stack+52279, dvrr_stack+68227, dvrr_stack+774751);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+596381, dvrr_stack+47449, dvrr_stack+632249, dvrr_stack+90793, dvrr_stack+68272, dvrr_stack+1975);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+211382, dvrr_stack+4339, dvrr_stack+596381, dvrr_stack+2318, dvrr_stack+47449, dvrr_stack+641636);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+786832, dvrr_stack+582351, dvrr_stack+211382, dvrr_stack+71678, dvrr_stack+4339, dvrr_stack+2075);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+25573, dvrr_stack+582666, dvrr_stack+786832, dvrr_stack+71903, dvrr_stack+582351, dvrr_stack+774811);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+97085, dvrr_stack+25573, dvrr_stack+72218, dvrr_stack+582666, dvrr_stack+631889);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+34632, dvrr_stack+583086, dvrr_stack+31432, dvrr_stack+91643, dvrr_stack+97085, dvrr_stack+696322);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2318, dvrr_stack+19310, dvrr_stack+32123, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+11452, dvrr_stack+90115, dvrr_stack+2318, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+79675);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+211697, dvrr_stack+90178, dvrr_stack+11452, dvrr_stack+90883, dvrr_stack+90115, dvrr_stack+446988);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+787900, dvrr_stack+69675, dvrr_stack+211697, dvrr_stack+90946, dvrr_stack+90178, dvrr_stack+632249);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+44467, dvrr_stack+583761, dvrr_stack+787900, dvrr_stack+92183, dvrr_stack+69675, dvrr_stack+596381);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+90793, dvrr_stack+584076, dvrr_stack+44467, dvrr_stack+93458, dvrr_stack+583761, dvrr_stack+211382);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+91381, dvrr_stack+584517, dvrr_stack+90793, dvrr_stack+93773, dvrr_stack+584076, dvrr_stack+786832);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+213319, dvrr_stack+585105, dvrr_stack+91381, dvrr_stack+94214, dvrr_stack+584517, dvrr_stack+25573);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+93339, dvrr_stack+585861, dvrr_stack+213319, dvrr_stack+94802, dvrr_stack+585105, dvrr_stack+31432);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1012388, dvrr_stack+586806, dvrr_stack+93339, dvrr_stack+392076, dvrr_stack+585861, dvrr_stack+34632);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2381, dvrr_stack+32144, dvrr_stack+47999, NULL, NULL, dvrr_stack+32123);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+129578, dvrr_stack+892, dvrr_stack+2381, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+2318);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+92137, dvrr_stack+976, dvrr_stack+129578, dvrr_stack+92807, dvrr_stack+892, dvrr_stack+11452);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+92417, dvrr_stack+90304, dvrr_stack+92137, dvrr_stack+92891, dvrr_stack+976, dvrr_stack+211697);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+8203, dvrr_stack+66805, dvrr_stack+92417, dvrr_stack+93059, dvrr_stack+90304, dvrr_stack+787900);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+5571, dvrr_stack+587961, dvrr_stack+8203, dvrr_stack+69255, dvrr_stack+66805, dvrr_stack+44467);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+94494, dvrr_stack+588549, dvrr_stack+5571, dvrr_stack+95558, dvrr_stack+587961, dvrr_stack+90793);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1013774, dvrr_stack+589333, dvrr_stack+94494, dvrr_stack+393021, dvrr_stack+588549, dvrr_stack+91381);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1015034, dvrr_stack+590341, dvrr_stack+1013774, dvrr_stack+393805, dvrr_stack+589333, dvrr_stack+213319);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+1016574, dvrr_stack+591601, dvrr_stack+1015034, dvrr_stack+394813, dvrr_stack+590341, dvrr_stack+93339);

 /* compute (10 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+1018422,dvrr_stack+1016574,dvrr_stack+1012388,66);


 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+393021, dvrr_stack+1018422, NULL);

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+787252, dvrr_stack+48027, dvrr_stack+67686, NULL, NULL, dvrr_stack+47999);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+394407, dvrr_stack+237780, dvrr_stack+787252, dvrr_stack+32172, dvrr_stack+48027, dvrr_stack+2381);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+92837, dvrr_stack+237888, dvrr_stack+394407, dvrr_stack+117646, dvrr_stack+237780, dvrr_stack+129578);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51601, dvrr_stack+238104, dvrr_stack+92837, dvrr_stack+117754, dvrr_stack+237888, dvrr_stack+92137);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95502, dvrr_stack+238464, dvrr_stack+51601, dvrr_stack+117970, dvrr_stack+238104, dvrr_stack+92417);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+71505, dvrr_stack+596606, dvrr_stack+95502, dvrr_stack+49008, dvrr_stack+238464, dvrr_stack+8203);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1022580, dvrr_stack+597362, dvrr_stack+71505, dvrr_stack+398908, dvrr_stack+596606, dvrr_stack+5571);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1023876, dvrr_stack+598370, dvrr_stack+1022580, dvrr_stack+399664, dvrr_stack+597362, dvrr_stack+94494);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+398638, dvrr_stack+599666, dvrr_stack+1023876, dvrr_stack+400672, dvrr_stack+598370, dvrr_stack+1013774);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1025496, dvrr_stack+601286, dvrr_stack+398638, dvrr_stack+121202, dvrr_stack+599666, dvrr_stack+1015034);

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+1027872,dvrr_stack+1025496,dvrr_stack+1016574,66);


 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+1033416, dvrr_stack+1027872, NULL);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+49008, dvrr_stack+67722, dvrr_stack+20176, NULL, NULL, dvrr_stack+67686);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+49143, dvrr_stack+242428, dvrr_stack+49008, dvrr_stack+48063, dvrr_stack+67722, dvrr_stack+787252);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+117646, dvrr_stack+242563, dvrr_stack+49143, dvrr_stack+66670, dvrr_stack+242428, dvrr_stack+394407);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+400618, dvrr_stack+242833, dvrr_stack+117646, dvrr_stack+118330, dvrr_stack+242563, dvrr_stack+92837);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1035264, dvrr_stack+243283, dvrr_stack+400618, dvrr_stack+32818, dvrr_stack+242833, dvrr_stack+51601);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1036209, dvrr_stack+618281, dvrr_stack+1035264, dvrr_stack+414253, dvrr_stack+243283, dvrr_stack+95502);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1037469, dvrr_stack+619226, dvrr_stack+1036209, dvrr_stack+414928, dvrr_stack+618281, dvrr_stack+71505);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1039089, dvrr_stack+620486, dvrr_stack+1037469, dvrr_stack+415873, dvrr_stack+619226, dvrr_stack+1022580);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+414253, dvrr_stack+622106, dvrr_stack+1039089, dvrr_stack+417133, dvrr_stack+620486, dvrr_stack+1023876);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1041114, dvrr_stack+624131, dvrr_stack+414253, dvrr_stack+131510, dvrr_stack+622106, dvrr_stack+398638);

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+1044084,dvrr_stack+1041114,dvrr_stack+1025496,66);


 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+1051212, dvrr_stack+1044084, NULL);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+416728, dvrr_stack+20221, dvrr_stack+264, NULL, NULL, dvrr_stack+20176);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+476013, dvrr_stack+255316, dvrr_stack+416728, dvrr_stack+67767, dvrr_stack+20221, dvrr_stack+49008);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+416893, dvrr_stack+255481, dvrr_stack+476013, dvrr_stack+4171, dvrr_stack+255316, dvrr_stack+49143);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+417443, dvrr_stack+255811, dvrr_stack+416893, dvrr_stack+8815, dvrr_stack+255481, dvrr_stack+117646);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1053588, dvrr_stack+256361, dvrr_stack+417443, dvrr_stack+434953, dvrr_stack+255811, dvrr_stack+400618);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1054743, dvrr_stack+646406, dvrr_stack+1053588, dvrr_stack+435503, dvrr_stack+256361, dvrr_stack+1035264);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1056283, dvrr_stack+647561, dvrr_stack+1054743, dvrr_stack+436328, dvrr_stack+646406, dvrr_stack+1036209);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+434953, dvrr_stack+649101, dvrr_stack+1056283, dvrr_stack+437483, dvrr_stack+647561, dvrr_stack+1037469);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1058263, dvrr_stack+651081, dvrr_stack+434953, dvrr_stack+439023, dvrr_stack+649101, dvrr_stack+1039089);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1061288, dvrr_stack+653556, dvrr_stack+1058263, dvrr_stack+144920, dvrr_stack+651081, dvrr_stack+414253);

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1064918,dvrr_stack+1061288,dvrr_stack+1041114,66);


 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+437428, dvrr_stack+1064918, NULL);

 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+440398, dvrr_stack+32263, dvrr_stack+164812, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+440596, dvrr_stack+272101, dvrr_stack+440398, dvrr_stack+20276, dvrr_stack+32263, dvrr_stack+416728);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+401293, dvrr_stack+272299, dvrr_stack+440596, dvrr_stack+18662, dvrr_stack+272101, dvrr_stack+476013);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1073828, dvrr_stack+272695, dvrr_stack+401293, dvrr_stack+18860, dvrr_stack+272299, dvrr_stack+416893);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1074818, dvrr_stack+273355, dvrr_stack+1073828, dvrr_stack+461658, dvrr_stack+272695, dvrr_stack+417443);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1076204, dvrr_stack+20857, dvrr_stack+1074818, dvrr_stack+462318, dvrr_stack+273355, dvrr_stack+1053588);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1078052, dvrr_stack+681826, dvrr_stack+1076204, dvrr_stack+463308, dvrr_stack+20857, dvrr_stack+1054743);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+461658, dvrr_stack+683674, dvrr_stack+1078052, dvrr_stack+464694, dvrr_stack+681826, dvrr_stack+1056283);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1080428, dvrr_stack+686050, dvrr_stack+461658, dvrr_stack+466542, dvrr_stack+683674, dvrr_stack+434953);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1084058, dvrr_stack+293300, dvrr_stack+1080428, dvrr_stack+161842, dvrr_stack+686050, dvrr_stack+1058263);

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+1088414,dvrr_stack+1084058,dvrr_stack+1061288,66);


 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+464628, dvrr_stack+1088414, NULL);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+468258, dvrr_stack+32329, dvrr_stack+4619, NULL, NULL, dvrr_stack+164812);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+418268, dvrr_stack+243958, dvrr_stack+468258, dvrr_stack+48174, dvrr_stack+32329, dvrr_stack+440398);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1099304, dvrr_stack+296930, dvrr_stack+418268, dvrr_stack+32422, dvrr_stack+243958, dvrr_stack+440596);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1100084, dvrr_stack+33852, dvrr_stack+1099304, dvrr_stack+494568, dvrr_stack+296930, dvrr_stack+401293);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1101254, dvrr_stack+720370, dvrr_stack+1100084, dvrr_stack+495036, dvrr_stack+33852, dvrr_stack+1073828);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1102892, dvrr_stack+721540, dvrr_stack+1101254, dvrr_stack+495816, dvrr_stack+720370, dvrr_stack+1074818);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1099304, dvrr_stack+723178, dvrr_stack+1102892, dvrr_stack+496986, dvrr_stack+721540, dvrr_stack+1076204);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+494568, dvrr_stack+725362, dvrr_stack+1099304, dvrr_stack+498624, dvrr_stack+723178, dvrr_stack+1078052);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1099304, dvrr_stack+728170, dvrr_stack+494568, dvrr_stack+500808, dvrr_stack+725362, dvrr_stack+461658);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+494568, dvrr_stack+320420, dvrr_stack+1099304, dvrr_stack+182686, dvrr_stack+728170, dvrr_stack+1080428);

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+1099304,dvrr_stack+494568,dvrr_stack+1084058,66);


 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+720370, dvrr_stack+1099304, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+182686, dvrr_stack+769795, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+183001, dvrr_stack+770740, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+183421, dvrr_stack+772420, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+183961, dvrr_stack+1004918, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+184636, dvrr_stack+1006943, NULL);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+320420, dvrr_stack+1009418, NULL);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+321410, dvrr_stack+1018422, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+322796, dvrr_stack+1027872, NULL);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+499716, dvrr_stack+1044084, NULL);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+724726, dvrr_stack+1064918, NULL);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+727696, dvrr_stack+1088414, NULL);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+1112372, dvrr_stack+1099304, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+185461, dvrr_stack+769795, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+185776, dvrr_stack+770740, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+769795, dvrr_stack+772420, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+772420, dvrr_stack+1004918, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+1004918, dvrr_stack+1006943, NULL);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+1005743, dvrr_stack+1009418, NULL);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+1006733, dvrr_stack+1018422, NULL);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+1018422, dvrr_stack+1027872, NULL);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+1027872, dvrr_stack+1044084, NULL);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+1044084, dvrr_stack+1064918, NULL);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+1064918, dvrr_stack+1088414, NULL);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+1088414, dvrr_stack+1099304, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+1092770, dvrr_stack+6439, dvrr_stack+788238);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+1093085, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+1093505, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+1094045, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+1094720, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+1095545, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (6 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+1096535, dvrr_stack+131, dvrr_stack+774586, dvrr_stack+32407, dvrr_stack+211960, NULL);

 /* compute (7 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+1096563, dvrr_stack+90709, dvrr_stack+774637, dvrr_stack+48, dvrr_stack+67888, dvrr_stack+1096535);

 /* compute (8 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+1096671, dvrr_stack+319, dvrr_stack+242212, dvrr_stack+759004, dvrr_stack+9145, dvrr_stack+1096563);

 /* compute (9 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1096941, dvrr_stack+760207, dvrr_stack+696322, dvrr_stack+759172, dvrr_stack+96511, dvrr_stack+1096671);

 /* compute (10 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1097491, dvrr_stack+612506, dvrr_stack+34632, dvrr_stack+759532, dvrr_stack+583086, dvrr_stack+1096941);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,66,1,dvrr_stack+759004, dvrr_stack+1016574, dvrr_stack+1097491);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+1098481, dvrr_stack+1025496, dvrr_stack+1012388);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+1100329, dvrr_stack+1041114, dvrr_stack+1016574);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+1102705, dvrr_stack+1061288, dvrr_stack+1025496);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+1105675, dvrr_stack+1084058, dvrr_stack+1041114);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+1068548, dvrr_stack+494568, dvrr_stack+1061288);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+612506, dvrr_stack+6439, dvrr_stack+788238);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+612821, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+1096535, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+1109305, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+1109980, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+1110805, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,66,1,dvrr_stack+1047054, dvrr_stack+1016574, dvrr_stack+1097491);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+1048440, dvrr_stack+1025496, dvrr_stack+1012388);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+1030248, dvrr_stack+1041114, dvrr_stack+1016574);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+1008119, dvrr_stack+1061288, dvrr_stack+1025496);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+1116728, dvrr_stack+1084058, dvrr_stack+1041114);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+1120358, dvrr_stack+494568, dvrr_stack+1061288);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+1097075, dvrr_stack+6439, dvrr_stack+788238);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+1111795, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+1072904, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+1050288, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+1020270, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+1021095, dvrr_stack+72754, dvrr_stack+35557);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,66,1,dvrr_stack+770335, dvrr_stack+1016574, dvrr_stack+1097491);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+1124714, dvrr_stack+1025496, dvrr_stack+1012388);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+1126562, dvrr_stack+1041114, dvrr_stack+1016574);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+1128938, dvrr_stack+1061288, dvrr_stack+1025496);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+1131908, dvrr_stack+1084058, dvrr_stack+1041114);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+1135538, dvrr_stack+494568, dvrr_stack+1061288);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+494568, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+494883, dvrr_stack+48252, dvrr_stack+3730);
 tmp = dvrr_stack + 494883;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+495471, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+495891, dvrr_stack+239152, dvrr_stack+6859);
 tmp = dvrr_stack + 495891;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+496675, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+497215, dvrr_stack+244192, dvrr_stack+12118);
 tmp = dvrr_stack + 497215;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+498223, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1011089, dvrr_stack+257521, dvrr_stack+22927);
 tmp = dvrr_stack + 1011089;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+1097390, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1139894, dvrr_stack+274796, dvrr_stack+36382);
 tmp = dvrr_stack + 1139894;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+502092, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1141434, dvrr_stack+297524, dvrr_stack+53314);
 tmp = dvrr_stack + 1141434;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+498898, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 498898;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1032624, dvrr_stack+392076, dvrr_stack+117058);
 tmp = dvrr_stack + 1032624;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+773095, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 773095;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+72513, dvrr_stack+394813, dvrr_stack+118654);
 tmp = dvrr_stack + 72513;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+33852, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 33852;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1143282, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 1143282;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+32329, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 32329;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1144578, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 1144578;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1146198, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 1146198;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1147353, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 1147353;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1149333, dvrr_stack+164878, dvrr_stack+52324);
 tmp = dvrr_stack + 1149333;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1150719, dvrr_stack+161842, dvrr_stack+164878);
 tmp = dvrr_stack + 1150719;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1153095, dvrr_stack+586806, dvrr_stack+48252);
 tmp = dvrr_stack + 1153095;
 target_ptr = Libderiv->deriv_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1154040, dvrr_stack+591601, dvrr_stack+239152);
 tmp = dvrr_stack + 1154040;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1155300, dvrr_stack+601286, dvrr_stack+244192);
 tmp = dvrr_stack + 1155300;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1156920, dvrr_stack+624131, dvrr_stack+257521);
 tmp = dvrr_stack + 1156920;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1158945, dvrr_stack+653556, dvrr_stack+274796);
 tmp = dvrr_stack + 1158945;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1161420, dvrr_stack+293300, dvrr_stack+297524);
 tmp = dvrr_stack + 1161420;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1164390, dvrr_stack+1012388, dvrr_stack+392076);
 tmp = dvrr_stack + 1164390;
 target_ptr = Libderiv->deriv_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1165545, dvrr_stack+1016574, dvrr_stack+394813);
 tmp = dvrr_stack + 1165545;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1167085, dvrr_stack+1025496, dvrr_stack+121202);
 tmp = dvrr_stack + 1167085;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1169065, dvrr_stack+1041114, dvrr_stack+131510);
 tmp = dvrr_stack + 1169065;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1171540, dvrr_stack+1061288, dvrr_stack+144920);
 tmp = dvrr_stack + 1171540;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1174565, dvrr_stack+1084058, dvrr_stack+161842);
 tmp = dvrr_stack + 1174565;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+499339, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+499342, dvrr_stack+4336, dvrr_stack+499339, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+499348, dvrr_stack+774580, dvrr_stack+499342, dvrr_stack+211957, dvrr_stack+4336, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+401953, dvrr_stack+2308, dvrr_stack+499348, dvrr_stack+15, dvrr_stack+774580, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+9344, dvrr_stack+0, dvrr_stack+401953, dvrr_stack+111, dvrr_stack+2308, NULL);

 /* compute (6 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+33274, dvrr_stack+774586, dvrr_stack+9344, dvrr_stack+211960, dvrr_stack+0, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+712936, dvrr_stack+1966, dvrr_stack+4591, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+0, dvrr_stack+22243, dvrr_stack+712936, dvrr_stack+704, dvrr_stack+1966, dvrr_stack+499339);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+704, dvrr_stack+698077, dvrr_stack+0, dvrr_stack+569, dvrr_stack+22243, dvrr_stack+499342);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+734, dvrr_stack+774607, dvrr_stack+704, dvrr_stack+211975, dvrr_stack+698077, dvrr_stack+499348);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+499339, dvrr_stack+133535, dvrr_stack+734, dvrr_stack+211993, dvrr_stack+774607, dvrr_stack+401953);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+6355, dvrr_stack+760657, dvrr_stack+499339, dvrr_stack+19395, dvrr_stack+133535, dvrr_stack+9344);

 /* compute (7 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+499402, dvrr_stack+774637, dvrr_stack+6355, dvrr_stack+67888, dvrr_stack+760657, dvrr_stack+33274);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+698077, dvrr_stack+1603, dvrr_stack+9313, NULL, NULL, dvrr_stack+4591);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+1033380, dvrr_stack+186196, dvrr_stack+698077, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+712936);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1603, dvrr_stack+578, dvrr_stack+1033380, dvrr_stack+96403, dvrr_stack+186196, dvrr_stack+0);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+613241, dvrr_stack+69179, dvrr_stack+1603, dvrr_stack+9365, dvrr_stack+578, dvrr_stack+704);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+0, dvrr_stack+797487, dvrr_stack+613241, dvrr_stack+186214, dvrr_stack+69179, dvrr_stack+734);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+4171, dvrr_stack+297398, dvrr_stack+0, dvrr_stack+614, dvrr_stack+797487, dvrr_stack+499339);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+69179, dvrr_stack+248344, dvrr_stack+4171, dvrr_stack+67951, dvrr_stack+297398, dvrr_stack+6355);

 /* compute (8 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+69395, dvrr_stack+242212, dvrr_stack+69179, dvrr_stack+9145, dvrr_stack+248344, dvrr_stack+499402);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+4564, dvrr_stack+9319, dvrr_stack+19285, NULL, NULL, dvrr_stack+9313);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+248344, dvrr_stack+774721, dvrr_stack+4564, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+698077);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+35457, dvrr_stack+774751, dvrr_stack+248344, dvrr_stack+96421, dvrr_stack+774721, dvrr_stack+1033380);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+4594, dvrr_stack+1975, dvrr_stack+35457, dvrr_stack+96451, dvrr_stack+774751, dvrr_stack+1603);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+1603, dvrr_stack+641636, dvrr_stack+4594, dvrr_stack+69079, dvrr_stack+1975, dvrr_stack+613241);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+4744, dvrr_stack+2075, dvrr_stack+1603, dvrr_stack+68077, dvrr_stack+641636, dvrr_stack+0);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+499339, dvrr_stack+774811, dvrr_stack+4744, dvrr_stack+47686, dvrr_stack+2075, dvrr_stack+4171);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+1813, dvrr_stack+631889, dvrr_stack+499339, dvrr_stack+582071, dvrr_stack+774811, dvrr_stack+69179);

 /* compute (9 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+9344, dvrr_stack+696322, dvrr_stack+1813, dvrr_stack+96511, dvrr_stack+631889, dvrr_stack+69395);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+133535, dvrr_stack+19295, dvrr_stack+32108, NULL, NULL, dvrr_stack+19285);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+613241, dvrr_stack+79675, dvrr_stack+133535, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+4564);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+641636, dvrr_stack+446988, dvrr_stack+613241, dvrr_stack+68227, dvrr_stack+79675, dvrr_stack+248344);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+63610, dvrr_stack+632249, dvrr_stack+641636, dvrr_stack+68272, dvrr_stack+446988, dvrr_stack+35457);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+631889, dvrr_stack+596381, dvrr_stack+63610, dvrr_stack+47449, dvrr_stack+632249, dvrr_stack+4594);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+696322, dvrr_stack+211382, dvrr_stack+631889, dvrr_stack+4339, dvrr_stack+596381, dvrr_stack+1603);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+786832, dvrr_stack+696322, dvrr_stack+582351, dvrr_stack+211382, dvrr_stack+4744);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+67888, dvrr_stack+25573, dvrr_stack+4171, dvrr_stack+582666, dvrr_stack+786832, dvrr_stack+499339);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+582071, dvrr_stack+31432, dvrr_stack+67888, dvrr_stack+97085, dvrr_stack+25573, dvrr_stack+1813);

 /* compute (10 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+96258, dvrr_stack+34632, dvrr_stack+582071, dvrr_stack+583086, dvrr_stack+31432, dvrr_stack+9344);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+31432, dvrr_stack+32123, dvrr_stack+47978, NULL, NULL, dvrr_stack+32108);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+31495, dvrr_stack+2318, dvrr_stack+31432, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+133535);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+31621, dvrr_stack+11452, dvrr_stack+31495, dvrr_stack+90115, dvrr_stack+2318, dvrr_stack+613241);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+211382, dvrr_stack+211697, dvrr_stack+31621, dvrr_stack+90178, dvrr_stack+11452, dvrr_stack+641636);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+25573, dvrr_stack+787900, dvrr_stack+211382, dvrr_stack+69675, dvrr_stack+211697, dvrr_stack+63610);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+1603, dvrr_stack+44467, dvrr_stack+25573, dvrr_stack+583761, dvrr_stack+787900, dvrr_stack+631889);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+582896, dvrr_stack+90793, dvrr_stack+1603, dvrr_stack+584076, dvrr_stack+44467, dvrr_stack+696322);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+34608, dvrr_stack+91381, dvrr_stack+582896, dvrr_stack+584517, dvrr_stack+90793, dvrr_stack+4171);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+583652, dvrr_stack+213319, dvrr_stack+34608, dvrr_stack+585105, dvrr_stack+91381, dvrr_stack+67888);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+93339, dvrr_stack+583652, dvrr_stack+585861, dvrr_stack+213319, dvrr_stack+582071);

 /* compute (11 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+584807, dvrr_stack+1012388, dvrr_stack+18607, dvrr_stack+586806, dvrr_stack+93339, dvrr_stack+96258);

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,21,dvrr_stack+90584, dvrr_stack+584807, dvrr_stack+586806);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+6355, dvrr_stack+47999, dvrr_stack+67658, NULL, NULL, dvrr_stack+47978);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+248344, dvrr_stack+2381, dvrr_stack+6355, dvrr_stack+32144, dvrr_stack+47999, dvrr_stack+31432);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+96258, dvrr_stack+129578, dvrr_stack+248344, dvrr_stack+892, dvrr_stack+2381, dvrr_stack+31495);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+786832, dvrr_stack+92137, dvrr_stack+96258, dvrr_stack+976, dvrr_stack+129578, dvrr_stack+31621);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+31432, dvrr_stack+92417, dvrr_stack+786832, dvrr_stack+90304, dvrr_stack+92137, dvrr_stack+211382);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+96538, dvrr_stack+8203, dvrr_stack+31432, dvrr_stack+66805, dvrr_stack+92417, dvrr_stack+25573);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+213319, dvrr_stack+5571, dvrr_stack+96538, dvrr_stack+587961, dvrr_stack+8203, dvrr_stack+1603);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+94494, dvrr_stack+213319, dvrr_stack+588549, dvrr_stack+5571, dvrr_stack+582896);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+582071, dvrr_stack+1013774, dvrr_stack+8203, dvrr_stack+589333, dvrr_stack+94494, dvrr_stack+34608);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+587961, dvrr_stack+1015034, dvrr_stack+582071, dvrr_stack+590341, dvrr_stack+1013774, dvrr_stack+583652);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+93197, dvrr_stack+1016574, dvrr_stack+587961, dvrr_stack+591601, dvrr_stack+1015034, dvrr_stack+18607);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+1013774, dvrr_stack+93197, dvrr_stack+591601);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+67686, dvrr_stack+1567, NULL, NULL, dvrr_stack+67658);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242212, dvrr_stack+787252, dvrr_stack+18607, dvrr_stack+48027, dvrr_stack+67686, dvrr_stack+6355);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18715, dvrr_stack+394407, dvrr_stack+242212, dvrr_stack+237780, dvrr_stack+787252, dvrr_stack+248344);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19075, dvrr_stack+92837, dvrr_stack+18715, dvrr_stack+237888, dvrr_stack+394407, dvrr_stack+96258);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1015622, dvrr_stack+51601, dvrr_stack+19075, dvrr_stack+238104, dvrr_stack+92837, dvrr_stack+786832);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+589809, dvrr_stack+95502, dvrr_stack+1015622, dvrr_stack+238464, dvrr_stack+51601, dvrr_stack+31432);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+237780, dvrr_stack+71505, dvrr_stack+589809, dvrr_stack+596606, dvrr_stack+95502, dvrr_stack+96538);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95381, dvrr_stack+1022580, dvrr_stack+237780, dvrr_stack+597362, dvrr_stack+71505, dvrr_stack+213319);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+596381, dvrr_stack+1023876, dvrr_stack+95381, dvrr_stack+598370, dvrr_stack+1022580, dvrr_stack+8203);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1178195, dvrr_stack+398638, dvrr_stack+596381, dvrr_stack+599666, dvrr_stack+1023876, dvrr_stack+582071);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+598361, dvrr_stack+1025496, dvrr_stack+1178195, dvrr_stack+601286, dvrr_stack+398638, dvrr_stack+587961);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+582071, dvrr_stack+598361, dvrr_stack+601286);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+587961, dvrr_stack+20176, dvrr_stack+68898, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+588096, dvrr_stack+49008, dvrr_stack+587961, dvrr_stack+67722, dvrr_stack+20176, dvrr_stack+18607);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+696322, dvrr_stack+49143, dvrr_stack+588096, dvrr_stack+242428, dvrr_stack+49008, dvrr_stack+242212);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+588366, dvrr_stack+117646, dvrr_stack+696322, dvrr_stack+242563, dvrr_stack+49143, dvrr_stack+18715);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+398638, dvrr_stack+400618, dvrr_stack+588366, dvrr_stack+242833, dvrr_stack+117646, dvrr_stack+19075);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+1035264, dvrr_stack+398638, dvrr_stack+243283, dvrr_stack+400618, dvrr_stack+1015622);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+242212, dvrr_stack+1036209, dvrr_stack+18607, dvrr_stack+618281, dvrr_stack+1035264, dvrr_stack+589809);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+589041, dvrr_stack+1037469, dvrr_stack+242212, dvrr_stack+619226, dvrr_stack+1036209, dvrr_stack+237780);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1022085, dvrr_stack+1039089, dvrr_stack+589041, dvrr_stack+620486, dvrr_stack+1037469, dvrr_stack+95381);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1035264, dvrr_stack+414253, dvrr_stack+1022085, dvrr_stack+622106, dvrr_stack+1039089, dvrr_stack+596381);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+618281, dvrr_stack+1041114, dvrr_stack+1035264, dvrr_stack+624131, dvrr_stack+414253, dvrr_stack+1178195);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+1178195, dvrr_stack+618281, dvrr_stack+624131);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1181165, dvrr_stack+264, dvrr_stack+147395, NULL, NULL, dvrr_stack+68898);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+760390, dvrr_stack+416728, dvrr_stack+1181165, dvrr_stack+20221, dvrr_stack+264, dvrr_stack+587961);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1181330, dvrr_stack+476013, dvrr_stack+760390, dvrr_stack+255316, dvrr_stack+416728, dvrr_stack+588096);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+414253, dvrr_stack+416893, dvrr_stack+1181330, dvrr_stack+255481, dvrr_stack+476013, dvrr_stack+696322);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+415078, dvrr_stack+417443, dvrr_stack+414253, dvrr_stack+255811, dvrr_stack+416893, dvrr_stack+588366);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+596381, dvrr_stack+1053588, dvrr_stack+415078, dvrr_stack+256361, dvrr_stack+417443, dvrr_stack+398638);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+398638, dvrr_stack+1054743, dvrr_stack+596381, dvrr_stack+646406, dvrr_stack+1053588, dvrr_stack+18607);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+416233, dvrr_stack+1056283, dvrr_stack+398638, dvrr_stack+647561, dvrr_stack+1054743, dvrr_stack+242212);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1181880, dvrr_stack+434953, dvrr_stack+416233, dvrr_stack+649101, dvrr_stack+1056283, dvrr_stack+589041);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1053588, dvrr_stack+1058263, dvrr_stack+1181880, dvrr_stack+651081, dvrr_stack+434953, dvrr_stack+1022085);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+646406, dvrr_stack+1061288, dvrr_stack+1053588, dvrr_stack+653556, dvrr_stack+1058263, dvrr_stack+1035264);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+1035264, dvrr_stack+646406, dvrr_stack+653556);

 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1038894, dvrr_stack+164812, dvrr_stack+67822, NULL, NULL, dvrr_stack+147395);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1039092, dvrr_stack+440398, dvrr_stack+1038894, dvrr_stack+32263, dvrr_stack+164812, dvrr_stack+1181165);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+468258, dvrr_stack+440596, dvrr_stack+1039092, dvrr_stack+272101, dvrr_stack+440398, dvrr_stack+760390);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1038894, dvrr_stack+401293, dvrr_stack+468258, dvrr_stack+272299, dvrr_stack+440596, dvrr_stack+1181330);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1022085, dvrr_stack+1073828, dvrr_stack+1038894, dvrr_stack+272695, dvrr_stack+401293, dvrr_stack+414253);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1038894, dvrr_stack+1074818, dvrr_stack+1022085, dvrr_stack+273355, dvrr_stack+1073828, dvrr_stack+415078);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1022085, dvrr_stack+1076204, dvrr_stack+1038894, dvrr_stack+20857, dvrr_stack+1074818, dvrr_stack+596381);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1057218, dvrr_stack+1078052, dvrr_stack+1022085, dvrr_stack+681826, dvrr_stack+1076204, dvrr_stack+398638);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+587961, dvrr_stack+461658, dvrr_stack+1057218, dvrr_stack+683674, dvrr_stack+1078052, dvrr_stack+416233);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+414253, dvrr_stack+1080428, dvrr_stack+587961, dvrr_stack+686050, dvrr_stack+461658, dvrr_stack+1181880);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+681826, dvrr_stack+1084058, dvrr_stack+414253, dvrr_stack+293300, dvrr_stack+1080428, dvrr_stack+1053588);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+1053588, dvrr_stack+681826, dvrr_stack+293300);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+1057944, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1058259, dvrr_stack+48252, dvrr_stack+3730);
 tmp = dvrr_stack + 1058259;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+1058847, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1059267, dvrr_stack+239152, dvrr_stack+6859);
 tmp = dvrr_stack + 1059267;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+1060051, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+117646, dvrr_stack+244192, dvrr_stack+12118);
 tmp = dvrr_stack + 117646;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+1060591, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+414253, dvrr_stack+257521, dvrr_stack+22927);
 tmp = dvrr_stack + 414253;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+415513, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+416338, dvrr_stack+274796, dvrr_stack+36382);
 tmp = dvrr_stack + 416338;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+461658, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+462648, dvrr_stack+297524, dvrr_stack+53314);
 tmp = dvrr_stack + 462648;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+44467, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 44467;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+417878, dvrr_stack+392076, dvrr_stack+117058);
 tmp = dvrr_stack + 417878;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+587961, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 587961;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+71505, dvrr_stack+394813, dvrr_stack+118654);
 tmp = dvrr_stack + 71505;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+588549, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 588549;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+589305, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 589305;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+590601, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 590601;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+398638, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 398638;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+400258, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 400258;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+596381, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 596381;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+686974, dvrr_stack+164878, dvrr_stack+52324);
 tmp = dvrr_stack + 686974;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+1022085, dvrr_stack+161842, dvrr_stack+164878);
 tmp = dvrr_stack + 1022085;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1024461, dvrr_stack+586806, dvrr_stack+48252);
 tmp = dvrr_stack + 1024461;
 target_ptr = Libderiv->deriv_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+20857, dvrr_stack+591601, dvrr_stack+239152);
 tmp = dvrr_stack + 20857;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1038894, dvrr_stack+601286, dvrr_stack+244192);
 tmp = dvrr_stack + 1038894;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+272101, dvrr_stack+624131, dvrr_stack+257521);
 tmp = dvrr_stack + 272101;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+434953, dvrr_stack+653556, dvrr_stack+274796);
 tmp = dvrr_stack + 434953;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+1181165, dvrr_stack+293300, dvrr_stack+297524);
 tmp = dvrr_stack + 1181165;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+242212, dvrr_stack+1012388, dvrr_stack+392076);
 tmp = dvrr_stack + 242212;
 target_ptr = Libderiv->deriv_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+18607, dvrr_stack+1016574, dvrr_stack+394813);
 tmp = dvrr_stack + 18607;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+650696, dvrr_stack+1025496, dvrr_stack+121202);
 tmp = dvrr_stack + 650696;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+0, dvrr_stack+1041114, dvrr_stack+131510);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1073444, dvrr_stack+1061288, dvrr_stack+144920);
 tmp = dvrr_stack + 1073444;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+1076469, dvrr_stack+1084058, dvrr_stack+161842);
 tmp = dvrr_stack + 1076469;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,21,dvrr_stack+255316, dvrr_stack+584807, dvrr_stack+586806);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+95381, dvrr_stack+93197, dvrr_stack+591601);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+1080099, dvrr_stack+598361, dvrr_stack+601286);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+66670, dvrr_stack+618281, dvrr_stack+624131);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+1184135, dvrr_stack+646406, dvrr_stack+653556);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+1187765, dvrr_stack+681826, dvrr_stack+293300);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+401413, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+688360, dvrr_stack+48252, dvrr_stack+3730);
 tmp = dvrr_stack + 688360;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+3730, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+4150, dvrr_stack+239152, dvrr_stack+6859);
 tmp = dvrr_stack + 4150;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+6859, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+4934, dvrr_stack+244192, dvrr_stack+12118);
 tmp = dvrr_stack + 4934;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+12118, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+237780, dvrr_stack+257521, dvrr_stack+22927);
 tmp = dvrr_stack + 237780;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+243367, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+621791, dvrr_stack+274796, dvrr_stack+36382);
 tmp = dvrr_stack + 621791;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+36382, dvrr_stack+53314, dvrr_stack+49618);

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+8203, dvrr_stack+297524, dvrr_stack+53314);
 tmp = dvrr_stack + 8203;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+53314, dvrr_stack+117058, dvrr_stack+3415);
 tmp = dvrr_stack + 53314;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+53755, dvrr_stack+392076, dvrr_stack+117058);
 tmp = dvrr_stack + 53755;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+117058, dvrr_stack+118654, dvrr_stack+6439);
 tmp = dvrr_stack + 117058;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+49008, dvrr_stack+394813, dvrr_stack+118654);
 tmp = dvrr_stack + 49008;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+118654, dvrr_stack+122858, dvrr_stack+11578);
 tmp = dvrr_stack + 118654;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+1082475, dvrr_stack+121202, dvrr_stack+122858);
 tmp = dvrr_stack + 1082475;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+22927, dvrr_stack+133580, dvrr_stack+22252);
 tmp = dvrr_stack + 22927;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+1192121, dvrr_stack+131510, dvrr_stack+133580);
 tmp = dvrr_stack + 1192121;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+213319, dvrr_stack+147450, dvrr_stack+35557);
 tmp = dvrr_stack + 213319;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1193741, dvrr_stack+144920, dvrr_stack+147450);
 tmp = dvrr_stack + 1193741;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+147395, dvrr_stack+164878, dvrr_stack+52324);
 tmp = dvrr_stack + 147395;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1195721, dvrr_stack+161842, dvrr_stack+164878);
 tmp = dvrr_stack + 1195721;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+164812, dvrr_stack+586806, dvrr_stack+48252);
 tmp = dvrr_stack + 164812;
 target_ptr = Libderiv->deriv_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+51601, dvrr_stack+591601, dvrr_stack+239152);
 tmp = dvrr_stack + 51601;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+34608, dvrr_stack+601286, dvrr_stack+244192);
 tmp = dvrr_stack + 34608;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1198097, dvrr_stack+624131, dvrr_stack+257521);
 tmp = dvrr_stack + 1198097;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1200122, dvrr_stack+653556, dvrr_stack+274796);
 tmp = dvrr_stack + 1200122;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1202597, dvrr_stack+293300, dvrr_stack+297524);
 tmp = dvrr_stack + 1202597;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+244192, dvrr_stack+1012388, dvrr_stack+392076);
 tmp = dvrr_stack + 244192;
 target_ptr = Libderiv->deriv_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+274126, dvrr_stack+1016574, dvrr_stack+394813);
 tmp = dvrr_stack + 274126;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+256702, dvrr_stack+1025496, dvrr_stack+121202);
 tmp = dvrr_stack + 256702;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+121202, dvrr_stack+1041114, dvrr_stack+131510);
 tmp = dvrr_stack + 121202;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+131510, dvrr_stack+1061288, dvrr_stack+144920);
 tmp = dvrr_stack + 131510;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1061266, dvrr_stack+1084058, dvrr_stack+161842);
 tmp = dvrr_stack + 1061266;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,21,dvrr_stack+161842, dvrr_stack+584807, dvrr_stack+586806);

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+144920, dvrr_stack+93197, dvrr_stack+591601);

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+1025406, dvrr_stack+598361, dvrr_stack+601286);

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+296930, dvrr_stack+618281, dvrr_stack+624131);

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+598361, dvrr_stack+646406, dvrr_stack+653556);

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+1083771, dvrr_stack+681826, dvrr_stack+293300);

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+293300, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 293300;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+293741, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 293741;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+294329, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 294329;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+392076, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 392076;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+295085, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 295085;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+681826, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 681826;
 target_ptr = Libderiv->deriv2_classes[5][10][143];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+296240, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 296240;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+683212, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 683212;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+683996, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 683996;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+685004, dvrr_stack+178906, NULL);
 tmp = dvrr_stack + 685004;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+646406, dvrr_stack+203242, NULL);
 tmp = dvrr_stack + 646406;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+647946, dvrr_stack+232236, NULL);
 tmp = dvrr_stack + 647946;
 target_ptr = Libderiv->deriv2_classes[6][10][143];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+649794, dvrr_stack+253048, NULL);
 tmp = dvrr_stack + 649794;
 target_ptr = Libderiv->deriv2_classes[7][5][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+618281, dvrr_stack+269077, NULL);
 tmp = dvrr_stack + 618281;
 target_ptr = Libderiv->deriv2_classes[7][6][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+619289, dvrr_stack+289412, NULL);
 tmp = dvrr_stack + 619289;
 target_ptr = Libderiv->deriv2_classes[7][7][143];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+1040514, dvrr_stack+315560, NULL);
 tmp = dvrr_stack + 1040514;
 target_ptr = Libderiv->deriv2_classes[7][8][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+652676, dvrr_stack+347228, NULL);
 tmp = dvrr_stack + 652676;
 target_ptr = Libderiv->deriv2_classes[7][9][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+623331, dvrr_stack+384948, NULL);
 tmp = dvrr_stack + 623331;
 target_ptr = Libderiv->deriv2_classes[7][10][143];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+620585, dvrr_stack+411418, NULL);
 tmp = dvrr_stack + 620585;
 target_ptr = Libderiv->deriv2_classes[8][5][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+601991, dvrr_stack+431173, NULL);
 tmp = dvrr_stack + 601991;
 target_ptr = Libderiv->deriv2_classes[8][6][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+1042134, dvrr_stack+456798, NULL);
 tmp = dvrr_stack + 1042134;
 target_ptr = Libderiv->deriv2_classes[8][7][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+1015622, dvrr_stack+488493, NULL);
 tmp = dvrr_stack + 1015622;
 target_ptr = Libderiv->deriv2_classes[8][8][143];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+584447, dvrr_stack+527376, NULL);
 tmp = dvrr_stack + 584447;
 target_ptr = Libderiv->deriv2_classes[8][9][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+91970, dvrr_stack+573161, NULL);
 tmp = dvrr_stack + 91970;
 target_ptr = Libderiv->deriv2_classes[8][10][143];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+163228, dvrr_stack+614816, NULL);
 tmp = dvrr_stack + 163228;
 target_ptr = Libderiv->deriv2_classes[9][5][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+591546, dvrr_stack+641786, NULL);
 tmp = dvrr_stack + 591546;
 target_ptr = Libderiv->deriv2_classes[9][6][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+1205567, dvrr_stack+675886, NULL);
 tmp = dvrr_stack + 1205567;
 target_ptr = Libderiv->deriv2_classes[9][7][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+1207547, dvrr_stack+712945, NULL);
 tmp = dvrr_stack + 1207547;
 target_ptr = Libderiv->deriv2_classes[9][8][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+1210022, dvrr_stack+760720, NULL);
 tmp = dvrr_stack + 1210022;
 target_ptr = Libderiv->deriv2_classes[9][9][143];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+1213047, dvrr_stack+809450, NULL);
 tmp = dvrr_stack + 1213047;
 target_ptr = Libderiv->deriv2_classes[9][10][143];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+94940, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 94940;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+686264, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 686264;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+5942, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 5942;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+275666, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 275666;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+654656, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 654656;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1386,dvrr_stack+394407, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 394407;
 target_ptr = Libderiv->deriv2_classes[5][10][131];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+146768, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 146768;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+22117, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 22117;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+239040, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 239040;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1012349, dvrr_stack+178906, NULL);
 tmp = dvrr_stack + 1012349;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+47176, dvrr_stack+203242, NULL);
 tmp = dvrr_stack + 47176;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1216677, dvrr_stack+232236, NULL);
 tmp = dvrr_stack + 1216677;
 target_ptr = Libderiv->deriv2_classes[6][10][131];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+165757, dvrr_stack+253048, NULL);
 tmp = dvrr_stack + 165757;
 target_ptr = Libderiv->deriv2_classes[7][5][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+586922, dvrr_stack+269077, NULL);
 tmp = dvrr_stack + 586922;
 target_ptr = Libderiv->deriv2_classes[7][6][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1296,dvrr_stack+1218525, dvrr_stack+289412, NULL);
 tmp = dvrr_stack + 1218525;
 target_ptr = Libderiv->deriv2_classes[7][7][131];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1219821, dvrr_stack+315560, NULL);
 tmp = dvrr_stack + 1219821;
 target_ptr = Libderiv->deriv2_classes[7][8][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1221441, dvrr_stack+347228, NULL);
 tmp = dvrr_stack + 1221441;
 target_ptr = Libderiv->deriv2_classes[7][9][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1223421, dvrr_stack+384948, NULL);
 tmp = dvrr_stack + 1223421;
 target_ptr = Libderiv->deriv2_classes[7][10][131];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+2475, dvrr_stack+411418, NULL);
 tmp = dvrr_stack + 2475;
 target_ptr = Libderiv->deriv2_classes[8][5][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1225797, dvrr_stack+431173, NULL);
 tmp = dvrr_stack + 1225797;
 target_ptr = Libderiv->deriv2_classes[8][6][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1227057, dvrr_stack+456798, NULL);
 tmp = dvrr_stack + 1227057;
 target_ptr = Libderiv->deriv2_classes[8][7][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2025,dvrr_stack+1228677, dvrr_stack+488493, NULL);
 tmp = dvrr_stack + 1228677;
 target_ptr = Libderiv->deriv2_classes[8][8][131];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1230702, dvrr_stack+527376, NULL);
 tmp = dvrr_stack + 1230702;
 target_ptr = Libderiv->deriv2_classes[8][9][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1233177, dvrr_stack+573161, NULL);
 tmp = dvrr_stack + 1233177;
 target_ptr = Libderiv->deriv2_classes[8][10][131];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1236147, dvrr_stack+614816, NULL);
 tmp = dvrr_stack + 1236147;
 target_ptr = Libderiv->deriv2_classes[9][5][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1237302, dvrr_stack+641786, NULL);
 tmp = dvrr_stack + 1237302;
 target_ptr = Libderiv->deriv2_classes[9][6][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1238842, dvrr_stack+675886, NULL);
 tmp = dvrr_stack + 1238842;
 target_ptr = Libderiv->deriv2_classes[9][7][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1240822, dvrr_stack+712945, NULL);
 tmp = dvrr_stack + 1240822;
 target_ptr = Libderiv->deriv2_classes[9][8][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3025,dvrr_stack+1243297, dvrr_stack+760720, NULL);
 tmp = dvrr_stack + 1243297;
 target_ptr = Libderiv->deriv2_classes[9][9][131];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1246322, dvrr_stack+809450, NULL);
 tmp = dvrr_stack + 1246322;
 target_ptr = Libderiv->deriv2_classes[9][10][131];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+468258, dvrr_stack+534801, NULL);
 tmp = dvrr_stack + 468258;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+440398, dvrr_stack+536124, NULL);
 tmp = dvrr_stack + 440398;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+655811, dvrr_stack+537888, NULL);
 tmp = dvrr_stack + 655811;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+1249952, dvrr_stack+540156, NULL);
 tmp = dvrr_stack + 1249952;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1250897, dvrr_stack+353168, NULL);
 tmp = dvrr_stack + 1250897;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+1252052, dvrr_stack+820340, NULL);
 tmp = dvrr_stack + 1252052;
 target_ptr = Libderiv->deriv2_classes[5][10][130];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+20147, dvrr_stack+542991, NULL);
 tmp = dvrr_stack + 20147;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+625707, dvrr_stack+356633, NULL);
 tmp = dvrr_stack + 625707;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+1253438, dvrr_stack+824498, NULL);
 tmp = dvrr_stack + 1253438;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1254446, dvrr_stack+827522, NULL);
 tmp = dvrr_stack + 1254446;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1255706, dvrr_stack+831302, NULL);
 tmp = dvrr_stack + 1255706;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+1257246, dvrr_stack+835922, NULL);
 tmp = dvrr_stack + 1257246;
 target_ptr = Libderiv->deriv2_classes[6][10][130];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+1259094, dvrr_stack+841466, NULL);
 tmp = dvrr_stack + 1259094;
 target_ptr = Libderiv->deriv2_classes[7][5][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+1259850, dvrr_stack+843734, NULL);
 tmp = dvrr_stack + 1259850;
 target_ptr = Libderiv->deriv2_classes[7][6][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+1260858, dvrr_stack+846758, NULL);
 tmp = dvrr_stack + 1260858;
 target_ptr = Libderiv->deriv2_classes[7][7][130];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1262154, dvrr_stack+850646, NULL);
 tmp = dvrr_stack + 1262154;
 target_ptr = Libderiv->deriv2_classes[7][8][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1263774, dvrr_stack+855506, NULL);
 tmp = dvrr_stack + 1263774;
 target_ptr = Libderiv->deriv2_classes[7][9][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+1265754, dvrr_stack+861446, NULL);
 tmp = dvrr_stack + 1265754;
 target_ptr = Libderiv->deriv2_classes[7][10][130];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+1268130, dvrr_stack+868574, NULL);
 tmp = dvrr_stack + 1268130;
 target_ptr = Libderiv->deriv2_classes[8][5][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1269075, dvrr_stack+871409, NULL);
 tmp = dvrr_stack + 1269075;
 target_ptr = Libderiv->deriv2_classes[8][6][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1270335, dvrr_stack+875189, NULL);
 tmp = dvrr_stack + 1270335;
 target_ptr = Libderiv->deriv2_classes[8][7][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+1271955, dvrr_stack+880049, NULL);
 tmp = dvrr_stack + 1271955;
 target_ptr = Libderiv->deriv2_classes[8][8][130];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1273980, dvrr_stack+886124, NULL);
 tmp = dvrr_stack + 1273980;
 target_ptr = Libderiv->deriv2_classes[8][9][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+1276455, dvrr_stack+893549, NULL);
 tmp = dvrr_stack + 1276455;
 target_ptr = Libderiv->deriv2_classes[8][10][130];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+1279425, dvrr_stack+902459, NULL);
 tmp = dvrr_stack + 1279425;
 target_ptr = Libderiv->deriv2_classes[9][5][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+1280580, dvrr_stack+905924, NULL);
 tmp = dvrr_stack + 1280580;
 target_ptr = Libderiv->deriv2_classes[9][6][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+1282120, dvrr_stack+910544, NULL);
 tmp = dvrr_stack + 1282120;
 target_ptr = Libderiv->deriv2_classes[9][7][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+1284100, dvrr_stack+916484, NULL);
 tmp = dvrr_stack + 1284100;
 target_ptr = Libderiv->deriv2_classes[9][8][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+1286575, dvrr_stack+923909, NULL);
 tmp = dvrr_stack + 1286575;
 target_ptr = Libderiv->deriv2_classes[9][9][130];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+1289600, dvrr_stack+932984, NULL);
 tmp = dvrr_stack + 1289600;
 target_ptr = Libderiv->deriv2_classes[9][10][130];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+1293230, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 1293230;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+1017647, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 1017647;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+29192, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 29192;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+44908, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 44908;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+45853, dvrr_stack+86650, NULL);
 tmp = dvrr_stack + 45853;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1386,dvrr_stack+63610, dvrr_stack+112900, NULL);
 tmp = dvrr_stack + 63610;
 target_ptr = Libderiv->deriv2_classes[5][10][119];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+211382, dvrr_stack+129746, NULL);
 tmp = dvrr_stack + 211382;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+129578, dvrr_stack+142568, NULL);
 tmp = dvrr_stack + 129578;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+130362, dvrr_stack+158818, NULL);
 tmp = dvrr_stack + 130362;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+158818, dvrr_stack+178906, NULL);
 tmp = dvrr_stack + 158818;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+160078, dvrr_stack+203242, NULL);
 tmp = dvrr_stack + 160078;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1848,dvrr_stack+29948, dvrr_stack+232236, NULL);
 tmp = dvrr_stack + 29948;
 target_ptr = Libderiv->deriv2_classes[6][10][119];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+64996, dvrr_stack+253048, NULL);
 tmp = dvrr_stack + 64996;
 target_ptr = Libderiv->deriv2_classes[7][5][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+252796, dvrr_stack+269077, NULL);
 tmp = dvrr_stack + 252796;
 target_ptr = Libderiv->deriv2_classes[7][6][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1296,dvrr_stack+268897, dvrr_stack+289412, NULL);
 tmp = dvrr_stack + 268897;
 target_ptr = Libderiv->deriv2_classes[7][7][119];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+289412, dvrr_stack+315560, NULL);
 tmp = dvrr_stack + 289412;
 target_ptr = Libderiv->deriv2_classes[7][8][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+315560, dvrr_stack+347228, NULL);
 tmp = dvrr_stack + 315560;
 target_ptr = Libderiv->deriv2_classes[7][9][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2376,dvrr_stack+317540, dvrr_stack+384948, NULL);
 tmp = dvrr_stack + 317540;
 target_ptr = Libderiv->deriv2_classes[7][10][119];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+291032, dvrr_stack+411418, NULL);
 tmp = dvrr_stack + 291032;
 target_ptr = Libderiv->deriv2_classes[8][5][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+291977, dvrr_stack+431173, NULL);
 tmp = dvrr_stack + 291977;
 target_ptr = Libderiv->deriv2_classes[8][6][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+431014, dvrr_stack+456798, NULL);
 tmp = dvrr_stack + 431014;
 target_ptr = Libderiv->deriv2_classes[8][7][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2025,dvrr_stack+456766, dvrr_stack+488493, NULL);
 tmp = dvrr_stack + 456766;
 target_ptr = Libderiv->deriv2_classes[8][8][119];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+488484, dvrr_stack+527376, NULL);
 tmp = dvrr_stack + 488484;
 target_ptr = Libderiv->deriv2_classes[8][9][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2970,dvrr_stack+527376, dvrr_stack+573161, NULL);
 tmp = dvrr_stack + 527376;
 target_ptr = Libderiv->deriv2_classes[8][10][119];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+530346, dvrr_stack+614816, NULL);
 tmp = dvrr_stack + 530346;
 target_ptr = Libderiv->deriv2_classes[9][5][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+531501, dvrr_stack+641786, NULL);
 tmp = dvrr_stack + 531501;
 target_ptr = Libderiv->deriv2_classes[9][6][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+641636, dvrr_stack+675886, NULL);
 tmp = dvrr_stack + 641636;
 target_ptr = Libderiv->deriv2_classes[9][7][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+643616, dvrr_stack+712945, NULL);
 tmp = dvrr_stack + 643616;
 target_ptr = Libderiv->deriv2_classes[9][8][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3025,dvrr_stack+712936, dvrr_stack+760720, NULL);
 tmp = dvrr_stack + 712936;
 target_ptr = Libderiv->deriv2_classes[9][9][119];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,3630,dvrr_stack+760390, dvrr_stack+809450, NULL);
 tmp = dvrr_stack + 760390;
 target_ptr = Libderiv->deriv2_classes[9][10][119];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+533041, dvrr_stack+534801, NULL);
 tmp = dvrr_stack + 533041;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+533482, dvrr_stack+536124, NULL);
 tmp = dvrr_stack + 533482;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+534070, dvrr_stack+537888, NULL);
 tmp = dvrr_stack + 534070;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+534826, dvrr_stack+540156, NULL);
 tmp = dvrr_stack + 534826;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+535771, dvrr_stack+353168, NULL);
 tmp = dvrr_stack + 535771;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+536926, dvrr_stack+820340, NULL);
 tmp = dvrr_stack + 536926;
 target_ptr = Libderiv->deriv2_classes[5][10][118];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+538312, dvrr_stack+542991, NULL);
 tmp = dvrr_stack + 538312;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+538900, dvrr_stack+356633, NULL);
 tmp = dvrr_stack + 538900;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+539684, dvrr_stack+824498, NULL);
 tmp = dvrr_stack + 539684;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+540692, dvrr_stack+827522, NULL);
 tmp = dvrr_stack + 540692;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+541952, dvrr_stack+831302, NULL);
 tmp = dvrr_stack + 541952;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+764020, dvrr_stack+835922, NULL);
 tmp = dvrr_stack + 764020;
 target_ptr = Libderiv->deriv2_classes[6][10][118];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+543492, dvrr_stack+841466, NULL);
 tmp = dvrr_stack + 543492;
 target_ptr = Libderiv->deriv2_classes[7][5][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+765868, dvrr_stack+843734, NULL);
 tmp = dvrr_stack + 765868;
 target_ptr = Libderiv->deriv2_classes[7][6][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+766876, dvrr_stack+846758, NULL);
 tmp = dvrr_stack + 766876;
 target_ptr = Libderiv->deriv2_classes[7][7][118];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+768172, dvrr_stack+850646, NULL);
 tmp = dvrr_stack + 768172;
 target_ptr = Libderiv->deriv2_classes[7][8][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+715961, dvrr_stack+855506, NULL);
 tmp = dvrr_stack + 715961;
 target_ptr = Libderiv->deriv2_classes[7][9][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+717941, dvrr_stack+861446, NULL);
 tmp = dvrr_stack + 717941;
 target_ptr = Libderiv->deriv2_classes[7][10][118];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+809325, dvrr_stack+868574, NULL);
 tmp = dvrr_stack + 809325;
 target_ptr = Libderiv->deriv2_classes[8][5][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+810270, dvrr_stack+871409, NULL);
 tmp = dvrr_stack + 810270;
 target_ptr = Libderiv->deriv2_classes[8][6][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+811530, dvrr_stack+875189, NULL);
 tmp = dvrr_stack + 811530;
 target_ptr = Libderiv->deriv2_classes[8][7][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+813150, dvrr_stack+880049, NULL);
 tmp = dvrr_stack + 813150;
 target_ptr = Libderiv->deriv2_classes[8][8][118];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+815175, dvrr_stack+886124, NULL);
 tmp = dvrr_stack + 815175;
 target_ptr = Libderiv->deriv2_classes[8][9][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+817650, dvrr_stack+893549, NULL);
 tmp = dvrr_stack + 817650;
 target_ptr = Libderiv->deriv2_classes[8][10][118];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+820620, dvrr_stack+902459, NULL);
 tmp = dvrr_stack + 820620;
 target_ptr = Libderiv->deriv2_classes[9][5][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+821775, dvrr_stack+905924, NULL);
 tmp = dvrr_stack + 821775;
 target_ptr = Libderiv->deriv2_classes[9][6][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+823315, dvrr_stack+910544, NULL);
 tmp = dvrr_stack + 823315;
 target_ptr = Libderiv->deriv2_classes[9][7][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+825295, dvrr_stack+916484, NULL);
 tmp = dvrr_stack + 825295;
 target_ptr = Libderiv->deriv2_classes[9][8][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+827770, dvrr_stack+923909, NULL);
 tmp = dvrr_stack + 827770;
 target_ptr = Libderiv->deriv2_classes[9][9][118];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+830795, dvrr_stack+932984, NULL);
 tmp = dvrr_stack + 830795;
 target_ptr = Libderiv->deriv2_classes[9][10][118];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+544248, dvrr_stack+50278, NULL);
 tmp = dvrr_stack + 544248;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+50016, dvrr_stack+14638, NULL);
 tmp = dvrr_stack + 50016;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+50604, dvrr_stack+26140, NULL);
 tmp = dvrr_stack + 50604;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+25573, dvrr_stack+40372, NULL);
 tmp = dvrr_stack + 25573;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+26518, dvrr_stack+58165, NULL);
 tmp = dvrr_stack + 26518;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+57626, dvrr_stack+79720, NULL);
 tmp = dvrr_stack + 57626;
 target_ptr = Libderiv->deriv2_classes[5][10][117];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+27673, dvrr_stack+104584, NULL);
 tmp = dvrr_stack + 27673;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+65752, dvrr_stack+126218, NULL);
 tmp = dvrr_stack + 65752;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+79675, dvrr_stack+137864, NULL);
 tmp = dvrr_stack + 79675;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+80683, dvrr_stack+152770, NULL);
 tmp = dvrr_stack + 80683;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+81943, dvrr_stack+171346, NULL);
 tmp = dvrr_stack + 81943;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+171019, dvrr_stack+194002, NULL);
 tmp = dvrr_stack + 171019;
 target_ptr = Libderiv->deriv2_classes[6][10][117];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+193771, dvrr_stack+156550, NULL);
 tmp = dvrr_stack + 193771;
 target_ptr = Libderiv->deriv2_classes[7][5][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+194527, dvrr_stack+248512, NULL);
 tmp = dvrr_stack + 194527;
 target_ptr = Libderiv->deriv2_classes[7][6][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+248344, dvrr_stack+263029, NULL);
 tmp = dvrr_stack + 248344;
 target_ptr = Libderiv->deriv2_classes[7][7][117];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+249640, dvrr_stack+281636, NULL);
 tmp = dvrr_stack + 249640;
 target_ptr = Libderiv->deriv2_classes[7][8][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+281612, dvrr_stack+305840, NULL);
 tmp = dvrr_stack + 281612;
 target_ptr = Libderiv->deriv2_classes[7][9][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+305840, dvrr_stack+335348, NULL);
 tmp = dvrr_stack + 305840;
 target_ptr = Libderiv->deriv2_classes[7][10][117];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+308216, dvrr_stack+370692, NULL);
 tmp = dvrr_stack + 308216;
 target_ptr = Libderiv->deriv2_classes[8][5][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+309161, dvrr_stack+311780, NULL);
 tmp = dvrr_stack + 309161;
 target_ptr = Libderiv->deriv2_classes[8][6][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+310421, dvrr_stack+423613, NULL);
 tmp = dvrr_stack + 310421;
 target_ptr = Libderiv->deriv2_classes[8][7][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+312041, dvrr_stack+447078, NULL);
 tmp = dvrr_stack + 312041;
 target_ptr = Libderiv->deriv2_classes[8][8][117];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+446988, dvrr_stack+476343, NULL);
 tmp = dvrr_stack + 446988;
 target_ptr = Libderiv->deriv2_classes[8][9][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+476013, dvrr_stack+512526, NULL);
 tmp = dvrr_stack + 476013;
 target_ptr = Libderiv->deriv2_classes[8][10][117];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+314066, dvrr_stack+555341, NULL);
 tmp = dvrr_stack + 314066;
 target_ptr = Libderiv->deriv2_classes[9][5][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+478983, dvrr_stack+607886, NULL);
 tmp = dvrr_stack + 478983;
 target_ptr = Libderiv->deriv2_classes[9][6][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+480523, dvrr_stack+521436, NULL);
 tmp = dvrr_stack + 480523;
 target_ptr = Libderiv->deriv2_classes[9][7][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+449463, dvrr_stack+664006, NULL);
 tmp = dvrr_stack + 449463;
 target_ptr = Libderiv->deriv2_classes[9][8][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+663962, dvrr_stack+698095, NULL);
 tmp = dvrr_stack + 663962;
 target_ptr = Libderiv->deriv2_classes[9][9][117];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+698077, dvrr_stack+742570, NULL);
 tmp = dvrr_stack + 698077;
 target_ptr = Libderiv->deriv2_classes[9][10][117];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+319916, dvrr_stack+790038, dvrr_stack+789723);
 tmp = dvrr_stack + 319916;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+482503, dvrr_stack+791067, dvrr_stack+790626);
 tmp = dvrr_stack + 482503;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+451938, dvrr_stack+791823, dvrr_stack+790038);
 tmp = dvrr_stack + 451938;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+701707, dvrr_stack+792768, dvrr_stack+791067);
 tmp = dvrr_stack + 701707;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+702652, dvrr_stack+793923, dvrr_stack+791823);
 tmp = dvrr_stack + 702652;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+703807, dvrr_stack+795309, dvrr_stack+792768);
 tmp = dvrr_stack + 703807;
 target_ptr = Libderiv->deriv2_classes[5][10][107];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+483091, dvrr_stack+797997, dvrr_stack+797577);
 tmp = dvrr_stack + 483091;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+705193, dvrr_stack+799369, dvrr_stack+798781);
 tmp = dvrr_stack + 705193;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+705977, dvrr_stack+800377, dvrr_stack+797997);
 tmp = dvrr_stack + 705977;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+742550, dvrr_stack+801637, dvrr_stack+799369);
 tmp = dvrr_stack + 742550;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+743810, dvrr_stack+803177, dvrr_stack+800377);
 tmp = dvrr_stack + 743810;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+745350, dvrr_stack+805025, dvrr_stack+801637);
 tmp = dvrr_stack + 745350;
 target_ptr = Libderiv->deriv2_classes[6][10][107];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+747198, dvrr_stack+755080, dvrr_stack+808029);
 tmp = dvrr_stack + 747198;
 target_ptr = Libderiv->deriv2_classes[7][5][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+747954, dvrr_stack+756088, dvrr_stack+808569);
 tmp = dvrr_stack + 747954;
 target_ptr = Libderiv->deriv2_classes[7][6][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+748962, dvrr_stack+757384, dvrr_stack+755080);
 tmp = dvrr_stack + 748962;
 target_ptr = Libderiv->deriv2_classes[7][7][107];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+750258, dvrr_stack+707170, dvrr_stack+756088);
 tmp = dvrr_stack + 750258;
 target_ptr = Libderiv->deriv2_classes[7][8][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+666987, dvrr_stack+709150, dvrr_stack+757384);
 tmp = dvrr_stack + 666987;
 target_ptr = Libderiv->deriv2_classes[7][9][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+668967, dvrr_stack+671431, dvrr_stack+707170);
 tmp = dvrr_stack + 668967;
 target_ptr = Libderiv->deriv2_classes[7][10][107];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+751878, dvrr_stack+674239, dvrr_stack+711526);
 tmp = dvrr_stack + 751878;
 target_ptr = Libderiv->deriv2_classes[8][5][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+607811, dvrr_stack+635516, dvrr_stack+634571);
 tmp = dvrr_stack + 607811;
 target_ptr = Libderiv->deriv2_classes[8][6][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+609071, dvrr_stack+637136, dvrr_stack+674239);
 tmp = dvrr_stack + 609071;
 target_ptr = Libderiv->deriv2_classes[8][7][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+512451, dvrr_stack+639161, dvrr_stack+635516);
 tmp = dvrr_stack + 512451;
 target_ptr = Libderiv->deriv2_classes[8][8][107];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+514476, dvrr_stack+558806, dvrr_stack+637136);
 tmp = dvrr_stack + 514476;
 target_ptr = Libderiv->deriv2_classes[8][9][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+516951, dvrr_stack+561776, dvrr_stack+639161);
 tmp = dvrr_stack + 516951;
 target_ptr = Libderiv->deriv2_classes[8][10][107];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+610691, dvrr_stack+567761, dvrr_stack+613331);
 tmp = dvrr_stack + 610691;
 target_ptr = Libderiv->deriv2_classes[9][5][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+519921, dvrr_stack+570456, dvrr_stack+569301);
 tmp = dvrr_stack + 519921;
 target_ptr = Libderiv->deriv2_classes[9][6][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+521461, dvrr_stack+483768, dvrr_stack+567761);
 tmp = dvrr_stack + 521461;
 target_ptr = Libderiv->deriv2_classes[9][7][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+523441, dvrr_stack+453153, dvrr_stack+570456);
 tmp = dvrr_stack + 523441;
 target_ptr = Libderiv->deriv2_classes[9][8][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+423515, dvrr_stack+405748, dvrr_stack+483768);
 tmp = dvrr_stack + 423515;
 target_ptr = Libderiv->deriv2_classes[9][9][107];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+335333, dvrr_stack+373527, dvrr_stack+453153);
 tmp = dvrr_stack + 335333;
 target_ptr = Libderiv->deriv2_classes[9][10][107];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+696322, dvrr_stack+614156, dvrr_stack+712201);
 tmp = dvrr_stack + 696322;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+631889, dvrr_stack+486243, dvrr_stack+572436);
 tmp = dvrr_stack + 631889;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+525916, dvrr_stack+486999, dvrr_stack+614156);
 tmp = dvrr_stack + 525916;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+426540, dvrr_stack+428473, dvrr_stack+486243);
 tmp = dvrr_stack + 426540;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+370382, dvrr_stack+429628, dvrr_stack+486999);
 tmp = dvrr_stack + 370382;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+371537, dvrr_stack+409378, dvrr_stack+428473);
 tmp = dvrr_stack + 371537;
 target_ptr = Libderiv->deriv2_classes[5][10][106];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+11452, dvrr_stack+377817, dvrr_stack+712516);
 tmp = dvrr_stack + 11452;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+427485, dvrr_stack+378601, dvrr_stack+456178);
 tmp = dvrr_stack + 427485;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+338963, dvrr_stack+379609, dvrr_stack+377817);
 tmp = dvrr_stack + 338963;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+339971, dvrr_stack+380869, dvrr_stack+378601);
 tmp = dvrr_stack + 339971;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+283592, dvrr_stack+382409, dvrr_stack+379609);
 tmp = dvrr_stack + 283592;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+262742, dvrr_stack+342476, dvrr_stack+380869);
 tmp = dvrr_stack + 262742;
 target_ptr = Libderiv->deriv2_classes[6][10][106];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+341231, dvrr_stack+344660, dvrr_stack+487944);
 tmp = dvrr_stack + 341231;
 target_ptr = Libderiv->deriv2_classes[7][5][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+285132, dvrr_stack+286496, dvrr_stack+345668);
 tmp = dvrr_stack + 285132;
 target_ptr = Libderiv->deriv2_classes[7][6][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+264590, dvrr_stack+287792, dvrr_stack+344660);
 tmp = dvrr_stack + 264590;
 target_ptr = Libderiv->deriv2_classes[7][7][106];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+195535, dvrr_stack+266917, dvrr_stack+286496);
 tmp = dvrr_stack + 195535;
 target_ptr = Libderiv->deriv2_classes[7][8][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+197155, dvrr_stack+221148, dvrr_stack+287792);
 tmp = dvrr_stack + 197155;
 target_ptr = Libderiv->deriv2_classes[7][9][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+172867, dvrr_stack+223524, dvrr_stack+266917);
 tmp = dvrr_stack + 172867;
 target_ptr = Libderiv->deriv2_classes[7][10][106];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+265886, dvrr_stack+251536, dvrr_stack+384257);
 tmp = dvrr_stack + 265886;
 target_ptr = Libderiv->deriv2_classes[8][5][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+152510, dvrr_stack+227277, dvrr_stack+226332);
 tmp = dvrr_stack + 152510;
 target_ptr = Libderiv->deriv2_classes[8][6][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+153770, dvrr_stack+228897, dvrr_stack+251536);
 tmp = dvrr_stack + 153770;
 target_ptr = Libderiv->deriv2_classes[8][7][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+155390, dvrr_stack+199546, dvrr_stack+227277);
 tmp = dvrr_stack + 155390;
 target_ptr = Libderiv->deriv2_classes[8][8][106];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+137360, dvrr_stack+106348, dvrr_stack+228897);
 tmp = dvrr_stack + 137360;
 target_ptr = Libderiv->deriv2_classes[8][9][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+39847, dvrr_stack+109318, dvrr_stack+199546);
 tmp = dvrr_stack + 39847;
 target_ptr = Libderiv->deriv2_classes[8][10][106];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+157415, dvrr_stack+175966, dvrr_stack+230922);
 tmp = dvrr_stack + 157415;
 target_ptr = Libderiv->deriv2_classes[9][5][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+126074, dvrr_stack+83878, dvrr_stack+202021);
 tmp = dvrr_stack + 126074;
 target_ptr = Libderiv->deriv2_classes[9][6][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+59012, dvrr_stack+943874, dvrr_stack+175966);
 tmp = dvrr_stack + 59012;
 target_ptr = Libderiv->deriv2_classes[9][7][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+834425, dvrr_stack+946349, dvrr_stack+83878);
 tmp = dvrr_stack + 834425;
 target_ptr = Libderiv->deriv2_classes[9][8][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+836900, dvrr_stack+949374, dvrr_stack+943874);
 tmp = dvrr_stack + 836900;
 target_ptr = Libderiv->deriv2_classes[9][9][106];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+839925, dvrr_stack+953004, dvrr_stack+946349);
 tmp = dvrr_stack + 839925;
 target_ptr = Libderiv->deriv2_classes[9][10][106];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+258682, dvrr_stack+788778, dvrr_stack+675499);
 tmp = dvrr_stack + 258682;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+752823, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 752823;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+139835, dvrr_stack+23872, dvrr_stack+788778);
 tmp = dvrr_stack + 139835;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+127614, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 127614;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+104491, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 104491;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+14260, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 14260;
 target_ptr = Libderiv->deriv2_classes[5][10][105];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+611846, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 611846;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+843555, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 843555;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+844339, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 844339;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+845347, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 845347;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+846607, dvrr_stack+166726, dvrr_stack+134840);
 tmp = dvrr_stack + 846607;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+848147, dvrr_stack+188458, dvrr_stack+148990);
 tmp = dvrr_stack + 848147;
 target_ptr = Libderiv->deriv2_classes[6][10][105];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+15646, dvrr_stack+753460, dvrr_stack+214596);
 tmp = dvrr_stack + 15646;
 target_ptr = Libderiv->deriv2_classes[7][5][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+849995, dvrr_stack+240160, dvrr_stack+120446);
 tmp = dvrr_stack + 849995;
 target_ptr = Libderiv->deriv2_classes[7][6][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+851003, dvrr_stack+259141, dvrr_stack+753460);
 tmp = dvrr_stack + 851003;
 target_ptr = Libderiv->deriv2_classes[7][7][105];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+852299, dvrr_stack+276776, dvrr_stack+240160);
 tmp = dvrr_stack + 852299;
 target_ptr = Libderiv->deriv2_classes[7][8][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+853919, dvrr_stack+299900, dvrr_stack+259141);
 tmp = dvrr_stack + 853919;
 target_ptr = Libderiv->deriv2_classes[7][9][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+855899, dvrr_stack+328220, dvrr_stack+276776);
 tmp = dvrr_stack + 855899;
 target_ptr = Libderiv->deriv2_classes[7][10][105];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+858275, dvrr_stack+632546, dvrr_stack+362268);
 tmp = dvrr_stack + 858275;
 target_ptr = Libderiv->deriv2_classes[8][5][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+859220, dvrr_stack+396073, dvrr_stack+401968);
 tmp = dvrr_stack + 859220;
 target_ptr = Libderiv->deriv2_classes[8][6][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+860480, dvrr_stack+418753, dvrr_stack+632546);
 tmp = dvrr_stack + 860480;
 target_ptr = Libderiv->deriv2_classes[8][7][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+862100, dvrr_stack+441003, dvrr_stack+396073);
 tmp = dvrr_stack + 862100;
 target_ptr = Libderiv->deriv2_classes[8][8][105];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+864125, dvrr_stack+468918, dvrr_stack+418753);
 tmp = dvrr_stack + 864125;
 target_ptr = Libderiv->deriv2_classes[8][9][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+866600, dvrr_stack+503616, dvrr_stack+441003);
 tmp = dvrr_stack + 866600;
 target_ptr = Libderiv->deriv2_classes[8][10][105];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+869570, dvrr_stack+565286, dvrr_stack+507126);
 tmp = dvrr_stack + 869570;
 target_ptr = Libderiv->deriv2_classes[9][5][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+870725, dvrr_stack+593141, dvrr_stack+603266);
 tmp = dvrr_stack + 870725;
 target_ptr = Libderiv->deriv2_classes[9][6][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+872265, dvrr_stack+626606, dvrr_stack+565286);
 tmp = dvrr_stack + 872265;
 target_ptr = Libderiv->deriv2_classes[9][7][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+874245, dvrr_stack+656581, dvrr_stack+593141);
 tmp = dvrr_stack + 874245;
 target_ptr = Libderiv->deriv2_classes[9][8][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+876720, dvrr_stack+689020, dvrr_stack+626606);
 tmp = dvrr_stack + 876720;
 target_ptr = Libderiv->deriv2_classes[9][9][105];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+879745, dvrr_stack+731680, dvrr_stack+656581);
 tmp = dvrr_stack + 879745;
 target_ptr = Libderiv->deriv2_classes[9][10][105];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+52861, dvrr_stack+775457, dvrr_stack+775142);
 tmp = dvrr_stack + 52861;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+526672, dvrr_stack+776486, dvrr_stack+776045);
 tmp = dvrr_stack + 526672;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+883375, dvrr_stack+777242, dvrr_stack+775457);
 tmp = dvrr_stack + 883375;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+884131, dvrr_stack+778187, dvrr_stack+776486);
 tmp = dvrr_stack + 884131;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+885076, dvrr_stack+779342, dvrr_stack+777242);
 tmp = dvrr_stack + 885076;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+886231, dvrr_stack+780728, dvrr_stack+778187);
 tmp = dvrr_stack + 886231;
 target_ptr = Libderiv->deriv2_classes[5][10][104];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+372923, dvrr_stack+783192, dvrr_stack+782772);
 tmp = dvrr_stack + 372923;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+887617, dvrr_stack+784564, dvrr_stack+783976);
 tmp = dvrr_stack + 887617;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+888401, dvrr_stack+785572, dvrr_stack+783192);
 tmp = dvrr_stack + 888401;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+889409, dvrr_stack+735970, dvrr_stack+784564);
 tmp = dvrr_stack + 889409;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+890669, dvrr_stack+737510, dvrr_stack+785572);
 tmp = dvrr_stack + 890669;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+892209, dvrr_stack+739358, dvrr_stack+735970);
 tmp = dvrr_stack + 892209;
 target_ptr = Libderiv->deriv2_classes[6][10][104];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+894057, dvrr_stack+741542, dvrr_stack+787360);
 tmp = dvrr_stack + 894057;
 target_ptr = Libderiv->deriv2_classes[7][5][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+894813, dvrr_stack+693406, dvrr_stack+692650);
 tmp = dvrr_stack + 894813;
 target_ptr = Libderiv->deriv2_classes[7][6][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+895821, dvrr_stack+694702, dvrr_stack+741542);
 tmp = dvrr_stack + 895821;
 target_ptr = Libderiv->deriv2_classes[7][7][104];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+897117, dvrr_stack+659606, dvrr_stack+693406);
 tmp = dvrr_stack + 897117;
 target_ptr = Libderiv->deriv2_classes[7][8][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+898737, dvrr_stack+661586, dvrr_stack+694702);
 tmp = dvrr_stack + 898737;
 target_ptr = Libderiv->deriv2_classes[7][9][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+900717, dvrr_stack+629081, dvrr_stack+659606);
 tmp = dvrr_stack + 900717;
 target_ptr = Libderiv->deriv2_classes[7][10][104];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+903093, dvrr_stack+595121, dvrr_stack+696772);
 tmp = dvrr_stack + 903093;
 target_ptr = Libderiv->deriv2_classes[8][5][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+904038, dvrr_stack+605366, dvrr_stack+604421);
 tmp = dvrr_stack + 904038;
 target_ptr = Libderiv->deriv2_classes[8][6][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+905298, dvrr_stack+507951, dvrr_stack+595121);
 tmp = dvrr_stack + 905298;
 target_ptr = Libderiv->deriv2_classes[8][7][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+906918, dvrr_stack+509976, dvrr_stack+605366);
 tmp = dvrr_stack + 906918;
 target_ptr = Libderiv->deriv2_classes[8][8][104];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+908943, dvrr_stack+471888, dvrr_stack+507951);
 tmp = dvrr_stack + 908943;
 target_ptr = Libderiv->deriv2_classes[8][9][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+911418, dvrr_stack+443478, dvrr_stack+509976);
 tmp = dvrr_stack + 911418;
 target_ptr = Libderiv->deriv2_classes[8][10][104];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+914388, dvrr_stack+420778, dvrr_stack+606986);
 tmp = dvrr_stack + 914388;
 target_ptr = Libderiv->deriv2_classes[9][5][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+915543, dvrr_stack+402913, dvrr_stack+474858);
 tmp = dvrr_stack + 915543;
 target_ptr = Libderiv->deriv2_classes[9][6][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+917083, dvrr_stack+362943, dvrr_stack+420778);
 tmp = dvrr_stack + 917083;
 target_ptr = Libderiv->deriv2_classes[9][7][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+919063, dvrr_stack+365418, dvrr_stack+402913);
 tmp = dvrr_stack + 919063;
 target_ptr = Libderiv->deriv2_classes[9][8][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+921538, dvrr_stack+331028, dvrr_stack+362943);
 tmp = dvrr_stack + 921538;
 target_ptr = Libderiv->deriv2_classes[9][9][104];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+924563, dvrr_stack+215136, dvrr_stack+365418);
 tmp = dvrr_stack + 924563;
 target_ptr = Libderiv->deriv2_classes[9][10][104];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+786832, dvrr_stack+790038, dvrr_stack+789723);
 tmp = dvrr_stack + 786832;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+175243, dvrr_stack+791067, dvrr_stack+790626);
 tmp = dvrr_stack + 175243;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+928193, dvrr_stack+791823, dvrr_stack+790038);
 tmp = dvrr_stack + 928193;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+928949, dvrr_stack+792768, dvrr_stack+791067);
 tmp = dvrr_stack + 928949;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+929894, dvrr_stack+793923, dvrr_stack+791823);
 tmp = dvrr_stack + 929894;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+931049, dvrr_stack+795309, dvrr_stack+792768);
 tmp = dvrr_stack + 931049;
 target_ptr = Libderiv->deriv2_classes[5][10][95];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+105646, dvrr_stack+797997, dvrr_stack+797577);
 tmp = dvrr_stack + 105646;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+932435, dvrr_stack+799369, dvrr_stack+798781);
 tmp = dvrr_stack + 932435;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+933219, dvrr_stack+800377, dvrr_stack+797997);
 tmp = dvrr_stack + 933219;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+934227, dvrr_stack+801637, dvrr_stack+799369);
 tmp = dvrr_stack + 934227;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+935487, dvrr_stack+803177, dvrr_stack+800377);
 tmp = dvrr_stack + 935487;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+937027, dvrr_stack+805025, dvrr_stack+801637);
 tmp = dvrr_stack + 937027;
 target_ptr = Libderiv->deriv2_classes[6][10][95];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+938875, dvrr_stack+755080, dvrr_stack+808029);
 tmp = dvrr_stack + 938875;
 target_ptr = Libderiv->deriv2_classes[7][5][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+939631, dvrr_stack+756088, dvrr_stack+808569);
 tmp = dvrr_stack + 939631;
 target_ptr = Libderiv->deriv2_classes[7][6][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+940639, dvrr_stack+757384, dvrr_stack+755080);
 tmp = dvrr_stack + 940639;
 target_ptr = Libderiv->deriv2_classes[7][7][95];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+941935, dvrr_stack+707170, dvrr_stack+756088);
 tmp = dvrr_stack + 941935;
 target_ptr = Libderiv->deriv2_classes[7][8][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+675814, dvrr_stack+709150, dvrr_stack+757384);
 tmp = dvrr_stack + 675814;
 target_ptr = Libderiv->deriv2_classes[7][9][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+677794, dvrr_stack+671431, dvrr_stack+707170);
 tmp = dvrr_stack + 677794;
 target_ptr = Libderiv->deriv2_classes[7][10][95];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+680170, dvrr_stack+674239, dvrr_stack+711526);
 tmp = dvrr_stack + 680170;
 target_ptr = Libderiv->deriv2_classes[8][5][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+614744, dvrr_stack+635516, dvrr_stack+634571);
 tmp = dvrr_stack + 614744;
 target_ptr = Libderiv->deriv2_classes[8][6][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+616004, dvrr_stack+637136, dvrr_stack+674239);
 tmp = dvrr_stack + 616004;
 target_ptr = Libderiv->deriv2_classes[8][7][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+572877, dvrr_stack+639161, dvrr_stack+635516);
 tmp = dvrr_stack + 572877;
 target_ptr = Libderiv->deriv2_classes[8][8][95];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+574902, dvrr_stack+558806, dvrr_stack+637136);
 tmp = dvrr_stack + 574902;
 target_ptr = Libderiv->deriv2_classes[8][9][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+577377, dvrr_stack+561776, dvrr_stack+639161);
 tmp = dvrr_stack + 577377;
 target_ptr = Libderiv->deriv2_classes[8][10][95];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+580347, dvrr_stack+567761, dvrr_stack+613331);
 tmp = dvrr_stack + 580347;
 target_ptr = Libderiv->deriv2_classes[9][5][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+490959, dvrr_stack+570456, dvrr_stack+569301);
 tmp = dvrr_stack + 490959;
 target_ptr = Libderiv->deriv2_classes[9][6][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+492499, dvrr_stack+483768, dvrr_stack+567761);
 tmp = dvrr_stack + 492499;
 target_ptr = Libderiv->deriv2_classes[9][7][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+458791, dvrr_stack+453153, dvrr_stack+570456);
 tmp = dvrr_stack + 458791;
 target_ptr = Libderiv->deriv2_classes[9][8][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+411016, dvrr_stack+405748, dvrr_stack+483768);
 tmp = dvrr_stack + 411016;
 target_ptr = Libderiv->deriv2_classes[9][9][95];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+384932, dvrr_stack+373527, dvrr_stack+453153);
 tmp = dvrr_stack + 384932;
 target_ptr = Libderiv->deriv2_classes[9][10][95];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+787900, dvrr_stack+614156, dvrr_stack+712201);
 tmp = dvrr_stack + 787900;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+60992, dvrr_stack+486243, dvrr_stack+572436);
 tmp = dvrr_stack + 60992;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+432634, dvrr_stack+486999, dvrr_stack+614156);
 tmp = dvrr_stack + 432634;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+433390, dvrr_stack+428473, dvrr_stack+486243);
 tmp = dvrr_stack + 433390;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+388562, dvrr_stack+429628, dvrr_stack+486999);
 tmp = dvrr_stack + 388562;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+389717, dvrr_stack+409378, dvrr_stack+428473);
 tmp = dvrr_stack + 389717;
 target_ptr = Libderiv->deriv2_classes[5][10][94];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+681115, dvrr_stack+377817, dvrr_stack+712516);
 tmp = dvrr_stack + 681115;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+391103, dvrr_stack+378601, dvrr_stack+456178);
 tmp = dvrr_stack + 391103;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+347208, dvrr_stack+379609, dvrr_stack+377817);
 tmp = dvrr_stack + 347208;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+348216, dvrr_stack+380869, dvrr_stack+378601);
 tmp = dvrr_stack + 348216;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+349476, dvrr_stack+382409, dvrr_stack+379609);
 tmp = dvrr_stack + 349476;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+351016, dvrr_stack+342476, dvrr_stack+380869);
 tmp = dvrr_stack + 351016;
 target_ptr = Libderiv->deriv2_classes[6][10][94];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+352864, dvrr_stack+344660, dvrr_stack+487944);
 tmp = dvrr_stack + 352864;
 target_ptr = Libderiv->deriv2_classes[7][5][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+353620, dvrr_stack+286496, dvrr_stack+345668);
 tmp = dvrr_stack + 353620;
 target_ptr = Libderiv->deriv2_classes[7][6][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+354628, dvrr_stack+287792, dvrr_stack+344660);
 tmp = dvrr_stack + 354628;
 target_ptr = Libderiv->deriv2_classes[7][7][94];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+355924, dvrr_stack+266917, dvrr_stack+286496);
 tmp = dvrr_stack + 355924;
 target_ptr = Libderiv->deriv2_classes[7][8][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+231747, dvrr_stack+221148, dvrr_stack+287792);
 tmp = dvrr_stack + 231747;
 target_ptr = Libderiv->deriv2_classes[7][9][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+233727, dvrr_stack+223524, dvrr_stack+266917);
 tmp = dvrr_stack + 233727;
 target_ptr = Libderiv->deriv2_classes[7][10][94];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+357544, dvrr_stack+251536, dvrr_stack+384257);
 tmp = dvrr_stack + 357544;
 target_ptr = Libderiv->deriv2_classes[8][5][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+270193, dvrr_stack+227277, dvrr_stack+226332);
 tmp = dvrr_stack + 270193;
 target_ptr = Libderiv->deriv2_classes[8][6][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+236103, dvrr_stack+228897, dvrr_stack+251536);
 tmp = dvrr_stack + 236103;
 target_ptr = Libderiv->deriv2_classes[8][7][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+203176, dvrr_stack+199546, dvrr_stack+227277);
 tmp = dvrr_stack + 203176;
 target_ptr = Libderiv->deriv2_classes[8][8][94];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+205201, dvrr_stack+106348, dvrr_stack+228897);
 tmp = dvrr_stack + 205201;
 target_ptr = Libderiv->deriv2_classes[8][9][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+178661, dvrr_stack+109318, dvrr_stack+199546);
 tmp = dvrr_stack + 178661;
 target_ptr = Libderiv->deriv2_classes[8][10][94];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+253804, dvrr_stack+175966, dvrr_stack+230922);
 tmp = dvrr_stack + 253804;
 target_ptr = Libderiv->deriv2_classes[9][5][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+142274, dvrr_stack+83878, dvrr_stack+202021);
 tmp = dvrr_stack + 142274;
 target_ptr = Libderiv->deriv2_classes[9][6][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+112828, dvrr_stack+943874, dvrr_stack+175966);
 tmp = dvrr_stack + 112828;
 target_ptr = Libderiv->deriv2_classes[9][7][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+86614, dvrr_stack+946349, dvrr_stack+83878);
 tmp = dvrr_stack + 86614;
 target_ptr = Libderiv->deriv2_classes[9][8][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+555051, dvrr_stack+949374, dvrr_stack+943874);
 tmp = dvrr_stack + 555051;
 target_ptr = Libderiv->deriv2_classes[9][9][94];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1293671, dvrr_stack+953004, dvrr_stack+946349);
 tmp = dvrr_stack + 1293671;
 target_ptr = Libderiv->deriv2_classes[9][10][94];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1297301, dvrr_stack+788778, dvrr_stack+675499);
 tmp = dvrr_stack + 1297301;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+617624, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 617624;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+181631, dvrr_stack+23872, dvrr_stack+788778);
 tmp = dvrr_stack + 181631;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+143814, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 143814;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+114808, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 114808;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+89089, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 89089;
 target_ptr = Libderiv->deriv2_classes[5][10][93];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+434335, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 434335;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+115963, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 115963;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+17077, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 17077;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1297742, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 1297742;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1299002, dvrr_stack+166726, dvrr_stack+134840);
 tmp = dvrr_stack + 1299002;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+1300542, dvrr_stack+188458, dvrr_stack+148990);
 tmp = dvrr_stack + 1300542;
 target_ptr = Libderiv->deriv2_classes[6][10][93];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1302390, dvrr_stack+753460, dvrr_stack+214596);
 tmp = dvrr_stack + 1302390;
 target_ptr = Libderiv->deriv2_classes[7][5][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1303146, dvrr_stack+240160, dvrr_stack+120446);
 tmp = dvrr_stack + 1303146;
 target_ptr = Libderiv->deriv2_classes[7][6][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1304154, dvrr_stack+259141, dvrr_stack+753460);
 tmp = dvrr_stack + 1304154;
 target_ptr = Libderiv->deriv2_classes[7][7][93];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1305450, dvrr_stack+276776, dvrr_stack+240160);
 tmp = dvrr_stack + 1305450;
 target_ptr = Libderiv->deriv2_classes[7][8][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1307070, dvrr_stack+299900, dvrr_stack+259141);
 tmp = dvrr_stack + 1307070;
 target_ptr = Libderiv->deriv2_classes[7][9][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1309050, dvrr_stack+328220, dvrr_stack+276776);
 tmp = dvrr_stack + 1309050;
 target_ptr = Libderiv->deriv2_classes[7][10][93];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1311426, dvrr_stack+632546, dvrr_stack+362268);
 tmp = dvrr_stack + 1311426;
 target_ptr = Libderiv->deriv2_classes[8][5][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1312371, dvrr_stack+396073, dvrr_stack+401968);
 tmp = dvrr_stack + 1312371;
 target_ptr = Libderiv->deriv2_classes[8][6][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1313631, dvrr_stack+418753, dvrr_stack+632546);
 tmp = dvrr_stack + 1313631;
 target_ptr = Libderiv->deriv2_classes[8][7][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1315251, dvrr_stack+441003, dvrr_stack+396073);
 tmp = dvrr_stack + 1315251;
 target_ptr = Libderiv->deriv2_classes[8][8][93];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1317276, dvrr_stack+468918, dvrr_stack+418753);
 tmp = dvrr_stack + 1317276;
 target_ptr = Libderiv->deriv2_classes[8][9][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1319751, dvrr_stack+503616, dvrr_stack+441003);
 tmp = dvrr_stack + 1319751;
 target_ptr = Libderiv->deriv2_classes[8][10][93];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1322721, dvrr_stack+565286, dvrr_stack+507126);
 tmp = dvrr_stack + 1322721;
 target_ptr = Libderiv->deriv2_classes[9][5][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1323876, dvrr_stack+593141, dvrr_stack+603266);
 tmp = dvrr_stack + 1323876;
 target_ptr = Libderiv->deriv2_classes[9][6][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1325416, dvrr_stack+626606, dvrr_stack+565286);
 tmp = dvrr_stack + 1325416;
 target_ptr = Libderiv->deriv2_classes[9][7][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1327396, dvrr_stack+656581, dvrr_stack+593141);
 tmp = dvrr_stack + 1327396;
 target_ptr = Libderiv->deriv2_classes[9][8][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1329871, dvrr_stack+689020, dvrr_stack+626606);
 tmp = dvrr_stack + 1329871;
 target_ptr = Libderiv->deriv2_classes[9][9][93];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1332896, dvrr_stack+731680, dvrr_stack+656581);
 tmp = dvrr_stack + 1332896;
 target_ptr = Libderiv->deriv2_classes[9][10][93];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+1336526, dvrr_stack+775457, dvrr_stack+775142);
 tmp = dvrr_stack + 1336526;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+271453, dvrr_stack+776486, dvrr_stack+776045);
 tmp = dvrr_stack + 271453;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+1336967, dvrr_stack+777242, dvrr_stack+775457);
 tmp = dvrr_stack + 1336967;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1337723, dvrr_stack+778187, dvrr_stack+776486);
 tmp = dvrr_stack + 1337723;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1338668, dvrr_stack+779342, dvrr_stack+777242);
 tmp = dvrr_stack + 1338668;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+1339823, dvrr_stack+780728, dvrr_stack+778187);
 tmp = dvrr_stack + 1339823;
 target_ptr = Libderiv->deriv2_classes[5][10][92];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1341209, dvrr_stack+783192, dvrr_stack+782772);
 tmp = dvrr_stack + 1341209;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1341797, dvrr_stack+784564, dvrr_stack+783976);
 tmp = dvrr_stack + 1341797;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1342581, dvrr_stack+785572, dvrr_stack+783192);
 tmp = dvrr_stack + 1342581;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1343589, dvrr_stack+735970, dvrr_stack+784564);
 tmp = dvrr_stack + 1343589;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1344849, dvrr_stack+737510, dvrr_stack+785572);
 tmp = dvrr_stack + 1344849;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+1346389, dvrr_stack+739358, dvrr_stack+735970);
 tmp = dvrr_stack + 1346389;
 target_ptr = Libderiv->deriv2_classes[6][10][92];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1348237, dvrr_stack+741542, dvrr_stack+787360);
 tmp = dvrr_stack + 1348237;
 target_ptr = Libderiv->deriv2_classes[7][5][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1348993, dvrr_stack+693406, dvrr_stack+692650);
 tmp = dvrr_stack + 1348993;
 target_ptr = Libderiv->deriv2_classes[7][6][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1350001, dvrr_stack+694702, dvrr_stack+741542);
 tmp = dvrr_stack + 1350001;
 target_ptr = Libderiv->deriv2_classes[7][7][92];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1351297, dvrr_stack+659606, dvrr_stack+693406);
 tmp = dvrr_stack + 1351297;
 target_ptr = Libderiv->deriv2_classes[7][8][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1352917, dvrr_stack+661586, dvrr_stack+694702);
 tmp = dvrr_stack + 1352917;
 target_ptr = Libderiv->deriv2_classes[7][9][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1354897, dvrr_stack+629081, dvrr_stack+659606);
 tmp = dvrr_stack + 1354897;
 target_ptr = Libderiv->deriv2_classes[7][10][92];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1357273, dvrr_stack+595121, dvrr_stack+696772);
 tmp = dvrr_stack + 1357273;
 target_ptr = Libderiv->deriv2_classes[8][5][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1358218, dvrr_stack+605366, dvrr_stack+604421);
 tmp = dvrr_stack + 1358218;
 target_ptr = Libderiv->deriv2_classes[8][6][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1359478, dvrr_stack+507951, dvrr_stack+595121);
 tmp = dvrr_stack + 1359478;
 target_ptr = Libderiv->deriv2_classes[8][7][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1361098, dvrr_stack+509976, dvrr_stack+605366);
 tmp = dvrr_stack + 1361098;
 target_ptr = Libderiv->deriv2_classes[8][8][92];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1363123, dvrr_stack+471888, dvrr_stack+507951);
 tmp = dvrr_stack + 1363123;
 target_ptr = Libderiv->deriv2_classes[8][9][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1365598, dvrr_stack+443478, dvrr_stack+509976);
 tmp = dvrr_stack + 1365598;
 target_ptr = Libderiv->deriv2_classes[8][10][92];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1368568, dvrr_stack+420778, dvrr_stack+606986);
 tmp = dvrr_stack + 1368568;
 target_ptr = Libderiv->deriv2_classes[9][5][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1369723, dvrr_stack+402913, dvrr_stack+474858);
 tmp = dvrr_stack + 1369723;
 target_ptr = Libderiv->deriv2_classes[9][6][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1371263, dvrr_stack+362943, dvrr_stack+420778);
 tmp = dvrr_stack + 1371263;
 target_ptr = Libderiv->deriv2_classes[9][7][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1373243, dvrr_stack+365418, dvrr_stack+402913);
 tmp = dvrr_stack + 1373243;
 target_ptr = Libderiv->deriv2_classes[9][8][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1375718, dvrr_stack+331028, dvrr_stack+362943);
 tmp = dvrr_stack + 1375718;
 target_ptr = Libderiv->deriv2_classes[9][9][92];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1378743, dvrr_stack+215136, dvrr_stack+365418);
 tmp = dvrr_stack + 1378743;
 target_ptr = Libderiv->deriv2_classes[9][10][92];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+452694, dvrr_stack+566826, dvrr_stack+697447);
 tmp = dvrr_stack + 452694;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+558076, dvrr_stack+422759, dvrr_stack+422318);
 tmp = dvrr_stack + 558076;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+1382373, dvrr_stack+397693, dvrr_stack+566826);
 tmp = dvrr_stack + 1382373;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+1383129, dvrr_stack+368443, dvrr_stack+422759);
 tmp = dvrr_stack + 1383129;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+1384074, dvrr_stack+302276, dvrr_stack+397693);
 tmp = dvrr_stack + 1384074;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+1385229, dvrr_stack+303662, dvrr_stack+368443);
 tmp = dvrr_stack + 1385229;
 target_ptr = Libderiv->deriv2_classes[5][10][91];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+1386615, dvrr_stack+369598, dvrr_stack+404893);
 tmp = dvrr_stack + 1386615;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+1387203, dvrr_stack+278756, dvrr_stack+633806);
 tmp = dvrr_stack + 1387203;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+1387987, dvrr_stack+279764, dvrr_stack+369598);
 tmp = dvrr_stack + 1387987;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+1388995, dvrr_stack+260761, dvrr_stack+278756);
 tmp = dvrr_stack + 1388995;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+1390255, dvrr_stack+245488, dvrr_stack+279764);
 tmp = dvrr_stack + 1390255;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+1391795, dvrr_stack+190642, dvrr_stack+260761);
 tmp = dvrr_stack + 1391795;
 target_ptr = Libderiv->deriv2_classes[6][10][91];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+1393643, dvrr_stack+247336, dvrr_stack+305300);
 tmp = dvrr_stack + 1393643;
 target_ptr = Libderiv->deriv2_classes[7][5][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+1394399, dvrr_stack+219426, dvrr_stack+241456);
 tmp = dvrr_stack + 1394399;
 target_ptr = Libderiv->deriv2_classes[7][6][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+1395407, dvrr_stack+168574, dvrr_stack+247336);
 tmp = dvrr_stack + 1395407;
 target_ptr = Libderiv->deriv2_classes[7][7][91];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+1396703, dvrr_stack+150530, dvrr_stack+219426);
 tmp = dvrr_stack + 1396703;
 target_ptr = Libderiv->deriv2_classes[7][8][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+1398323, dvrr_stack+100090, dvrr_stack+168574);
 tmp = dvrr_stack + 1398323;
 target_ptr = Libderiv->deriv2_classes[7][9][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+1400303, dvrr_stack+544755, dvrr_stack+150530);
 tmp = dvrr_stack + 1400303;
 target_ptr = Libderiv->deriv2_classes[7][10][91];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+1402679, dvrr_stack+136100, dvrr_stack+334658);
 tmp = dvrr_stack + 1402679;
 target_ptr = Libderiv->deriv2_classes[8][5][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+1403624, dvrr_stack+124454, dvrr_stack+192826);
 tmp = dvrr_stack + 1403624;
 target_ptr = Libderiv->deriv2_classes[8][6][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+1404884, dvrr_stack+102466, dvrr_stack+136100);
 tmp = dvrr_stack + 1404884;
 target_ptr = Libderiv->deriv2_classes[8][7][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+1406504, dvrr_stack+77200, dvrr_stack+124454);
 tmp = dvrr_stack + 1406504;
 target_ptr = Libderiv->deriv2_classes[8][8][91];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+1408529, dvrr_stack+547563, dvrr_stack+102466);
 tmp = dvrr_stack + 1408529;
 target_ptr = Libderiv->deriv2_classes[8][9][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+1411004, dvrr_stack+550533, dvrr_stack+77200);
 tmp = dvrr_stack + 1411004;
 target_ptr = Libderiv->deriv2_classes[8][10][91];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+1413974, dvrr_stack+56086, dvrr_stack+170194);
 tmp = dvrr_stack + 1413974;
 target_ptr = Libderiv->deriv2_classes[9][5][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+1415129, dvrr_stack+61630, dvrr_stack+38692);
 tmp = dvrr_stack + 1415129;
 target_ptr = Libderiv->deriv2_classes[9][6][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+1416669, dvrr_stack+957294, dvrr_stack+56086);
 tmp = dvrr_stack + 1416669;
 target_ptr = Libderiv->deriv2_classes[9][7][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+1418649, dvrr_stack+959769, dvrr_stack+61630);
 tmp = dvrr_stack + 1418649;
 target_ptr = Libderiv->deriv2_classes[9][8][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+1421124, dvrr_stack+962794, dvrr_stack+957294);
 tmp = dvrr_stack + 1421124;
 target_ptr = Libderiv->deriv2_classes[9][9][91];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+1424149, dvrr_stack+966424, dvrr_stack+959769);
 tmp = dvrr_stack + 1424149;
 target_ptr = Libderiv->deriv2_classes[9][10][91];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+1427779, dvrr_stack+790038, dvrr_stack+789723);
 tmp = dvrr_stack + 1427779;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+789366, dvrr_stack+791067, dvrr_stack+790626);
 tmp = dvrr_stack + 789366;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1428220, dvrr_stack+791823, dvrr_stack+790038);
 tmp = dvrr_stack + 1428220;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+1428976, dvrr_stack+792768, dvrr_stack+791067);
 tmp = dvrr_stack + 1428976;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+1429921, dvrr_stack+793923, dvrr_stack+791823);
 tmp = dvrr_stack + 1429921;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1431076, dvrr_stack+795309, dvrr_stack+792768);
 tmp = dvrr_stack + 1431076;
 target_ptr = Libderiv->deriv2_classes[5][10][83];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+795309, dvrr_stack+797997, dvrr_stack+797577);
 tmp = dvrr_stack + 795309;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+795897, dvrr_stack+799369, dvrr_stack+798781);
 tmp = dvrr_stack + 795897;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1432462, dvrr_stack+800377, dvrr_stack+797997);
 tmp = dvrr_stack + 1432462;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1433470, dvrr_stack+801637, dvrr_stack+799369);
 tmp = dvrr_stack + 1433470;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1434730, dvrr_stack+803177, dvrr_stack+800377);
 tmp = dvrr_stack + 1434730;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1436270, dvrr_stack+805025, dvrr_stack+801637);
 tmp = dvrr_stack + 1436270;
 target_ptr = Libderiv->deriv2_classes[6][10][83];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+805025, dvrr_stack+755080, dvrr_stack+808029);
 tmp = dvrr_stack + 805025;
 target_ptr = Libderiv->deriv2_classes[7][5][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+805781, dvrr_stack+756088, dvrr_stack+808569);
 tmp = dvrr_stack + 805781;
 target_ptr = Libderiv->deriv2_classes[7][6][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1438118, dvrr_stack+757384, dvrr_stack+755080);
 tmp = dvrr_stack + 1438118;
 target_ptr = Libderiv->deriv2_classes[7][7][83];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1439414, dvrr_stack+707170, dvrr_stack+756088);
 tmp = dvrr_stack + 1439414;
 target_ptr = Libderiv->deriv2_classes[7][8][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1441034, dvrr_stack+709150, dvrr_stack+757384);
 tmp = dvrr_stack + 1441034;
 target_ptr = Libderiv->deriv2_classes[7][9][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1443014, dvrr_stack+671431, dvrr_stack+707170);
 tmp = dvrr_stack + 1443014;
 target_ptr = Libderiv->deriv2_classes[7][10][83];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+671343, dvrr_stack+674239, dvrr_stack+711526);
 tmp = dvrr_stack + 671343;
 target_ptr = Libderiv->deriv2_classes[8][5][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+672288, dvrr_stack+635516, dvrr_stack+634571);
 tmp = dvrr_stack + 672288;
 target_ptr = Libderiv->deriv2_classes[8][6][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1445390, dvrr_stack+637136, dvrr_stack+674239);
 tmp = dvrr_stack + 1445390;
 target_ptr = Libderiv->deriv2_classes[8][7][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1447010, dvrr_stack+639161, dvrr_stack+635516);
 tmp = dvrr_stack + 1447010;
 target_ptr = Libderiv->deriv2_classes[8][8][83];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1449035, dvrr_stack+558806, dvrr_stack+637136);
 tmp = dvrr_stack + 1449035;
 target_ptr = Libderiv->deriv2_classes[8][9][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1451510, dvrr_stack+561776, dvrr_stack+639161);
 tmp = dvrr_stack + 1451510;
 target_ptr = Libderiv->deriv2_classes[8][10][83];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+561776, dvrr_stack+567761, dvrr_stack+613331);
 tmp = dvrr_stack + 561776;
 target_ptr = Libderiv->deriv2_classes[9][5][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+562931, dvrr_stack+570456, dvrr_stack+569301);
 tmp = dvrr_stack + 562931;
 target_ptr = Libderiv->deriv2_classes[9][6][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1454480, dvrr_stack+483768, dvrr_stack+567761);
 tmp = dvrr_stack + 1454480;
 target_ptr = Libderiv->deriv2_classes[9][7][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1456460, dvrr_stack+453153, dvrr_stack+570456);
 tmp = dvrr_stack + 1456460;
 target_ptr = Libderiv->deriv2_classes[9][8][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1458935, dvrr_stack+405748, dvrr_stack+483768);
 tmp = dvrr_stack + 1458935;
 target_ptr = Libderiv->deriv2_classes[9][9][83];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1461960, dvrr_stack+373527, dvrr_stack+453153);
 tmp = dvrr_stack + 1461960;
 target_ptr = Libderiv->deriv2_classes[9][10][83];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+564471, dvrr_stack+614156, dvrr_stack+712201);
 tmp = dvrr_stack + 564471;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+711526, dvrr_stack+486243, dvrr_stack+572436);
 tmp = dvrr_stack + 711526;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1465590, dvrr_stack+486999, dvrr_stack+614156);
 tmp = dvrr_stack + 1465590;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+373511, dvrr_stack+428473, dvrr_stack+486243);
 tmp = dvrr_stack + 373511;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+374456, dvrr_stack+429628, dvrr_stack+486999);
 tmp = dvrr_stack + 374456;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+375611, dvrr_stack+409378, dvrr_stack+428473);
 tmp = dvrr_stack + 375611;
 target_ptr = Libderiv->deriv2_classes[5][10][82];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+409378, dvrr_stack+377817, dvrr_stack+712516);
 tmp = dvrr_stack + 409378;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+409966, dvrr_stack+378601, dvrr_stack+456178);
 tmp = dvrr_stack + 409966;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1466346, dvrr_stack+379609, dvrr_stack+377817);
 tmp = dvrr_stack + 1466346;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1467354, dvrr_stack+380869, dvrr_stack+378601);
 tmp = dvrr_stack + 1467354;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1468614, dvrr_stack+382409, dvrr_stack+379609);
 tmp = dvrr_stack + 1468614;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1470154, dvrr_stack+342476, dvrr_stack+380869);
 tmp = dvrr_stack + 1470154;
 target_ptr = Libderiv->deriv2_classes[6][10][82];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+712114, dvrr_stack+344660, dvrr_stack+487944);
 tmp = dvrr_stack + 712114;
 target_ptr = Libderiv->deriv2_classes[7][5][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+341987, dvrr_stack+286496, dvrr_stack+345668);
 tmp = dvrr_stack + 341987;
 target_ptr = Libderiv->deriv2_classes[7][6][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+342995, dvrr_stack+287792, dvrr_stack+344660);
 tmp = dvrr_stack + 342995;
 target_ptr = Libderiv->deriv2_classes[7][7][82];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1472002, dvrr_stack+266917, dvrr_stack+286496);
 tmp = dvrr_stack + 1472002;
 target_ptr = Libderiv->deriv2_classes[7][8][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1473622, dvrr_stack+221148, dvrr_stack+287792);
 tmp = dvrr_stack + 1473622;
 target_ptr = Libderiv->deriv2_classes[7][9][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1475602, dvrr_stack+223524, dvrr_stack+266917);
 tmp = dvrr_stack + 1475602;
 target_ptr = Libderiv->deriv2_classes[7][10][82];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+223524, dvrr_stack+251536, dvrr_stack+384257);
 tmp = dvrr_stack + 223524;
 target_ptr = Libderiv->deriv2_classes[8][5][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+224469, dvrr_stack+227277, dvrr_stack+226332);
 tmp = dvrr_stack + 224469;
 target_ptr = Libderiv->deriv2_classes[8][6][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1477978, dvrr_stack+228897, dvrr_stack+251536);
 tmp = dvrr_stack + 1477978;
 target_ptr = Libderiv->deriv2_classes[8][7][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1479598, dvrr_stack+199546, dvrr_stack+227277);
 tmp = dvrr_stack + 1479598;
 target_ptr = Libderiv->deriv2_classes[8][8][82];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1481623, dvrr_stack+106348, dvrr_stack+228897);
 tmp = dvrr_stack + 1481623;
 target_ptr = Libderiv->deriv2_classes[8][9][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1484098, dvrr_stack+109318, dvrr_stack+199546);
 tmp = dvrr_stack + 1484098;
 target_ptr = Libderiv->deriv2_classes[8][10][82];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+109318, dvrr_stack+175966, dvrr_stack+230922);
 tmp = dvrr_stack + 109318;
 target_ptr = Libderiv->deriv2_classes[9][5][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+110473, dvrr_stack+83878, dvrr_stack+202021);
 tmp = dvrr_stack + 110473;
 target_ptr = Libderiv->deriv2_classes[9][6][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1487068, dvrr_stack+943874, dvrr_stack+175966);
 tmp = dvrr_stack + 1487068;
 target_ptr = Libderiv->deriv2_classes[9][7][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1489048, dvrr_stack+946349, dvrr_stack+83878);
 tmp = dvrr_stack + 1489048;
 target_ptr = Libderiv->deriv2_classes[9][8][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1491523, dvrr_stack+949374, dvrr_stack+943874);
 tmp = dvrr_stack + 1491523;
 target_ptr = Libderiv->deriv2_classes[9][9][82];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1494548, dvrr_stack+953004, dvrr_stack+946349);
 tmp = dvrr_stack + 1494548;
 target_ptr = Libderiv->deriv2_classes[9][10][82];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+953004, dvrr_stack+788778, dvrr_stack+675499);
 tmp = dvrr_stack + 953004;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+953445, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 953445;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+954033, dvrr_stack+23872, dvrr_stack+788778);
 tmp = dvrr_stack + 954033;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+954789, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 954789;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+955734, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 955734;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1498178, dvrr_stack+75562, dvrr_stack+37537);
 tmp = dvrr_stack + 1498178;
 target_ptr = Libderiv->deriv2_classes[5][10][81];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+75562, dvrr_stack+28408, dvrr_stack+99670);
 tmp = dvrr_stack + 75562;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+76150, dvrr_stack+119438, dvrr_stack+123866);
 tmp = dvrr_stack + 76150;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+1499564, dvrr_stack+134840, dvrr_stack+28408);
 tmp = dvrr_stack + 1499564;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1500572, dvrr_stack+148990, dvrr_stack+119438);
 tmp = dvrr_stack + 1500572;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1501832, dvrr_stack+166726, dvrr_stack+134840);
 tmp = dvrr_stack + 1501832;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1503372, dvrr_stack+188458, dvrr_stack+148990);
 tmp = dvrr_stack + 1503372;
 target_ptr = Libderiv->deriv2_classes[6][10][81];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+188458, dvrr_stack+753460, dvrr_stack+214596);
 tmp = dvrr_stack + 188458;
 target_ptr = Libderiv->deriv2_classes[7][5][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+189214, dvrr_stack+240160, dvrr_stack+120446);
 tmp = dvrr_stack + 189214;
 target_ptr = Libderiv->deriv2_classes[7][6][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1505220, dvrr_stack+259141, dvrr_stack+753460);
 tmp = dvrr_stack + 1505220;
 target_ptr = Libderiv->deriv2_classes[7][7][81];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1506516, dvrr_stack+276776, dvrr_stack+240160);
 tmp = dvrr_stack + 1506516;
 target_ptr = Libderiv->deriv2_classes[7][8][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1508136, dvrr_stack+299900, dvrr_stack+259141);
 tmp = dvrr_stack + 1508136;
 target_ptr = Libderiv->deriv2_classes[7][9][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1510116, dvrr_stack+328220, dvrr_stack+276776);
 tmp = dvrr_stack + 1510116;
 target_ptr = Libderiv->deriv2_classes[7][10][81];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+327518, dvrr_stack+632546, dvrr_stack+362268);
 tmp = dvrr_stack + 327518;
 target_ptr = Libderiv->deriv2_classes[8][5][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+328463, dvrr_stack+396073, dvrr_stack+401968);
 tmp = dvrr_stack + 328463;
 target_ptr = Libderiv->deriv2_classes[8][6][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1512492, dvrr_stack+418753, dvrr_stack+632546);
 tmp = dvrr_stack + 1512492;
 target_ptr = Libderiv->deriv2_classes[8][7][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1514112, dvrr_stack+441003, dvrr_stack+396073);
 tmp = dvrr_stack + 1514112;
 target_ptr = Libderiv->deriv2_classes[8][8][81];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1516137, dvrr_stack+468918, dvrr_stack+418753);
 tmp = dvrr_stack + 1516137;
 target_ptr = Libderiv->deriv2_classes[8][9][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1518612, dvrr_stack+503616, dvrr_stack+441003);
 tmp = dvrr_stack + 1518612;
 target_ptr = Libderiv->deriv2_classes[8][10][81];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+503082, dvrr_stack+565286, dvrr_stack+507126);
 tmp = dvrr_stack + 503082;
 target_ptr = Libderiv->deriv2_classes[9][5][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+504237, dvrr_stack+593141, dvrr_stack+603266);
 tmp = dvrr_stack + 504237;
 target_ptr = Libderiv->deriv2_classes[9][6][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+505777, dvrr_stack+626606, dvrr_stack+565286);
 tmp = dvrr_stack + 505777;
 target_ptr = Libderiv->deriv2_classes[9][7][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1521582, dvrr_stack+656581, dvrr_stack+593141);
 tmp = dvrr_stack + 1521582;
 target_ptr = Libderiv->deriv2_classes[9][8][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1524057, dvrr_stack+689020, dvrr_stack+626606);
 tmp = dvrr_stack + 1524057;
 target_ptr = Libderiv->deriv2_classes[9][9][81];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1527082, dvrr_stack+731680, dvrr_stack+656581);
 tmp = dvrr_stack + 1527082;
 target_ptr = Libderiv->deriv2_classes[9][10][81];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+230922, dvrr_stack+775457, dvrr_stack+775142);
 tmp = dvrr_stack + 230922;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+112013, dvrr_stack+776486, dvrr_stack+776045);
 tmp = dvrr_stack + 112013;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+1530712, dvrr_stack+777242, dvrr_stack+775457);
 tmp = dvrr_stack + 1530712;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+731326, dvrr_stack+778187, dvrr_stack+776486);
 tmp = dvrr_stack + 731326;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+732271, dvrr_stack+779342, dvrr_stack+777242);
 tmp = dvrr_stack + 732271;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+733426, dvrr_stack+780728, dvrr_stack+778187);
 tmp = dvrr_stack + 733426;
 target_ptr = Libderiv->deriv2_classes[5][10][80];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+780728, dvrr_stack+783192, dvrr_stack+782772);
 tmp = dvrr_stack + 780728;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+781316, dvrr_stack+784564, dvrr_stack+783976);
 tmp = dvrr_stack + 781316;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+782100, dvrr_stack+785572, dvrr_stack+783192);
 tmp = dvrr_stack + 782100;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+329723, dvrr_stack+735970, dvrr_stack+784564);
 tmp = dvrr_stack + 329723;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1531468, dvrr_stack+737510, dvrr_stack+785572);
 tmp = dvrr_stack + 1531468;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1533008, dvrr_stack+739358, dvrr_stack+735970);
 tmp = dvrr_stack + 1533008;
 target_ptr = Libderiv->deriv2_classes[6][10][80];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+739358, dvrr_stack+741542, dvrr_stack+787360);
 tmp = dvrr_stack + 739358;
 target_ptr = Libderiv->deriv2_classes[7][5][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+740114, dvrr_stack+693406, dvrr_stack+692650);
 tmp = dvrr_stack + 740114;
 target_ptr = Libderiv->deriv2_classes[7][6][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1534856, dvrr_stack+694702, dvrr_stack+741542);
 tmp = dvrr_stack + 1534856;
 target_ptr = Libderiv->deriv2_classes[7][7][80];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1536152, dvrr_stack+659606, dvrr_stack+693406);
 tmp = dvrr_stack + 1536152;
 target_ptr = Libderiv->deriv2_classes[7][8][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1537772, dvrr_stack+661586, dvrr_stack+694702);
 tmp = dvrr_stack + 1537772;
 target_ptr = Libderiv->deriv2_classes[7][9][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1539752, dvrr_stack+629081, dvrr_stack+659606);
 tmp = dvrr_stack + 1539752;
 target_ptr = Libderiv->deriv2_classes[7][10][80];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+629081, dvrr_stack+595121, dvrr_stack+696772);
 tmp = dvrr_stack + 629081;
 target_ptr = Libderiv->deriv2_classes[8][5][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+630026, dvrr_stack+605366, dvrr_stack+604421);
 tmp = dvrr_stack + 630026;
 target_ptr = Libderiv->deriv2_classes[8][6][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1542128, dvrr_stack+507951, dvrr_stack+595121);
 tmp = dvrr_stack + 1542128;
 target_ptr = Libderiv->deriv2_classes[8][7][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1543748, dvrr_stack+509976, dvrr_stack+605366);
 tmp = dvrr_stack + 1543748;
 target_ptr = Libderiv->deriv2_classes[8][8][80];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1545773, dvrr_stack+471888, dvrr_stack+507951);
 tmp = dvrr_stack + 1545773;
 target_ptr = Libderiv->deriv2_classes[8][9][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1548248, dvrr_stack+443478, dvrr_stack+509976);
 tmp = dvrr_stack + 1548248;
 target_ptr = Libderiv->deriv2_classes[8][10][80];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+443478, dvrr_stack+420778, dvrr_stack+606986);
 tmp = dvrr_stack + 443478;
 target_ptr = Libderiv->deriv2_classes[9][5][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+444633, dvrr_stack+402913, dvrr_stack+474858);
 tmp = dvrr_stack + 444633;
 target_ptr = Libderiv->deriv2_classes[9][6][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1551218, dvrr_stack+362943, dvrr_stack+420778);
 tmp = dvrr_stack + 1551218;
 target_ptr = Libderiv->deriv2_classes[9][7][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1553198, dvrr_stack+365418, dvrr_stack+402913);
 tmp = dvrr_stack + 1553198;
 target_ptr = Libderiv->deriv2_classes[9][8][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1555673, dvrr_stack+331028, dvrr_stack+362943);
 tmp = dvrr_stack + 1555673;
 target_ptr = Libderiv->deriv2_classes[9][9][80];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1558698, dvrr_stack+215136, dvrr_stack+365418);
 tmp = dvrr_stack + 1558698;
 target_ptr = Libderiv->deriv2_classes[9][10][80];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+606986, dvrr_stack+566826, dvrr_stack+697447);
 tmp = dvrr_stack + 606986;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+446173, dvrr_stack+422759, dvrr_stack+422318);
 tmp = dvrr_stack + 446173;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+696763, dvrr_stack+397693, dvrr_stack+566826);
 tmp = dvrr_stack + 696763;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+214474, dvrr_stack+368443, dvrr_stack+422759);
 tmp = dvrr_stack + 214474;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+215419, dvrr_stack+302276, dvrr_stack+397693);
 tmp = dvrr_stack + 215419;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+216574, dvrr_stack+303662, dvrr_stack+368443);
 tmp = dvrr_stack + 216574;
 target_ptr = Libderiv->deriv2_classes[5][10][79];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+303662, dvrr_stack+369598, dvrr_stack+404893);
 tmp = dvrr_stack + 303662;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+304250, dvrr_stack+278756, dvrr_stack+633806);
 tmp = dvrr_stack + 304250;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+217960, dvrr_stack+279764, dvrr_stack+369598);
 tmp = dvrr_stack + 217960;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+1562328, dvrr_stack+260761, dvrr_stack+278756);
 tmp = dvrr_stack + 1562328;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1563588, dvrr_stack+245488, dvrr_stack+279764);
 tmp = dvrr_stack + 1563588;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1565128, dvrr_stack+190642, dvrr_stack+260761);
 tmp = dvrr_stack + 1565128;
 target_ptr = Libderiv->deriv2_classes[6][10][79];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+190222, dvrr_stack+247336, dvrr_stack+305300);
 tmp = dvrr_stack + 190222;
 target_ptr = Libderiv->deriv2_classes[7][5][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+190978, dvrr_stack+219426, dvrr_stack+241456);
 tmp = dvrr_stack + 190978;
 target_ptr = Libderiv->deriv2_classes[7][6][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+1566976, dvrr_stack+168574, dvrr_stack+247336);
 tmp = dvrr_stack + 1566976;
 target_ptr = Libderiv->deriv2_classes[7][7][79];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1568272, dvrr_stack+150530, dvrr_stack+219426);
 tmp = dvrr_stack + 1568272;
 target_ptr = Libderiv->deriv2_classes[7][8][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1569892, dvrr_stack+100090, dvrr_stack+168574);
 tmp = dvrr_stack + 1569892;
 target_ptr = Libderiv->deriv2_classes[7][9][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1571872, dvrr_stack+544755, dvrr_stack+150530);
 tmp = dvrr_stack + 1571872;
 target_ptr = Libderiv->deriv2_classes[7][10][79];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+544689, dvrr_stack+136100, dvrr_stack+334658);
 tmp = dvrr_stack + 544689;
 target_ptr = Libderiv->deriv2_classes[8][5][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+545634, dvrr_stack+124454, dvrr_stack+192826);
 tmp = dvrr_stack + 545634;
 target_ptr = Libderiv->deriv2_classes[8][6][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+1574248, dvrr_stack+102466, dvrr_stack+136100);
 tmp = dvrr_stack + 1574248;
 target_ptr = Libderiv->deriv2_classes[8][7][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1575868, dvrr_stack+77200, dvrr_stack+124454);
 tmp = dvrr_stack + 1575868;
 target_ptr = Libderiv->deriv2_classes[8][8][79];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1577893, dvrr_stack+547563, dvrr_stack+102466);
 tmp = dvrr_stack + 1577893;
 target_ptr = Libderiv->deriv2_classes[8][9][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1580368, dvrr_stack+550533, dvrr_stack+77200);
 tmp = dvrr_stack + 1580368;
 target_ptr = Libderiv->deriv2_classes[8][10][79];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+550533, dvrr_stack+56086, dvrr_stack+170194);
 tmp = dvrr_stack + 550533;
 target_ptr = Libderiv->deriv2_classes[9][5][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+551688, dvrr_stack+61630, dvrr_stack+38692);
 tmp = dvrr_stack + 551688;
 target_ptr = Libderiv->deriv2_classes[9][6][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1583338, dvrr_stack+957294, dvrr_stack+56086);
 tmp = dvrr_stack + 1583338;
 target_ptr = Libderiv->deriv2_classes[9][7][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1585318, dvrr_stack+959769, dvrr_stack+61630);
 tmp = dvrr_stack + 1585318;
 target_ptr = Libderiv->deriv2_classes[9][8][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1587793, dvrr_stack+962794, dvrr_stack+957294);
 tmp = dvrr_stack + 1587793;
 target_ptr = Libderiv->deriv2_classes[9][9][79];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1590818, dvrr_stack+966424, dvrr_stack+959769);
 tmp = dvrr_stack + 1590818;
 target_ptr = Libderiv->deriv2_classes[9][10][79];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+966424, dvrr_stack+281024, dvrr_stack+697762);
 tmp = dvrr_stack + 966424;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+966865, dvrr_stack+24817, dvrr_stack+262301);
 tmp = dvrr_stack + 966865;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+967453, dvrr_stack+13315, dvrr_stack+281024);
 tmp = dvrr_stack + 967453;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+968209, dvrr_stack+177506, dvrr_stack+24817);
 tmp = dvrr_stack + 968209;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+969154, dvrr_stack+140888, dvrr_stack+13315);
 tmp = dvrr_stack + 969154;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+1594448, dvrr_stack+73924, dvrr_stack+177506);
 tmp = dvrr_stack + 1594448;
 target_ptr = Libderiv->deriv2_classes[5][10][78];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+170194, dvrr_stack+346424, dvrr_stack+405313);
 tmp = dvrr_stack + 170194;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+553228, dvrr_stack+128570, dvrr_stack+754468);
 tmp = dvrr_stack + 553228;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+734812, dvrr_stack+43207, dvrr_stack+346424);
 tmp = dvrr_stack + 734812;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+73521, dvrr_stack+97625, dvrr_stack+128570);
 tmp = dvrr_stack + 73521;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+1595834, dvrr_stack+970714, dvrr_stack+43207);
 tmp = dvrr_stack + 1595834;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+1597374, dvrr_stack+186274, dvrr_stack+97625);
 tmp = dvrr_stack + 1597374;
 target_ptr = Libderiv->deriv2_classes[6][10][78];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+404893, dvrr_stack+554043, dvrr_stack+796947);
 tmp = dvrr_stack + 404893;
 target_ptr = Libderiv->deriv2_classes[7][5][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+796681, dvrr_stack+212023, dvrr_stack+85858);
 tmp = dvrr_stack + 796681;
 target_ptr = Libderiv->deriv2_classes[7][6][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+186196, dvrr_stack+69885, dvrr_stack+554043);
 tmp = dvrr_stack + 186196;
 target_ptr = Libderiv->deriv2_classes[7][7][78];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+1599222, dvrr_stack+972562, dvrr_stack+212023);
 tmp = dvrr_stack + 1599222;
 target_ptr = Libderiv->deriv2_classes[7][8][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+1600842, dvrr_stack+974542, dvrr_stack+69885);
 tmp = dvrr_stack + 1600842;
 target_ptr = Libderiv->deriv2_classes[7][9][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+1602822, dvrr_stack+324710, dvrr_stack+972562);
 tmp = dvrr_stack + 1602822;
 target_ptr = Libderiv->deriv2_classes[7][10][78];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+187492, dvrr_stack+358985, dvrr_stack+807209);
 tmp = dvrr_stack + 187492;
 target_ptr = Libderiv->deriv2_classes[8][5][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+806789, dvrr_stack+976918, dvrr_stack+360245);
 tmp = dvrr_stack + 806789;
 target_ptr = Libderiv->deriv2_classes[8][6][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+324644, dvrr_stack+978538, dvrr_stack+358985);
 tmp = dvrr_stack + 324644;
 target_ptr = Libderiv->deriv2_classes[8][7][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+1605198, dvrr_stack+980563, dvrr_stack+976918);
 tmp = dvrr_stack + 1605198;
 target_ptr = Libderiv->deriv2_classes[8][8][78];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+1607223, dvrr_stack+983038, dvrr_stack+978538);
 tmp = dvrr_stack + 1607223;
 target_ptr = Libderiv->deriv2_classes[8][9][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+1609698, dvrr_stack+986008, dvrr_stack+980563);
 tmp = dvrr_stack + 1609698;
 target_ptr = Libderiv->deriv2_classes[8][10][78];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+986008, dvrr_stack+208687, dvrr_stack+207862);
 tmp = dvrr_stack + 986008;
 target_ptr = Libderiv->deriv2_classes[9][5][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+987163, dvrr_stack+989518, dvrr_stack+210227);
 tmp = dvrr_stack + 987163;
 target_ptr = Libderiv->deriv2_classes[9][6][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+1612668, dvrr_stack+991498, dvrr_stack+208687);
 tmp = dvrr_stack + 1612668;
 target_ptr = Libderiv->deriv2_classes[9][7][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+1614648, dvrr_stack+993973, dvrr_stack+989518);
 tmp = dvrr_stack + 1614648;
 target_ptr = Libderiv->deriv2_classes[9][8][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+1617123, dvrr_stack+996998, dvrr_stack+991498);
 tmp = dvrr_stack + 1617123;
 target_ptr = Libderiv->deriv2_classes[9][9][78];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+1620148, dvrr_stack+1000628, dvrr_stack+993973);
 tmp = dvrr_stack + 1620148;
 target_ptr = Libderiv->deriv2_classes[9][10][78];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1000628, dvrr_stack+798781, dvrr_stack+788463);
 tmp = dvrr_stack + 1000628;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1001069, dvrr_stack+797997, dvrr_stack+772000);
 tmp = dvrr_stack + 1001069;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1001657, dvrr_stack+799369, dvrr_stack+774040);
 tmp = dvrr_stack + 1001657;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1002413, dvrr_stack+800377, dvrr_stack+16402);
 tmp = dvrr_stack + 1002413;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1003358, dvrr_stack+801637, dvrr_stack+361190);
 tmp = dvrr_stack + 1003358;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1623778, dvrr_stack+803177, dvrr_stack+10462);
 tmp = dvrr_stack + 1623778;
 target_ptr = Libderiv->deriv2_classes[5][10][35];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+988703, dvrr_stack+808569, dvrr_stack+790626);
 tmp = dvrr_stack + 988703;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+305034, dvrr_stack+755080, dvrr_stack+790038);
 tmp = dvrr_stack + 305034;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+326264, dvrr_stack+756088, dvrr_stack+791067);
 tmp = dvrr_stack + 326264;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1625164, dvrr_stack+757384, dvrr_stack+791823);
 tmp = dvrr_stack + 1625164;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1626424, dvrr_stack+707170, dvrr_stack+792768);
 tmp = dvrr_stack + 1626424;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1627964, dvrr_stack+709150, dvrr_stack+793923);
 tmp = dvrr_stack + 1627964;
 target_ptr = Libderiv->deriv2_classes[6][10][35];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,21,dvrr_stack+191986, dvrr_stack+634571, dvrr_stack+798781);
 tmp = dvrr_stack + 191986;
 target_ptr = Libderiv->deriv2_classes[7][5][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,28,dvrr_stack+207676, dvrr_stack+674239, dvrr_stack+797997);
 tmp = dvrr_stack + 207676;
 target_ptr = Libderiv->deriv2_classes[7][6][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1629812, dvrr_stack+635516, dvrr_stack+799369);
 tmp = dvrr_stack + 1629812;
 target_ptr = Libderiv->deriv2_classes[7][7][35];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1631108, dvrr_stack+637136, dvrr_stack+800377);
 tmp = dvrr_stack + 1631108;
 target_ptr = Libderiv->deriv2_classes[7][8][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1632728, dvrr_stack+639161, dvrr_stack+801637);
 tmp = dvrr_stack + 1632728;
 target_ptr = Libderiv->deriv2_classes[7][9][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1634708, dvrr_stack+558806, dvrr_stack+803177);
 tmp = dvrr_stack + 1634708;
 target_ptr = Libderiv->deriv2_classes[7][10][35];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1637084, dvrr_stack+569301, dvrr_stack+808569);
 tmp = dvrr_stack + 1637084;
 target_ptr = Libderiv->deriv2_classes[8][5][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1638029, dvrr_stack+567761, dvrr_stack+755080);
 tmp = dvrr_stack + 1638029;
 target_ptr = Libderiv->deriv2_classes[8][6][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1639289, dvrr_stack+570456, dvrr_stack+756088);
 tmp = dvrr_stack + 1639289;
 target_ptr = Libderiv->deriv2_classes[8][7][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1640909, dvrr_stack+483768, dvrr_stack+757384);
 tmp = dvrr_stack + 1640909;
 target_ptr = Libderiv->deriv2_classes[8][8][35];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1642934, dvrr_stack+453153, dvrr_stack+707170);
 tmp = dvrr_stack + 1642934;
 target_ptr = Libderiv->deriv2_classes[8][9][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1645409, dvrr_stack+405748, dvrr_stack+709150);
 tmp = dvrr_stack + 1645409;
 target_ptr = Libderiv->deriv2_classes[8][10][35];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1648379, dvrr_stack+393021, dvrr_stack+634571);
 tmp = dvrr_stack + 1648379;
 target_ptr = Libderiv->deriv2_classes[9][5][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1649534, dvrr_stack+1033416, dvrr_stack+674239);
 tmp = dvrr_stack + 1649534;
 target_ptr = Libderiv->deriv2_classes[9][6][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1651074, dvrr_stack+1051212, dvrr_stack+635516);
 tmp = dvrr_stack + 1651074;
 target_ptr = Libderiv->deriv2_classes[9][7][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1653054, dvrr_stack+437428, dvrr_stack+637136);
 tmp = dvrr_stack + 1653054;
 target_ptr = Libderiv->deriv2_classes[9][8][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1655529, dvrr_stack+464628, dvrr_stack+639161);
 tmp = dvrr_stack + 1655529;
 target_ptr = Libderiv->deriv2_classes[9][9][35];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1658554, dvrr_stack+720370, dvrr_stack+558806);
 tmp = dvrr_stack + 1658554;
 target_ptr = Libderiv->deriv2_classes[9][10][35];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+334658, dvrr_stack+456178, dvrr_stack+182686);
 tmp = dvrr_stack + 334658;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+631286, dvrr_stack+377817, dvrr_stack+183001);
 tmp = dvrr_stack + 631286;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+613241, dvrr_stack+378601, dvrr_stack+183421);
 tmp = dvrr_stack + 613241;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1662184, dvrr_stack+379609, dvrr_stack+183961);
 tmp = dvrr_stack + 1662184;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1663129, dvrr_stack+380869, dvrr_stack+184636);
 tmp = dvrr_stack + 1663129;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1664284, dvrr_stack+382409, dvrr_stack+320420);
 tmp = dvrr_stack + 1664284;
 target_ptr = Libderiv->deriv2_classes[5][10][34];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+384257, dvrr_stack+345668, dvrr_stack+572436);
 tmp = dvrr_stack + 384257;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1665670, dvrr_stack+344660, dvrr_stack+614156);
 tmp = dvrr_stack + 1665670;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1666454, dvrr_stack+286496, dvrr_stack+486243);
 tmp = dvrr_stack + 1666454;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1667462, dvrr_stack+287792, dvrr_stack+486999);
 tmp = dvrr_stack + 1667462;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1668722, dvrr_stack+266917, dvrr_stack+428473);
 tmp = dvrr_stack + 1668722;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1670262, dvrr_stack+221148, dvrr_stack+429628);
 tmp = dvrr_stack + 1670262;
 target_ptr = Libderiv->deriv2_classes[6][10][34];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+774580, dvrr_stack+226332, dvrr_stack+456178);
 tmp = dvrr_stack + 774580;
 target_ptr = Libderiv->deriv2_classes[7][5][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1672110, dvrr_stack+251536, dvrr_stack+377817);
 tmp = dvrr_stack + 1672110;
 target_ptr = Libderiv->deriv2_classes[7][6][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1673118, dvrr_stack+227277, dvrr_stack+378601);
 tmp = dvrr_stack + 1673118;
 target_ptr = Libderiv->deriv2_classes[7][7][34];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1674414, dvrr_stack+228897, dvrr_stack+379609);
 tmp = dvrr_stack + 1674414;
 target_ptr = Libderiv->deriv2_classes[7][8][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1676034, dvrr_stack+199546, dvrr_stack+380869);
 tmp = dvrr_stack + 1676034;
 target_ptr = Libderiv->deriv2_classes[7][9][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1678014, dvrr_stack+106348, dvrr_stack+382409);
 tmp = dvrr_stack + 1678014;
 target_ptr = Libderiv->deriv2_classes[7][10][34];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1680390, dvrr_stack+202021, dvrr_stack+345668);
 tmp = dvrr_stack + 1680390;
 target_ptr = Libderiv->deriv2_classes[8][5][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1681335, dvrr_stack+175966, dvrr_stack+344660);
 tmp = dvrr_stack + 1681335;
 target_ptr = Libderiv->deriv2_classes[8][6][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1682595, dvrr_stack+83878, dvrr_stack+286496);
 tmp = dvrr_stack + 1682595;
 target_ptr = Libderiv->deriv2_classes[8][7][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1684215, dvrr_stack+943874, dvrr_stack+287792);
 tmp = dvrr_stack + 1684215;
 target_ptr = Libderiv->deriv2_classes[8][8][34];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1686240, dvrr_stack+946349, dvrr_stack+266917);
 tmp = dvrr_stack + 1686240;
 target_ptr = Libderiv->deriv2_classes[8][9][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1688715, dvrr_stack+949374, dvrr_stack+221148);
 tmp = dvrr_stack + 1688715;
 target_ptr = Libderiv->deriv2_classes[8][10][34];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1691685, dvrr_stack+321410, dvrr_stack+226332);
 tmp = dvrr_stack + 1691685;
 target_ptr = Libderiv->deriv2_classes[9][5][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1692840, dvrr_stack+322796, dvrr_stack+251536);
 tmp = dvrr_stack + 1692840;
 target_ptr = Libderiv->deriv2_classes[9][6][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1694380, dvrr_stack+499716, dvrr_stack+227277);
 tmp = dvrr_stack + 1694380;
 target_ptr = Libderiv->deriv2_classes[9][7][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1696360, dvrr_stack+724726, dvrr_stack+228897);
 tmp = dvrr_stack + 1696360;
 target_ptr = Libderiv->deriv2_classes[9][8][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1698835, dvrr_stack+727696, dvrr_stack+199546);
 tmp = dvrr_stack + 1698835;
 target_ptr = Libderiv->deriv2_classes[9][9][34];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1701860, dvrr_stack+1112372, dvrr_stack+106348);
 tmp = dvrr_stack + 1701860;
 target_ptr = Libderiv->deriv2_classes[9][10][34];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+225729, dvrr_stack+123866, dvrr_stack+185461);
 tmp = dvrr_stack + 225729;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+546894, dvrr_stack+28408, dvrr_stack+185776);
 tmp = dvrr_stack + 546894;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+376997, dvrr_stack+119438, dvrr_stack+769795);
 tmp = dvrr_stack + 376997;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1705490, dvrr_stack+134840, dvrr_stack+772420);
 tmp = dvrr_stack + 1705490;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1706435, dvrr_stack+148990, dvrr_stack+1004918);
 tmp = dvrr_stack + 1706435;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1707590, dvrr_stack+166726, dvrr_stack+1005743);
 tmp = dvrr_stack + 1707590;
 target_ptr = Libderiv->deriv2_classes[5][10][33];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+787273, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 787273;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+362015, dvrr_stack+753460, dvrr_stack+788778);
 tmp = dvrr_stack + 362015;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1708976, dvrr_stack+240160, dvrr_stack+7447);
 tmp = dvrr_stack + 1708976;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1709984, dvrr_stack+259141, dvrr_stack+23872);
 tmp = dvrr_stack + 1709984;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1711244, dvrr_stack+276776, dvrr_stack+37537);
 tmp = dvrr_stack + 1711244;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1712784, dvrr_stack+299900, dvrr_stack+54700);
 tmp = dvrr_stack + 1712784;
 target_ptr = Libderiv->deriv2_classes[6][10][33];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1714632, dvrr_stack+401968, dvrr_stack+123866);
 tmp = dvrr_stack + 1714632;
 target_ptr = Libderiv->deriv2_classes[7][5][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1715388, dvrr_stack+632546, dvrr_stack+28408);
 tmp = dvrr_stack + 1715388;
 target_ptr = Libderiv->deriv2_classes[7][6][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1716396, dvrr_stack+396073, dvrr_stack+119438);
 tmp = dvrr_stack + 1716396;
 target_ptr = Libderiv->deriv2_classes[7][7][33];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1717692, dvrr_stack+418753, dvrr_stack+134840);
 tmp = dvrr_stack + 1717692;
 target_ptr = Libderiv->deriv2_classes[7][8][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1719312, dvrr_stack+441003, dvrr_stack+148990);
 tmp = dvrr_stack + 1719312;
 target_ptr = Libderiv->deriv2_classes[7][9][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1721292, dvrr_stack+468918, dvrr_stack+166726);
 tmp = dvrr_stack + 1721292;
 target_ptr = Libderiv->deriv2_classes[7][10][33];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1723668, dvrr_stack+603266, dvrr_stack+120446);
 tmp = dvrr_stack + 1723668;
 target_ptr = Libderiv->deriv2_classes[8][5][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1724613, dvrr_stack+565286, dvrr_stack+753460);
 tmp = dvrr_stack + 1724613;
 target_ptr = Libderiv->deriv2_classes[8][6][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1725873, dvrr_stack+593141, dvrr_stack+240160);
 tmp = dvrr_stack + 1725873;
 target_ptr = Libderiv->deriv2_classes[8][7][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1727493, dvrr_stack+626606, dvrr_stack+259141);
 tmp = dvrr_stack + 1727493;
 target_ptr = Libderiv->deriv2_classes[8][8][33];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1729518, dvrr_stack+656581, dvrr_stack+276776);
 tmp = dvrr_stack + 1729518;
 target_ptr = Libderiv->deriv2_classes[8][9][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1731993, dvrr_stack+689020, dvrr_stack+299900);
 tmp = dvrr_stack + 1731993;
 target_ptr = Libderiv->deriv2_classes[8][10][33];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1734963, dvrr_stack+1006733, dvrr_stack+401968);
 tmp = dvrr_stack + 1734963;
 target_ptr = Libderiv->deriv2_classes[9][5][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1736118, dvrr_stack+1018422, dvrr_stack+632546);
 tmp = dvrr_stack + 1736118;
 target_ptr = Libderiv->deriv2_classes[9][6][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1737658, dvrr_stack+1027872, dvrr_stack+396073);
 tmp = dvrr_stack + 1737658;
 target_ptr = Libderiv->deriv2_classes[9][7][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1739638, dvrr_stack+1044084, dvrr_stack+418753);
 tmp = dvrr_stack + 1739638;
 target_ptr = Libderiv->deriv2_classes[9][8][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1742113, dvrr_stack+1064918, dvrr_stack+441003);
 tmp = dvrr_stack + 1742113;
 target_ptr = Libderiv->deriv2_classes[9][9][33];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1745138, dvrr_stack+1088414, dvrr_stack+468918);
 tmp = dvrr_stack + 1745138;
 target_ptr = Libderiv->deriv2_classes[9][10][33];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+487944, dvrr_stack+783976, dvrr_stack+1092770);
 tmp = dvrr_stack + 487944;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1748768, dvrr_stack+783192, dvrr_stack+1093085);
 tmp = dvrr_stack + 1748768;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+99165, dvrr_stack+784564, dvrr_stack+1093505);
 tmp = dvrr_stack + 99165;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1749356, dvrr_stack+785572, dvrr_stack+1094045);
 tmp = dvrr_stack + 1749356;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1750301, dvrr_stack+735970, dvrr_stack+1094720);
 tmp = dvrr_stack + 1750301;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1751456, dvrr_stack+737510, dvrr_stack+1095545);
 tmp = dvrr_stack + 1751456;
 target_ptr = Libderiv->deriv2_classes[5][10][32];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1752842, dvrr_stack+692650, dvrr_stack+776045);
 tmp = dvrr_stack + 1752842;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1753430, dvrr_stack+741542, dvrr_stack+775457);
 tmp = dvrr_stack + 1753430;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1754214, dvrr_stack+693406, dvrr_stack+776486);
 tmp = dvrr_stack + 1754214;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1755222, dvrr_stack+694702, dvrr_stack+777242);
 tmp = dvrr_stack + 1755222;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1756482, dvrr_stack+659606, dvrr_stack+778187);
 tmp = dvrr_stack + 1756482;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1758022, dvrr_stack+661586, dvrr_stack+779342);
 tmp = dvrr_stack + 1758022;
 target_ptr = Libderiv->deriv2_classes[6][10][32];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+74781, dvrr_stack+604421, dvrr_stack+783976);
 tmp = dvrr_stack + 74781;
 target_ptr = Libderiv->deriv2_classes[7][5][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1759870, dvrr_stack+595121, dvrr_stack+783192);
 tmp = dvrr_stack + 1759870;
 target_ptr = Libderiv->deriv2_classes[7][6][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1760878, dvrr_stack+605366, dvrr_stack+784564);
 tmp = dvrr_stack + 1760878;
 target_ptr = Libderiv->deriv2_classes[7][7][32];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1762174, dvrr_stack+507951, dvrr_stack+785572);
 tmp = dvrr_stack + 1762174;
 target_ptr = Libderiv->deriv2_classes[7][8][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1763794, dvrr_stack+509976, dvrr_stack+735970);
 tmp = dvrr_stack + 1763794;
 target_ptr = Libderiv->deriv2_classes[7][9][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1765774, dvrr_stack+471888, dvrr_stack+737510);
 tmp = dvrr_stack + 1765774;
 target_ptr = Libderiv->deriv2_classes[7][10][32];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1768150, dvrr_stack+474858, dvrr_stack+692650);
 tmp = dvrr_stack + 1768150;
 target_ptr = Libderiv->deriv2_classes[8][5][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1769095, dvrr_stack+420778, dvrr_stack+741542);
 tmp = dvrr_stack + 1769095;
 target_ptr = Libderiv->deriv2_classes[8][6][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1770355, dvrr_stack+402913, dvrr_stack+693406);
 tmp = dvrr_stack + 1770355;
 target_ptr = Libderiv->deriv2_classes[8][7][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1771975, dvrr_stack+362943, dvrr_stack+694702);
 tmp = dvrr_stack + 1771975;
 target_ptr = Libderiv->deriv2_classes[8][8][32];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1774000, dvrr_stack+365418, dvrr_stack+659606);
 tmp = dvrr_stack + 1774000;
 target_ptr = Libderiv->deriv2_classes[8][9][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1776475, dvrr_stack+331028, dvrr_stack+661586);
 tmp = dvrr_stack + 1776475;
 target_ptr = Libderiv->deriv2_classes[8][10][32];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1779445, dvrr_stack+759004, dvrr_stack+604421);
 tmp = dvrr_stack + 1779445;
 target_ptr = Libderiv->deriv2_classes[9][5][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1780600, dvrr_stack+1098481, dvrr_stack+595121);
 tmp = dvrr_stack + 1780600;
 target_ptr = Libderiv->deriv2_classes[9][6][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1782140, dvrr_stack+1100329, dvrr_stack+605366);
 tmp = dvrr_stack + 1782140;
 target_ptr = Libderiv->deriv2_classes[9][7][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1784120, dvrr_stack+1102705, dvrr_stack+507951);
 tmp = dvrr_stack + 1784120;
 target_ptr = Libderiv->deriv2_classes[9][8][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1786595, dvrr_stack+1105675, dvrr_stack+509976);
 tmp = dvrr_stack + 1786595;
 target_ptr = Libderiv->deriv2_classes[9][9][32];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1789620, dvrr_stack+1068548, dvrr_stack+471888);
 tmp = dvrr_stack + 1789620;
 target_ptr = Libderiv->deriv2_classes[9][10][32];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+808049, dvrr_stack+633806, dvrr_stack+612506);
 tmp = dvrr_stack + 808049;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+673548, dvrr_stack+369598, dvrr_stack+612821);
 tmp = dvrr_stack + 673548;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1793250, dvrr_stack+278756, dvrr_stack+1096535);
 tmp = dvrr_stack + 1793250;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1794006, dvrr_stack+279764, dvrr_stack+1109305);
 tmp = dvrr_stack + 1794006;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1794951, dvrr_stack+260761, dvrr_stack+1109980);
 tmp = dvrr_stack + 1794951;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1796106, dvrr_stack+245488, dvrr_stack+1110805);
 tmp = dvrr_stack + 1796106;
 target_ptr = Libderiv->deriv2_classes[5][10][31];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1797492, dvrr_stack+241456, dvrr_stack+422318);
 tmp = dvrr_stack + 1797492;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1798080, dvrr_stack+247336, dvrr_stack+566826);
 tmp = dvrr_stack + 1798080;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1798864, dvrr_stack+219426, dvrr_stack+422759);
 tmp = dvrr_stack + 1798864;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1799872, dvrr_stack+168574, dvrr_stack+397693);
 tmp = dvrr_stack + 1799872;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1801132, dvrr_stack+150530, dvrr_stack+368443);
 tmp = dvrr_stack + 1801132;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1802672, dvrr_stack+100090, dvrr_stack+302276);
 tmp = dvrr_stack + 1802672;
 target_ptr = Libderiv->deriv2_classes[6][10][31];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1804520, dvrr_stack+192826, dvrr_stack+633806);
 tmp = dvrr_stack + 1804520;
 target_ptr = Libderiv->deriv2_classes[7][5][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1805276, dvrr_stack+136100, dvrr_stack+369598);
 tmp = dvrr_stack + 1805276;
 target_ptr = Libderiv->deriv2_classes[7][6][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1806284, dvrr_stack+124454, dvrr_stack+278756);
 tmp = dvrr_stack + 1806284;
 target_ptr = Libderiv->deriv2_classes[7][7][31];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1807580, dvrr_stack+102466, dvrr_stack+279764);
 tmp = dvrr_stack + 1807580;
 target_ptr = Libderiv->deriv2_classes[7][8][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1809200, dvrr_stack+77200, dvrr_stack+260761);
 tmp = dvrr_stack + 1809200;
 target_ptr = Libderiv->deriv2_classes[7][9][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1811180, dvrr_stack+547563, dvrr_stack+245488);
 tmp = dvrr_stack + 1811180;
 target_ptr = Libderiv->deriv2_classes[7][10][31];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1813556, dvrr_stack+38692, dvrr_stack+241456);
 tmp = dvrr_stack + 1813556;
 target_ptr = Libderiv->deriv2_classes[8][5][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1814501, dvrr_stack+56086, dvrr_stack+247336);
 tmp = dvrr_stack + 1814501;
 target_ptr = Libderiv->deriv2_classes[8][6][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1815761, dvrr_stack+61630, dvrr_stack+219426);
 tmp = dvrr_stack + 1815761;
 target_ptr = Libderiv->deriv2_classes[8][7][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1817381, dvrr_stack+957294, dvrr_stack+168574);
 tmp = dvrr_stack + 1817381;
 target_ptr = Libderiv->deriv2_classes[8][8][31];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1819406, dvrr_stack+959769, dvrr_stack+150530);
 tmp = dvrr_stack + 1819406;
 target_ptr = Libderiv->deriv2_classes[8][9][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1821881, dvrr_stack+962794, dvrr_stack+100090);
 tmp = dvrr_stack + 1821881;
 target_ptr = Libderiv->deriv2_classes[8][10][31];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1824851, dvrr_stack+1047054, dvrr_stack+192826);
 tmp = dvrr_stack + 1824851;
 target_ptr = Libderiv->deriv2_classes[9][5][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1826006, dvrr_stack+1048440, dvrr_stack+136100);
 tmp = dvrr_stack + 1826006;
 target_ptr = Libderiv->deriv2_classes[9][6][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1827546, dvrr_stack+1030248, dvrr_stack+124454);
 tmp = dvrr_stack + 1827546;
 target_ptr = Libderiv->deriv2_classes[9][7][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1829526, dvrr_stack+1008119, dvrr_stack+102466);
 tmp = dvrr_stack + 1829526;
 target_ptr = Libderiv->deriv2_classes[9][8][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1832001, dvrr_stack+1116728, dvrr_stack+77200);
 tmp = dvrr_stack + 1832001;
 target_ptr = Libderiv->deriv2_classes[9][9][31];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1835026, dvrr_stack+1120358, dvrr_stack+547563);
 tmp = dvrr_stack + 1835026;
 target_ptr = Libderiv->deriv2_classes[9][10][31];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1838656, dvrr_stack+754468, dvrr_stack+1097075);
 tmp = dvrr_stack + 1838656;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1839097, dvrr_stack+346424, dvrr_stack+1111795);
 tmp = dvrr_stack + 1839097;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1839685, dvrr_stack+128570, dvrr_stack+1072904);
 tmp = dvrr_stack + 1839685;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1840441, dvrr_stack+43207, dvrr_stack+1050288);
 tmp = dvrr_stack + 1840441;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1841386, dvrr_stack+97625, dvrr_stack+1020270);
 tmp = dvrr_stack + 1841386;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1842541, dvrr_stack+970714, dvrr_stack+1021095);
 tmp = dvrr_stack + 1842541;
 target_ptr = Libderiv->deriv2_classes[5][10][30];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1843927, dvrr_stack+85858, dvrr_stack+262301);
 tmp = dvrr_stack + 1843927;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1844515, dvrr_stack+554043, dvrr_stack+281024);
 tmp = dvrr_stack + 1844515;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1845299, dvrr_stack+212023, dvrr_stack+24817);
 tmp = dvrr_stack + 1845299;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1846307, dvrr_stack+69885, dvrr_stack+13315);
 tmp = dvrr_stack + 1846307;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1847567, dvrr_stack+972562, dvrr_stack+177506);
 tmp = dvrr_stack + 1847567;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1849107, dvrr_stack+974542, dvrr_stack+140888);
 tmp = dvrr_stack + 1849107;
 target_ptr = Libderiv->deriv2_classes[6][10][30];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1850955, dvrr_stack+360245, dvrr_stack+754468);
 tmp = dvrr_stack + 1850955;
 target_ptr = Libderiv->deriv2_classes[7][5][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1851711, dvrr_stack+358985, dvrr_stack+346424);
 tmp = dvrr_stack + 1851711;
 target_ptr = Libderiv->deriv2_classes[7][6][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1852719, dvrr_stack+976918, dvrr_stack+128570);
 tmp = dvrr_stack + 1852719;
 target_ptr = Libderiv->deriv2_classes[7][7][30];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1854015, dvrr_stack+978538, dvrr_stack+43207);
 tmp = dvrr_stack + 1854015;
 target_ptr = Libderiv->deriv2_classes[7][8][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1855635, dvrr_stack+980563, dvrr_stack+97625);
 tmp = dvrr_stack + 1855635;
 target_ptr = Libderiv->deriv2_classes[7][9][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1857615, dvrr_stack+983038, dvrr_stack+970714);
 tmp = dvrr_stack + 1857615;
 target_ptr = Libderiv->deriv2_classes[7][10][30];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1859991, dvrr_stack+210227, dvrr_stack+85858);
 tmp = dvrr_stack + 1859991;
 target_ptr = Libderiv->deriv2_classes[8][5][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1860936, dvrr_stack+208687, dvrr_stack+554043);
 tmp = dvrr_stack + 1860936;
 target_ptr = Libderiv->deriv2_classes[8][6][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1862196, dvrr_stack+989518, dvrr_stack+212023);
 tmp = dvrr_stack + 1862196;
 target_ptr = Libderiv->deriv2_classes[8][7][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1863816, dvrr_stack+991498, dvrr_stack+69885);
 tmp = dvrr_stack + 1863816;
 target_ptr = Libderiv->deriv2_classes[8][8][30];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1865841, dvrr_stack+993973, dvrr_stack+972562);
 tmp = dvrr_stack + 1865841;
 target_ptr = Libderiv->deriv2_classes[8][9][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1868316, dvrr_stack+996998, dvrr_stack+974542);
 tmp = dvrr_stack + 1868316;
 target_ptr = Libderiv->deriv2_classes[8][10][30];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1871286, dvrr_stack+770335, dvrr_stack+360245);
 tmp = dvrr_stack + 1871286;
 target_ptr = Libderiv->deriv2_classes[9][5][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1872441, dvrr_stack+1124714, dvrr_stack+358985);
 tmp = dvrr_stack + 1872441;
 target_ptr = Libderiv->deriv2_classes[9][6][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1873981, dvrr_stack+1126562, dvrr_stack+976918);
 tmp = dvrr_stack + 1873981;
 target_ptr = Libderiv->deriv2_classes[9][7][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1875961, dvrr_stack+1128938, dvrr_stack+978538);
 tmp = dvrr_stack + 1875961;
 target_ptr = Libderiv->deriv2_classes[9][8][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1878436, dvrr_stack+1131908, dvrr_stack+980563);
 tmp = dvrr_stack + 1878436;
 target_ptr = Libderiv->deriv2_classes[9][9][30];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1881461, dvrr_stack+1135538, dvrr_stack+983038);
 tmp = dvrr_stack + 1881461;
 target_ptr = Libderiv->deriv2_classes[9][10][30];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+697519, dvrr_stack+494883, dvrr_stack+494568);
 tmp = dvrr_stack + 697519;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1885091, dvrr_stack+495891, dvrr_stack+495471);
 tmp = dvrr_stack + 1885091;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1885679, dvrr_stack+497215, dvrr_stack+496675);
 tmp = dvrr_stack + 1885679;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1886435, dvrr_stack+1011089, dvrr_stack+498223);
 tmp = dvrr_stack + 1886435;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1887380, dvrr_stack+1139894, dvrr_stack+1097390);
 tmp = dvrr_stack + 1887380;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+1888535, dvrr_stack+1141434, dvrr_stack+502092);
 tmp = dvrr_stack + 1888535;
 target_ptr = Libderiv->deriv2_classes[5][10][26];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1889921, dvrr_stack+1032624, dvrr_stack+498898);
 tmp = dvrr_stack + 1889921;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1890509, dvrr_stack+72513, dvrr_stack+773095);
 tmp = dvrr_stack + 1890509;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1891293, dvrr_stack+1143282, dvrr_stack+33852);
 tmp = dvrr_stack + 1891293;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1892301, dvrr_stack+1144578, dvrr_stack+32329);
 tmp = dvrr_stack + 1892301;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1893561, dvrr_stack+1147353, dvrr_stack+1146198);
 tmp = dvrr_stack + 1893561;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+1895101, dvrr_stack+1150719, dvrr_stack+1149333);
 tmp = dvrr_stack + 1895101;
 target_ptr = Libderiv->deriv2_classes[6][10][26];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1896949, dvrr_stack+1153095, dvrr_stack+494883);
 tmp = dvrr_stack + 1896949;
 target_ptr = Libderiv->deriv2_classes[7][5][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1897705, dvrr_stack+1154040, dvrr_stack+495891);
 tmp = dvrr_stack + 1897705;
 target_ptr = Libderiv->deriv2_classes[7][6][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1898713, dvrr_stack+1155300, dvrr_stack+497215);
 tmp = dvrr_stack + 1898713;
 target_ptr = Libderiv->deriv2_classes[7][7][26];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1900009, dvrr_stack+1156920, dvrr_stack+1011089);
 tmp = dvrr_stack + 1900009;
 target_ptr = Libderiv->deriv2_classes[7][8][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1901629, dvrr_stack+1158945, dvrr_stack+1139894);
 tmp = dvrr_stack + 1901629;
 target_ptr = Libderiv->deriv2_classes[7][9][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+1903609, dvrr_stack+1161420, dvrr_stack+1141434);
 tmp = dvrr_stack + 1903609;
 target_ptr = Libderiv->deriv2_classes[7][10][26];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1905985, dvrr_stack+1164390, dvrr_stack+1032624);
 tmp = dvrr_stack + 1905985;
 target_ptr = Libderiv->deriv2_classes[8][5][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1906930, dvrr_stack+1165545, dvrr_stack+72513);
 tmp = dvrr_stack + 1906930;
 target_ptr = Libderiv->deriv2_classes[8][6][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1908190, dvrr_stack+1167085, dvrr_stack+1143282);
 tmp = dvrr_stack + 1908190;
 target_ptr = Libderiv->deriv2_classes[8][7][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1909810, dvrr_stack+1169065, dvrr_stack+1144578);
 tmp = dvrr_stack + 1909810;
 target_ptr = Libderiv->deriv2_classes[8][8][26];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1911835, dvrr_stack+1171540, dvrr_stack+1147353);
 tmp = dvrr_stack + 1911835;
 target_ptr = Libderiv->deriv2_classes[8][9][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+1914310, dvrr_stack+1174565, dvrr_stack+1150719);
 tmp = dvrr_stack + 1914310;
 target_ptr = Libderiv->deriv2_classes[8][10][26];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+1917280, dvrr_stack+90584, dvrr_stack+1153095);
 tmp = dvrr_stack + 1917280;
 target_ptr = Libderiv->deriv2_classes[9][5][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+1918435, dvrr_stack+1013774, dvrr_stack+1154040);
 tmp = dvrr_stack + 1918435;
 target_ptr = Libderiv->deriv2_classes[9][6][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+1919975, dvrr_stack+582071, dvrr_stack+1155300);
 tmp = dvrr_stack + 1919975;
 target_ptr = Libderiv->deriv2_classes[9][7][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+1921955, dvrr_stack+1178195, dvrr_stack+1156920);
 tmp = dvrr_stack + 1921955;
 target_ptr = Libderiv->deriv2_classes[9][8][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+1924430, dvrr_stack+1035264, dvrr_stack+1158945);
 tmp = dvrr_stack + 1924430;
 target_ptr = Libderiv->deriv2_classes[9][9][26];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+1927455, dvrr_stack+1053588, dvrr_stack+1161420);
 tmp = dvrr_stack + 1927455;
 target_ptr = Libderiv->deriv2_classes[9][10][26];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+218968, dvrr_stack+798781, dvrr_stack+788463);
 tmp = dvrr_stack + 218968;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+1931085, dvrr_stack+797997, dvrr_stack+772000);
 tmp = dvrr_stack + 1931085;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+1931673, dvrr_stack+799369, dvrr_stack+774040);
 tmp = dvrr_stack + 1931673;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+1932429, dvrr_stack+800377, dvrr_stack+16402);
 tmp = dvrr_stack + 1932429;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+1933374, dvrr_stack+801637, dvrr_stack+361190);
 tmp = dvrr_stack + 1933374;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,66,dvrr_stack+1934529, dvrr_stack+803177, dvrr_stack+10462);
 tmp = dvrr_stack + 1934529;
 target_ptr = Libderiv->deriv2_classes[5][10][23];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+1935915, dvrr_stack+808569, dvrr_stack+790626);
 tmp = dvrr_stack + 1935915;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+1936503, dvrr_stack+755080, dvrr_stack+790038);
 tmp = dvrr_stack + 1936503;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+1937287, dvrr_stack+756088, dvrr_stack+791067);
 tmp = dvrr_stack + 1937287;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+1938295, dvrr_stack+757384, dvrr_stack+791823);
 tmp = dvrr_stack + 1938295;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+1939555, dvrr_stack+707170, dvrr_stack+792768);
 tmp = dvrr_stack + 1939555;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,66,dvrr_stack+1941095, dvrr_stack+709150, dvrr_stack+793923);
 tmp = dvrr_stack + 1941095;
 target_ptr = Libderiv->deriv2_classes[6][10][23];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,21,dvrr_stack+1942943, dvrr_stack+634571, dvrr_stack+798781);
 tmp = dvrr_stack + 1942943;
 target_ptr = Libderiv->deriv2_classes[7][5][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,28,dvrr_stack+1943699, dvrr_stack+674239, dvrr_stack+797997);
 tmp = dvrr_stack + 1943699;
 target_ptr = Libderiv->deriv2_classes[7][6][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,36,dvrr_stack+1944707, dvrr_stack+635516, dvrr_stack+799369);
 tmp = dvrr_stack + 1944707;
 target_ptr = Libderiv->deriv2_classes[7][7][23];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,45,dvrr_stack+1946003, dvrr_stack+637136, dvrr_stack+800377);
 tmp = dvrr_stack + 1946003;
 target_ptr = Libderiv->deriv2_classes[7][8][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,55,dvrr_stack+1947623, dvrr_stack+639161, dvrr_stack+801637);
 tmp = dvrr_stack + 1947623;
 target_ptr = Libderiv->deriv2_classes[7][9][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,66,dvrr_stack+1949603, dvrr_stack+558806, dvrr_stack+803177);
 tmp = dvrr_stack + 1949603;
 target_ptr = Libderiv->deriv2_classes[7][10][23];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,21,dvrr_stack+1951979, dvrr_stack+569301, dvrr_stack+808569);
 tmp = dvrr_stack + 1951979;
 target_ptr = Libderiv->deriv2_classes[8][5][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,28,dvrr_stack+1952924, dvrr_stack+567761, dvrr_stack+755080);
 tmp = dvrr_stack + 1952924;
 target_ptr = Libderiv->deriv2_classes[8][6][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,36,dvrr_stack+1954184, dvrr_stack+570456, dvrr_stack+756088);
 tmp = dvrr_stack + 1954184;
 target_ptr = Libderiv->deriv2_classes[8][7][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,45,dvrr_stack+1955804, dvrr_stack+483768, dvrr_stack+757384);
 tmp = dvrr_stack + 1955804;
 target_ptr = Libderiv->deriv2_classes[8][8][23];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,55,dvrr_stack+1957829, dvrr_stack+453153, dvrr_stack+707170);
 tmp = dvrr_stack + 1957829;
 target_ptr = Libderiv->deriv2_classes[8][9][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,66,dvrr_stack+1960304, dvrr_stack+405748, dvrr_stack+709150);
 tmp = dvrr_stack + 1960304;
 target_ptr = Libderiv->deriv2_classes[8][10][23];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,21,dvrr_stack+1963274, dvrr_stack+393021, dvrr_stack+634571);
 tmp = dvrr_stack + 1963274;
 target_ptr = Libderiv->deriv2_classes[9][5][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,28,dvrr_stack+1964429, dvrr_stack+1033416, dvrr_stack+674239);
 tmp = dvrr_stack + 1964429;
 target_ptr = Libderiv->deriv2_classes[9][6][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,36,dvrr_stack+1965969, dvrr_stack+1051212, dvrr_stack+635516);
 tmp = dvrr_stack + 1965969;
 target_ptr = Libderiv->deriv2_classes[9][7][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,45,dvrr_stack+1967949, dvrr_stack+437428, dvrr_stack+637136);
 tmp = dvrr_stack + 1967949;
 target_ptr = Libderiv->deriv2_classes[9][8][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,55,dvrr_stack+1970424, dvrr_stack+464628, dvrr_stack+639161);
 tmp = dvrr_stack + 1970424;
 target_ptr = Libderiv->deriv2_classes[9][9][23];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_m(Data,66,dvrr_stack+1973449, dvrr_stack+720370, dvrr_stack+558806);
 tmp = dvrr_stack + 1973449;
 target_ptr = Libderiv->deriv2_classes[9][10][23];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+33274, dvrr_stack+456178, dvrr_stack+182686);
 tmp = dvrr_stack + 33274;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1977079, dvrr_stack+377817, dvrr_stack+183001);
 tmp = dvrr_stack + 1977079;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1977667, dvrr_stack+378601, dvrr_stack+183421);
 tmp = dvrr_stack + 1977667;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1978423, dvrr_stack+379609, dvrr_stack+183961);
 tmp = dvrr_stack + 1978423;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1979368, dvrr_stack+380869, dvrr_stack+184636);
 tmp = dvrr_stack + 1979368;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+1980523, dvrr_stack+382409, dvrr_stack+320420);
 tmp = dvrr_stack + 1980523;
 target_ptr = Libderiv->deriv2_classes[5][10][22];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1981909, dvrr_stack+345668, dvrr_stack+572436);
 tmp = dvrr_stack + 1981909;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1982497, dvrr_stack+344660, dvrr_stack+614156);
 tmp = dvrr_stack + 1982497;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1983281, dvrr_stack+286496, dvrr_stack+486243);
 tmp = dvrr_stack + 1983281;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1984289, dvrr_stack+287792, dvrr_stack+486999);
 tmp = dvrr_stack + 1984289;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1985549, dvrr_stack+266917, dvrr_stack+428473);
 tmp = dvrr_stack + 1985549;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+1987089, dvrr_stack+221148, dvrr_stack+429628);
 tmp = dvrr_stack + 1987089;
 target_ptr = Libderiv->deriv2_classes[6][10][22];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1988937, dvrr_stack+226332, dvrr_stack+456178);
 tmp = dvrr_stack + 1988937;
 target_ptr = Libderiv->deriv2_classes[7][5][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1989693, dvrr_stack+251536, dvrr_stack+377817);
 tmp = dvrr_stack + 1989693;
 target_ptr = Libderiv->deriv2_classes[7][6][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1990701, dvrr_stack+227277, dvrr_stack+378601);
 tmp = dvrr_stack + 1990701;
 target_ptr = Libderiv->deriv2_classes[7][7][22];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1991997, dvrr_stack+228897, dvrr_stack+379609);
 tmp = dvrr_stack + 1991997;
 target_ptr = Libderiv->deriv2_classes[7][8][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1993617, dvrr_stack+199546, dvrr_stack+380869);
 tmp = dvrr_stack + 1993617;
 target_ptr = Libderiv->deriv2_classes[7][9][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+1995597, dvrr_stack+106348, dvrr_stack+382409);
 tmp = dvrr_stack + 1995597;
 target_ptr = Libderiv->deriv2_classes[7][10][22];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1997973, dvrr_stack+202021, dvrr_stack+345668);
 tmp = dvrr_stack + 1997973;
 target_ptr = Libderiv->deriv2_classes[8][5][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1998918, dvrr_stack+175966, dvrr_stack+344660);
 tmp = dvrr_stack + 1998918;
 target_ptr = Libderiv->deriv2_classes[8][6][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2000178, dvrr_stack+83878, dvrr_stack+286496);
 tmp = dvrr_stack + 2000178;
 target_ptr = Libderiv->deriv2_classes[8][7][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2001798, dvrr_stack+943874, dvrr_stack+287792);
 tmp = dvrr_stack + 2001798;
 target_ptr = Libderiv->deriv2_classes[8][8][22];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2003823, dvrr_stack+946349, dvrr_stack+266917);
 tmp = dvrr_stack + 2003823;
 target_ptr = Libderiv->deriv2_classes[8][9][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2006298, dvrr_stack+949374, dvrr_stack+221148);
 tmp = dvrr_stack + 2006298;
 target_ptr = Libderiv->deriv2_classes[8][10][22];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2009268, dvrr_stack+321410, dvrr_stack+226332);
 tmp = dvrr_stack + 2009268;
 target_ptr = Libderiv->deriv2_classes[9][5][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2010423, dvrr_stack+322796, dvrr_stack+251536);
 tmp = dvrr_stack + 2010423;
 target_ptr = Libderiv->deriv2_classes[9][6][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2011963, dvrr_stack+499716, dvrr_stack+227277);
 tmp = dvrr_stack + 2011963;
 target_ptr = Libderiv->deriv2_classes[9][7][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2013943, dvrr_stack+724726, dvrr_stack+228897);
 tmp = dvrr_stack + 2013943;
 target_ptr = Libderiv->deriv2_classes[9][8][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2016418, dvrr_stack+727696, dvrr_stack+199546);
 tmp = dvrr_stack + 2016418;
 target_ptr = Libderiv->deriv2_classes[9][9][22];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2019443, dvrr_stack+1112372, dvrr_stack+106348);
 tmp = dvrr_stack + 2019443;
 target_ptr = Libderiv->deriv2_classes[9][10][22];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+31796, dvrr_stack+123866, dvrr_stack+185461);
 tmp = dvrr_stack + 31796;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2023073, dvrr_stack+28408, dvrr_stack+185776);
 tmp = dvrr_stack + 2023073;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2023661, dvrr_stack+119438, dvrr_stack+769795);
 tmp = dvrr_stack + 2023661;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2024417, dvrr_stack+134840, dvrr_stack+772420);
 tmp = dvrr_stack + 2024417;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2025362, dvrr_stack+148990, dvrr_stack+1004918);
 tmp = dvrr_stack + 2025362;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2026517, dvrr_stack+166726, dvrr_stack+1005743);
 tmp = dvrr_stack + 2026517;
 target_ptr = Libderiv->deriv2_classes[5][10][21];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2027903, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 2027903;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2028491, dvrr_stack+753460, dvrr_stack+788778);
 tmp = dvrr_stack + 2028491;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2029275, dvrr_stack+240160, dvrr_stack+7447);
 tmp = dvrr_stack + 2029275;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2030283, dvrr_stack+259141, dvrr_stack+23872);
 tmp = dvrr_stack + 2030283;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2031543, dvrr_stack+276776, dvrr_stack+37537);
 tmp = dvrr_stack + 2031543;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2033083, dvrr_stack+299900, dvrr_stack+54700);
 tmp = dvrr_stack + 2033083;
 target_ptr = Libderiv->deriv2_classes[6][10][21];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2034931, dvrr_stack+401968, dvrr_stack+123866);
 tmp = dvrr_stack + 2034931;
 target_ptr = Libderiv->deriv2_classes[7][5][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2035687, dvrr_stack+632546, dvrr_stack+28408);
 tmp = dvrr_stack + 2035687;
 target_ptr = Libderiv->deriv2_classes[7][6][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2036695, dvrr_stack+396073, dvrr_stack+119438);
 tmp = dvrr_stack + 2036695;
 target_ptr = Libderiv->deriv2_classes[7][7][21];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2037991, dvrr_stack+418753, dvrr_stack+134840);
 tmp = dvrr_stack + 2037991;
 target_ptr = Libderiv->deriv2_classes[7][8][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2039611, dvrr_stack+441003, dvrr_stack+148990);
 tmp = dvrr_stack + 2039611;
 target_ptr = Libderiv->deriv2_classes[7][9][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2041591, dvrr_stack+468918, dvrr_stack+166726);
 tmp = dvrr_stack + 2041591;
 target_ptr = Libderiv->deriv2_classes[7][10][21];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2043967, dvrr_stack+603266, dvrr_stack+120446);
 tmp = dvrr_stack + 2043967;
 target_ptr = Libderiv->deriv2_classes[8][5][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2044912, dvrr_stack+565286, dvrr_stack+753460);
 tmp = dvrr_stack + 2044912;
 target_ptr = Libderiv->deriv2_classes[8][6][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2046172, dvrr_stack+593141, dvrr_stack+240160);
 tmp = dvrr_stack + 2046172;
 target_ptr = Libderiv->deriv2_classes[8][7][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2047792, dvrr_stack+626606, dvrr_stack+259141);
 tmp = dvrr_stack + 2047792;
 target_ptr = Libderiv->deriv2_classes[8][8][21];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2049817, dvrr_stack+656581, dvrr_stack+276776);
 tmp = dvrr_stack + 2049817;
 target_ptr = Libderiv->deriv2_classes[8][9][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2052292, dvrr_stack+689020, dvrr_stack+299900);
 tmp = dvrr_stack + 2052292;
 target_ptr = Libderiv->deriv2_classes[8][10][21];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2055262, dvrr_stack+1006733, dvrr_stack+401968);
 tmp = dvrr_stack + 2055262;
 target_ptr = Libderiv->deriv2_classes[9][5][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2056417, dvrr_stack+1018422, dvrr_stack+632546);
 tmp = dvrr_stack + 2056417;
 target_ptr = Libderiv->deriv2_classes[9][6][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2057957, dvrr_stack+1027872, dvrr_stack+396073);
 tmp = dvrr_stack + 2057957;
 target_ptr = Libderiv->deriv2_classes[9][7][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2059937, dvrr_stack+1044084, dvrr_stack+418753);
 tmp = dvrr_stack + 2059937;
 target_ptr = Libderiv->deriv2_classes[9][8][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2062412, dvrr_stack+1064918, dvrr_stack+441003);
 tmp = dvrr_stack + 2062412;
 target_ptr = Libderiv->deriv2_classes[9][9][21];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2065437, dvrr_stack+1088414, dvrr_stack+468918);
 tmp = dvrr_stack + 2065437;
 target_ptr = Libderiv->deriv2_classes[9][10][21];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+581502, dvrr_stack+783976, dvrr_stack+1092770);
 tmp = dvrr_stack + 581502;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2069067, dvrr_stack+783192, dvrr_stack+1093085);
 tmp = dvrr_stack + 2069067;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2069655, dvrr_stack+784564, dvrr_stack+1093505);
 tmp = dvrr_stack + 2069655;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2070411, dvrr_stack+785572, dvrr_stack+1094045);
 tmp = dvrr_stack + 2070411;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2071356, dvrr_stack+735970, dvrr_stack+1094720);
 tmp = dvrr_stack + 2071356;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2072511, dvrr_stack+737510, dvrr_stack+1095545);
 tmp = dvrr_stack + 2072511;
 target_ptr = Libderiv->deriv2_classes[5][10][20];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2073897, dvrr_stack+692650, dvrr_stack+776045);
 tmp = dvrr_stack + 2073897;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2074485, dvrr_stack+741542, dvrr_stack+775457);
 tmp = dvrr_stack + 2074485;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2075269, dvrr_stack+693406, dvrr_stack+776486);
 tmp = dvrr_stack + 2075269;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2076277, dvrr_stack+694702, dvrr_stack+777242);
 tmp = dvrr_stack + 2076277;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2077537, dvrr_stack+659606, dvrr_stack+778187);
 tmp = dvrr_stack + 2077537;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2079077, dvrr_stack+661586, dvrr_stack+779342);
 tmp = dvrr_stack + 2079077;
 target_ptr = Libderiv->deriv2_classes[6][10][20];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2080925, dvrr_stack+604421, dvrr_stack+783976);
 tmp = dvrr_stack + 2080925;
 target_ptr = Libderiv->deriv2_classes[7][5][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2081681, dvrr_stack+595121, dvrr_stack+783192);
 tmp = dvrr_stack + 2081681;
 target_ptr = Libderiv->deriv2_classes[7][6][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2082689, dvrr_stack+605366, dvrr_stack+784564);
 tmp = dvrr_stack + 2082689;
 target_ptr = Libderiv->deriv2_classes[7][7][20];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2083985, dvrr_stack+507951, dvrr_stack+785572);
 tmp = dvrr_stack + 2083985;
 target_ptr = Libderiv->deriv2_classes[7][8][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2085605, dvrr_stack+509976, dvrr_stack+735970);
 tmp = dvrr_stack + 2085605;
 target_ptr = Libderiv->deriv2_classes[7][9][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2087585, dvrr_stack+471888, dvrr_stack+737510);
 tmp = dvrr_stack + 2087585;
 target_ptr = Libderiv->deriv2_classes[7][10][20];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2089961, dvrr_stack+474858, dvrr_stack+692650);
 tmp = dvrr_stack + 2089961;
 target_ptr = Libderiv->deriv2_classes[8][5][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2090906, dvrr_stack+420778, dvrr_stack+741542);
 tmp = dvrr_stack + 2090906;
 target_ptr = Libderiv->deriv2_classes[8][6][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2092166, dvrr_stack+402913, dvrr_stack+693406);
 tmp = dvrr_stack + 2092166;
 target_ptr = Libderiv->deriv2_classes[8][7][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2093786, dvrr_stack+362943, dvrr_stack+694702);
 tmp = dvrr_stack + 2093786;
 target_ptr = Libderiv->deriv2_classes[8][8][20];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2095811, dvrr_stack+365418, dvrr_stack+659606);
 tmp = dvrr_stack + 2095811;
 target_ptr = Libderiv->deriv2_classes[8][9][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2098286, dvrr_stack+331028, dvrr_stack+661586);
 tmp = dvrr_stack + 2098286;
 target_ptr = Libderiv->deriv2_classes[8][10][20];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2101256, dvrr_stack+759004, dvrr_stack+604421);
 tmp = dvrr_stack + 2101256;
 target_ptr = Libderiv->deriv2_classes[9][5][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2102411, dvrr_stack+1098481, dvrr_stack+595121);
 tmp = dvrr_stack + 2102411;
 target_ptr = Libderiv->deriv2_classes[9][6][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2103951, dvrr_stack+1100329, dvrr_stack+605366);
 tmp = dvrr_stack + 2103951;
 target_ptr = Libderiv->deriv2_classes[9][7][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2105931, dvrr_stack+1102705, dvrr_stack+507951);
 tmp = dvrr_stack + 2105931;
 target_ptr = Libderiv->deriv2_classes[9][8][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2108406, dvrr_stack+1105675, dvrr_stack+509976);
 tmp = dvrr_stack + 2108406;
 target_ptr = Libderiv->deriv2_classes[9][9][20];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2111431, dvrr_stack+1068548, dvrr_stack+471888);
 tmp = dvrr_stack + 2111431;
 target_ptr = Libderiv->deriv2_classes[9][10][20];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+358489, dvrr_stack+633806, dvrr_stack+612506);
 tmp = dvrr_stack + 358489;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2115061, dvrr_stack+369598, dvrr_stack+612821);
 tmp = dvrr_stack + 2115061;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2115649, dvrr_stack+278756, dvrr_stack+1096535);
 tmp = dvrr_stack + 2115649;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2116405, dvrr_stack+279764, dvrr_stack+1109305);
 tmp = dvrr_stack + 2116405;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2117350, dvrr_stack+260761, dvrr_stack+1109980);
 tmp = dvrr_stack + 2117350;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2118505, dvrr_stack+245488, dvrr_stack+1110805);
 tmp = dvrr_stack + 2118505;
 target_ptr = Libderiv->deriv2_classes[5][10][19];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2119891, dvrr_stack+241456, dvrr_stack+422318);
 tmp = dvrr_stack + 2119891;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2120479, dvrr_stack+247336, dvrr_stack+566826);
 tmp = dvrr_stack + 2120479;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2121263, dvrr_stack+219426, dvrr_stack+422759);
 tmp = dvrr_stack + 2121263;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2122271, dvrr_stack+168574, dvrr_stack+397693);
 tmp = dvrr_stack + 2122271;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2123531, dvrr_stack+150530, dvrr_stack+368443);
 tmp = dvrr_stack + 2123531;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2125071, dvrr_stack+100090, dvrr_stack+302276);
 tmp = dvrr_stack + 2125071;
 target_ptr = Libderiv->deriv2_classes[6][10][19];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2126919, dvrr_stack+192826, dvrr_stack+633806);
 tmp = dvrr_stack + 2126919;
 target_ptr = Libderiv->deriv2_classes[7][5][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2127675, dvrr_stack+136100, dvrr_stack+369598);
 tmp = dvrr_stack + 2127675;
 target_ptr = Libderiv->deriv2_classes[7][6][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2128683, dvrr_stack+124454, dvrr_stack+278756);
 tmp = dvrr_stack + 2128683;
 target_ptr = Libderiv->deriv2_classes[7][7][19];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2129979, dvrr_stack+102466, dvrr_stack+279764);
 tmp = dvrr_stack + 2129979;
 target_ptr = Libderiv->deriv2_classes[7][8][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2131599, dvrr_stack+77200, dvrr_stack+260761);
 tmp = dvrr_stack + 2131599;
 target_ptr = Libderiv->deriv2_classes[7][9][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2133579, dvrr_stack+547563, dvrr_stack+245488);
 tmp = dvrr_stack + 2133579;
 target_ptr = Libderiv->deriv2_classes[7][10][19];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2135955, dvrr_stack+38692, dvrr_stack+241456);
 tmp = dvrr_stack + 2135955;
 target_ptr = Libderiv->deriv2_classes[8][5][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2136900, dvrr_stack+56086, dvrr_stack+247336);
 tmp = dvrr_stack + 2136900;
 target_ptr = Libderiv->deriv2_classes[8][6][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2138160, dvrr_stack+61630, dvrr_stack+219426);
 tmp = dvrr_stack + 2138160;
 target_ptr = Libderiv->deriv2_classes[8][7][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2139780, dvrr_stack+957294, dvrr_stack+168574);
 tmp = dvrr_stack + 2139780;
 target_ptr = Libderiv->deriv2_classes[8][8][19];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2141805, dvrr_stack+959769, dvrr_stack+150530);
 tmp = dvrr_stack + 2141805;
 target_ptr = Libderiv->deriv2_classes[8][9][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2144280, dvrr_stack+962794, dvrr_stack+100090);
 tmp = dvrr_stack + 2144280;
 target_ptr = Libderiv->deriv2_classes[8][10][19];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2147250, dvrr_stack+1047054, dvrr_stack+192826);
 tmp = dvrr_stack + 2147250;
 target_ptr = Libderiv->deriv2_classes[9][5][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2148405, dvrr_stack+1048440, dvrr_stack+136100);
 tmp = dvrr_stack + 2148405;
 target_ptr = Libderiv->deriv2_classes[9][6][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2149945, dvrr_stack+1030248, dvrr_stack+124454);
 tmp = dvrr_stack + 2149945;
 target_ptr = Libderiv->deriv2_classes[9][7][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2151925, dvrr_stack+1008119, dvrr_stack+102466);
 tmp = dvrr_stack + 2151925;
 target_ptr = Libderiv->deriv2_classes[9][8][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2154400, dvrr_stack+1116728, dvrr_stack+77200);
 tmp = dvrr_stack + 2154400;
 target_ptr = Libderiv->deriv2_classes[9][9][19];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2157425, dvrr_stack+1120358, dvrr_stack+547563);
 tmp = dvrr_stack + 2157425;
 target_ptr = Libderiv->deriv2_classes[9][10][19];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2161055, dvrr_stack+754468, dvrr_stack+1097075);
 tmp = dvrr_stack + 2161055;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2161496, dvrr_stack+346424, dvrr_stack+1111795);
 tmp = dvrr_stack + 2161496;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2162084, dvrr_stack+128570, dvrr_stack+1072904);
 tmp = dvrr_stack + 2162084;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2162840, dvrr_stack+43207, dvrr_stack+1050288);
 tmp = dvrr_stack + 2162840;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2163785, dvrr_stack+97625, dvrr_stack+1020270);
 tmp = dvrr_stack + 2163785;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2164940, dvrr_stack+970714, dvrr_stack+1021095);
 tmp = dvrr_stack + 2164940;
 target_ptr = Libderiv->deriv2_classes[5][10][18];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2166326, dvrr_stack+85858, dvrr_stack+262301);
 tmp = dvrr_stack + 2166326;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2166914, dvrr_stack+554043, dvrr_stack+281024);
 tmp = dvrr_stack + 2166914;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2167698, dvrr_stack+212023, dvrr_stack+24817);
 tmp = dvrr_stack + 2167698;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2168706, dvrr_stack+69885, dvrr_stack+13315);
 tmp = dvrr_stack + 2168706;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2169966, dvrr_stack+972562, dvrr_stack+177506);
 tmp = dvrr_stack + 2169966;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2171506, dvrr_stack+974542, dvrr_stack+140888);
 tmp = dvrr_stack + 2171506;
 target_ptr = Libderiv->deriv2_classes[6][10][18];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2173354, dvrr_stack+360245, dvrr_stack+754468);
 tmp = dvrr_stack + 2173354;
 target_ptr = Libderiv->deriv2_classes[7][5][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2174110, dvrr_stack+358985, dvrr_stack+346424);
 tmp = dvrr_stack + 2174110;
 target_ptr = Libderiv->deriv2_classes[7][6][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2175118, dvrr_stack+976918, dvrr_stack+128570);
 tmp = dvrr_stack + 2175118;
 target_ptr = Libderiv->deriv2_classes[7][7][18];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2176414, dvrr_stack+978538, dvrr_stack+43207);
 tmp = dvrr_stack + 2176414;
 target_ptr = Libderiv->deriv2_classes[7][8][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2178034, dvrr_stack+980563, dvrr_stack+97625);
 tmp = dvrr_stack + 2178034;
 target_ptr = Libderiv->deriv2_classes[7][9][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2180014, dvrr_stack+983038, dvrr_stack+970714);
 tmp = dvrr_stack + 2180014;
 target_ptr = Libderiv->deriv2_classes[7][10][18];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2182390, dvrr_stack+210227, dvrr_stack+85858);
 tmp = dvrr_stack + 2182390;
 target_ptr = Libderiv->deriv2_classes[8][5][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2183335, dvrr_stack+208687, dvrr_stack+554043);
 tmp = dvrr_stack + 2183335;
 target_ptr = Libderiv->deriv2_classes[8][6][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2184595, dvrr_stack+989518, dvrr_stack+212023);
 tmp = dvrr_stack + 2184595;
 target_ptr = Libderiv->deriv2_classes[8][7][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2186215, dvrr_stack+991498, dvrr_stack+69885);
 tmp = dvrr_stack + 2186215;
 target_ptr = Libderiv->deriv2_classes[8][8][18];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2188240, dvrr_stack+993973, dvrr_stack+972562);
 tmp = dvrr_stack + 2188240;
 target_ptr = Libderiv->deriv2_classes[8][9][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2190715, dvrr_stack+996998, dvrr_stack+974542);
 tmp = dvrr_stack + 2190715;
 target_ptr = Libderiv->deriv2_classes[8][10][18];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2193685, dvrr_stack+770335, dvrr_stack+360245);
 tmp = dvrr_stack + 2193685;
 target_ptr = Libderiv->deriv2_classes[9][5][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2194840, dvrr_stack+1124714, dvrr_stack+358985);
 tmp = dvrr_stack + 2194840;
 target_ptr = Libderiv->deriv2_classes[9][6][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2196380, dvrr_stack+1126562, dvrr_stack+976918);
 tmp = dvrr_stack + 2196380;
 target_ptr = Libderiv->deriv2_classes[9][7][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2198360, dvrr_stack+1128938, dvrr_stack+978538);
 tmp = dvrr_stack + 2198360;
 target_ptr = Libderiv->deriv2_classes[9][8][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2200835, dvrr_stack+1131908, dvrr_stack+980563);
 tmp = dvrr_stack + 2200835;
 target_ptr = Libderiv->deriv2_classes[9][9][18];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2203860, dvrr_stack+1135538, dvrr_stack+983038);
 tmp = dvrr_stack + 2203860;
 target_ptr = Libderiv->deriv2_classes[9][10][18];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+18085, dvrr_stack+494883, dvrr_stack+494568);
 tmp = dvrr_stack + 18085;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2207490, dvrr_stack+495891, dvrr_stack+495471);
 tmp = dvrr_stack + 2207490;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2208078, dvrr_stack+497215, dvrr_stack+496675);
 tmp = dvrr_stack + 2208078;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2208834, dvrr_stack+1011089, dvrr_stack+498223);
 tmp = dvrr_stack + 2208834;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2209779, dvrr_stack+1139894, dvrr_stack+1097390);
 tmp = dvrr_stack + 2209779;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2210934, dvrr_stack+1141434, dvrr_stack+502092);
 tmp = dvrr_stack + 2210934;
 target_ptr = Libderiv->deriv2_classes[5][10][14];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2212320, dvrr_stack+1032624, dvrr_stack+498898);
 tmp = dvrr_stack + 2212320;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2212908, dvrr_stack+72513, dvrr_stack+773095);
 tmp = dvrr_stack + 2212908;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2213692, dvrr_stack+1143282, dvrr_stack+33852);
 tmp = dvrr_stack + 2213692;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2214700, dvrr_stack+1144578, dvrr_stack+32329);
 tmp = dvrr_stack + 2214700;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2215960, dvrr_stack+1147353, dvrr_stack+1146198);
 tmp = dvrr_stack + 2215960;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2217500, dvrr_stack+1150719, dvrr_stack+1149333);
 tmp = dvrr_stack + 2217500;
 target_ptr = Libderiv->deriv2_classes[6][10][14];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2219348, dvrr_stack+1153095, dvrr_stack+494883);
 tmp = dvrr_stack + 2219348;
 target_ptr = Libderiv->deriv2_classes[7][5][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2220104, dvrr_stack+1154040, dvrr_stack+495891);
 tmp = dvrr_stack + 2220104;
 target_ptr = Libderiv->deriv2_classes[7][6][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2221112, dvrr_stack+1155300, dvrr_stack+497215);
 tmp = dvrr_stack + 2221112;
 target_ptr = Libderiv->deriv2_classes[7][7][14];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2222408, dvrr_stack+1156920, dvrr_stack+1011089);
 tmp = dvrr_stack + 2222408;
 target_ptr = Libderiv->deriv2_classes[7][8][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2224028, dvrr_stack+1158945, dvrr_stack+1139894);
 tmp = dvrr_stack + 2224028;
 target_ptr = Libderiv->deriv2_classes[7][9][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2226008, dvrr_stack+1161420, dvrr_stack+1141434);
 tmp = dvrr_stack + 2226008;
 target_ptr = Libderiv->deriv2_classes[7][10][14];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2228384, dvrr_stack+1164390, dvrr_stack+1032624);
 tmp = dvrr_stack + 2228384;
 target_ptr = Libderiv->deriv2_classes[8][5][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2229329, dvrr_stack+1165545, dvrr_stack+72513);
 tmp = dvrr_stack + 2229329;
 target_ptr = Libderiv->deriv2_classes[8][6][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2230589, dvrr_stack+1167085, dvrr_stack+1143282);
 tmp = dvrr_stack + 2230589;
 target_ptr = Libderiv->deriv2_classes[8][7][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2232209, dvrr_stack+1169065, dvrr_stack+1144578);
 tmp = dvrr_stack + 2232209;
 target_ptr = Libderiv->deriv2_classes[8][8][14];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2234234, dvrr_stack+1171540, dvrr_stack+1147353);
 tmp = dvrr_stack + 2234234;
 target_ptr = Libderiv->deriv2_classes[8][9][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2236709, dvrr_stack+1174565, dvrr_stack+1150719);
 tmp = dvrr_stack + 2236709;
 target_ptr = Libderiv->deriv2_classes[8][10][14];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2239679, dvrr_stack+90584, dvrr_stack+1153095);
 tmp = dvrr_stack + 2239679;
 target_ptr = Libderiv->deriv2_classes[9][5][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2240834, dvrr_stack+1013774, dvrr_stack+1154040);
 tmp = dvrr_stack + 2240834;
 target_ptr = Libderiv->deriv2_classes[9][6][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2242374, dvrr_stack+582071, dvrr_stack+1155300);
 tmp = dvrr_stack + 2242374;
 target_ptr = Libderiv->deriv2_classes[9][7][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2244354, dvrr_stack+1178195, dvrr_stack+1156920);
 tmp = dvrr_stack + 2244354;
 target_ptr = Libderiv->deriv2_classes[9][8][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2246829, dvrr_stack+1035264, dvrr_stack+1158945);
 tmp = dvrr_stack + 2246829;
 target_ptr = Libderiv->deriv2_classes[9][9][14];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2249854, dvrr_stack+1053588, dvrr_stack+1161420);
 tmp = dvrr_stack + 2249854;
 target_ptr = Libderiv->deriv2_classes[9][10][14];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+2253484, dvrr_stack+1058259, dvrr_stack+1057944);
 tmp = dvrr_stack + 2253484;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+2253925, dvrr_stack+1059267, dvrr_stack+1058847);
 tmp = dvrr_stack + 2253925;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+2254513, dvrr_stack+117646, dvrr_stack+1060051);
 tmp = dvrr_stack + 2254513;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+2255269, dvrr_stack+414253, dvrr_stack+1060591);
 tmp = dvrr_stack + 2255269;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+2256214, dvrr_stack+416338, dvrr_stack+415513);
 tmp = dvrr_stack + 2256214;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+2257369, dvrr_stack+462648, dvrr_stack+461658);
 tmp = dvrr_stack + 2257369;
 target_ptr = Libderiv->deriv2_classes[5][10][13];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+2258755, dvrr_stack+417878, dvrr_stack+44467);
 tmp = dvrr_stack + 2258755;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+2259343, dvrr_stack+71505, dvrr_stack+587961);
 tmp = dvrr_stack + 2259343;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+2260127, dvrr_stack+589305, dvrr_stack+588549);
 tmp = dvrr_stack + 2260127;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+2261135, dvrr_stack+398638, dvrr_stack+590601);
 tmp = dvrr_stack + 2261135;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+2262395, dvrr_stack+596381, dvrr_stack+400258);
 tmp = dvrr_stack + 2262395;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+2263935, dvrr_stack+1022085, dvrr_stack+686974);
 tmp = dvrr_stack + 2263935;
 target_ptr = Libderiv->deriv2_classes[6][10][13];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+2265783, dvrr_stack+1024461, dvrr_stack+1058259);
 tmp = dvrr_stack + 2265783;
 target_ptr = Libderiv->deriv2_classes[7][5][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+2266539, dvrr_stack+20857, dvrr_stack+1059267);
 tmp = dvrr_stack + 2266539;
 target_ptr = Libderiv->deriv2_classes[7][6][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+2267547, dvrr_stack+1038894, dvrr_stack+117646);
 tmp = dvrr_stack + 2267547;
 target_ptr = Libderiv->deriv2_classes[7][7][13];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+2268843, dvrr_stack+272101, dvrr_stack+414253);
 tmp = dvrr_stack + 2268843;
 target_ptr = Libderiv->deriv2_classes[7][8][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+2270463, dvrr_stack+434953, dvrr_stack+416338);
 tmp = dvrr_stack + 2270463;
 target_ptr = Libderiv->deriv2_classes[7][9][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+2272443, dvrr_stack+1181165, dvrr_stack+462648);
 tmp = dvrr_stack + 2272443;
 target_ptr = Libderiv->deriv2_classes[7][10][13];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+2274819, dvrr_stack+242212, dvrr_stack+417878);
 tmp = dvrr_stack + 2274819;
 target_ptr = Libderiv->deriv2_classes[8][5][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+2275764, dvrr_stack+18607, dvrr_stack+71505);
 tmp = dvrr_stack + 2275764;
 target_ptr = Libderiv->deriv2_classes[8][6][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+2277024, dvrr_stack+650696, dvrr_stack+589305);
 tmp = dvrr_stack + 2277024;
 target_ptr = Libderiv->deriv2_classes[8][7][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+2278644, dvrr_stack+0, dvrr_stack+398638);
 tmp = dvrr_stack + 2278644;
 target_ptr = Libderiv->deriv2_classes[8][8][13];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+2280669, dvrr_stack+1073444, dvrr_stack+596381);
 tmp = dvrr_stack + 2280669;
 target_ptr = Libderiv->deriv2_classes[8][9][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+2283144, dvrr_stack+1076469, dvrr_stack+1022085);
 tmp = dvrr_stack + 2283144;
 target_ptr = Libderiv->deriv2_classes[8][10][13];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+2286114, dvrr_stack+255316, dvrr_stack+1024461);
 tmp = dvrr_stack + 2286114;
 target_ptr = Libderiv->deriv2_classes[9][5][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+2287269, dvrr_stack+95381, dvrr_stack+20857);
 tmp = dvrr_stack + 2287269;
 target_ptr = Libderiv->deriv2_classes[9][6][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+2288809, dvrr_stack+1080099, dvrr_stack+1038894);
 tmp = dvrr_stack + 2288809;
 target_ptr = Libderiv->deriv2_classes[9][7][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+2290789, dvrr_stack+66670, dvrr_stack+272101);
 tmp = dvrr_stack + 2290789;
 target_ptr = Libderiv->deriv2_classes[9][8][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+2293264, dvrr_stack+1184135, dvrr_stack+434953);
 tmp = dvrr_stack + 2293264;
 target_ptr = Libderiv->deriv2_classes[9][9][13];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+2296289, dvrr_stack+1187765, dvrr_stack+1181165);
 tmp = dvrr_stack + 2296289;
 target_ptr = Libderiv->deriv2_classes[9][10][13];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+2299919, dvrr_stack+798781, dvrr_stack+788463);
 tmp = dvrr_stack + 2299919;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+2300360, dvrr_stack+797997, dvrr_stack+772000);
 tmp = dvrr_stack + 2300360;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+2300948, dvrr_stack+799369, dvrr_stack+774040);
 tmp = dvrr_stack + 2300948;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+2301704, dvrr_stack+800377, dvrr_stack+16402);
 tmp = dvrr_stack + 2301704;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+2302649, dvrr_stack+801637, dvrr_stack+361190);
 tmp = dvrr_stack + 2302649;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,66,dvrr_stack+2303804, dvrr_stack+803177, dvrr_stack+10462);
 tmp = dvrr_stack + 2303804;
 target_ptr = Libderiv->deriv2_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+361190, dvrr_stack+808569, dvrr_stack+790626);
 tmp = dvrr_stack + 361190;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+10051, dvrr_stack+755080, dvrr_stack+790038);
 tmp = dvrr_stack + 10051;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+789954, dvrr_stack+756088, dvrr_stack+791067);
 tmp = dvrr_stack + 789954;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+2305190, dvrr_stack+757384, dvrr_stack+791823);
 tmp = dvrr_stack + 2305190;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+790962, dvrr_stack+707170, dvrr_stack+792768);
 tmp = dvrr_stack + 790962;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,66,dvrr_stack+2306450, dvrr_stack+709150, dvrr_stack+793923);
 tmp = dvrr_stack + 2306450;
 target_ptr = Libderiv->deriv2_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,21,dvrr_stack+773683, dvrr_stack+634571, dvrr_stack+798781);
 tmp = dvrr_stack + 773683;
 target_ptr = Libderiv->deriv2_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,28,dvrr_stack+792502, dvrr_stack+674239, dvrr_stack+797997);
 tmp = dvrr_stack + 792502;
 target_ptr = Libderiv->deriv2_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,36,dvrr_stack+797689, dvrr_stack+635516, dvrr_stack+799369);
 tmp = dvrr_stack + 797689;
 target_ptr = Libderiv->deriv2_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,45,dvrr_stack+793510, dvrr_stack+637136, dvrr_stack+800377);
 tmp = dvrr_stack + 793510;
 target_ptr = Libderiv->deriv2_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,55,dvrr_stack+798985, dvrr_stack+639161, dvrr_stack+801637);
 tmp = dvrr_stack + 798985;
 target_ptr = Libderiv->deriv2_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,66,dvrr_stack+2308298, dvrr_stack+558806, dvrr_stack+803177);
 tmp = dvrr_stack + 2308298;
 target_ptr = Libderiv->deriv2_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,21,dvrr_stack+800965, dvrr_stack+569301, dvrr_stack+808569);
 tmp = dvrr_stack + 800965;
 target_ptr = Libderiv->deriv2_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,28,dvrr_stack+801910, dvrr_stack+567761, dvrr_stack+755080);
 tmp = dvrr_stack + 801910;
 target_ptr = Libderiv->deriv2_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,36,dvrr_stack+803170, dvrr_stack+570456, dvrr_stack+756088);
 tmp = dvrr_stack + 803170;
 target_ptr = Libderiv->deriv2_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,45,dvrr_stack+567414, dvrr_stack+483768, dvrr_stack+757384);
 tmp = dvrr_stack + 567414;
 target_ptr = Libderiv->deriv2_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,55,dvrr_stack+483679, dvrr_stack+453153, dvrr_stack+707170);
 tmp = dvrr_stack + 483679;
 target_ptr = Libderiv->deriv2_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,66,dvrr_stack+453135, dvrr_stack+405748, dvrr_stack+709150);
 tmp = dvrr_stack + 453135;
 target_ptr = Libderiv->deriv2_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,21,dvrr_stack+405649, dvrr_stack+393021, dvrr_stack+634571);
 tmp = dvrr_stack + 405649;
 target_ptr = Libderiv->deriv2_classes[9][5][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,28,dvrr_stack+406804, dvrr_stack+1033416, dvrr_stack+674239);
 tmp = dvrr_stack + 406804;
 target_ptr = Libderiv->deriv2_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,36,dvrr_stack+706985, dvrr_stack+1051212, dvrr_stack+635516);
 tmp = dvrr_stack + 706985;
 target_ptr = Libderiv->deriv2_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,45,dvrr_stack+708965, dvrr_stack+437428, dvrr_stack+637136);
 tmp = dvrr_stack + 708965;
 target_ptr = Libderiv->deriv2_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,55,dvrr_stack+634394, dvrr_stack+464628, dvrr_stack+639161);
 tmp = dvrr_stack + 634394;
 target_ptr = Libderiv->deriv2_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_m(Data,66,dvrr_stack+464496, dvrr_stack+720370, dvrr_stack+558806);
 tmp = dvrr_stack + 464496;
 target_ptr = Libderiv->deriv2_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+437428, dvrr_stack+456178, dvrr_stack+182686);
 tmp = dvrr_stack + 437428;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+437869, dvrr_stack+377817, dvrr_stack+183001);
 tmp = dvrr_stack + 437869;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+438457, dvrr_stack+378601, dvrr_stack+183421);
 tmp = dvrr_stack + 438457;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+439213, dvrr_stack+379609, dvrr_stack+183961);
 tmp = dvrr_stack + 439213;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+393021, dvrr_stack+380869, dvrr_stack+184636);
 tmp = dvrr_stack + 393021;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+1033380, dvrr_stack+382409, dvrr_stack+320420);
 tmp = dvrr_stack + 1033380;
 target_ptr = Libderiv->deriv2_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+16402, dvrr_stack+345668, dvrr_stack+572436);
 tmp = dvrr_stack + 16402;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+408344, dvrr_stack+344660, dvrr_stack+614156);
 tmp = dvrr_stack + 408344;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+320357, dvrr_stack+286496, dvrr_stack+486243);
 tmp = dvrr_stack + 320357;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+720317, dvrr_stack+287792, dvrr_stack+486999);
 tmp = dvrr_stack + 720317;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+486154, dvrr_stack+266917, dvrr_stack+428473);
 tmp = dvrr_stack + 486154;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+721577, dvrr_stack+221148, dvrr_stack+429628);
 tmp = dvrr_stack + 721577;
 target_ptr = Libderiv->deriv2_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+808490, dvrr_stack+226332, dvrr_stack+456178);
 tmp = dvrr_stack + 808490;
 target_ptr = Libderiv->deriv2_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+723425, dvrr_stack+251536, dvrr_stack+377817);
 tmp = dvrr_stack + 723425;
 target_ptr = Libderiv->deriv2_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+1050963, dvrr_stack+227277, dvrr_stack+378601);
 tmp = dvrr_stack + 1050963;
 target_ptr = Libderiv->deriv2_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+674136, dvrr_stack+228897, dvrr_stack+379609);
 tmp = dvrr_stack + 674136;
 target_ptr = Libderiv->deriv2_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+569439, dvrr_stack+199546, dvrr_stack+380869);
 tmp = dvrr_stack + 569439;
 target_ptr = Libderiv->deriv2_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+428269, dvrr_stack+106348, dvrr_stack+382409);
 tmp = dvrr_stack + 428269;
 target_ptr = Libderiv->deriv2_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1052259, dvrr_stack+202021, dvrr_stack+345668);
 tmp = dvrr_stack + 1052259;
 target_ptr = Libderiv->deriv2_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+571419, dvrr_stack+175966, dvrr_stack+344660);
 tmp = dvrr_stack + 571419;
 target_ptr = Libderiv->deriv2_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+637419, dvrr_stack+83878, dvrr_stack+286496);
 tmp = dvrr_stack + 637419;
 target_ptr = Libderiv->deriv2_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+83483, dvrr_stack+943874, dvrr_stack+287792);
 tmp = dvrr_stack + 83483;
 target_ptr = Libderiv->deriv2_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+639039, dvrr_stack+946349, dvrr_stack+266917);
 tmp = dvrr_stack + 639039;
 target_ptr = Libderiv->deriv2_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+377753, dvrr_stack+949374, dvrr_stack+221148);
 tmp = dvrr_stack + 377753;
 target_ptr = Libderiv->deriv2_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+202021, dvrr_stack+321410, dvrr_stack+226332);
 tmp = dvrr_stack + 202021;
 target_ptr = Libderiv->deriv2_classes[9][5][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+380723, dvrr_stack+322796, dvrr_stack+251536);
 tmp = dvrr_stack + 380723;
 target_ptr = Libderiv->deriv2_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+321365, dvrr_stack+499716, dvrr_stack+227277);
 tmp = dvrr_stack + 321365;
 target_ptr = Libderiv->deriv2_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+226170, dvrr_stack+724726, dvrr_stack+228897);
 tmp = dvrr_stack + 226170;
 target_ptr = Libderiv->deriv2_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+724433, dvrr_stack+727696, dvrr_stack+199546);
 tmp = dvrr_stack + 724433;
 target_ptr = Libderiv->deriv2_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+727458, dvrr_stack+1112372, dvrr_stack+106348);
 tmp = dvrr_stack + 727458;
 target_ptr = Libderiv->deriv2_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+228645, dvrr_stack+123866, dvrr_stack+185461);
 tmp = dvrr_stack + 228645;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+229086, dvrr_stack+28408, dvrr_stack+185776);
 tmp = dvrr_stack + 229086;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+229674, dvrr_stack+119438, dvrr_stack+769795);
 tmp = dvrr_stack + 229674;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+323345, dvrr_stack+134840, dvrr_stack+772420);
 tmp = dvrr_stack + 323345;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+251260, dvrr_stack+148990, dvrr_stack+1004918);
 tmp = dvrr_stack + 251260;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+499339, dvrr_stack+166726, dvrr_stack+1005743);
 tmp = dvrr_stack + 499339;
 target_ptr = Libderiv->deriv2_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+1004513, dvrr_stack+120446, dvrr_stack+12874);
 tmp = dvrr_stack + 1004513;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1005101, dvrr_stack+753460, dvrr_stack+788778);
 tmp = dvrr_stack + 1005101;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+788341, dvrr_stack+240160, dvrr_stack+7447);
 tmp = dvrr_stack + 788341;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+500725, dvrr_stack+259141, dvrr_stack+23872);
 tmp = dvrr_stack + 500725;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1112215, dvrr_stack+276776, dvrr_stack+37537);
 tmp = dvrr_stack + 1112215;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+1113755, dvrr_stack+299900, dvrr_stack+54700);
 tmp = dvrr_stack + 1113755;
 target_ptr = Libderiv->deriv2_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+23872, dvrr_stack+401968, dvrr_stack+123866);
 tmp = dvrr_stack + 23872;
 target_ptr = Libderiv->deriv2_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+54511, dvrr_stack+632546, dvrr_stack+28408);
 tmp = dvrr_stack + 54511;
 target_ptr = Libderiv->deriv2_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+37372, dvrr_stack+396073, dvrr_stack+119438);
 tmp = dvrr_stack + 37372;
 target_ptr = Libderiv->deriv2_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+382263, dvrr_stack+418753, dvrr_stack+134840);
 tmp = dvrr_stack + 382263;
 target_ptr = Libderiv->deriv2_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+344291, dvrr_stack+441003, dvrr_stack+148990);
 tmp = dvrr_stack + 344291;
 target_ptr = Libderiv->deriv2_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+286140, dvrr_stack+468918, dvrr_stack+166726);
 tmp = dvrr_stack + 286140;
 target_ptr = Libderiv->deriv2_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+134535, dvrr_stack+603266, dvrr_stack+120446);
 tmp = dvrr_stack + 134535;
 target_ptr = Libderiv->deriv2_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+119410, dvrr_stack+565286, dvrr_stack+753460);
 tmp = dvrr_stack + 119410;
 target_ptr = Libderiv->deriv2_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+564912, dvrr_stack+593141, dvrr_stack+240160);
 tmp = dvrr_stack + 564912;
 target_ptr = Libderiv->deriv2_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+593086, dvrr_stack+626606, dvrr_stack+259141);
 tmp = dvrr_stack + 593086;
 target_ptr = Libderiv->deriv2_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+626491, dvrr_stack+656581, dvrr_stack+276776);
 tmp = dvrr_stack + 626491;
 target_ptr = Libderiv->deriv2_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+656567, dvrr_stack+689020, dvrr_stack+299900);
 tmp = dvrr_stack + 656567;
 target_ptr = Libderiv->deriv2_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+299900, dvrr_stack+1006733, dvrr_stack+401968);
 tmp = dvrr_stack + 299900;
 target_ptr = Libderiv->deriv2_classes[9][5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1005885, dvrr_stack+1018422, dvrr_stack+632546);
 tmp = dvrr_stack + 1005885;
 target_ptr = Libderiv->deriv2_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+688948, dvrr_stack+1027872, dvrr_stack+396073);
 tmp = dvrr_stack + 688948;
 target_ptr = Libderiv->deriv2_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+755056, dvrr_stack+1044084, dvrr_stack+418753);
 tmp = dvrr_stack + 755056;
 target_ptr = Libderiv->deriv2_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1043754, dvrr_stack+1064918, dvrr_stack+441003);
 tmp = dvrr_stack + 1043754;
 target_ptr = Libderiv->deriv2_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1064896, dvrr_stack+1088414, dvrr_stack+468918);
 tmp = dvrr_stack + 1064896;
 target_ptr = Libderiv->deriv2_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+301055, dvrr_stack+783976, dvrr_stack+1092770);
 tmp = dvrr_stack + 301055;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+301496, dvrr_stack+783192, dvrr_stack+1093085);
 tmp = dvrr_stack + 301496;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+603251, dvrr_stack+784564, dvrr_stack+1093505);
 tmp = dvrr_stack + 603251;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+418634, dvrr_stack+785572, dvrr_stack+1094045);
 tmp = dvrr_stack + 418634;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+419579, dvrr_stack+735970, dvrr_stack+1094720);
 tmp = dvrr_stack + 419579;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+690928, dvrr_stack+737510, dvrr_stack+1095545);
 tmp = dvrr_stack + 690928;
 target_ptr = Libderiv->deriv2_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+1007425, dvrr_stack+692650, dvrr_stack+776045);
 tmp = dvrr_stack + 1007425;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+7399, dvrr_stack+741542, dvrr_stack+775457);
 tmp = dvrr_stack + 7399;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+401728, dvrr_stack+693406, dvrr_stack+776486);
 tmp = dvrr_stack + 401728;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1027782, dvrr_stack+694702, dvrr_stack+777242);
 tmp = dvrr_stack + 1027782;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+468699, dvrr_stack+659606, dvrr_stack+778187);
 tmp = dvrr_stack + 468699;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+440986, dvrr_stack+661586, dvrr_stack+779342);
 tmp = dvrr_stack + 440986;
 target_ptr = Libderiv->deriv2_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+123677, dvrr_stack+604421, dvrr_stack+783976);
 tmp = dvrr_stack + 123677;
 target_ptr = Libderiv->deriv2_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+1029042, dvrr_stack+595121, dvrr_stack+783192);
 tmp = dvrr_stack + 1029042;
 target_ptr = Libderiv->deriv2_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+783108, dvrr_stack+605366, dvrr_stack+784564);
 tmp = dvrr_stack + 783108;
 target_ptr = Libderiv->deriv2_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+470239, dvrr_stack+507951, dvrr_stack+785572);
 tmp = dvrr_stack + 470239;
 target_ptr = Libderiv->deriv2_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+784404, dvrr_stack+509976, dvrr_stack+735970);
 tmp = dvrr_stack + 784404;
 target_ptr = Libderiv->deriv2_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+775336, dvrr_stack+471888, dvrr_stack+737510);
 tmp = dvrr_stack + 775336;
 target_ptr = Libderiv->deriv2_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+276611, dvrr_stack+474858, dvrr_stack+692650);
 tmp = dvrr_stack + 276611;
 target_ptr = Libderiv->deriv2_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+166513, dvrr_stack+420778, dvrr_stack+741542);
 tmp = dvrr_stack + 166513;
 target_ptr = Libderiv->deriv2_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+148781, dvrr_stack+402913, dvrr_stack+693406);
 tmp = dvrr_stack + 148781;
 target_ptr = Libderiv->deriv2_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+402736, dvrr_stack+362943, dvrr_stack+694702);
 tmp = dvrr_stack + 402736;
 target_ptr = Libderiv->deriv2_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+692314, dvrr_stack+365418, dvrr_stack+659606);
 tmp = dvrr_stack + 692314;
 target_ptr = Libderiv->deriv2_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+777712, dvrr_stack+331028, dvrr_stack+661586);
 tmp = dvrr_stack + 777712;
 target_ptr = Libderiv->deriv2_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+474858, dvrr_stack+759004, dvrr_stack+604421);
 tmp = dvrr_stack + 474858;
 target_ptr = Libderiv->deriv2_classes[9][5][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+420734, dvrr_stack+1098481, dvrr_stack+595121);
 tmp = dvrr_stack + 420734;
 target_ptr = Libderiv->deriv2_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+659537, dvrr_stack+1100329, dvrr_stack+605366);
 tmp = dvrr_stack + 659537;
 target_ptr = Libderiv->deriv2_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+604007, dvrr_stack+1102705, dvrr_stack+507951);
 tmp = dvrr_stack + 604007;
 target_ptr = Libderiv->deriv2_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1098215, dvrr_stack+1105675, dvrr_stack+509976);
 tmp = dvrr_stack + 1098215;
 target_ptr = Libderiv->deriv2_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1101240, dvrr_stack+1068548, dvrr_stack+471888);
 tmp = dvrr_stack + 1101240;
 target_ptr = Libderiv->deriv2_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+741122, dvrr_stack+633806, dvrr_stack+612506);
 tmp = dvrr_stack + 741122;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+741563, dvrr_stack+369598, dvrr_stack+612821);
 tmp = dvrr_stack + 741563;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1068526, dvrr_stack+278756, dvrr_stack+1096535);
 tmp = dvrr_stack + 1068526;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1069282, dvrr_stack+279764, dvrr_stack+1109305);
 tmp = dvrr_stack + 1069282;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1070227, dvrr_stack+260761, dvrr_stack+1109980);
 tmp = dvrr_stack + 1070227;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+1071382, dvrr_stack+245488, dvrr_stack+1110805);
 tmp = dvrr_stack + 1071382;
 target_ptr = Libderiv->deriv2_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+135480, dvrr_stack+241456, dvrr_stack+422318);
 tmp = dvrr_stack + 135480;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+595111, dvrr_stack+247336, dvrr_stack+566826);
 tmp = dvrr_stack + 595111;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+694789, dvrr_stack+219426, dvrr_stack+422759);
 tmp = dvrr_stack + 694789;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+471859, dvrr_stack+168574, dvrr_stack+397693);
 tmp = dvrr_stack + 471859;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+473119, dvrr_stack+150530, dvrr_stack+368443);
 tmp = dvrr_stack + 473119;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+661517, dvrr_stack+100090, dvrr_stack+302276);
 tmp = dvrr_stack + 661517;
 target_ptr = Libderiv->deriv2_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+302084, dvrr_stack+192826, dvrr_stack+633806);
 tmp = dvrr_stack + 302084;
 target_ptr = Libderiv->deriv2_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+422274, dvrr_stack+136100, dvrr_stack+369598);
 tmp = dvrr_stack + 422274;
 target_ptr = Libderiv->deriv2_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+259123, dvrr_stack+124454, dvrr_stack+278756);
 tmp = dvrr_stack + 259123;
 target_ptr = Libderiv->deriv2_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+277556, dvrr_stack+102466, dvrr_stack+279764);
 tmp = dvrr_stack + 277556;
 target_ptr = Libderiv->deriv2_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1018235, dvrr_stack+77200, dvrr_stack+260761);
 tmp = dvrr_stack + 1018235;
 target_ptr = Libderiv->deriv2_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+395793, dvrr_stack+547563, dvrr_stack+245488);
 tmp = dvrr_stack + 395793;
 target_ptr = Libderiv->deriv2_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+245347, dvrr_stack+38692, dvrr_stack+241456);
 tmp = dvrr_stack + 245347;
 target_ptr = Libderiv->deriv2_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+279176, dvrr_stack+56086, dvrr_stack+247336);
 tmp = dvrr_stack + 279176;
 target_ptr = Libderiv->deriv2_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+246292, dvrr_stack+61630, dvrr_stack+219426);
 tmp = dvrr_stack + 246292;
 target_ptr = Libderiv->deriv2_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+55519, dvrr_stack+957294, dvrr_stack+168574);
 tmp = dvrr_stack + 55519;
 target_ptr = Libderiv->deriv2_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+956889, dvrr_stack+959769, dvrr_stack+150530);
 tmp = dvrr_stack + 956889;
 target_ptr = Libderiv->deriv2_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+959364, dvrr_stack+962794, dvrr_stack+100090);
 tmp = dvrr_stack + 959364;
 target_ptr = Libderiv->deriv2_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+962334, dvrr_stack+1047054, dvrr_stack+192826);
 tmp = dvrr_stack + 962334;
 target_ptr = Libderiv->deriv2_classes[9][5][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+963489, dvrr_stack+1048440, dvrr_stack+136100);
 tmp = dvrr_stack + 963489;
 target_ptr = Libderiv->deriv2_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1046779, dvrr_stack+1030248, dvrr_stack+124454);
 tmp = dvrr_stack + 1046779;
 target_ptr = Libderiv->deriv2_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1030050, dvrr_stack+1008119, dvrr_stack+102466);
 tmp = dvrr_stack + 1030050;
 target_ptr = Libderiv->deriv2_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1008013, dvrr_stack+1116728, dvrr_stack+77200);
 tmp = dvrr_stack + 1008013;
 target_ptr = Libderiv->deriv2_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+219409, dvrr_stack+1120358, dvrr_stack+547563);
 tmp = dvrr_stack + 219409;
 target_ptr = Libderiv->deriv2_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+302840, dvrr_stack+754468, dvrr_stack+1097075);
 tmp = dvrr_stack + 302840;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+280436, dvrr_stack+346424, dvrr_stack+1111795);
 tmp = dvrr_stack + 280436;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+192742, dvrr_stack+128570, dvrr_stack+1072904);
 tmp = dvrr_stack + 192742;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+76934, dvrr_stack+43207, dvrr_stack+1050288);
 tmp = dvrr_stack + 76934;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+77879, dvrr_stack+97625, dvrr_stack+1020270);
 tmp = dvrr_stack + 77879;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+965029, dvrr_stack+970714, dvrr_stack+1021095);
 tmp = dvrr_stack + 965029;
 target_ptr = Libderiv->deriv2_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+79034, dvrr_stack+85858, dvrr_stack+262301);
 tmp = dvrr_stack + 79034;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+566532, dvrr_stack+554043, dvrr_stack+281024);
 tmp = dvrr_stack + 566532;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+547482, dvrr_stack+212023, dvrr_stack+24817);
 tmp = dvrr_stack + 547482;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+548490, dvrr_stack+69885, dvrr_stack+13315);
 tmp = dvrr_stack + 548490;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+124433, dvrr_stack+972562, dvrr_stack+177506);
 tmp = dvrr_stack + 124433;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+1048759, dvrr_stack+974542, dvrr_stack+140888);
 tmp = dvrr_stack + 1048759;
 target_ptr = Libderiv->deriv2_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+24628, dvrr_stack+360245, dvrr_stack+754468);
 tmp = dvrr_stack + 24628;
 target_ptr = Libderiv->deriv2_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+136068, dvrr_stack+358985, dvrr_stack+346424);
 tmp = dvrr_stack + 136068;
 target_ptr = Libderiv->deriv2_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+12793, dvrr_stack+976918, dvrr_stack+128570);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->deriv2_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+167773, dvrr_stack+978538, dvrr_stack+43207);
 tmp = dvrr_stack + 167773;
 target_ptr = Libderiv->deriv2_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+150401, dvrr_stack+980563, dvrr_stack+97625);
 tmp = dvrr_stack + 150401;
 target_ptr = Libderiv->deriv2_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1104870, dvrr_stack+983038, dvrr_stack+970714);
 tmp = dvrr_stack + 1104870;
 target_ptr = Libderiv->deriv2_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+970309, dvrr_stack+210227, dvrr_stack+85858);
 tmp = dvrr_stack + 970309;
 target_ptr = Libderiv->deriv2_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+971254, dvrr_stack+208687, dvrr_stack+554043);
 tmp = dvrr_stack + 971254;
 target_ptr = Libderiv->deriv2_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+260419, dvrr_stack+989518, dvrr_stack+212023);
 tmp = dvrr_stack + 260419;
 target_ptr = Libderiv->deriv2_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+989291, dvrr_stack+991498, dvrr_stack+69885);
 tmp = dvrr_stack + 989291;
 target_ptr = Libderiv->deriv2_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+991316, dvrr_stack+993973, dvrr_stack+972562);
 tmp = dvrr_stack + 991316;
 target_ptr = Libderiv->deriv2_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+993791, dvrr_stack+996998, dvrr_stack+974542);
 tmp = dvrr_stack + 993791;
 target_ptr = Libderiv->deriv2_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+996761, dvrr_stack+770335, dvrr_stack+360245);
 tmp = dvrr_stack + 996761;
 target_ptr = Libderiv->deriv2_classes[9][5][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+997916, dvrr_stack+1124714, dvrr_stack+358985);
 tmp = dvrr_stack + 997916;
 target_ptr = Libderiv->deriv2_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+972514, dvrr_stack+1126562, dvrr_stack+976918);
 tmp = dvrr_stack + 972514;
 target_ptr = Libderiv->deriv2_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+974494, dvrr_stack+1128938, dvrr_stack+978538);
 tmp = dvrr_stack + 974494;
 target_ptr = Libderiv->deriv2_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+976969, dvrr_stack+1131908, dvrr_stack+980563);
 tmp = dvrr_stack + 976969;
 target_ptr = Libderiv->deriv2_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1107246, dvrr_stack+1135538, dvrr_stack+983038);
 tmp = dvrr_stack + 1107246;
 target_ptr = Libderiv->deriv2_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+281024, dvrr_stack+494883, dvrr_stack+494568);
 tmp = dvrr_stack + 281024;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+999456, dvrr_stack+495891, dvrr_stack+495471);
 tmp = dvrr_stack + 999456;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+979994, dvrr_stack+497215, dvrr_stack+496675);
 tmp = dvrr_stack + 979994;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+980750, dvrr_stack+1011089, dvrr_stack+498223);
 tmp = dvrr_stack + 980750;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+981695, dvrr_stack+1139894, dvrr_stack+1097390);
 tmp = dvrr_stack + 981695;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+982850, dvrr_stack+1141434, dvrr_stack+502092);
 tmp = dvrr_stack + 982850;
 target_ptr = Libderiv->deriv2_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+498223, dvrr_stack+1032624, dvrr_stack+498898);
 tmp = dvrr_stack + 498223;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+984236, dvrr_stack+72513, dvrr_stack+773095);
 tmp = dvrr_stack + 984236;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+554012, dvrr_stack+1143282, dvrr_stack+33852);
 tmp = dvrr_stack + 554012;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+769792, dvrr_stack+1144578, dvrr_stack+32329);
 tmp = dvrr_stack + 769792;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+771052, dvrr_stack+1147353, dvrr_stack+1146198);
 tmp = dvrr_stack + 771052;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+97229, dvrr_stack+1150719, dvrr_stack+1149333);
 tmp = dvrr_stack + 97229;
 target_ptr = Libderiv->deriv2_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+1149333, dvrr_stack+1153095, dvrr_stack+494883);
 tmp = dvrr_stack + 1149333;
 target_ptr = Libderiv->deriv2_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+1146198, dvrr_stack+1154040, dvrr_stack+495891);
 tmp = dvrr_stack + 1146198;
 target_ptr = Libderiv->deriv2_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+240048, dvrr_stack+1155300, dvrr_stack+497215);
 tmp = dvrr_stack + 240048;
 target_ptr = Libderiv->deriv2_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+1020215, dvrr_stack+1156920, dvrr_stack+1011089);
 tmp = dvrr_stack + 1020215;
 target_ptr = Libderiv->deriv2_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1115603, dvrr_stack+1158945, dvrr_stack+1139894);
 tmp = dvrr_stack + 1115603;
 target_ptr = Libderiv->deriv2_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1117583, dvrr_stack+1161420, dvrr_stack+1141434);
 tmp = dvrr_stack + 1117583;
 target_ptr = Libderiv->deriv2_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1011038, dvrr_stack+1164390, dvrr_stack+1032624);
 tmp = dvrr_stack + 1011038;
 target_ptr = Libderiv->deriv2_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+211970, dvrr_stack+1165545, dvrr_stack+72513);
 tmp = dvrr_stack + 211970;
 target_ptr = Libderiv->deriv2_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+1164390, dvrr_stack+1167085, dvrr_stack+1143282);
 tmp = dvrr_stack + 1164390;
 target_ptr = Libderiv->deriv2_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1166010, dvrr_stack+1169065, dvrr_stack+1144578);
 tmp = dvrr_stack + 1166010;
 target_ptr = Libderiv->deriv2_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1168035, dvrr_stack+1171540, dvrr_stack+1147353);
 tmp = dvrr_stack + 1168035;
 target_ptr = Libderiv->deriv2_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1170510, dvrr_stack+1174565, dvrr_stack+1150719);
 tmp = dvrr_stack + 1170510;
 target_ptr = Libderiv->deriv2_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1173480, dvrr_stack+90584, dvrr_stack+1153095);
 tmp = dvrr_stack + 1173480;
 target_ptr = Libderiv->deriv2_classes[9][5][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1174635, dvrr_stack+1013774, dvrr_stack+1154040);
 tmp = dvrr_stack + 1174635;
 target_ptr = Libderiv->deriv2_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1176175, dvrr_stack+582071, dvrr_stack+1155300);
 tmp = dvrr_stack + 1176175;
 target_ptr = Libderiv->deriv2_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1150089, dvrr_stack+1178195, dvrr_stack+1156920);
 tmp = dvrr_stack + 1150089;
 target_ptr = Libderiv->deriv2_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1152564, dvrr_stack+1035264, dvrr_stack+1158945);
 tmp = dvrr_stack + 1152564;
 target_ptr = Libderiv->deriv2_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1155589, dvrr_stack+1053588, dvrr_stack+1161420);
 tmp = dvrr_stack + 1155589;
 target_ptr = Libderiv->deriv2_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+72513, dvrr_stack+1058259, dvrr_stack+1057944);
 tmp = dvrr_stack + 72513;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+1178155, dvrr_stack+1059267, dvrr_stack+1058847);
 tmp = dvrr_stack + 1178155;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1178743, dvrr_stack+117646, dvrr_stack+1060051);
 tmp = dvrr_stack + 1178743;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1179499, dvrr_stack+414253, dvrr_stack+1060591);
 tmp = dvrr_stack + 1179499;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1060051, dvrr_stack+416338, dvrr_stack+415513);
 tmp = dvrr_stack + 1060051;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+1159219, dvrr_stack+462648, dvrr_stack+461658);
 tmp = dvrr_stack + 1159219;
 target_ptr = Libderiv->deriv2_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+415513, dvrr_stack+417878, dvrr_stack+44467);
 tmp = dvrr_stack + 415513;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1160605, dvrr_stack+71505, dvrr_stack+587961);
 tmp = dvrr_stack + 1160605;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1161389, dvrr_stack+589305, dvrr_stack+588549);
 tmp = dvrr_stack + 1161389;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1162397, dvrr_stack+398638, dvrr_stack+590601);
 tmp = dvrr_stack + 1162397;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1147206, dvrr_stack+596381, dvrr_stack+400258);
 tmp = dvrr_stack + 1147206;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+632477, dvrr_stack+1022085, dvrr_stack+686974);
 tmp = dvrr_stack + 632477;
 target_ptr = Libderiv->deriv2_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+400258, dvrr_stack+1024461, dvrr_stack+1058259);
 tmp = dvrr_stack + 400258;
 target_ptr = Libderiv->deriv2_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+686852, dvrr_stack+20857, dvrr_stack+1059267);
 tmp = dvrr_stack + 686852;
 target_ptr = Libderiv->deriv2_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+587930, dvrr_stack+1038894, dvrr_stack+117646);
 tmp = dvrr_stack + 587930;
 target_ptr = Libderiv->deriv2_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+1034766, dvrr_stack+272101, dvrr_stack+414253);
 tmp = dvrr_stack + 1034766;
 target_ptr = Libderiv->deriv2_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+1036386, dvrr_stack+434953, dvrr_stack+416338);
 tmp = dvrr_stack + 1036386;
 target_ptr = Libderiv->deriv2_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1119959, dvrr_stack+1181165, dvrr_stack+462648);
 tmp = dvrr_stack + 1119959;
 target_ptr = Libderiv->deriv2_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+590601, dvrr_stack+242212, dvrr_stack+417878);
 tmp = dvrr_stack + 590601;
 target_ptr = Libderiv->deriv2_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+416101, dvrr_stack+18607, dvrr_stack+71505);
 tmp = dvrr_stack + 416101;
 target_ptr = Libderiv->deriv2_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+241344, dvrr_stack+650696, dvrr_stack+589305);
 tmp = dvrr_stack + 241344;
 target_ptr = Libderiv->deriv2_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+650550, dvrr_stack+0, dvrr_stack+398638);
 tmp = dvrr_stack + 650550;
 target_ptr = Libderiv->deriv2_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+0, dvrr_stack+1073444, dvrr_stack+596381);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1072768, dvrr_stack+1076469, dvrr_stack+1022085);
 tmp = dvrr_stack + 1072768;
 target_ptr = Libderiv->deriv2_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+417361, dvrr_stack+255316, dvrr_stack+1024461);
 tmp = dvrr_stack + 417361;
 target_ptr = Libderiv->deriv2_classes[9][5][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1075738, dvrr_stack+95381, dvrr_stack+20857);
 tmp = dvrr_stack + 1075738;
 target_ptr = Libderiv->deriv2_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1077278, dvrr_stack+1080099, dvrr_stack+1038894);
 tmp = dvrr_stack + 1077278;
 target_ptr = Libderiv->deriv2_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1079258, dvrr_stack+66670, dvrr_stack+272101);
 tmp = dvrr_stack + 1079258;
 target_ptr = Libderiv->deriv2_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+1021835, dvrr_stack+1184135, dvrr_stack+434953);
 tmp = dvrr_stack + 1021835;
 target_ptr = Libderiv->deriv2_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1184135, dvrr_stack+1187765, dvrr_stack+1181165);
 tmp = dvrr_stack + 1184135;
 target_ptr = Libderiv->deriv2_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+1187765, dvrr_stack+688360, dvrr_stack+401413);
 tmp = dvrr_stack + 1187765;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+1188206, dvrr_stack+4150, dvrr_stack+3730);
 tmp = dvrr_stack + 1188206;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+1188794, dvrr_stack+4934, dvrr_stack+6859);
 tmp = dvrr_stack + 1188794;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+1189550, dvrr_stack+237780, dvrr_stack+12118);
 tmp = dvrr_stack + 1189550;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+1190495, dvrr_stack+621791, dvrr_stack+243367);
 tmp = dvrr_stack + 1190495;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+95381, dvrr_stack+8203, dvrr_stack+36382);
 tmp = dvrr_stack + 95381;
 target_ptr = Libderiv->deriv2_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+117646, dvrr_stack+53755, dvrr_stack+53314);
 tmp = dvrr_stack + 117646;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+1180444, dvrr_stack+49008, dvrr_stack+117058);
 tmp = dvrr_stack + 1180444;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+1181228, dvrr_stack+1082475, dvrr_stack+118654);
 tmp = dvrr_stack + 1181228;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1182236, dvrr_stack+1192121, dvrr_stack+22927);
 tmp = dvrr_stack + 1182236;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+595895, dvrr_stack+1193741, dvrr_stack+213319);
 tmp = dvrr_stack + 595895;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+398169, dvrr_stack+1195721, dvrr_stack+147395);
 tmp = dvrr_stack + 398169;
 target_ptr = Libderiv->deriv2_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+118234, dvrr_stack+164812, dvrr_stack+688360);
 tmp = dvrr_stack + 118234;
 target_ptr = Libderiv->deriv2_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+687860, dvrr_stack+51601, dvrr_stack+4150);
 tmp = dvrr_stack + 687860;
 target_ptr = Libderiv->deriv2_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+147356, dvrr_stack+34608, dvrr_stack+4934);
 tmp = dvrr_stack + 147356;
 target_ptr = Libderiv->deriv2_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+66536, dvrr_stack+1198097, dvrr_stack+237780);
 tmp = dvrr_stack + 66536;
 target_ptr = Libderiv->deriv2_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+68156, dvrr_stack+1200122, dvrr_stack+621791);
 tmp = dvrr_stack + 68156;
 target_ptr = Libderiv->deriv2_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+70136, dvrr_stack+1202597, dvrr_stack+8203);
 tmp = dvrr_stack + 70136;
 target_ptr = Libderiv->deriv2_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+985020, dvrr_stack+244192, dvrr_stack+53755);
 tmp = dvrr_stack + 985020;
 target_ptr = Libderiv->deriv2_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+621530, dvrr_stack+274126, dvrr_stack+49008);
 tmp = dvrr_stack + 621530;
 target_ptr = Libderiv->deriv2_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+8183, dvrr_stack+256702, dvrr_stack+1082475);
 tmp = dvrr_stack + 8183;
 target_ptr = Libderiv->deriv2_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+1081733, dvrr_stack+121202, dvrr_stack+1192121);
 tmp = dvrr_stack + 1081733;
 target_ptr = Libderiv->deriv2_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+120670, dvrr_stack+131510, dvrr_stack+1193741);
 tmp = dvrr_stack + 120670;
 target_ptr = Libderiv->deriv2_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1191650, dvrr_stack+1061266, dvrr_stack+1195721);
 tmp = dvrr_stack + 1191650;
 target_ptr = Libderiv->deriv2_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+1194620, dvrr_stack+161842, dvrr_stack+164812);
 tmp = dvrr_stack + 1194620;
 target_ptr = Libderiv->deriv2_classes[9][5][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+1195775, dvrr_stack+144920, dvrr_stack+51601);
 tmp = dvrr_stack + 1195775;
 target_ptr = Libderiv->deriv2_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+1061206, dvrr_stack+1025406, dvrr_stack+34608);
 tmp = dvrr_stack + 1061206;
 target_ptr = Libderiv->deriv2_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+1024860, dvrr_stack+296930, dvrr_stack+1198097);
 tmp = dvrr_stack + 1024860;
 target_ptr = Libderiv->deriv2_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+296828, dvrr_stack+598361, dvrr_stack+1200122);
 tmp = dvrr_stack + 296828;
 target_ptr = Libderiv->deriv2_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1197315, dvrr_stack+1083771, dvrr_stack+1202597);
 tmp = dvrr_stack + 1197315;
 target_ptr = Libderiv->deriv2_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];


}

