/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gdii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gd|ii) integrals */

void d1hrr_order_gdii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[4][12][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5985;
 Libderiv->deriv_classes[5][7][11] = int_stack + 6573;
 Libderiv->deriv_classes[5][8][11] = int_stack + 7329;
 Libderiv->deriv_classes[5][9][11] = int_stack + 8274;
 Libderiv->deriv_classes[5][10][11] = int_stack + 9429;
 Libderiv->deriv_classes[5][11][11] = int_stack + 10815;
 Libderiv->deriv_classes[5][12][11] = int_stack + 12453;
 Libderiv->deriv_classes[6][6][11] = int_stack + 14364;
 Libderiv->deriv_classes[6][7][11] = int_stack + 15148;
 Libderiv->deriv_classes[6][8][11] = int_stack + 16156;
 Libderiv->deriv_classes[6][9][11] = int_stack + 17416;
 Libderiv->deriv_classes[6][10][11] = int_stack + 18956;
 Libderiv->deriv_classes[6][11][11] = int_stack + 20804;
 Libderiv->deriv_classes[6][12][11] = int_stack + 22988;
 Libderiv->deriv_classes[4][6][10] = int_stack + 25536;
 Libderiv->deriv_classes[4][7][10] = int_stack + 25956;
 Libderiv->deriv_classes[4][8][10] = int_stack + 26496;
 Libderiv->deriv_classes[4][9][10] = int_stack + 27171;
 Libderiv->deriv_classes[4][10][10] = int_stack + 27996;
 Libderiv->deriv_classes[4][11][10] = int_stack + 28986;
 Libderiv->deriv_classes[4][12][10] = int_stack + 30156;
 Libderiv->deriv_classes[5][6][10] = int_stack + 31521;
 Libderiv->deriv_classes[5][7][10] = int_stack + 32109;
 Libderiv->deriv_classes[5][8][10] = int_stack + 32865;
 Libderiv->deriv_classes[5][9][10] = int_stack + 33810;
 Libderiv->deriv_classes[5][10][10] = int_stack + 34965;
 Libderiv->deriv_classes[5][11][10] = int_stack + 36351;
 Libderiv->deriv_classes[5][12][10] = int_stack + 37989;
 Libderiv->deriv_classes[6][6][10] = int_stack + 39900;
 Libderiv->deriv_classes[6][7][10] = int_stack + 40684;
 Libderiv->deriv_classes[6][8][10] = int_stack + 41692;
 Libderiv->deriv_classes[6][9][10] = int_stack + 42952;
 Libderiv->deriv_classes[6][10][10] = int_stack + 44492;
 Libderiv->deriv_classes[6][11][10] = int_stack + 46340;
 Libderiv->deriv_classes[6][12][10] = int_stack + 48524;
 Libderiv->deriv_classes[4][6][9] = int_stack + 51072;
 Libderiv->deriv_classes[4][7][9] = int_stack + 51492;
 Libderiv->deriv_classes[4][8][9] = int_stack + 52032;
 Libderiv->deriv_classes[4][9][9] = int_stack + 52707;
 Libderiv->deriv_classes[4][10][9] = int_stack + 53532;
 Libderiv->deriv_classes[4][11][9] = int_stack + 54522;
 Libderiv->deriv_classes[4][12][9] = int_stack + 55692;
 Libderiv->deriv_classes[5][6][9] = int_stack + 57057;
 Libderiv->deriv_classes[5][7][9] = int_stack + 57645;
 Libderiv->deriv_classes[5][8][9] = int_stack + 58401;
 Libderiv->deriv_classes[5][9][9] = int_stack + 59346;
 Libderiv->deriv_classes[5][10][9] = int_stack + 60501;
 Libderiv->deriv_classes[5][11][9] = int_stack + 61887;
 Libderiv->deriv_classes[5][12][9] = int_stack + 63525;
 Libderiv->deriv_classes[6][6][9] = int_stack + 65436;
 Libderiv->deriv_classes[6][7][9] = int_stack + 66220;
 Libderiv->deriv_classes[6][8][9] = int_stack + 67228;
 Libderiv->deriv_classes[6][9][9] = int_stack + 68488;
 Libderiv->deriv_classes[6][10][9] = int_stack + 70028;
 Libderiv->deriv_classes[6][11][9] = int_stack + 71876;
 Libderiv->deriv_classes[6][12][9] = int_stack + 74060;
 Libderiv->deriv_classes[4][6][8] = int_stack + 76608;
 Libderiv->deriv_classes[4][7][8] = int_stack + 77028;
 Libderiv->deriv_classes[4][8][8] = int_stack + 77568;
 Libderiv->deriv_classes[4][9][8] = int_stack + 78243;
 Libderiv->deriv_classes[4][10][8] = int_stack + 79068;
 Libderiv->deriv_classes[4][11][8] = int_stack + 80058;
 Libderiv->deriv_classes[4][12][8] = int_stack + 81228;
 Libderiv->deriv_classes[5][6][8] = int_stack + 82593;
 Libderiv->deriv_classes[5][7][8] = int_stack + 83181;
 Libderiv->deriv_classes[5][8][8] = int_stack + 83937;
 Libderiv->deriv_classes[5][9][8] = int_stack + 84882;
 Libderiv->deriv_classes[5][10][8] = int_stack + 86037;
 Libderiv->deriv_classes[5][11][8] = int_stack + 87423;
 Libderiv->deriv_classes[5][12][8] = int_stack + 89061;
 Libderiv->deriv_classes[6][6][8] = int_stack + 90972;
 Libderiv->deriv_classes[6][7][8] = int_stack + 91756;
 Libderiv->deriv_classes[6][8][8] = int_stack + 92764;
 Libderiv->deriv_classes[6][9][8] = int_stack + 94024;
 Libderiv->deriv_classes[6][10][8] = int_stack + 95564;
 Libderiv->deriv_classes[6][11][8] = int_stack + 97412;
 Libderiv->deriv_classes[6][12][8] = int_stack + 99596;
 Libderiv->deriv_classes[4][6][7] = int_stack + 102144;
 Libderiv->deriv_classes[4][7][7] = int_stack + 102564;
 Libderiv->deriv_classes[4][8][7] = int_stack + 103104;
 Libderiv->deriv_classes[4][9][7] = int_stack + 103779;
 Libderiv->deriv_classes[4][10][7] = int_stack + 104604;
 Libderiv->deriv_classes[4][11][7] = int_stack + 105594;
 Libderiv->deriv_classes[4][12][7] = int_stack + 106764;
 Libderiv->deriv_classes[5][6][7] = int_stack + 108129;
 Libderiv->deriv_classes[5][7][7] = int_stack + 108717;
 Libderiv->deriv_classes[5][8][7] = int_stack + 109473;
 Libderiv->deriv_classes[5][9][7] = int_stack + 110418;
 Libderiv->deriv_classes[5][10][7] = int_stack + 111573;
 Libderiv->deriv_classes[5][11][7] = int_stack + 112959;
 Libderiv->deriv_classes[5][12][7] = int_stack + 114597;
 Libderiv->deriv_classes[6][6][7] = int_stack + 116508;
 Libderiv->deriv_classes[6][7][7] = int_stack + 117292;
 Libderiv->deriv_classes[6][8][7] = int_stack + 118300;
 Libderiv->deriv_classes[6][9][7] = int_stack + 119560;
 Libderiv->deriv_classes[6][10][7] = int_stack + 121100;
 Libderiv->deriv_classes[6][11][7] = int_stack + 122948;
 Libderiv->deriv_classes[6][12][7] = int_stack + 125132;
 Libderiv->deriv_classes[4][6][6] = int_stack + 127680;
 Libderiv->deriv_classes[4][7][6] = int_stack + 128100;
 Libderiv->deriv_classes[4][8][6] = int_stack + 128640;
 Libderiv->deriv_classes[4][9][6] = int_stack + 129315;
 Libderiv->deriv_classes[4][10][6] = int_stack + 130140;
 Libderiv->deriv_classes[4][11][6] = int_stack + 131130;
 Libderiv->deriv_classes[4][12][6] = int_stack + 132300;
 Libderiv->deriv_classes[5][6][6] = int_stack + 133665;
 Libderiv->deriv_classes[5][7][6] = int_stack + 134253;
 Libderiv->deriv_classes[5][8][6] = int_stack + 135009;
 Libderiv->deriv_classes[5][9][6] = int_stack + 135954;
 Libderiv->deriv_classes[5][10][6] = int_stack + 137109;
 Libderiv->deriv_classes[5][11][6] = int_stack + 138495;
 Libderiv->deriv_classes[5][12][6] = int_stack + 140133;
 Libderiv->dvrr_classes[6][6] = int_stack + 142044;
 Libderiv->deriv_classes[6][6][6] = int_stack + 142828;
 Libderiv->dvrr_classes[6][7] = int_stack + 143612;
 Libderiv->deriv_classes[6][7][6] = int_stack + 144620;
 Libderiv->dvrr_classes[6][8] = int_stack + 145628;
 Libderiv->deriv_classes[6][8][6] = int_stack + 146888;
 Libderiv->dvrr_classes[6][9] = int_stack + 148148;
 Libderiv->deriv_classes[6][9][6] = int_stack + 149688;
 Libderiv->dvrr_classes[6][10] = int_stack + 151228;
 Libderiv->deriv_classes[6][10][6] = int_stack + 153076;
 Libderiv->dvrr_classes[6][11] = int_stack + 154924;
 Libderiv->deriv_classes[6][11][6] = int_stack + 157108;
 Libderiv->deriv_classes[6][12][6] = int_stack + 159292;
 Libderiv->deriv_classes[4][6][2] = int_stack + 161840;
 Libderiv->deriv_classes[4][7][2] = int_stack + 162260;
 Libderiv->deriv_classes[4][8][2] = int_stack + 162800;
 Libderiv->deriv_classes[4][9][2] = int_stack + 163475;
 Libderiv->deriv_classes[4][10][2] = int_stack + 164300;
 Libderiv->deriv_classes[4][11][2] = int_stack + 165290;
 Libderiv->deriv_classes[4][12][2] = int_stack + 166460;
 Libderiv->deriv_classes[5][6][2] = int_stack + 167825;
 Libderiv->deriv_classes[5][7][2] = int_stack + 168413;
 Libderiv->deriv_classes[5][8][2] = int_stack + 169169;
 Libderiv->deriv_classes[5][9][2] = int_stack + 170114;
 Libderiv->deriv_classes[5][10][2] = int_stack + 171269;
 Libderiv->deriv_classes[5][11][2] = int_stack + 172655;
 Libderiv->deriv_classes[5][12][2] = int_stack + 174293;
 Libderiv->deriv_classes[6][6][2] = int_stack + 176204;
 Libderiv->deriv_classes[6][7][2] = int_stack + 176988;
 Libderiv->deriv_classes[6][8][2] = int_stack + 177996;
 Libderiv->deriv_classes[6][9][2] = int_stack + 179256;
 Libderiv->deriv_classes[6][10][2] = int_stack + 180796;
 Libderiv->deriv_classes[6][11][2] = int_stack + 182644;
 Libderiv->deriv_classes[6][12][2] = int_stack + 184828;
 Libderiv->deriv_classes[4][6][1] = int_stack + 187376;
 Libderiv->deriv_classes[4][7][1] = int_stack + 187796;
 Libderiv->deriv_classes[4][8][1] = int_stack + 188336;
 Libderiv->deriv_classes[4][9][1] = int_stack + 189011;
 Libderiv->deriv_classes[4][10][1] = int_stack + 189836;
 Libderiv->deriv_classes[4][11][1] = int_stack + 190826;
 Libderiv->deriv_classes[4][12][1] = int_stack + 191996;
 Libderiv->deriv_classes[5][6][1] = int_stack + 193361;
 Libderiv->deriv_classes[5][7][1] = int_stack + 193949;
 Libderiv->deriv_classes[5][8][1] = int_stack + 194705;
 Libderiv->deriv_classes[5][9][1] = int_stack + 195650;
 Libderiv->deriv_classes[5][10][1] = int_stack + 196805;
 Libderiv->deriv_classes[5][11][1] = int_stack + 198191;
 Libderiv->deriv_classes[5][12][1] = int_stack + 199829;
 Libderiv->deriv_classes[6][6][1] = int_stack + 201740;
 Libderiv->deriv_classes[6][7][1] = int_stack + 202524;
 Libderiv->deriv_classes[6][8][1] = int_stack + 203532;
 Libderiv->deriv_classes[6][9][1] = int_stack + 204792;
 Libderiv->deriv_classes[6][10][1] = int_stack + 206332;
 Libderiv->deriv_classes[6][11][1] = int_stack + 208180;
 Libderiv->deriv_classes[6][12][1] = int_stack + 210364;
 Libderiv->dvrr_classes[4][6] = int_stack + 212912;
 Libderiv->dvrr_classes[4][7] = int_stack + 213332;
 Libderiv->dvrr_classes[4][8] = int_stack + 213872;
 Libderiv->dvrr_classes[4][9] = int_stack + 214547;
 Libderiv->dvrr_classes[4][10] = int_stack + 215372;
 Libderiv->dvrr_classes[4][11] = int_stack + 216362;
 Libderiv->dvrr_classes[4][12] = int_stack + 217532;
 Libderiv->deriv_classes[4][6][0] = int_stack + 218897;
 Libderiv->deriv_classes[4][7][0] = int_stack + 219317;
 Libderiv->deriv_classes[4][8][0] = int_stack + 219857;
 Libderiv->deriv_classes[4][9][0] = int_stack + 220532;
 Libderiv->deriv_classes[4][10][0] = int_stack + 221357;
 Libderiv->deriv_classes[4][11][0] = int_stack + 222347;
 Libderiv->deriv_classes[4][12][0] = int_stack + 223517;
 Libderiv->dvrr_classes[5][6] = int_stack + 224882;
 Libderiv->dvrr_classes[5][7] = int_stack + 225470;
 Libderiv->dvrr_classes[5][8] = int_stack + 226226;
 Libderiv->dvrr_classes[5][9] = int_stack + 227171;
 Libderiv->dvrr_classes[5][10] = int_stack + 228326;
 Libderiv->dvrr_classes[5][11] = int_stack + 229712;
 Libderiv->dvrr_classes[5][12] = int_stack + 231350;
 Libderiv->deriv_classes[5][6][0] = int_stack + 233261;
 Libderiv->deriv_classes[5][7][0] = int_stack + 233849;
 Libderiv->deriv_classes[5][8][0] = int_stack + 234605;
 Libderiv->deriv_classes[5][9][0] = int_stack + 235550;
 Libderiv->deriv_classes[5][10][0] = int_stack + 236705;
 Libderiv->deriv_classes[5][11][0] = int_stack + 238091;
 Libderiv->deriv_classes[5][12][0] = int_stack + 239729;
 Libderiv->deriv_classes[6][6][0] = int_stack + 241640;
 Libderiv->deriv_classes[6][7][0] = int_stack + 242424;
 Libderiv->deriv_classes[6][8][0] = int_stack + 243432;
 Libderiv->deriv_classes[6][9][0] = int_stack + 244692;
 Libderiv->deriv_classes[6][10][0] = int_stack + 246232;
 Libderiv->deriv_classes[6][11][0] = int_stack + 248080;
 Libderiv->deriv_classes[6][12][0] = int_stack + 250264;
 memset(int_stack,0,2022496);

 Libderiv->dvrr_stack = int_stack + 1033668;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gdii(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+252812,int_stack+213332,int_stack+212912,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+254072,int_stack+213872,int_stack+213332,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+255692,int_stack+254072,int_stack+252812,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+258212,int_stack+214547,int_stack+213872,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+260237,int_stack+258212,int_stack+254072,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+263477,int_stack+260237,int_stack+255692,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+267677,int_stack+215372,int_stack+214547,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+270152,int_stack+267677,int_stack+258212,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+274202,int_stack+270152,int_stack+260237,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+279602,int_stack+274202,int_stack+263477,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+285902,int_stack+216362,int_stack+215372,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+288872,int_stack+285902,int_stack+267677,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+293822,int_stack+288872,int_stack+270152,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+300572,int_stack+293822,int_stack+274202,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+308672,int_stack+300572,int_stack+279602,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+317492,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212912,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+318752,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213332,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+320372,int_stack+318752,int_stack+317492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252812,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+322892,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213872,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+324917,int_stack+322892,int_stack+318752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254072,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+328157,int_stack+324917,int_stack+320372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255692,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+317492,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214547,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+332357,int_stack+317492,int_stack+322892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258212,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+336407,int_stack+332357,int_stack+324917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260237,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+319967,int_stack+336407,int_stack+328157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263477,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+326267,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215372,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+341807,int_stack+326267,int_stack+317492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267677,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+346757,int_stack+341807,int_stack+332357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270152,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+353507,int_stack+346757,int_stack+336407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274202,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+329237,int_stack+353507,int_stack+319967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279602,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+317492,int_stack+4620,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216362,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+317492,int_stack+326267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285902,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+317492,int_stack+0,int_stack+341807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288872,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+361607,int_stack+317492,int_stack+346757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293822,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+317492,int_stack+361607,int_stack+353507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300572,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+338057,int_stack+317492,int_stack+329237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308672,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+317492,int_stack+225470,int_stack+224882,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+319256,int_stack+226226,int_stack+225470,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+321524,int_stack+319256,int_stack+317492,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+325052,int_stack+227171,int_stack+226226,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+327887,int_stack+325052,int_stack+319256,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+327887,int_stack+321524,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+332423,int_stack+228326,int_stack+227171,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+349817,int_stack+332423,int_stack+325052,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+355487,int_stack+349817,int_stack+327887,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+363047,int_stack+355487,int_stack+0,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+371867,int_stack+229712,int_stack+228326,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+376025,int_stack+371867,int_stack+332423,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+382955,int_stack+376025,int_stack+349817,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+392405,int_stack+382955,int_stack+355487,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+403745,int_stack+392405,int_stack+363047,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+335888,int_stack+6573,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224882,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+416093,int_stack+7329,int_stack+6573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225470,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+418361,int_stack+416093,int_stack+335888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317492,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+421889,int_stack+8274,int_stack+7329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226226,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+424724,int_stack+421889,int_stack+416093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319256,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+429260,int_stack+424724,int_stack+418361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321524,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+416093,int_stack+9429,int_stack+8274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227171,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+435140,int_stack+416093,int_stack+421889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325052,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+440810,int_stack+435140,int_stack+424724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327887,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+419558,int_stack+440810,int_stack+429260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+428378,int_stack+10815,int_stack+9429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228326,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+448370,int_stack+428378,int_stack+416093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332423,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+455300,int_stack+448370,int_stack+435140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349817,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+464750,int_stack+455300,int_stack+440810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355487,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+432536,int_stack+464750,int_stack+419558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363047,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+416093,int_stack+12453,int_stack+10815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229712,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+5880,int_stack+416093,int_stack+428378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371867,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+416093,int_stack+5880,int_stack+448370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376025,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+476090,int_stack+416093,int_stack+455300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382955,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+416093,int_stack+476090,int_stack+464750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392405,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+444884,int_stack+416093,int_stack+432536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403745,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+461348,int_stack+444884,int_stack+338057,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+416093,int_stack+143612,int_stack+142044,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+418445,int_stack+145628,int_stack+143612,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+421469,int_stack+418445,int_stack+416093,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+426173,int_stack+148148,int_stack+145628,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+429953,int_stack+426173,int_stack+418445,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+436001,int_stack+429953,int_stack+421469,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+151228,int_stack+148148,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+335888,int_stack+5880,int_stack+426173,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+496628,int_stack+335888,int_stack+429953,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+506708,int_stack+496628,int_stack+436001,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+343448,int_stack+154924,int_stack+151228,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+518468,int_stack+343448,int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+527708,int_stack+518468,int_stack+335888,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+540308,int_stack+527708,int_stack+496628,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+555428,int_stack+540308,int_stack+506708,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+15148,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142044,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571892,int_stack+16156,int_stack+15148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143612,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574916,int_stack+571892,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416093,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10500,int_stack+17416,int_stack+16156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145628,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+579620,int_stack+10500,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418445,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+585668,int_stack+579620,int_stack+574916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421469,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+18956,int_stack+17416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148148,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+593508,int_stack+571892,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426173,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+601068,int_stack+593508,int_stack+579620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429953,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+611148,int_stack+601068,int_stack+585668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436001,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+10500,int_stack+20804,int_stack+18956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151228,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+576512,int_stack+10500,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+622908,int_stack+576512,int_stack+593508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335888,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+585752,int_stack+622908,int_stack+601068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496628,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+635508,int_stack+585752,int_stack+611148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506708,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+600872,int_stack+22988,int_stack+20804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154924,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+607424,int_stack+600872,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343448,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+651972,int_stack+607424,int_stack+576512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+600872,int_stack+651972,int_stack+622908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527708,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+651972,int_stack+600872,int_stack+585752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540308,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+651972,int_stack+635508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555428,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+593844,int_stack+571892,int_stack+444884,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+25956,int_stack+25536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212912, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+573152,int_stack+26496,int_stack+25956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213332, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574772,int_stack+573152,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252812, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+577292,int_stack+27171,int_stack+26496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213872, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+579317,int_stack+577292,int_stack+573152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254072, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+582557,int_stack+579317,int_stack+574772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255692, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+27996,int_stack+27171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214547, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+586757,int_stack+571892,int_stack+577292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258212, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10500,int_stack+586757,int_stack+579317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260237, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+574367,int_stack+10500,int_stack+582557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263477, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+580667,int_stack+28986,int_stack+27996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215372, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+15900,int_stack+580667,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267677, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+20850,int_stack+15900,int_stack+586757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270152, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+583637,int_stack+20850,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274202, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+643236,int_stack+583637,int_stack+574367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279602, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+10500,int_stack+30156,int_stack+28986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216362, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+580667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285902, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+652056,int_stack+571892,int_stack+15900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288872, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+571892,int_stack+652056,int_stack+20850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293822, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+652056,int_stack+571892,int_stack+583637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300572, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+652056,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308672, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+643236,int_stack+32109,int_stack+31521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224882, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+645000,int_stack+32865,int_stack+32109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225470, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+647268,int_stack+645000,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317492, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+650796,int_stack+33810,int_stack+32865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226226, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+653631,int_stack+650796,int_stack+645000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319256, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+658167,int_stack+653631,int_stack+647268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321524, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+643236,int_stack+34965,int_stack+33810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227171, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+664047,int_stack+643236,int_stack+650796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325052, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+583652,int_stack+664047,int_stack+653631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327887, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+646701,int_stack+583652,int_stack+658167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+655521,int_stack+36351,int_stack+34965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228326, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+10500,int_stack+655521,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332423, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+17430,int_stack+10500,int_stack+664047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349817, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+659679,int_stack+17430,int_stack+583652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355487, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+443841,int_stack+659679,int_stack+646701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363047, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+583652,int_stack+37989,int_stack+36351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229712, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+643236,int_stack+583652,int_stack+655521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371867, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+26880,int_stack+643236,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376025, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+643236,int_stack+26880,int_stack+17430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382955, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+10500,int_stack+643236,int_stack+659679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392405, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+643236,int_stack+10500,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403745, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+659700,int_stack+643236,int_stack+571892,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+40684,int_stack+39900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142044, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+574244,int_stack+41692,int_stack+40684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143612, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+577268,int_stack+574244,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416093, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+581972,int_stack+42952,int_stack+41692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145628, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+585752,int_stack+581972,int_stack+574244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418445, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+443841,int_stack+585752,int_stack+577268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421469, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+44492,int_stack+42952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148148, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+451681,int_stack+571892,int_stack+581972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426173, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10500,int_stack+451681,int_stack+585752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429953, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+576512,int_stack+10500,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436001, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+443841,int_stack+46340,int_stack+44492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151228, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+20580,int_stack+443841,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+29820,int_stack+20580,int_stack+451681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335888, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+694980,int_stack+29820,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496628, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+710100,int_stack+694980,int_stack+576512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506708, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+10500,int_stack+48524,int_stack+46340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154924, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343448, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+443841,int_stack+571892,int_stack+20580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+571892,int_stack+443841,int_stack+29820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527708, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+10500,int_stack+571892,int_stack+694980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540308, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+710100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555428, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+694980,int_stack+571892,int_stack+643236,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+643236,int_stack+51492,int_stack+51072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212912, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+644496,int_stack+52032,int_stack+51492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213332, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+646116,int_stack+644496,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252812, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+648636,int_stack+52707,int_stack+52032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213872, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+650661,int_stack+648636,int_stack+644496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254072, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+653901,int_stack+650661,int_stack+646116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255692, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+643236,int_stack+53532,int_stack+52707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214547, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+571892,int_stack+643236,int_stack+648636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258212, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+575942,int_stack+571892,int_stack+650661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260237, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+645711,int_stack+575942,int_stack+653901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263477, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+652011,int_stack+54522,int_stack+53532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215372, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+581342,int_stack+652011,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267677, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+586292,int_stack+581342,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270152, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+10500,int_stack+586292,int_stack+575942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274202, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+645711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279602, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+643236,int_stack+55692,int_stack+54522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216362, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+18600,int_stack+643236,int_stack+652011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285902, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+643236,int_stack+18600,int_stack+581342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288872, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+18600,int_stack+643236,int_stack+586292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293822, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+643236,int_stack+18600,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300572, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+10500,int_stack+643236,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308672, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+57645,int_stack+57057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224882, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+573656,int_stack+58401,int_stack+57645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225470, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+575924,int_stack+573656,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+579452,int_stack+59346,int_stack+58401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226226, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+582287,int_stack+579452,int_stack+573656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319256, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+586823,int_stack+582287,int_stack+575924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321524, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+60501,int_stack+59346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227171, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+643236,int_stack+571892,int_stack+579452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325052, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+648906,int_stack+643236,int_stack+582287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327887, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+575357,int_stack+648906,int_stack+586823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+584177,int_stack+61887,int_stack+60501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228326, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+22260,int_stack+584177,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332423, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+29190,int_stack+22260,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349817, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+38640,int_stack+29190,int_stack+648906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355487, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+643236,int_stack+38640,int_stack+575357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363047, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+571892,int_stack+63525,int_stack+61887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229712, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+49980,int_stack+571892,int_stack+584177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371867, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+571892,int_stack+49980,int_stack+22260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376025, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+49980,int_stack+571892,int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382955, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+571892,int_stack+49980,int_stack+38640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+22260,int_stack+571892,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403745, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+744372,int_stack+22260,int_stack+10500,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+66220,int_stack+65436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142044, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12852,int_stack+67228,int_stack+66220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143612, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15876,int_stack+12852,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416093, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+643236,int_stack+68488,int_stack+67228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145628, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+647016,int_stack+643236,int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418445, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571892,int_stack+647016,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421469, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10500,int_stack+70028,int_stack+68488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148148, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+579732,int_stack+10500,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426173, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+38724,int_stack+579732,int_stack+647016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429953, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+643236,int_stack+38724,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436001, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+571892,int_stack+71876,int_stack+70028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151228, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+48804,int_stack+571892,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+58044,int_stack+48804,int_stack+579732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335888, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+577436,int_stack+58044,int_stack+38724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496628, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+443841,int_stack+577436,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506708, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+643236,int_stack+74060,int_stack+71876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154924, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+10500,int_stack+643236,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+643236,int_stack+10500,int_stack+48804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+38724,int_stack+643236,int_stack+58044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527708, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+779652,int_stack+38724,int_stack+577436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540308, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+779652,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555428, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+779652,int_stack+571892,int_stack+22260,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+77028,int_stack+76608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+573152,int_stack+77568,int_stack+77028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574772,int_stack+573152,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+577292,int_stack+78243,int_stack+77568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+579317,int_stack+577292,int_stack+573152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+582557,int_stack+579317,int_stack+574772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+79068,int_stack+78243, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+586757,int_stack+571892,int_stack+577292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+443841,int_stack+586757,int_stack+579317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+574367,int_stack+443841,int_stack+582557, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+580667,int_stack+80058,int_stack+79068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+449241,int_stack+580667,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+454191,int_stack+449241,int_stack+586757, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+583637,int_stack+454191,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+643236,int_stack+583637,int_stack+574367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+443841,int_stack+81228,int_stack+80058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+571892,int_stack+443841,int_stack+580667, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+10500,int_stack+571892,int_stack+449241, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+454191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+10500,int_stack+571892,int_stack+583637, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+10500,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+643236,int_stack+83181,int_stack+82593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+645000,int_stack+83937,int_stack+83181, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+647268,int_stack+645000,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+650796,int_stack+84882,int_stack+83937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+653631,int_stack+650796,int_stack+645000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10500,int_stack+653631,int_stack+647268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+643236,int_stack+86037,int_stack+84882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16380,int_stack+643236,int_stack+650796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+22050,int_stack+16380,int_stack+653631, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+646701,int_stack+22050,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+10500,int_stack+87423,int_stack+86037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+29610,int_stack+10500,int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+36540,int_stack+29610,int_stack+16380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+45990,int_stack+36540,int_stack+22050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+14658,int_stack+45990,int_stack+646701, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+643236,int_stack+89061,int_stack+87423, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+648150,int_stack+643236,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+57330,int_stack+648150,int_stack+29610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+643236,int_stack+57330,int_stack+36540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+57330,int_stack+643236,int_stack+45990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+643236,int_stack+57330,int_stack+14658, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+10500,int_stack+643236,int_stack+571892,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+91756,int_stack+90972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+574244,int_stack+92764,int_stack+91756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+577268,int_stack+574244,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+581972,int_stack+94024,int_stack+92764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+585752,int_stack+581972,int_stack+574244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45780,int_stack+585752,int_stack+577268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+95564,int_stack+94024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+53620,int_stack+571892,int_stack+581972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+61180,int_stack+53620,int_stack+585752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+576512,int_stack+61180,int_stack+45780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+45780,int_stack+97412,int_stack+95564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+71260,int_stack+45780,int_stack+571892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+80500,int_stack+71260,int_stack+53620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+443841,int_stack+80500,int_stack+61180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51324,int_stack+443841,int_stack+576512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+571892,int_stack+99596,int_stack+97412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+578444,int_stack+571892,int_stack+45780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+829044,int_stack+578444,int_stack+71260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+571892,int_stack+829044,int_stack+80500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+67788,int_stack+571892,int_stack+443841, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+67788,int_stack+51324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+45780,int_stack+571892,int_stack+643236,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+643236,int_stack+102564,int_stack+102144, 0.0, zero_stack, 1.0, int_stack+212912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+644496,int_stack+103104,int_stack+102564, 0.0, zero_stack, 1.0, int_stack+213332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+646116,int_stack+644496,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+252812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+648636,int_stack+103779,int_stack+103104, 0.0, zero_stack, 1.0, int_stack+213872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+650661,int_stack+648636,int_stack+644496, 0.0, zero_stack, 1.0, int_stack+254072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+653901,int_stack+650661,int_stack+646116, 0.0, zero_stack, 1.0, int_stack+255692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+643236,int_stack+104604,int_stack+103779, 0.0, zero_stack, 1.0, int_stack+214547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+571892,int_stack+643236,int_stack+648636, 0.0, zero_stack, 1.0, int_stack+258212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+575942,int_stack+571892,int_stack+650661, 0.0, zero_stack, 1.0, int_stack+260237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+645711,int_stack+575942,int_stack+653901, 0.0, zero_stack, 1.0, int_stack+263477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+652011,int_stack+105594,int_stack+104604, 0.0, zero_stack, 1.0, int_stack+215372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+581342,int_stack+652011,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+267677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+586292,int_stack+581342,int_stack+571892, 0.0, zero_stack, 1.0, int_stack+270152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+443841,int_stack+586292,int_stack+575942, 0.0, zero_stack, 1.0, int_stack+274202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+571892,int_stack+443841,int_stack+645711, 0.0, zero_stack, 1.0, int_stack+279602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+643236,int_stack+106764,int_stack+105594, 0.0, zero_stack, 1.0, int_stack+216362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+451941,int_stack+643236,int_stack+652011, 0.0, zero_stack, 1.0, int_stack+285902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+643236,int_stack+451941,int_stack+581342, 0.0, zero_stack, 1.0, int_stack+288872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+829044,int_stack+643236,int_stack+586292, 0.0, zero_stack, 1.0, int_stack+293822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+643236,int_stack+829044,int_stack+443841, 0.0, zero_stack, 1.0, int_stack+300572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+443841,int_stack+643236,int_stack+571892, 0.0, zero_stack, 1.0, int_stack+308672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+108717,int_stack+108129, 0.0, zero_stack, 1.0, int_stack+224882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+573656,int_stack+109473,int_stack+108717, 0.0, zero_stack, 1.0, int_stack+225470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+575924,int_stack+573656,int_stack+571892, 0.0, zero_stack, 1.0, int_stack+317492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+579452,int_stack+110418,int_stack+109473, 0.0, zero_stack, 1.0, int_stack+226226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+582287,int_stack+579452,int_stack+573656, 0.0, zero_stack, 1.0, int_stack+319256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+586823,int_stack+582287,int_stack+575924, 0.0, zero_stack, 1.0, int_stack+321524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571892,int_stack+111573,int_stack+110418, 0.0, zero_stack, 1.0, int_stack+227171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+643236,int_stack+571892,int_stack+579452, 0.0, zero_stack, 1.0, int_stack+325052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+648906,int_stack+643236,int_stack+582287, 0.0, zero_stack, 1.0, int_stack+327887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+575357,int_stack+648906,int_stack+586823, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+584177,int_stack+112959,int_stack+111573, 0.0, zero_stack, 1.0, int_stack+228326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+829044,int_stack+584177,int_stack+571892, 0.0, zero_stack, 1.0, int_stack+332423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+95172,int_stack+829044,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+349817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+835974,int_stack+95172,int_stack+648906, 0.0, zero_stack, 1.0, int_stack+355487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+643236,int_stack+835974,int_stack+575357, 0.0, zero_stack, 1.0, int_stack+363047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+571892,int_stack+114597,int_stack+112959, 0.0, zero_stack, 1.0, int_stack+229712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+104622,int_stack+571892,int_stack+584177, 0.0, zero_stack, 1.0, int_stack+371867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+571892,int_stack+104622,int_stack+829044, 0.0, zero_stack, 1.0, int_stack+376025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+847314,int_stack+571892,int_stack+95172, 0.0, zero_stack, 1.0, int_stack+382955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+95172,int_stack+847314,int_stack+835974, 0.0, zero_stack, 1.0, int_stack+392405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+571892,int_stack+95172,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+403745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+829044,int_stack+571892,int_stack+443841,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+443841,int_stack+117292,int_stack+116508, 0.0, zero_stack, 1.0, int_stack+142044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+446193,int_stack+118300,int_stack+117292, 0.0, zero_stack, 1.0, int_stack+143612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+449217,int_stack+446193,int_stack+443841, 0.0, zero_stack, 1.0, int_stack+416093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+453921,int_stack+119560,int_stack+118300, 0.0, zero_stack, 1.0, int_stack+145628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+643236,int_stack+453921,int_stack+446193, 0.0, zero_stack, 1.0, int_stack+418445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+649284,int_stack+643236,int_stack+449217, 0.0, zero_stack, 1.0, int_stack+421469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+443841,int_stack+121100,int_stack+119560, 0.0, zero_stack, 1.0, int_stack+148148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+95172,int_stack+443841,int_stack+453921, 0.0, zero_stack, 1.0, int_stack+426173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+448461,int_stack+95172,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+429953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+102732,int_stack+448461,int_stack+649284, 0.0, zero_stack, 1.0, int_stack+436001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+643236,int_stack+122948,int_stack+121100, 0.0, zero_stack, 1.0, int_stack+151228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+648780,int_stack+643236,int_stack+443841, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+864324,int_stack+648780,int_stack+95172, 0.0, zero_stack, 1.0, int_stack+335888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+876924,int_stack+864324,int_stack+448461, 0.0, zero_stack, 1.0, int_stack+496628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+443841,int_stack+876924,int_stack+102732, 0.0, zero_stack, 1.0, int_stack+506708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+95172,int_stack+125132,int_stack+122948, 0.0, zero_stack, 1.0, int_stack+154924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+101724,int_stack+95172,int_stack+643236, 0.0, zero_stack, 1.0, int_stack+343448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+892044,int_stack+101724,int_stack+648780, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+95172,int_stack+892044,int_stack+864324, 0.0, zero_stack, 1.0, int_stack+527708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+892044,int_stack+95172,int_stack+876924, 0.0, zero_stack, 1.0, int_stack+540308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+95172,int_stack+892044,int_stack+443841, 0.0, zero_stack, 1.0, int_stack+555428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+864324,int_stack+95172,int_stack+571892,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571892,int_stack+128100,int_stack+127680, 1.0, int_stack+212912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+573152,int_stack+128640,int_stack+128100, 1.0, int_stack+213332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574772,int_stack+573152,int_stack+571892, 1.0, int_stack+252812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+577292,int_stack+129315,int_stack+128640, 1.0, int_stack+213872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+579317,int_stack+577292,int_stack+573152, 1.0, int_stack+254072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+582557,int_stack+579317,int_stack+574772, 1.0, int_stack+255692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+252812,int_stack+130140,int_stack+129315, 1.0, int_stack+214547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+571892,int_stack+252812,int_stack+577292, 1.0, int_stack+258212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+586757,int_stack+571892,int_stack+579317, 1.0, int_stack+260237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+255287,int_stack+586757,int_stack+582557, 1.0, int_stack+263477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+261587,int_stack+131130,int_stack+130140, 1.0, int_stack+215372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+575942,int_stack+261587,int_stack+252812, 1.0, int_stack+267677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+95172,int_stack+575942,int_stack+571892, 1.0, int_stack+270152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+264557,int_stack+95172,int_stack+586757, 1.0, int_stack+274202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+580892,int_stack+264557,int_stack+255287, 1.0, int_stack+279602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+571892,int_stack+132300,int_stack+131130, 1.0, int_stack+216362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+252812,int_stack+571892,int_stack+261587, 1.0, int_stack+285902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+272657,int_stack+252812,int_stack+575942, 1.0, int_stack+288872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+252812,int_stack+272657,int_stack+95172, 1.0, int_stack+293822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+95172,int_stack+252812,int_stack+264557, 1.0, int_stack+300572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+252812,int_stack+95172,int_stack+580892, 1.0, int_stack+308672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95172,int_stack+134253,int_stack+133665, 1.0, int_stack+224882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96936,int_stack+135009,int_stack+134253, 1.0, int_stack+225470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99204,int_stack+96936,int_stack+95172, 1.0, int_stack+317492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+102732,int_stack+135954,int_stack+135009, 1.0, int_stack+226226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+105567,int_stack+102732,int_stack+96936, 1.0, int_stack+319256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+110103,int_stack+105567,int_stack+99204, 1.0, int_stack+321524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+317492,int_stack+137109,int_stack+135954, 1.0, int_stack+227171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+95172,int_stack+317492,int_stack+102732, 1.0, int_stack+325052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+115983,int_stack+95172,int_stack+105567, 1.0, int_stack+327887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+320957,int_stack+115983,int_stack+110103, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+138495,int_stack+137109, 1.0, int_stack+228326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+100842,int_stack+0,int_stack+317492, 1.0, int_stack+332423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+123543,int_stack+100842,int_stack+95172, 1.0, int_stack+349817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+264572,int_stack+123543,int_stack+115983, 1.0, int_stack+355487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+107772,int_stack+264572,int_stack+320957, 1.0, int_stack+363047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+95172,int_stack+140133,int_stack+138495, 1.0, int_stack+229712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+317492,int_stack+95172,int_stack+0, 1.0, int_stack+371867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+571892,int_stack+317492,int_stack+100842, 1.0, int_stack+376025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+317492,int_stack+571892,int_stack+123543, 1.0, int_stack+382955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+571892,int_stack+317492,int_stack+264572, 1.0, int_stack+392405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+643236,int_stack+571892,int_stack+107772, 1.0, int_stack+403745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+95172,int_stack+643236,int_stack+252812,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252812,int_stack+144620,int_stack+142828, 1.0, int_stack+142044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+255164,int_stack+146888,int_stack+144620, 1.0, int_stack+143612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+258188,int_stack+255164,int_stack+252812, 1.0, int_stack+416093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+262892,int_stack+149688,int_stack+146888, 1.0, int_stack+145628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+266672,int_stack+262892,int_stack+255164, 1.0, int_stack+418445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+272720,int_stack+266672,int_stack+258188, 1.0, int_stack+421469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+416093,int_stack+153076,int_stack+149688, 1.0, int_stack+148148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+252812,int_stack+416093,int_stack+262892, 1.0, int_stack+426173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+571892,int_stack+252812,int_stack+266672, 1.0, int_stack+429953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+420713,int_stack+571892,int_stack+272720, 1.0, int_stack+436001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+432473,int_stack+157108,int_stack+153076, 1.0, int_stack+151228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+438017,int_stack+432473,int_stack+416093, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+447257,int_stack+438017,int_stack+252812, 1.0, int_stack+335888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+252812,int_stack+447257,int_stack+571892, 1.0, int_stack+496628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+571892,int_stack+252812,int_stack+420713, 1.0, int_stack+506708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+496628,int_stack+159292,int_stack+157108, 1.0, int_stack+154924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+503180,int_stack+496628,int_stack+432473, 1.0, int_stack+343448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+267932,int_stack+503180,int_stack+438017, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+496628,int_stack+267932,int_stack+447257, 1.0, int_stack+527708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+515528,int_stack+496628,int_stack+252812, 1.0, int_stack+540308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+252812,int_stack+515528,int_stack+571892, 1.0, int_stack+555428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+496628,int_stack+252812,int_stack+643236,784);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+643236,int_stack+217532,int_stack+216362,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+646746,int_stack+643236,int_stack+285902,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+252812,int_stack+646746,int_stack+288872,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+643236,int_stack+252812,int_stack+293822,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+252812,int_stack+643236,int_stack+300572,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+643236,int_stack+252812,int_stack+308672,15);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+252812,int_stack+231350,int_stack+229712,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+257726,int_stack+252812,int_stack+371867,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+266042,int_stack+257726,int_stack+376025,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+277592,int_stack+266042,int_stack+382955,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+252812,int_stack+277592,int_stack+392405,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+268688,int_stack+252812,int_stack+403745,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+285152,int_stack+268688,int_stack+643236,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+252812,int_stack+162260,int_stack+161840,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+254072,int_stack+162800,int_stack+162260,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+255692,int_stack+254072,int_stack+252812,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+258212,int_stack+163475,int_stack+162800,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+260237,int_stack+258212,int_stack+254072,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+263477,int_stack+260237,int_stack+255692,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+252812,int_stack+164300,int_stack+163475,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+320432,int_stack+252812,int_stack+258212,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+324482,int_stack+320432,int_stack+260237,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+255287,int_stack+324482,int_stack+263477,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+261587,int_stack+165290,int_stack+164300,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+329882,int_stack+261587,int_stack+252812,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+334832,int_stack+329882,int_stack+320432,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+341582,int_stack+334832,int_stack+324482,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+320432,int_stack+341582,int_stack+255287,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+252812,int_stack+166460,int_stack+165290,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+349682,int_stack+252812,int_stack+261587,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+252812,int_stack+349682,int_stack+329882,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+349682,int_stack+252812,int_stack+334832,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+252812,int_stack+349682,int_stack+341582,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+329252,int_stack+252812,int_stack+320432,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+320432,int_stack+168413,int_stack+167825,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+322196,int_stack+169169,int_stack+168413,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+324464,int_stack+322196,int_stack+320432,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+252812,int_stack+170114,int_stack+169169,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+255647,int_stack+252812,int_stack+322196,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+260183,int_stack+255647,int_stack+324464,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+320432,int_stack+171269,int_stack+170114,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+341012,int_stack+320432,int_stack+252812,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+346682,int_stack+341012,int_stack+255647,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+354242,int_stack+346682,int_stack+260183,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+252812,int_stack+172655,int_stack+171269,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+256970,int_stack+252812,int_stack+320432,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+363062,int_stack+256970,int_stack+341012,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+372512,int_stack+363062,int_stack+346682,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+341012,int_stack+372512,int_stack+354242,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+353360,int_stack+174293,int_stack+172655,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+320432,int_stack+353360,int_stack+252812,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+383852,int_stack+320432,int_stack+256970,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+252812,int_stack+383852,int_stack+363062,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+383852,int_stack+252812,int_stack+372512,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+399728,int_stack+383852,int_stack+341012,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+341012,int_stack+399728,int_stack+329252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+376292,int_stack+176988,int_stack+176204,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+378644,int_stack+177996,int_stack+176988,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+654996,int_stack+378644,int_stack+376292,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+381668,int_stack+179256,int_stack+177996,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+385448,int_stack+381668,int_stack+378644,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+391496,int_stack+385448,int_stack+654996,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+654996,int_stack+180796,int_stack+179256,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+252812,int_stack+654996,int_stack+381668,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+416192,int_stack+252812,int_stack+385448,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+376292,int_stack+416192,int_stack+391496,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+388052,int_stack+182644,int_stack+180796,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+426272,int_stack+388052,int_stack+654996,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+435512,int_stack+426272,int_stack+252812,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+252812,int_stack+435512,int_stack+416192,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+320432,int_stack+252812,int_stack+376292,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+376292,int_stack+184828,int_stack+182644,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+448112,int_stack+376292,int_stack+388052,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+376292,int_stack+448112,int_stack+426272,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+416192,int_stack+376292,int_stack+435512,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+376292,int_stack+416192,int_stack+252812,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+416192,int_stack+376292,int_stack+320432,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+130452,int_stack+416192,int_stack+399728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+320432,int_stack+187796,int_stack+187376,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+321692,int_stack+188336,int_stack+187796,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+323312,int_stack+321692,int_stack+320432,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+325832,int_stack+189011,int_stack+188336,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+327857,int_stack+325832,int_stack+321692,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+331097,int_stack+327857,int_stack+323312,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+320432,int_stack+189836,int_stack+189011,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+335297,int_stack+320432,int_stack+325832,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+376292,int_stack+335297,int_stack+327857,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+322907,int_stack+376292,int_stack+331097,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+329207,int_stack+190826,int_stack+189836,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+381692,int_stack+329207,int_stack+320432,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+386642,int_stack+381692,int_stack+335297,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+332177,int_stack+386642,int_stack+376292,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+393392,int_stack+332177,int_stack+322907,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+376292,int_stack+191996,int_stack+190826,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+320432,int_stack+376292,int_stack+329207,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+402212,int_stack+320432,int_stack+381692,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+320432,int_stack+402212,int_stack+386642,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+402212,int_stack+320432,int_stack+332177,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+320432,int_stack+402212,int_stack+393392,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+332192,int_stack+193949,int_stack+193361,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+333956,int_stack+194705,int_stack+193949,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+336224,int_stack+333956,int_stack+332192,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+376292,int_stack+195650,int_stack+194705,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+379127,int_stack+376292,int_stack+333956,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+383663,int_stack+379127,int_stack+336224,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+332192,int_stack+196805,int_stack+195650,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+389543,int_stack+332192,int_stack+376292,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+395213,int_stack+389543,int_stack+379127,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+402773,int_stack+395213,int_stack+383663,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+376292,int_stack+198191,int_stack+196805,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+380450,int_stack+376292,int_stack+332192,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+411593,int_stack+380450,int_stack+389543,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+421043,int_stack+411593,int_stack+395213,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+387380,int_stack+421043,int_stack+402773,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+332192,int_stack+199829,int_stack+198191,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+399728,int_stack+332192,int_stack+376292,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+432383,int_stack+399728,int_stack+380450,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+443933,int_stack+432383,int_stack+411593,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+252812,int_stack+443933,int_stack+421043,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+399728,int_stack+252812,int_stack+387380,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+416192,int_stack+399728,int_stack+320432, 0.0, zero_stack, 1.0, int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+320432,int_stack+202524,int_stack+201740,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+322784,int_stack+203532,int_stack+202524,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+654996,int_stack+322784,int_stack+320432,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+325808,int_stack+204792,int_stack+203532,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+329588,int_stack+325808,int_stack+322784,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+252812,int_stack+329588,int_stack+654996,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+654996,int_stack+206332,int_stack+204792,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+260652,int_stack+654996,int_stack+325808,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+376292,int_stack+260652,int_stack+329588,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+320432,int_stack+376292,int_stack+252812,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+252812,int_stack+208180,int_stack+206332,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+451472,int_stack+252812,int_stack+654996,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+386372,int_stack+451472,int_stack+260652,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+546020,int_stack+386372,int_stack+376292,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+561140,int_stack+546020,int_stack+320432,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+320432,int_stack+210364,int_stack+208180,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+326984,int_stack+320432,int_stack+252812,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+252812,int_stack+326984,int_stack+451472,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+320432,int_stack+252812,int_stack+386372,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+376292,int_stack+320432,int_stack+546020,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+179844,int_stack+376292,int_stack+561140,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+913716,int_stack+179844,int_stack+399728, 0.0, zero_stack, 1.0, int_stack+268688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+179844,int_stack+219317,int_stack+218897,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+181104,int_stack+219857,int_stack+219317,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+182724,int_stack+181104,int_stack+179844,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+185244,int_stack+220532,int_stack+219857,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+187269,int_stack+185244,int_stack+181104,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+190509,int_stack+187269,int_stack+182724,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+179844,int_stack+221357,int_stack+220532,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+194709,int_stack+179844,int_stack+185244,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+198759,int_stack+194709,int_stack+187269,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+182319,int_stack+198759,int_stack+190509,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+188619,int_stack+222347,int_stack+221357,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+204159,int_stack+188619,int_stack+179844,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+209109,int_stack+204159,int_stack+194709,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+376292,int_stack+209109,int_stack+198759,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+191589,int_stack+376292,int_stack+182319,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+179844,int_stack+223517,int_stack+222347,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+215859,int_stack+179844,int_stack+188619,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+179844,int_stack+215859,int_stack+204159,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+215859,int_stack+179844,int_stack+209109,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+179844,int_stack+215859,int_stack+376292,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+376292,int_stack+179844,int_stack+191589,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+179844,int_stack+233849,int_stack+233261,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+181608,int_stack+234605,int_stack+233849,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+183876,int_stack+181608,int_stack+179844,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+187404,int_stack+235550,int_stack+234605,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+190239,int_stack+187404,int_stack+181608,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+194775,int_stack+190239,int_stack+183876,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+179844,int_stack+236705,int_stack+235550,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+200655,int_stack+179844,int_stack+187404,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+206325,int_stack+200655,int_stack+190239,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+183309,int_stack+206325,int_stack+194775,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+192129,int_stack+238091,int_stack+236705,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+213885,int_stack+192129,int_stack+179844,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+220815,int_stack+213885,int_stack+200655,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+388052,int_stack+220815,int_stack+206325,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+196287,int_stack+388052,int_stack+183309,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+179844,int_stack+239729,int_stack+238091,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+230265,int_stack+179844,int_stack+192129,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+179844,int_stack+230265,int_stack+213885,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+399392,int_stack+179844,int_stack+220815,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+252812,int_stack+399392,int_stack+388052,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+388052,int_stack+252812,int_stack+196287,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+179844,int_stack+388052,int_stack+376292, 1.0, int_stack+643236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+643236,int_stack+242424,int_stack+241640,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+645588,int_stack+243432,int_stack+242424,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+648612,int_stack+645588,int_stack+643236,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+653316,int_stack+244692,int_stack+243432,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+376292,int_stack+653316,int_stack+645588,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+252812,int_stack+376292,int_stack+648612,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+643236,int_stack+246232,int_stack+244692,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+260652,int_stack+643236,int_stack+653316,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+647856,int_stack+260652,int_stack+376292,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+376292,int_stack+647856,int_stack+252812,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+252812,int_stack+248080,int_stack+246232,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+404516,int_stack+252812,int_stack+643236,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+215124,int_stack+404516,int_stack+260652,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+227724,int_stack+215124,int_stack+647856,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+643236,int_stack+227724,int_stack+376292,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+376292,int_stack+250264,int_stack+248080,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+546020,int_stack+376292,int_stack+252812,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+242844,int_stack+546020,int_stack+404516,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+546020,int_stack+242844,int_stack+215124,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+242844,int_stack+546020,int_stack+227724,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+546020,int_stack+242844,int_stack+643236,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+215124,int_stack+546020,int_stack+388052, 1.0, int_stack+268688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+963108,int_stack+593844,int_stack+461348,784);
     Libderiv->ABCD[11] = int_stack + 963108;
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+546020,int_stack+694980,int_stack+659700,784);
     Libderiv->ABCD[10] = int_stack + 546020;
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+616580,int_stack+779652,int_stack+744372,784);
     Libderiv->ABCD[9] = int_stack + 616580;
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+687140,int_stack+45780,int_stack+10500,784);
     Libderiv->ABCD[8] = int_stack + 687140;
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+757700,int_stack+864324,int_stack+829044,784);
     Libderiv->ABCD[7] = int_stack + 757700;
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+828260,int_stack+496628,int_stack+95172,784);
     Libderiv->ABCD[6] = int_stack + 828260;
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+451472,int_stack+130452,int_stack+341012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 451472;
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+320432,int_stack+913716,int_stack+416192, 0.0, zero_stack, 1.0, int_stack+285152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 320432;
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+215124,int_stack+179844, 1.0, int_stack+285152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 0;

}
