/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_igih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ig|ih) integrals */

void d1hrr_order_igih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[6][11][11] = int_stack + 6440;
 Libderiv->deriv_classes[7][6][11] = int_stack + 8624;
 Libderiv->deriv_classes[7][7][11] = int_stack + 9632;
 Libderiv->deriv_classes[7][8][11] = int_stack + 10928;
 Libderiv->deriv_classes[7][9][11] = int_stack + 12548;
 Libderiv->deriv_classes[7][10][11] = int_stack + 14528;
 Libderiv->deriv_classes[7][11][11] = int_stack + 16904;
 Libderiv->deriv_classes[8][6][11] = int_stack + 19712;
 Libderiv->deriv_classes[8][7][11] = int_stack + 20972;
 Libderiv->deriv_classes[8][8][11] = int_stack + 22592;
 Libderiv->deriv_classes[8][9][11] = int_stack + 24617;
 Libderiv->deriv_classes[8][10][11] = int_stack + 27092;
 Libderiv->deriv_classes[8][11][11] = int_stack + 30062;
 Libderiv->deriv_classes[9][6][11] = int_stack + 33572;
 Libderiv->deriv_classes[9][7][11] = int_stack + 35112;
 Libderiv->deriv_classes[9][8][11] = int_stack + 37092;
 Libderiv->deriv_classes[9][9][11] = int_stack + 39567;
 Libderiv->deriv_classes[9][10][11] = int_stack + 42592;
 Libderiv->deriv_classes[9][11][11] = int_stack + 46222;
 Libderiv->deriv_classes[10][6][11] = int_stack + 50512;
 Libderiv->deriv_classes[10][7][11] = int_stack + 52360;
 Libderiv->deriv_classes[10][8][11] = int_stack + 54736;
 Libderiv->deriv_classes[10][9][11] = int_stack + 57706;
 Libderiv->deriv_classes[10][10][11] = int_stack + 61336;
 Libderiv->deriv_classes[10][11][11] = int_stack + 65692;
 Libderiv->deriv_classes[6][6][10] = int_stack + 70840;
 Libderiv->deriv_classes[6][7][10] = int_stack + 71624;
 Libderiv->deriv_classes[6][8][10] = int_stack + 72632;
 Libderiv->deriv_classes[6][9][10] = int_stack + 73892;
 Libderiv->deriv_classes[6][10][10] = int_stack + 75432;
 Libderiv->deriv_classes[6][11][10] = int_stack + 77280;
 Libderiv->deriv_classes[7][6][10] = int_stack + 79464;
 Libderiv->deriv_classes[7][7][10] = int_stack + 80472;
 Libderiv->deriv_classes[7][8][10] = int_stack + 81768;
 Libderiv->deriv_classes[7][9][10] = int_stack + 83388;
 Libderiv->deriv_classes[7][10][10] = int_stack + 85368;
 Libderiv->deriv_classes[7][11][10] = int_stack + 87744;
 Libderiv->deriv_classes[8][6][10] = int_stack + 90552;
 Libderiv->deriv_classes[8][7][10] = int_stack + 91812;
 Libderiv->deriv_classes[8][8][10] = int_stack + 93432;
 Libderiv->deriv_classes[8][9][10] = int_stack + 95457;
 Libderiv->deriv_classes[8][10][10] = int_stack + 97932;
 Libderiv->deriv_classes[8][11][10] = int_stack + 100902;
 Libderiv->deriv_classes[9][6][10] = int_stack + 104412;
 Libderiv->deriv_classes[9][7][10] = int_stack + 105952;
 Libderiv->deriv_classes[9][8][10] = int_stack + 107932;
 Libderiv->deriv_classes[9][9][10] = int_stack + 110407;
 Libderiv->deriv_classes[9][10][10] = int_stack + 113432;
 Libderiv->deriv_classes[9][11][10] = int_stack + 117062;
 Libderiv->deriv_classes[10][6][10] = int_stack + 121352;
 Libderiv->deriv_classes[10][7][10] = int_stack + 123200;
 Libderiv->deriv_classes[10][8][10] = int_stack + 125576;
 Libderiv->deriv_classes[10][9][10] = int_stack + 128546;
 Libderiv->deriv_classes[10][10][10] = int_stack + 132176;
 Libderiv->deriv_classes[10][11][10] = int_stack + 136532;
 Libderiv->deriv_classes[6][6][9] = int_stack + 141680;
 Libderiv->deriv_classes[6][7][9] = int_stack + 142464;
 Libderiv->deriv_classes[6][8][9] = int_stack + 143472;
 Libderiv->deriv_classes[6][9][9] = int_stack + 144732;
 Libderiv->deriv_classes[6][10][9] = int_stack + 146272;
 Libderiv->deriv_classes[6][11][9] = int_stack + 148120;
 Libderiv->deriv_classes[7][6][9] = int_stack + 150304;
 Libderiv->deriv_classes[7][7][9] = int_stack + 151312;
 Libderiv->deriv_classes[7][8][9] = int_stack + 152608;
 Libderiv->deriv_classes[7][9][9] = int_stack + 154228;
 Libderiv->deriv_classes[7][10][9] = int_stack + 156208;
 Libderiv->deriv_classes[7][11][9] = int_stack + 158584;
 Libderiv->deriv_classes[8][6][9] = int_stack + 161392;
 Libderiv->deriv_classes[8][7][9] = int_stack + 162652;
 Libderiv->deriv_classes[8][8][9] = int_stack + 164272;
 Libderiv->deriv_classes[8][9][9] = int_stack + 166297;
 Libderiv->deriv_classes[8][10][9] = int_stack + 168772;
 Libderiv->deriv_classes[8][11][9] = int_stack + 171742;
 Libderiv->deriv_classes[9][6][9] = int_stack + 175252;
 Libderiv->deriv_classes[9][7][9] = int_stack + 176792;
 Libderiv->deriv_classes[9][8][9] = int_stack + 178772;
 Libderiv->deriv_classes[9][9][9] = int_stack + 181247;
 Libderiv->deriv_classes[9][10][9] = int_stack + 184272;
 Libderiv->deriv_classes[9][11][9] = int_stack + 187902;
 Libderiv->deriv_classes[10][6][9] = int_stack + 192192;
 Libderiv->deriv_classes[10][7][9] = int_stack + 194040;
 Libderiv->deriv_classes[10][8][9] = int_stack + 196416;
 Libderiv->deriv_classes[10][9][9] = int_stack + 199386;
 Libderiv->deriv_classes[10][10][9] = int_stack + 203016;
 Libderiv->deriv_classes[10][11][9] = int_stack + 207372;
 Libderiv->deriv_classes[6][6][8] = int_stack + 212520;
 Libderiv->deriv_classes[6][7][8] = int_stack + 213304;
 Libderiv->deriv_classes[6][8][8] = int_stack + 214312;
 Libderiv->deriv_classes[6][9][8] = int_stack + 215572;
 Libderiv->deriv_classes[6][10][8] = int_stack + 217112;
 Libderiv->deriv_classes[6][11][8] = int_stack + 218960;
 Libderiv->deriv_classes[7][6][8] = int_stack + 221144;
 Libderiv->deriv_classes[7][7][8] = int_stack + 222152;
 Libderiv->deriv_classes[7][8][8] = int_stack + 223448;
 Libderiv->deriv_classes[7][9][8] = int_stack + 225068;
 Libderiv->deriv_classes[7][10][8] = int_stack + 227048;
 Libderiv->deriv_classes[7][11][8] = int_stack + 229424;
 Libderiv->deriv_classes[8][6][8] = int_stack + 232232;
 Libderiv->deriv_classes[8][7][8] = int_stack + 233492;
 Libderiv->deriv_classes[8][8][8] = int_stack + 235112;
 Libderiv->deriv_classes[8][9][8] = int_stack + 237137;
 Libderiv->deriv_classes[8][10][8] = int_stack + 239612;
 Libderiv->deriv_classes[8][11][8] = int_stack + 242582;
 Libderiv->deriv_classes[9][6][8] = int_stack + 246092;
 Libderiv->deriv_classes[9][7][8] = int_stack + 247632;
 Libderiv->deriv_classes[9][8][8] = int_stack + 249612;
 Libderiv->deriv_classes[9][9][8] = int_stack + 252087;
 Libderiv->deriv_classes[9][10][8] = int_stack + 255112;
 Libderiv->deriv_classes[9][11][8] = int_stack + 258742;
 Libderiv->deriv_classes[10][6][8] = int_stack + 263032;
 Libderiv->deriv_classes[10][7][8] = int_stack + 264880;
 Libderiv->deriv_classes[10][8][8] = int_stack + 267256;
 Libderiv->deriv_classes[10][9][8] = int_stack + 270226;
 Libderiv->deriv_classes[10][10][8] = int_stack + 273856;
 Libderiv->deriv_classes[10][11][8] = int_stack + 278212;
 Libderiv->deriv_classes[6][6][7] = int_stack + 283360;
 Libderiv->deriv_classes[6][7][7] = int_stack + 284144;
 Libderiv->deriv_classes[6][8][7] = int_stack + 285152;
 Libderiv->deriv_classes[6][9][7] = int_stack + 286412;
 Libderiv->deriv_classes[6][10][7] = int_stack + 287952;
 Libderiv->deriv_classes[6][11][7] = int_stack + 289800;
 Libderiv->deriv_classes[7][6][7] = int_stack + 291984;
 Libderiv->deriv_classes[7][7][7] = int_stack + 292992;
 Libderiv->deriv_classes[7][8][7] = int_stack + 294288;
 Libderiv->deriv_classes[7][9][7] = int_stack + 295908;
 Libderiv->deriv_classes[7][10][7] = int_stack + 297888;
 Libderiv->deriv_classes[7][11][7] = int_stack + 300264;
 Libderiv->deriv_classes[8][6][7] = int_stack + 303072;
 Libderiv->deriv_classes[8][7][7] = int_stack + 304332;
 Libderiv->deriv_classes[8][8][7] = int_stack + 305952;
 Libderiv->deriv_classes[8][9][7] = int_stack + 307977;
 Libderiv->deriv_classes[8][10][7] = int_stack + 310452;
 Libderiv->deriv_classes[8][11][7] = int_stack + 313422;
 Libderiv->deriv_classes[9][6][7] = int_stack + 316932;
 Libderiv->deriv_classes[9][7][7] = int_stack + 318472;
 Libderiv->deriv_classes[9][8][7] = int_stack + 320452;
 Libderiv->deriv_classes[9][9][7] = int_stack + 322927;
 Libderiv->deriv_classes[9][10][7] = int_stack + 325952;
 Libderiv->deriv_classes[9][11][7] = int_stack + 329582;
 Libderiv->deriv_classes[10][6][7] = int_stack + 333872;
 Libderiv->deriv_classes[10][7][7] = int_stack + 335720;
 Libderiv->deriv_classes[10][8][7] = int_stack + 338096;
 Libderiv->deriv_classes[10][9][7] = int_stack + 341066;
 Libderiv->deriv_classes[10][10][7] = int_stack + 344696;
 Libderiv->deriv_classes[10][11][7] = int_stack + 349052;
 Libderiv->deriv_classes[6][6][6] = int_stack + 354200;
 Libderiv->deriv_classes[6][7][6] = int_stack + 354984;
 Libderiv->deriv_classes[6][8][6] = int_stack + 355992;
 Libderiv->deriv_classes[6][9][6] = int_stack + 357252;
 Libderiv->deriv_classes[6][10][6] = int_stack + 358792;
 Libderiv->deriv_classes[6][11][6] = int_stack + 360640;
 Libderiv->deriv_classes[7][6][6] = int_stack + 362824;
 Libderiv->deriv_classes[7][7][6] = int_stack + 363832;
 Libderiv->deriv_classes[7][8][6] = int_stack + 365128;
 Libderiv->deriv_classes[7][9][6] = int_stack + 366748;
 Libderiv->deriv_classes[7][10][6] = int_stack + 368728;
 Libderiv->deriv_classes[7][11][6] = int_stack + 371104;
 Libderiv->deriv_classes[8][6][6] = int_stack + 373912;
 Libderiv->deriv_classes[8][7][6] = int_stack + 375172;
 Libderiv->deriv_classes[8][8][6] = int_stack + 376792;
 Libderiv->deriv_classes[8][9][6] = int_stack + 378817;
 Libderiv->deriv_classes[8][10][6] = int_stack + 381292;
 Libderiv->deriv_classes[8][11][6] = int_stack + 384262;
 Libderiv->deriv_classes[9][6][6] = int_stack + 387772;
 Libderiv->deriv_classes[9][7][6] = int_stack + 389312;
 Libderiv->deriv_classes[9][8][6] = int_stack + 391292;
 Libderiv->deriv_classes[9][9][6] = int_stack + 393767;
 Libderiv->deriv_classes[9][10][6] = int_stack + 396792;
 Libderiv->deriv_classes[9][11][6] = int_stack + 400422;
 Libderiv->dvrr_classes[10][6] = int_stack + 404712;
 Libderiv->deriv_classes[10][6][6] = int_stack + 406560;
 Libderiv->dvrr_classes[10][7] = int_stack + 408408;
 Libderiv->deriv_classes[10][7][6] = int_stack + 410784;
 Libderiv->dvrr_classes[10][8] = int_stack + 413160;
 Libderiv->deriv_classes[10][8][6] = int_stack + 416130;
 Libderiv->dvrr_classes[10][9] = int_stack + 419100;
 Libderiv->deriv_classes[10][9][6] = int_stack + 422730;
 Libderiv->dvrr_classes[10][10] = int_stack + 426360;
 Libderiv->deriv_classes[10][10][6] = int_stack + 430716;
 Libderiv->deriv_classes[10][11][6] = int_stack + 435072;
 Libderiv->deriv_classes[6][6][2] = int_stack + 440220;
 Libderiv->deriv_classes[6][7][2] = int_stack + 441004;
 Libderiv->deriv_classes[6][8][2] = int_stack + 442012;
 Libderiv->deriv_classes[6][9][2] = int_stack + 443272;
 Libderiv->deriv_classes[6][10][2] = int_stack + 444812;
 Libderiv->deriv_classes[6][11][2] = int_stack + 446660;
 Libderiv->deriv_classes[7][6][2] = int_stack + 448844;
 Libderiv->deriv_classes[7][7][2] = int_stack + 449852;
 Libderiv->deriv_classes[7][8][2] = int_stack + 451148;
 Libderiv->deriv_classes[7][9][2] = int_stack + 452768;
 Libderiv->deriv_classes[7][10][2] = int_stack + 454748;
 Libderiv->deriv_classes[7][11][2] = int_stack + 457124;
 Libderiv->deriv_classes[8][6][2] = int_stack + 459932;
 Libderiv->deriv_classes[8][7][2] = int_stack + 461192;
 Libderiv->deriv_classes[8][8][2] = int_stack + 462812;
 Libderiv->deriv_classes[8][9][2] = int_stack + 464837;
 Libderiv->deriv_classes[8][10][2] = int_stack + 467312;
 Libderiv->deriv_classes[8][11][2] = int_stack + 470282;
 Libderiv->deriv_classes[9][6][2] = int_stack + 473792;
 Libderiv->deriv_classes[9][7][2] = int_stack + 475332;
 Libderiv->deriv_classes[9][8][2] = int_stack + 477312;
 Libderiv->deriv_classes[9][9][2] = int_stack + 479787;
 Libderiv->deriv_classes[9][10][2] = int_stack + 482812;
 Libderiv->deriv_classes[9][11][2] = int_stack + 486442;
 Libderiv->deriv_classes[10][6][2] = int_stack + 490732;
 Libderiv->deriv_classes[10][7][2] = int_stack + 492580;
 Libderiv->deriv_classes[10][8][2] = int_stack + 494956;
 Libderiv->deriv_classes[10][9][2] = int_stack + 497926;
 Libderiv->deriv_classes[10][10][2] = int_stack + 501556;
 Libderiv->deriv_classes[10][11][2] = int_stack + 505912;
 Libderiv->deriv_classes[6][6][1] = int_stack + 511060;
 Libderiv->deriv_classes[6][7][1] = int_stack + 511844;
 Libderiv->deriv_classes[6][8][1] = int_stack + 512852;
 Libderiv->deriv_classes[6][9][1] = int_stack + 514112;
 Libderiv->deriv_classes[6][10][1] = int_stack + 515652;
 Libderiv->deriv_classes[6][11][1] = int_stack + 517500;
 Libderiv->deriv_classes[7][6][1] = int_stack + 519684;
 Libderiv->deriv_classes[7][7][1] = int_stack + 520692;
 Libderiv->deriv_classes[7][8][1] = int_stack + 521988;
 Libderiv->deriv_classes[7][9][1] = int_stack + 523608;
 Libderiv->deriv_classes[7][10][1] = int_stack + 525588;
 Libderiv->deriv_classes[7][11][1] = int_stack + 527964;
 Libderiv->deriv_classes[8][6][1] = int_stack + 530772;
 Libderiv->deriv_classes[8][7][1] = int_stack + 532032;
 Libderiv->deriv_classes[8][8][1] = int_stack + 533652;
 Libderiv->deriv_classes[8][9][1] = int_stack + 535677;
 Libderiv->deriv_classes[8][10][1] = int_stack + 538152;
 Libderiv->deriv_classes[8][11][1] = int_stack + 541122;
 Libderiv->deriv_classes[9][6][1] = int_stack + 544632;
 Libderiv->deriv_classes[9][7][1] = int_stack + 546172;
 Libderiv->deriv_classes[9][8][1] = int_stack + 548152;
 Libderiv->deriv_classes[9][9][1] = int_stack + 550627;
 Libderiv->deriv_classes[9][10][1] = int_stack + 553652;
 Libderiv->deriv_classes[9][11][1] = int_stack + 557282;
 Libderiv->deriv_classes[10][6][1] = int_stack + 561572;
 Libderiv->deriv_classes[10][7][1] = int_stack + 563420;
 Libderiv->deriv_classes[10][8][1] = int_stack + 565796;
 Libderiv->deriv_classes[10][9][1] = int_stack + 568766;
 Libderiv->deriv_classes[10][10][1] = int_stack + 572396;
 Libderiv->deriv_classes[10][11][1] = int_stack + 576752;
 Libderiv->dvrr_classes[6][6] = int_stack + 581900;
 Libderiv->dvrr_classes[6][7] = int_stack + 582684;
 Libderiv->dvrr_classes[6][8] = int_stack + 583692;
 Libderiv->dvrr_classes[6][9] = int_stack + 584952;
 Libderiv->dvrr_classes[6][10] = int_stack + 586492;
 Libderiv->dvrr_classes[6][11] = int_stack + 588340;
 Libderiv->deriv_classes[6][6][0] = int_stack + 590524;
 Libderiv->deriv_classes[6][7][0] = int_stack + 591308;
 Libderiv->deriv_classes[6][8][0] = int_stack + 592316;
 Libderiv->deriv_classes[6][9][0] = int_stack + 593576;
 Libderiv->deriv_classes[6][10][0] = int_stack + 595116;
 Libderiv->deriv_classes[6][11][0] = int_stack + 596964;
 Libderiv->dvrr_classes[7][6] = int_stack + 599148;
 Libderiv->dvrr_classes[7][7] = int_stack + 600156;
 Libderiv->dvrr_classes[7][8] = int_stack + 601452;
 Libderiv->dvrr_classes[7][9] = int_stack + 603072;
 Libderiv->dvrr_classes[7][10] = int_stack + 605052;
 Libderiv->dvrr_classes[7][11] = int_stack + 607428;
 Libderiv->deriv_classes[7][6][0] = int_stack + 610236;
 Libderiv->deriv_classes[7][7][0] = int_stack + 611244;
 Libderiv->deriv_classes[7][8][0] = int_stack + 612540;
 Libderiv->deriv_classes[7][9][0] = int_stack + 614160;
 Libderiv->deriv_classes[7][10][0] = int_stack + 616140;
 Libderiv->deriv_classes[7][11][0] = int_stack + 618516;
 Libderiv->dvrr_classes[8][6] = int_stack + 621324;
 Libderiv->dvrr_classes[8][7] = int_stack + 622584;
 Libderiv->dvrr_classes[8][8] = int_stack + 624204;
 Libderiv->dvrr_classes[8][9] = int_stack + 626229;
 Libderiv->dvrr_classes[8][10] = int_stack + 628704;
 Libderiv->dvrr_classes[8][11] = int_stack + 631674;
 Libderiv->deriv_classes[8][6][0] = int_stack + 635184;
 Libderiv->deriv_classes[8][7][0] = int_stack + 636444;
 Libderiv->deriv_classes[8][8][0] = int_stack + 638064;
 Libderiv->deriv_classes[8][9][0] = int_stack + 640089;
 Libderiv->deriv_classes[8][10][0] = int_stack + 642564;
 Libderiv->deriv_classes[8][11][0] = int_stack + 645534;
 Libderiv->dvrr_classes[9][6] = int_stack + 649044;
 Libderiv->dvrr_classes[9][7] = int_stack + 650584;
 Libderiv->dvrr_classes[9][8] = int_stack + 652564;
 Libderiv->dvrr_classes[9][9] = int_stack + 655039;
 Libderiv->dvrr_classes[9][10] = int_stack + 658064;
 Libderiv->dvrr_classes[9][11] = int_stack + 661694;
 Libderiv->deriv_classes[9][6][0] = int_stack + 665984;
 Libderiv->deriv_classes[9][7][0] = int_stack + 667524;
 Libderiv->deriv_classes[9][8][0] = int_stack + 669504;
 Libderiv->deriv_classes[9][9][0] = int_stack + 671979;
 Libderiv->deriv_classes[9][10][0] = int_stack + 675004;
 Libderiv->deriv_classes[9][11][0] = int_stack + 678634;
 Libderiv->deriv_classes[10][6][0] = int_stack + 682924;
 Libderiv->deriv_classes[10][7][0] = int_stack + 684772;
 Libderiv->deriv_classes[10][8][0] = int_stack + 687148;
 Libderiv->deriv_classes[10][9][0] = int_stack + 690118;
 Libderiv->deriv_classes[10][10][0] = int_stack + 693748;
 Libderiv->deriv_classes[10][11][0] = int_stack + 698104;
 memset(int_stack,0,5626016);

 Libderiv->dvrr_stack = int_stack + 4694003;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_igih(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+703252,int_stack+582684,int_stack+581900,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+705604,int_stack+583692,int_stack+582684,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+708628,int_stack+705604,int_stack+703252,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+713332,int_stack+584952,int_stack+583692,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+717112,int_stack+713332,int_stack+705604,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+723160,int_stack+717112,int_stack+708628,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+731000,int_stack+586492,int_stack+584952,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+735620,int_stack+731000,int_stack+713332,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+743180,int_stack+735620,int_stack+717112,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+753260,int_stack+743180,int_stack+723160,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+765020,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581900,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767372,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582684,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+770396,int_stack+767372,int_stack+765020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703252,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+775100,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583692,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+778880,int_stack+775100,int_stack+767372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705604,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+784928,int_stack+778880,int_stack+770396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708628,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+765020,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584952,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+792768,int_stack+765020,int_stack+775100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713332,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+800328,int_stack+792768,int_stack+778880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717112,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+769640,int_stack+800328,int_stack+784928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723160,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+781400,int_stack+6440,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586492,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+810408,int_stack+781400,int_stack+765020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731000,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+819648,int_stack+810408,int_stack+792768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735620,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+781400,int_stack+819648,int_stack+800328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743180,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+796520,int_stack+781400,int_stack+769640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753260,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+765020,int_stack+600156,int_stack+599148,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+768044,int_stack+601452,int_stack+600156,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+771932,int_stack+768044,int_stack+765020,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+777980,int_stack+603072,int_stack+601452,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+782840,int_stack+777980,int_stack+768044,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+812984,int_stack+782840,int_stack+771932,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+823064,int_stack+605052,int_stack+603072,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+829004,int_stack+823064,int_stack+777980,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+838724,int_stack+829004,int_stack+782840,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+851684,int_stack+838724,int_stack+812984,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+790616,int_stack+9632,int_stack+8624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599148,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+10928,int_stack+9632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600156,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3888,int_stack+0,int_stack+790616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765020,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+790616,int_stack+12548,int_stack+10928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601452,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+866804,int_stack+790616,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768044,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+874580,int_stack+866804,int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771932,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+14528,int_stack+12548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603072,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+884660,int_stack+0,int_stack+790616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777980,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+894380,int_stack+884660,int_stack+866804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782840,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+907340,int_stack+894380,int_stack+874580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812984,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+866804,int_stack+16904,int_stack+14528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605052,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+5940,int_stack+866804,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823064,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+866804,int_stack+5940,int_stack+884660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829004,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+866804,int_stack+894380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838724,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+866804,int_stack+0,int_stack+907340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851684,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+887972,int_stack+866804,int_stack+796520,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+622584,int_stack+621324,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+624204,int_stack+622584,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8640,int_stack+3780,int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+790616,int_stack+626229,int_stack+624204,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+796691,int_stack+790616,int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+937364,int_stack+796691,int_stack+8640,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+949964,int_stack+628704,int_stack+626229,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+957389,int_stack+949964,int_stack+790616,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+969539,int_stack+957389,int_stack+796691,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+985739,int_stack+969539,int_stack+937364,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+806411,int_stack+20972,int_stack+19712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621324,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1004639,int_stack+22592,int_stack+20972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622584,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1009499,int_stack+1004639,int_stack+806411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+806411,int_stack+24617,int_stack+22592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624204,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1017059,int_stack+806411,int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1026779,int_stack+1017059,int_stack+1009499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1004639,int_stack+27092,int_stack+24617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+626229,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1039379,int_stack+1004639,int_stack+806411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790616,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1051529,int_stack+1039379,int_stack+1017059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796691,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1067729,int_stack+1051529,int_stack+1026779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+937364,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1012064,int_stack+30062,int_stack+27092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628704,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1020974,int_stack+1012064,int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949964,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1086629,int_stack+1020974,int_stack+1039379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957389,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1004639,int_stack+1086629,int_stack+1051529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+969539,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1028939,int_stack+1004639,int_stack+1067729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+985739,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1055399,int_stack+1028939,int_stack+866804,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1118903,int_stack+1055399,int_stack+887972,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+866804,int_stack+650584,int_stack+649044,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+871424,int_stack+652564,int_stack+650584,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+877364,int_stack+871424,int_stack+866804,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+886604,int_stack+655039,int_stack+652564,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+894029,int_stack+886604,int_stack+871424,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+905909,int_stack+894029,int_stack+877364,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+921309,int_stack+658064,int_stack+655039,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1004639,int_stack+921309,int_stack+886604,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1217687,int_stack+1004639,int_stack+894029,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1237487,int_stack+1217687,int_stack+905909,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+930384,int_stack+35112,int_stack+33572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649044,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1019489,int_stack+37092,int_stack+35112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650584,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16200,int_stack+1019489,int_stack+930384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866804,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+25440,int_stack+39567,int_stack+37092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652564,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1260587,int_stack+25440,int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871424,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1272467,int_stack+1260587,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877364,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16200,int_stack+42592,int_stack+39567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655039,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1287867,int_stack+16200,int_stack+25440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886604,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1302717,int_stack+1287867,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894029,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1322517,int_stack+1302717,int_stack+1272467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905909,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1260587,int_stack+46222,int_stack+42592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658064,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+25275,int_stack+1260587,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921309,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1260587,int_stack+25275,int_stack+1287867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004639,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+16200,int_stack+1260587,int_stack+1302717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1217687,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1260587,int_stack+16200,int_stack+1322517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1237487,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1292927,int_stack+1260587,int_stack+1028939,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1372307,int_stack+1292927,int_stack+1055399,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1499315,int_stack+1372307,int_stack+1118903,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+16200,int_stack+408408,int_stack+404712,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+21744,int_stack+413160,int_stack+408408,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+28872,int_stack+21744,int_stack+16200,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+39960,int_stack+419100,int_stack+413160,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1019489,int_stack+39960,int_stack+21744,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1033745,int_stack+1019489,int_stack+28872,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1052225,int_stack+426360,int_stack+419100,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1063115,int_stack+1052225,int_stack+39960,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1080935,int_stack+1063115,int_stack+1019489,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1104695,int_stack+1080935,int_stack+1033745,66);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1132415,int_stack+52360,int_stack+50512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404712,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1137959,int_stack+54736,int_stack+52360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408408,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1145087,int_stack+1137959,int_stack+1132415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16200,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1156175,int_stack+57706,int_stack+54736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413160,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1165085,int_stack+1156175,int_stack+1137959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21744,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1179341,int_stack+1165085,int_stack+1145087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28872,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1132415,int_stack+61336,int_stack+57706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419100,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1197821,int_stack+1132415,int_stack+1156175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39960,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1663955,int_stack+1197821,int_stack+1165085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019489,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1143305,int_stack+1663955,int_stack+1179341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1033745,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1171025,int_stack+65692,int_stack+61336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426360,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+48870,int_stack+1171025,int_stack+1132415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052225,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1687715,int_stack+48870,int_stack+1197821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063115,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1171025,int_stack+1687715,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080935,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1663955,int_stack+1171025,int_stack+1143305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1104695,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1702763,int_stack+1663955,int_stack+1260587,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1799783,int_stack+1702763,int_stack+1292927,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1958543,int_stack+1799783,int_stack+1372307,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+71624,int_stack+70840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581900, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262939,int_stack+72632,int_stack+71624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582684, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1265963,int_stack+1262939,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1270667,int_stack+73892,int_stack+72632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583692, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1274447,int_stack+1270667,int_stack+1262939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705604, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1280495,int_stack+1274447,int_stack+1265963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708628, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+75432,int_stack+73892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584952, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1288335,int_stack+1260587,int_stack+1270667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713332, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295895,int_stack+1288335,int_stack+1274447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717112, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1265207,int_stack+1295895,int_stack+1280495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723160, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1276967,int_stack+77280,int_stack+75432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586492, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1305975,int_stack+1276967,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731000, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1315215,int_stack+1305975,int_stack+1288335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735620, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1276967,int_stack+1315215,int_stack+1295895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743180, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1292087,int_stack+1276967,int_stack+1265207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753260, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+80472,int_stack+79464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599148, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263611,int_stack+81768,int_stack+80472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600156, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267499,int_stack+1263611,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765020, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1273547,int_stack+83388,int_stack+81768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601452, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1278407,int_stack+1273547,int_stack+1263611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768044, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1308551,int_stack+1278407,int_stack+1267499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771932, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+85368,int_stack+83388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603072, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1318631,int_stack+1260587,int_stack+1273547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777980, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1328351,int_stack+1318631,int_stack+1278407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782840, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1266527,int_stack+1328351,int_stack+1308551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812984, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1308551,int_stack+87744,int_stack+85368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605052, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1341311,int_stack+1308551,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823064, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1353191,int_stack+1341311,int_stack+1318631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829004, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1308551,int_stack+1353191,int_stack+1328351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838724, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1327991,int_stack+1308551,int_stack+1266527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851684, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1349159,int_stack+1327991,int_stack+1292087,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+91812,int_stack+90552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621324, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1264367,int_stack+93432,int_stack+91812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622584, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269227,int_stack+1264367,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1276787,int_stack+95457,int_stack+93432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624204, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1282862,int_stack+1276787,int_stack+1264367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1292582,int_stack+1282862,int_stack+1269227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+97932,int_stack+95457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+626229, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1305182,int_stack+1260587,int_stack+1276787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790616, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1398551,int_stack+1305182,int_stack+1282862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796691, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1268012,int_stack+1398551,int_stack+1292582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+937364, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1286912,int_stack+100902,int_stack+97932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628704, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1414751,int_stack+1286912,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949964, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1429601,int_stack+1414751,int_stack+1305182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957389, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1286912,int_stack+1429601,int_stack+1398551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+969539, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1398551,int_stack+1286912,int_stack+1268012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+985739, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1425011,int_stack+1398551,int_stack+1327991,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1663955,int_stack+1425011,int_stack+1349159,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488515,int_stack+105952,int_stack+104412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649044, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1493135,int_stack+107932,int_stack+105952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650584, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1260587,int_stack+1493135,int_stack+1488515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866804, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1269827,int_stack+110407,int_stack+107932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652564, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1277252,int_stack+1269827,int_stack+1493135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871424, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1289132,int_stack+1277252,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877364, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+113432,int_stack+110407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655039, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1304532,int_stack+1260587,int_stack+1269827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886604, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1319382,int_stack+1304532,int_stack+1277252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894029, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1339182,int_stack+1319382,int_stack+1289132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905909, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1269662,int_stack+117062,int_stack+113432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658064, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1280552,int_stack+1269662,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921309, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1362282,int_stack+1280552,int_stack+1304532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004639, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260587,int_stack+1362282,int_stack+1319382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1217687, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1362282,int_stack+1260587,int_stack+1339182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1237487, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1260587,int_stack+1362282,int_stack+1398551,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1762739,int_stack+1260587,int_stack+1425011,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2170223,int_stack+1762739,int_stack+1663955,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1663955,int_stack+123200,int_stack+121352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404712, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1669499,int_stack+125576,int_stack+123200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408408, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1676627,int_stack+1669499,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16200, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1687715,int_stack+128546,int_stack+125576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413160, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1696625,int_stack+1687715,int_stack+1669499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21744, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1710881,int_stack+1696625,int_stack+1676627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28872, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1663955,int_stack+132176,int_stack+128546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419100, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1729361,int_stack+1663955,int_stack+1687715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39960, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1394622,int_stack+1729361,int_stack+1696625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1674845,int_stack+1394622,int_stack+1710881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1033745, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1702565,int_stack+136532,int_stack+132176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426360, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1339967,int_stack+1702565,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052225, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1418382,int_stack+1339967,int_stack+1729361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063115, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1702565,int_stack+1418382,int_stack+1394622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080935, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1394622,int_stack+1702565,int_stack+1674845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1104695, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1663955,int_stack+1394622,int_stack+1362282,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1339967,int_stack+1663955,int_stack+1260587,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2334863,int_stack+1339967,int_stack+1762739,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+142464,int_stack+141680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581900, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262939,int_stack+143472,int_stack+142464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582684, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1265963,int_stack+1262939,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1270667,int_stack+144732,int_stack+143472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583692, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1274447,int_stack+1270667,int_stack+1262939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705604, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1280495,int_stack+1274447,int_stack+1265963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708628, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+146272,int_stack+144732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584952, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1288335,int_stack+1260587,int_stack+1270667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713332, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295895,int_stack+1288335,int_stack+1274447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1265207,int_stack+1295895,int_stack+1280495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723160, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1276967,int_stack+148120,int_stack+146272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586492, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1305975,int_stack+1276967,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731000, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1315215,int_stack+1305975,int_stack+1288335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735620, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1276967,int_stack+1315215,int_stack+1295895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1292087,int_stack+1276967,int_stack+1265207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753260, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+151312,int_stack+150304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599148, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263611,int_stack+152608,int_stack+151312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600156, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267499,int_stack+1263611,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765020, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1273547,int_stack+154228,int_stack+152608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601452, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1278407,int_stack+1273547,int_stack+1263611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768044, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1308551,int_stack+1278407,int_stack+1267499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771932, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+156208,int_stack+154228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603072, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1318631,int_stack+1260587,int_stack+1273547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777980, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1328351,int_stack+1318631,int_stack+1278407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782840, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1266527,int_stack+1328351,int_stack+1308551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812984, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1308551,int_stack+158584,int_stack+156208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605052, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1341311,int_stack+1308551,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823064, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1353191,int_stack+1341311,int_stack+1318631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829004, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1308551,int_stack+1353191,int_stack+1328351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838724, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1327991,int_stack+1308551,int_stack+1266527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851684, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1349159,int_stack+1327991,int_stack+1292087,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+162652,int_stack+161392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621324, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1264367,int_stack+164272,int_stack+162652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622584, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269227,int_stack+1264367,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1276787,int_stack+166297,int_stack+164272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624204, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1282862,int_stack+1276787,int_stack+1264367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1292582,int_stack+1282862,int_stack+1269227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+168772,int_stack+166297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+626229, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1305182,int_stack+1260587,int_stack+1276787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790616, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1398551,int_stack+1305182,int_stack+1282862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796691, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1268012,int_stack+1398551,int_stack+1292582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+937364, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1286912,int_stack+171742,int_stack+168772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628704, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1414751,int_stack+1286912,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949964, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1429601,int_stack+1414751,int_stack+1305182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957389, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1286912,int_stack+1429601,int_stack+1398551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+969539, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1398551,int_stack+1286912,int_stack+1268012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+985739, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1425011,int_stack+1398551,int_stack+1327991,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1663955,int_stack+1425011,int_stack+1349159,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488515,int_stack+176792,int_stack+175252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649044, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1493135,int_stack+178772,int_stack+176792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650584, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1260587,int_stack+1493135,int_stack+1488515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866804, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1269827,int_stack+181247,int_stack+178772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652564, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1277252,int_stack+1269827,int_stack+1493135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871424, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1289132,int_stack+1277252,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877364, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+184272,int_stack+181247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655039, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1304532,int_stack+1260587,int_stack+1269827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886604, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1319382,int_stack+1304532,int_stack+1277252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894029, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1339182,int_stack+1319382,int_stack+1289132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905909, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1269662,int_stack+187902,int_stack+184272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658064, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1280552,int_stack+1269662,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921309, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1362282,int_stack+1280552,int_stack+1304532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260587,int_stack+1362282,int_stack+1319382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1217687, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1362282,int_stack+1260587,int_stack+1339182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1237487, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1260587,int_stack+1362282,int_stack+1398551,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1762739,int_stack+1260587,int_stack+1425011,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2546543,int_stack+1762739,int_stack+1663955,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1663955,int_stack+194040,int_stack+192192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404712, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1669499,int_stack+196416,int_stack+194040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408408, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1676627,int_stack+1669499,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16200, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1687715,int_stack+199386,int_stack+196416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413160, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1696625,int_stack+1687715,int_stack+1669499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21744, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1710881,int_stack+1696625,int_stack+1676627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28872, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1663955,int_stack+203016,int_stack+199386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419100, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1729361,int_stack+1663955,int_stack+1687715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39960, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1394622,int_stack+1729361,int_stack+1696625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1674845,int_stack+1394622,int_stack+1710881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1033745, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1702565,int_stack+207372,int_stack+203016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426360, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1339967,int_stack+1702565,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052225, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1418382,int_stack+1339967,int_stack+1729361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063115, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1702565,int_stack+1418382,int_stack+1394622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080935, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1394622,int_stack+1702565,int_stack+1674845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1104695, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1663955,int_stack+1394622,int_stack+1362282,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1339967,int_stack+1663955,int_stack+1260587,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2711183,int_stack+1339967,int_stack+1762739,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+213304,int_stack+212520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262939,int_stack+214312,int_stack+213304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1265963,int_stack+1262939,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1270667,int_stack+215572,int_stack+214312, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1274447,int_stack+1270667,int_stack+1262939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1280495,int_stack+1274447,int_stack+1265963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+217112,int_stack+215572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1288335,int_stack+1260587,int_stack+1270667, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295895,int_stack+1288335,int_stack+1274447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1265207,int_stack+1295895,int_stack+1280495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1276967,int_stack+218960,int_stack+217112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1305975,int_stack+1276967,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1315215,int_stack+1305975,int_stack+1288335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1276967,int_stack+1315215,int_stack+1295895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1292087,int_stack+1276967,int_stack+1265207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+222152,int_stack+221144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263611,int_stack+223448,int_stack+222152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267499,int_stack+1263611,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1273547,int_stack+225068,int_stack+223448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1278407,int_stack+1273547,int_stack+1263611, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1308551,int_stack+1278407,int_stack+1267499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+227048,int_stack+225068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1318631,int_stack+1260587,int_stack+1273547, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1328351,int_stack+1318631,int_stack+1278407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1266527,int_stack+1328351,int_stack+1308551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1308551,int_stack+229424,int_stack+227048, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1341311,int_stack+1308551,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1353191,int_stack+1341311,int_stack+1318631, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1308551,int_stack+1353191,int_stack+1328351, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1327991,int_stack+1308551,int_stack+1266527, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1349159,int_stack+1327991,int_stack+1292087,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+233492,int_stack+232232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1264367,int_stack+235112,int_stack+233492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269227,int_stack+1264367,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1276787,int_stack+237137,int_stack+235112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1282862,int_stack+1276787,int_stack+1264367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1292582,int_stack+1282862,int_stack+1269227, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+239612,int_stack+237137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+626229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1305182,int_stack+1260587,int_stack+1276787, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1398551,int_stack+1305182,int_stack+1282862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1268012,int_stack+1398551,int_stack+1292582, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+937364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1286912,int_stack+242582,int_stack+239612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1414751,int_stack+1286912,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1429601,int_stack+1414751,int_stack+1305182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1286912,int_stack+1429601,int_stack+1398551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+969539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1398551,int_stack+1286912,int_stack+1268012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+985739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1425011,int_stack+1398551,int_stack+1327991,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1663955,int_stack+1425011,int_stack+1349159,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488515,int_stack+247632,int_stack+246092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1493135,int_stack+249612,int_stack+247632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1260587,int_stack+1493135,int_stack+1488515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1269827,int_stack+252087,int_stack+249612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1277252,int_stack+1269827,int_stack+1493135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1289132,int_stack+1277252,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+255112,int_stack+252087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1304532,int_stack+1260587,int_stack+1269827, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1319382,int_stack+1304532,int_stack+1277252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1339182,int_stack+1319382,int_stack+1289132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1269662,int_stack+258742,int_stack+255112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1280552,int_stack+1269662,int_stack+1260587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1362282,int_stack+1280552,int_stack+1304532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260587,int_stack+1362282,int_stack+1319382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1217687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1362282,int_stack+1260587,int_stack+1339182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1237487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1260587,int_stack+1362282,int_stack+1398551,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1762739,int_stack+1260587,int_stack+1425011,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+48870,int_stack+1762739,int_stack+1663955,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1663955,int_stack+264880,int_stack+263032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1669499,int_stack+267256,int_stack+264880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1676627,int_stack+1669499,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1687715,int_stack+270226,int_stack+267256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1696625,int_stack+1687715,int_stack+1669499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1710881,int_stack+1696625,int_stack+1676627, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1663955,int_stack+273856,int_stack+270226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1729361,int_stack+1663955,int_stack+1687715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1394622,int_stack+1729361,int_stack+1696625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1674845,int_stack+1394622,int_stack+1710881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1033745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1702565,int_stack+278212,int_stack+273856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1339967,int_stack+1702565,int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1418382,int_stack+1339967,int_stack+1729361, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1702565,int_stack+1418382,int_stack+1394622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1394622,int_stack+1702565,int_stack+1674845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1104695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1663955,int_stack+1394622,int_stack+1362282,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1339967,int_stack+1663955,int_stack+1260587,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2922863,int_stack+1339967,int_stack+1762739,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+284144,int_stack+283360, 0.0, zero_stack, 1.0, int_stack+581900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262939,int_stack+285152,int_stack+284144, 0.0, zero_stack, 1.0, int_stack+582684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1265963,int_stack+1262939,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1270667,int_stack+286412,int_stack+285152, 0.0, zero_stack, 1.0, int_stack+583692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1274447,int_stack+1270667,int_stack+1262939, 0.0, zero_stack, 1.0, int_stack+705604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1280495,int_stack+1274447,int_stack+1265963, 0.0, zero_stack, 1.0, int_stack+708628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+287952,int_stack+286412, 0.0, zero_stack, 1.0, int_stack+584952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1288335,int_stack+1260587,int_stack+1270667, 0.0, zero_stack, 1.0, int_stack+713332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295895,int_stack+1288335,int_stack+1274447, 0.0, zero_stack, 1.0, int_stack+717112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1265207,int_stack+1295895,int_stack+1280495, 0.0, zero_stack, 1.0, int_stack+723160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1276967,int_stack+289800,int_stack+287952, 0.0, zero_stack, 1.0, int_stack+586492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1305975,int_stack+1276967,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+731000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1315215,int_stack+1305975,int_stack+1288335, 0.0, zero_stack, 1.0, int_stack+735620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1276967,int_stack+1315215,int_stack+1295895, 0.0, zero_stack, 1.0, int_stack+743180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1292087,int_stack+1276967,int_stack+1265207, 0.0, zero_stack, 1.0, int_stack+753260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+292992,int_stack+291984, 0.0, zero_stack, 1.0, int_stack+599148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263611,int_stack+294288,int_stack+292992, 0.0, zero_stack, 1.0, int_stack+600156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267499,int_stack+1263611,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+765020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1273547,int_stack+295908,int_stack+294288, 0.0, zero_stack, 1.0, int_stack+601452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1278407,int_stack+1273547,int_stack+1263611, 0.0, zero_stack, 1.0, int_stack+768044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1308551,int_stack+1278407,int_stack+1267499, 0.0, zero_stack, 1.0, int_stack+771932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+297888,int_stack+295908, 0.0, zero_stack, 1.0, int_stack+603072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1318631,int_stack+1260587,int_stack+1273547, 0.0, zero_stack, 1.0, int_stack+777980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1328351,int_stack+1318631,int_stack+1278407, 0.0, zero_stack, 1.0, int_stack+782840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1266527,int_stack+1328351,int_stack+1308551, 0.0, zero_stack, 1.0, int_stack+812984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1308551,int_stack+300264,int_stack+297888, 0.0, zero_stack, 1.0, int_stack+605052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1341311,int_stack+1308551,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+823064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1353191,int_stack+1341311,int_stack+1318631, 0.0, zero_stack, 1.0, int_stack+829004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1308551,int_stack+1353191,int_stack+1328351, 0.0, zero_stack, 1.0, int_stack+838724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1327991,int_stack+1308551,int_stack+1266527, 0.0, zero_stack, 1.0, int_stack+851684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1349159,int_stack+1327991,int_stack+1292087,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+304332,int_stack+303072, 0.0, zero_stack, 1.0, int_stack+621324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1264367,int_stack+305952,int_stack+304332, 0.0, zero_stack, 1.0, int_stack+622584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269227,int_stack+1264367,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1276787,int_stack+307977,int_stack+305952, 0.0, zero_stack, 1.0, int_stack+624204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1282862,int_stack+1276787,int_stack+1264367, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1292582,int_stack+1282862,int_stack+1269227, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+310452,int_stack+307977, 0.0, zero_stack, 1.0, int_stack+626229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1305182,int_stack+1260587,int_stack+1276787, 0.0, zero_stack, 1.0, int_stack+790616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1398551,int_stack+1305182,int_stack+1282862, 0.0, zero_stack, 1.0, int_stack+796691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1268012,int_stack+1398551,int_stack+1292582, 0.0, zero_stack, 1.0, int_stack+937364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1286912,int_stack+313422,int_stack+310452, 0.0, zero_stack, 1.0, int_stack+628704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1414751,int_stack+1286912,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+949964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1429601,int_stack+1414751,int_stack+1305182, 0.0, zero_stack, 1.0, int_stack+957389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1286912,int_stack+1429601,int_stack+1398551, 0.0, zero_stack, 1.0, int_stack+969539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1398551,int_stack+1286912,int_stack+1268012, 0.0, zero_stack, 1.0, int_stack+985739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1425011,int_stack+1398551,int_stack+1327991,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1663955,int_stack+1425011,int_stack+1349159,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488515,int_stack+318472,int_stack+316932, 0.0, zero_stack, 1.0, int_stack+649044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1493135,int_stack+320452,int_stack+318472, 0.0, zero_stack, 1.0, int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1260587,int_stack+1493135,int_stack+1488515, 0.0, zero_stack, 1.0, int_stack+866804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1269827,int_stack+322927,int_stack+320452, 0.0, zero_stack, 1.0, int_stack+652564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1277252,int_stack+1269827,int_stack+1493135, 0.0, zero_stack, 1.0, int_stack+871424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1289132,int_stack+1277252,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+877364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1260587,int_stack+325952,int_stack+322927, 0.0, zero_stack, 1.0, int_stack+655039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1304532,int_stack+1260587,int_stack+1269827, 0.0, zero_stack, 1.0, int_stack+886604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1319382,int_stack+1304532,int_stack+1277252, 0.0, zero_stack, 1.0, int_stack+894029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1339182,int_stack+1319382,int_stack+1289132, 0.0, zero_stack, 1.0, int_stack+905909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1269662,int_stack+329582,int_stack+325952, 0.0, zero_stack, 1.0, int_stack+658064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1280552,int_stack+1269662,int_stack+1260587, 0.0, zero_stack, 1.0, int_stack+921309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1362282,int_stack+1280552,int_stack+1304532, 0.0, zero_stack, 1.0, int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260587,int_stack+1362282,int_stack+1319382, 0.0, zero_stack, 1.0, int_stack+1217687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1362282,int_stack+1260587,int_stack+1339182, 0.0, zero_stack, 1.0, int_stack+1237487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1260587,int_stack+1362282,int_stack+1398551,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1762739,int_stack+1260587,int_stack+1425011,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3134543,int_stack+1762739,int_stack+1663955,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1663955,int_stack+335720,int_stack+333872, 0.0, zero_stack, 1.0, int_stack+404712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1669499,int_stack+338096,int_stack+335720, 0.0, zero_stack, 1.0, int_stack+408408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1676627,int_stack+1669499,int_stack+1663955, 0.0, zero_stack, 1.0, int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1687715,int_stack+341066,int_stack+338096, 0.0, zero_stack, 1.0, int_stack+413160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1696625,int_stack+1687715,int_stack+1669499, 0.0, zero_stack, 1.0, int_stack+21744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1710881,int_stack+1696625,int_stack+1676627, 0.0, zero_stack, 1.0, int_stack+28872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1663955,int_stack+344696,int_stack+341066, 0.0, zero_stack, 1.0, int_stack+419100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1729361,int_stack+1663955,int_stack+1687715, 0.0, zero_stack, 1.0, int_stack+39960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1394622,int_stack+1729361,int_stack+1696625, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1674845,int_stack+1394622,int_stack+1710881, 0.0, zero_stack, 1.0, int_stack+1033745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1702565,int_stack+349052,int_stack+344696, 0.0, zero_stack, 1.0, int_stack+426360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1339967,int_stack+1702565,int_stack+1663955, 0.0, zero_stack, 1.0, int_stack+1052225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1418382,int_stack+1339967,int_stack+1729361, 0.0, zero_stack, 1.0, int_stack+1063115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1702565,int_stack+1418382,int_stack+1394622, 0.0, zero_stack, 1.0, int_stack+1080935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1394622,int_stack+1702565,int_stack+1674845, 0.0, zero_stack, 1.0, int_stack+1104695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1663955,int_stack+1394622,int_stack+1362282,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1339967,int_stack+1663955,int_stack+1260587,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+3299183,int_stack+1339967,int_stack+1762739,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+354984,int_stack+354200, 1.0, int_stack+581900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1262939,int_stack+355992,int_stack+354984, 1.0, int_stack+582684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1265963,int_stack+1262939,int_stack+1260587, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1270667,int_stack+357252,int_stack+355992, 1.0, int_stack+583692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1274447,int_stack+1270667,int_stack+1262939, 1.0, int_stack+705604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1280495,int_stack+1274447,int_stack+1265963, 1.0, int_stack+708628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+703252,int_stack+358792,int_stack+357252, 1.0, int_stack+584952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1260587,int_stack+703252,int_stack+1270667, 1.0, int_stack+713332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1288335,int_stack+1260587,int_stack+1274447, 1.0, int_stack+717112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+707872,int_stack+1288335,int_stack+1280495, 1.0, int_stack+723160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+719632,int_stack+360640,int_stack+358792, 1.0, int_stack+586492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1268147,int_stack+719632,int_stack+703252, 1.0, int_stack+731000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1298415,int_stack+1268147,int_stack+1260587, 1.0, int_stack+735620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1260587,int_stack+1298415,int_stack+1288335, 1.0, int_stack+743180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1275707,int_stack+1260587,int_stack+707872, 1.0, int_stack+753260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+363832,int_stack+362824, 1.0, int_stack+599148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1263611,int_stack+365128,int_stack+363832, 1.0, int_stack+600156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1267499,int_stack+1263611,int_stack+1260587, 1.0, int_stack+765020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1292171,int_stack+366748,int_stack+365128, 1.0, int_stack+601452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1297031,int_stack+1292171,int_stack+1263611, 1.0, int_stack+768044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1304807,int_stack+1297031,int_stack+1267499, 1.0, int_stack+771932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+765020,int_stack+368728,int_stack+366748, 1.0, int_stack+603072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1260587,int_stack+765020,int_stack+1292171, 1.0, int_stack+777980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1314887,int_stack+1260587,int_stack+1297031, 1.0, int_stack+782840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+770960,int_stack+1314887,int_stack+1304807, 1.0, int_stack+812984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1292171,int_stack+371104,int_stack+368728, 1.0, int_stack+605052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1299299,int_stack+1292171,int_stack+765020, 1.0, int_stack+823064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1327847,int_stack+1299299,int_stack+1260587, 1.0, int_stack+829004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1292171,int_stack+1327847,int_stack+1314887, 1.0, int_stack+838724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1311611,int_stack+1292171,int_stack+770960, 1.0, int_stack+851684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1332779,int_stack+1311611,int_stack+1275707,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260587,int_stack+375172,int_stack+373912, 1.0, int_stack+621324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1264367,int_stack+376792,int_stack+375172, 1.0, int_stack+622584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269227,int_stack+1264367,int_stack+1260587, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1276787,int_stack+378817,int_stack+376792, 1.0, int_stack+624204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1282862,int_stack+1276787,int_stack+1264367, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1292582,int_stack+1282862,int_stack+1269227, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+381292,int_stack+378817, 1.0, int_stack+626229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1260587,int_stack+0,int_stack+1276787, 1.0, int_stack+790616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+765020,int_stack+1260587,int_stack+1282862, 1.0, int_stack+796691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1272737,int_stack+765020,int_stack+1292582, 1.0, int_stack+937364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1291637,int_stack+384262,int_stack+381292, 1.0, int_stack+628704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+781220,int_stack+1291637,int_stack+0, 1.0, int_stack+949964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+796070,int_stack+781220,int_stack+1260587, 1.0, int_stack+957389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1382171,int_stack+796070,int_stack+765020, 1.0, int_stack+969539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+765020,int_stack+1382171,int_stack+1272737, 1.0, int_stack+985739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1382171,int_stack+765020,int_stack+1311611,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1663955,int_stack+1382171,int_stack+1332779,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1445675,int_stack+389312,int_stack+387772, 1.0, int_stack+649044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1450295,int_stack+391292,int_stack+389312, 1.0, int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1456235,int_stack+1450295,int_stack+1445675, 1.0, int_stack+866804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1465475,int_stack+393767,int_stack+391292, 1.0, int_stack+652564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472900,int_stack+1465475,int_stack+1450295, 1.0, int_stack+871424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+791480,int_stack+1472900,int_stack+1456235, 1.0, int_stack+877364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+866804,int_stack+396792,int_stack+393767, 1.0, int_stack+655039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1445675,int_stack+866804,int_stack+1465475, 1.0, int_stack+886604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1260587,int_stack+1445675,int_stack+1472900, 1.0, int_stack+894029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+875879,int_stack+1260587,int_stack+791480, 1.0, int_stack+905909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+791480,int_stack+400422,int_stack+396792, 1.0, int_stack+658064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+802370,int_stack+791480,int_stack+866804, 1.0, int_stack+921309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1460525,int_stack+802370,int_stack+1445675, 1.0, int_stack+1004639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+791480,int_stack+1460525,int_stack+1260587, 1.0, int_stack+1217687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1260587,int_stack+791480,int_stack+875879, 1.0, int_stack+1237487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1292927,int_stack+1260587,int_stack+765020,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1762739,int_stack+1292927,int_stack+1382171,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+213510,int_stack+1762739,int_stack+1663955,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1663955,int_stack+410784,int_stack+406560, 1.0, int_stack+404712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1669499,int_stack+416130,int_stack+410784, 1.0, int_stack+408408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1676627,int_stack+1669499,int_stack+1663955, 1.0, int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1687715,int_stack+422730,int_stack+416130, 1.0, int_stack+413160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1696625,int_stack+1687715,int_stack+1669499, 1.0, int_stack+21744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1710881,int_stack+1696625,int_stack+1676627, 1.0, int_stack+28872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1663955,int_stack+430716,int_stack+422730, 1.0, int_stack+419100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1729361,int_stack+1663955,int_stack+1687715, 1.0, int_stack+39960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+765020,int_stack+1729361,int_stack+1696625, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1674845,int_stack+765020,int_stack+1710881, 1.0, int_stack+1033745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1019489,int_stack+435072,int_stack+430716, 1.0, int_stack+426360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1702565,int_stack+1019489,int_stack+1663955, 1.0, int_stack+1052225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1019489,int_stack+1702565,int_stack+1729361, 1.0, int_stack+1063115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1702565,int_stack+1019489,int_stack+765020, 1.0, int_stack+1080935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+765020,int_stack+1702565,int_stack+1674845, 1.0, int_stack+1104695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1019489,int_stack+765020,int_stack+1260587,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+3510863,int_stack+1019489,int_stack+1292927,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1260587,int_stack+3510863,int_stack+1762739,588);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3510863,int_stack+588340,int_stack+586492,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3516407,int_stack+3510863,int_stack+731000,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3525647,int_stack+3516407,int_stack+735620,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3538247,int_stack+3525647,int_stack+743180,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3510863,int_stack+3538247,int_stack+753260,28);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3527327,int_stack+607428,int_stack+605052,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3534455,int_stack+3527327,int_stack+823064,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3546335,int_stack+3534455,int_stack+829004,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3562535,int_stack+3546335,int_stack+838724,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3527327,int_stack+3562535,int_stack+851684,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3548495,int_stack+3527327,int_stack+3510863,588);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3597887,int_stack+631674,int_stack+628704,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3606797,int_stack+3597887,int_stack+949964,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3621647,int_stack+3606797,int_stack+957389,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3641897,int_stack+3621647,int_stack+969539,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3597887,int_stack+3641897,int_stack+985739,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1019489,int_stack+3597887,int_stack+3527327,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1082993,int_stack+1019489,int_stack+3548495,588);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3624347,int_stack+661694,int_stack+658064,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3635237,int_stack+3624347,int_stack+921309,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1181777,int_stack+3635237,int_stack+1004639,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3624347,int_stack+1181777,int_stack+1217687,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1181777,int_stack+3624347,int_stack+1237487,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1663955,int_stack+1181777,int_stack+3597887,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1743335,int_stack+1663955,int_stack+1019489,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+703252,int_stack+1743335,int_stack+1082993,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3624347,int_stack+441004,int_stack+440220,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3626699,int_stack+442012,int_stack+441004,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3629723,int_stack+3626699,int_stack+3624347,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3634427,int_stack+443272,int_stack+442012,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3638207,int_stack+3634427,int_stack+3626699,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3644255,int_stack+3638207,int_stack+3629723,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3624347,int_stack+444812,int_stack+443272,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3652095,int_stack+3624347,int_stack+3634427,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3659655,int_stack+3652095,int_stack+3638207,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3628967,int_stack+3659655,int_stack+3644255,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3640727,int_stack+446660,int_stack+444812,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1214117,int_stack+3640727,int_stack+3624347,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1223357,int_stack+1214117,int_stack+3652095,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3640727,int_stack+1223357,int_stack+3659655,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1214117,int_stack+3640727,int_stack+3628967,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1230581,int_stack+449852,int_stack+448844,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1233605,int_stack+451148,int_stack+449852,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1237493,int_stack+1233605,int_stack+1230581,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1243541,int_stack+452768,int_stack+451148,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1248401,int_stack+1243541,int_stack+1233605,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3624347,int_stack+1248401,int_stack+1237493,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1230581,int_stack+454748,int_stack+452768,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3634427,int_stack+1230581,int_stack+1243541,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3644147,int_stack+3634427,int_stack+1248401,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1236521,int_stack+3644147,int_stack+3624347,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3624347,int_stack+457124,int_stack+454748,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3657107,int_stack+3624347,int_stack+1230581,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1472267,int_stack+3657107,int_stack+3634427,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3624347,int_stack+1472267,int_stack+3644147,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1472267,int_stack+3624347,int_stack+1236521,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1870343,int_stack+1472267,int_stack+1214117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3510863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1214117,int_stack+461192,int_stack+459932,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1217897,int_stack+462812,int_stack+461192,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1222757,int_stack+1217897,int_stack+1214117,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1230317,int_stack+464837,int_stack+462812,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1236392,int_stack+1230317,int_stack+1217897,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1246112,int_stack+1236392,int_stack+1222757,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1214117,int_stack+467312,int_stack+464837,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3624347,int_stack+1214117,int_stack+1230317,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3636497,int_stack+3624347,int_stack+1236392,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1221542,int_stack+3636497,int_stack+1246112,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1240442,int_stack+470282,int_stack+467312,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3652697,int_stack+1240442,int_stack+1214117,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1919735,int_stack+3652697,int_stack+3624347,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+1919735,int_stack+3636497,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1919735,int_stack+0,int_stack+1221542,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+867892,int_stack+1919735,int_stack+1472267, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3527327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3624347,int_stack+867892,int_stack+1870343, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3548495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1870343,int_stack+475332,int_stack+473792,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1874963,int_stack+477312,int_stack+475332,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1880903,int_stack+1874963,int_stack+1870343,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1890143,int_stack+479787,int_stack+477312,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1897568,int_stack+1890143,int_stack+1874963,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1472267,int_stack+1897568,int_stack+1880903,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1870343,int_stack+482812,int_stack+479787,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+1870343,int_stack+1890143,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+14850,int_stack+0,int_stack+1897568,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1879418,int_stack+14850,int_stack+1472267,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1472267,int_stack+486442,int_stack+482812,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1214117,int_stack+1472267,int_stack+1870343,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1472267,int_stack+1214117,int_stack+0,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1214117,int_stack+1472267,int_stack+14850,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+0,int_stack+1214117,int_stack+1879418,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+931396,int_stack+0,int_stack+1919735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3597887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+3723131,int_stack+931396,int_stack+867892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3850139,int_stack+3723131,int_stack+3624347, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1082993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3624347,int_stack+492580,int_stack+490732,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3629891,int_stack+494956,int_stack+492580,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+599148,int_stack+3629891,int_stack+3624347,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3637019,int_stack+497926,int_stack+494956,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3645929,int_stack+3637019,int_stack+3629891,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3660185,int_stack+3645929,int_stack+599148,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+599148,int_stack+501556,int_stack+497926,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3678665,int_stack+599148,int_stack+3637019,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3696485,int_stack+3678665,int_stack+3645929,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3624347,int_stack+3696485,int_stack+3660185,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3652067,int_stack+505912,int_stack+501556,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+867892,int_stack+3652067,int_stack+599148,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+889672,int_stack+867892,int_stack+3678665,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3652067,int_stack+889672,int_stack+3696485,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+867892,int_stack+3652067,int_stack+3624347,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+3624347,int_stack+867892,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1181777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+4014779,int_stack+3624347,int_stack+931396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+4173539,int_stack+4014779,int_stack+3723131, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1743335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4014779,int_stack+511844,int_stack+511060,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4017131,int_stack+512852,int_stack+511844,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4020155,int_stack+4017131,int_stack+4014779,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4024859,int_stack+514112,int_stack+512852,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4028639,int_stack+4024859,int_stack+4017131,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4034687,int_stack+4028639,int_stack+4020155,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4014779,int_stack+515652,int_stack+514112,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4042527,int_stack+4014779,int_stack+4024859,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4050087,int_stack+4042527,int_stack+4028639,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4019399,int_stack+4050087,int_stack+4034687,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4031159,int_stack+517500,int_stack+515652,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4060167,int_stack+4031159,int_stack+4014779,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4069407,int_stack+4060167,int_stack+4042527,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4031159,int_stack+4069407,int_stack+4050087,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4046279,int_stack+4031159,int_stack+4019399,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4014779,int_stack+520692,int_stack+519684,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4017803,int_stack+521988,int_stack+520692,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4021691,int_stack+4017803,int_stack+4014779,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4027739,int_stack+523608,int_stack+521988,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4032599,int_stack+4027739,int_stack+4017803,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4062743,int_stack+4032599,int_stack+4021691,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4014779,int_stack+525588,int_stack+523608,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4072823,int_stack+4014779,int_stack+4027739,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4082543,int_stack+4072823,int_stack+4032599,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4020719,int_stack+4082543,int_stack+4062743,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4062743,int_stack+527964,int_stack+525588,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4095503,int_stack+4062743,int_stack+4014779,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4107383,int_stack+4095503,int_stack+4072823,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4062743,int_stack+4107383,int_stack+4082543,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4082183,int_stack+4062743,int_stack+4020719,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4103351,int_stack+4082183,int_stack+4046279, 0.0, zero_stack, 1.0, int_stack+3510863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4014779,int_stack+532032,int_stack+530772,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4018559,int_stack+533652,int_stack+532032,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4023419,int_stack+4018559,int_stack+4014779,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4030979,int_stack+535677,int_stack+533652,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4037054,int_stack+4030979,int_stack+4018559,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4046774,int_stack+4037054,int_stack+4023419,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4014779,int_stack+538152,int_stack+535677,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4059374,int_stack+4014779,int_stack+4030979,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4152743,int_stack+4059374,int_stack+4037054,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4022204,int_stack+4152743,int_stack+4046774,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4041104,int_stack+541122,int_stack+538152,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3624347,int_stack+4041104,int_stack+4014779,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3639197,int_stack+3624347,int_stack+4059374,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4041104,int_stack+3639197,int_stack+4152743,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3624347,int_stack+4041104,int_stack+4022204,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3650807,int_stack+3624347,int_stack+4082183, 0.0, zero_stack, 1.0, int_stack+3527327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3714311,int_stack+3650807,int_stack+4103351, 0.0, zero_stack, 1.0, int_stack+3548495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3813095,int_stack+546172,int_stack+544632,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3817715,int_stack+548152,int_stack+546172,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3823655,int_stack+3817715,int_stack+3813095,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3832895,int_stack+550627,int_stack+548152,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4014779,int_stack+3832895,int_stack+3817715,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4026659,int_stack+4014779,int_stack+3823655,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3813095,int_stack+553652,int_stack+550627,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4042059,int_stack+3813095,int_stack+3832895,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3822170,int_stack+4042059,int_stack+4014779,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4056909,int_stack+3822170,int_stack+4026659,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4014779,int_stack+557282,int_stack+553652,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4080009,int_stack+4014779,int_stack+3813095,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4014779,int_stack+4080009,int_stack+4042059,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4080009,int_stack+4014779,int_stack+3822170,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4014779,int_stack+4080009,int_stack+4056909,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4047119,int_stack+4014779,int_stack+3624347, 0.0, zero_stack, 1.0, int_stack+3597887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+867892,int_stack+4047119,int_stack+3650807, 0.0, zero_stack, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+378150,int_stack+867892,int_stack+3714311, 0.0, zero_stack, 1.0, int_stack+1082993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3624347,int_stack+563420,int_stack+561572,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3629891,int_stack+565796,int_stack+563420,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+599148,int_stack+3629891,int_stack+3624347,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3637019,int_stack+568766,int_stack+565796,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3645929,int_stack+3637019,int_stack+3629891,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3660185,int_stack+3645929,int_stack+599148,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+599148,int_stack+572396,int_stack+568766,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3678665,int_stack+599148,int_stack+3637019,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3696485,int_stack+3678665,int_stack+3645929,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3624347,int_stack+3696485,int_stack+3660185,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3652067,int_stack+576752,int_stack+572396,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3720245,int_stack+3652067,int_stack+599148,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3742025,int_stack+3720245,int_stack+3678665,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3652067,int_stack+3742025,int_stack+3696485,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3687707,int_stack+3652067,int_stack+3624347,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+3726515,int_stack+3687707,int_stack+4014779, 0.0, zero_stack, 1.0, int_stack+1181777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+4385219,int_stack+3726515,int_stack+4047119, 0.0, zero_stack, 1.0, int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+3624347,int_stack+4385219,int_stack+867892, 0.0, zero_stack, 1.0, int_stack+1743335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+867892,int_stack+591308,int_stack+590524,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+870244,int_stack+592316,int_stack+591308,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+873268,int_stack+870244,int_stack+867892,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+877972,int_stack+593576,int_stack+592316,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+881752,int_stack+877972,int_stack+870244,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+887800,int_stack+881752,int_stack+873268,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+867892,int_stack+595116,int_stack+593576,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+895640,int_stack+867892,int_stack+877972,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+903200,int_stack+895640,int_stack+881752,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+872512,int_stack+903200,int_stack+887800,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+884272,int_stack+596964,int_stack+595116,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+913280,int_stack+884272,int_stack+867892,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+922520,int_stack+913280,int_stack+895640,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+884272,int_stack+922520,int_stack+903200,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+899392,int_stack+884272,int_stack+872512,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+867892,int_stack+611244,int_stack+610236,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+870916,int_stack+612540,int_stack+611244,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+874804,int_stack+870916,int_stack+867892,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+880852,int_stack+614160,int_stack+612540,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+885712,int_stack+880852,int_stack+870916,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+915856,int_stack+885712,int_stack+874804,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+867892,int_stack+616140,int_stack+614160,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+925936,int_stack+867892,int_stack+880852,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+935656,int_stack+925936,int_stack+885712,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+873832,int_stack+935656,int_stack+915856,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+915856,int_stack+618516,int_stack+616140,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+948616,int_stack+915856,int_stack+867892,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+960496,int_stack+948616,int_stack+925936,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+915856,int_stack+960496,int_stack+935656,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+935296,int_stack+915856,int_stack+873832,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+956464,int_stack+935296,int_stack+899392, 1.0, int_stack+3510863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3510863,int_stack+636444,int_stack+635184,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3514643,int_stack+638064,int_stack+636444,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3519503,int_stack+3514643,int_stack+3510863,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+867892,int_stack+640089,int_stack+638064,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+873967,int_stack+867892,int_stack+3514643,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+883687,int_stack+873967,int_stack+3519503,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3510863,int_stack+642564,int_stack+640089,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+896287,int_stack+3510863,int_stack+867892,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+908437,int_stack+896287,int_stack+873967,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4385219,int_stack+908437,int_stack+883687,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+867892,int_stack+645534,int_stack+642564,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+876802,int_stack+867892,int_stack+3510863,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4404119,int_stack+876802,int_stack+896287,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+867892,int_stack+4404119,int_stack+908437,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4404119,int_stack+867892,int_stack+4385219,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+867892,int_stack+4404119,int_stack+935296, 1.0, int_stack+3527327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4430579,int_stack+867892,int_stack+956464, 1.0, int_stack+3548495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4385219,int_stack+667524,int_stack+665984,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4389839,int_stack+669504,int_stack+667524,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+931396,int_stack+4389839,int_stack+4385219,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4395779,int_stack+671979,int_stack+669504,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+940636,int_stack+4395779,int_stack+4389839,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+952516,int_stack+940636,int_stack+931396,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+931396,int_stack+675004,int_stack+671979,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+967916,int_stack+931396,int_stack+4395779,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+982766,int_stack+967916,int_stack+940636,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3510863,int_stack+982766,int_stack+952516,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+940471,int_stack+678634,int_stack+675004,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4385219,int_stack+940471,int_stack+931396,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+931396,int_stack+4385219,int_stack+967916,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3533963,int_stack+931396,int_stack+982766,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+931396,int_stack+3533963,int_stack+3510863,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+3510863,int_stack+931396,int_stack+4404119, 1.0, int_stack+3597887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4014779,int_stack+3510863,int_stack+867892, 1.0, int_stack+1019489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4529363,int_stack+4014779,int_stack+4430579, 1.0, int_stack+1082993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+867892,int_stack+684772,int_stack+682924,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+873436,int_stack+687148,int_stack+684772,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+880564,int_stack+873436,int_stack+867892,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+891652,int_stack+690118,int_stack+687148,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+900562,int_stack+891652,int_stack+873436,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3590243,int_stack+900562,int_stack+880564,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+867892,int_stack+693748,int_stack+690118,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+963736,int_stack+867892,int_stack+891652,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+981556,int_stack+963736,int_stack+900562,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+878782,int_stack+981556,int_stack+3590243,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3590243,int_stack+698104,int_stack+693748,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+906502,int_stack+3590243,int_stack+867892,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3590243,int_stack+906502,int_stack+963736,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1005316,int_stack+3590243,int_stack+981556,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+963736,int_stack+1005316,int_stack+878782,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+1002544,int_stack+963736,int_stack+931396, 1.0, int_stack+1181777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+1099564,int_stack+1002544,int_stack+3510863, 1.0, int_stack+1663955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+867892,int_stack+1099564,int_stack+4014779, 1.0, int_stack+1743335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+1663955,int_stack+1958543,int_stack+1499315,588);
     Libderiv->ABCD[11] = int_stack + 1663955;
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+1910915,int_stack+2334863,int_stack+2170223,588);
     Libderiv->ABCD[10] = int_stack + 1910915;
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2157875,int_stack+2711183,int_stack+2546543,588);
     Libderiv->ABCD[9] = int_stack + 2157875;
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2404835,int_stack+2922863,int_stack+48870,588);
     Libderiv->ABCD[8] = int_stack + 2404835;
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2651795,int_stack+3299183,int_stack+3134543,588);
     Libderiv->ABCD[7] = int_stack + 2651795;
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2898755,int_stack+1260587,int_stack+213510,588);
     Libderiv->ABCD[6] = int_stack + 2898755;
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+3145715,int_stack+4173539,int_stack+3850139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 3145715;
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+1079572,int_stack+3624347,int_stack+378150, 0.0, zero_stack, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 1079572;
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+3392675,int_stack+867892,int_stack+4529363, 1.0, int_stack+703252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 3392675;

}
