/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (fd|ii) integrals */

void d1vrr_order_fdii(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+9, dvrr_stack+34, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+21, dvrr_stack+40, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+65, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+68, dvrr_stack+15, dvrr_stack+65, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+74, dvrr_stack+21, dvrr_stack+68, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+99, dvrr_stack+84, dvrr_stack+50, NULL, NULL, dvrr_stack+21);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+144, dvrr_stack+84, dvrr_stack+50, dvrr_stack+74, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+3, dvrr_stack+65, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+171, dvrr_stack+165, dvrr_stack+68, dvrr_stack+3, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+181, dvrr_stack+171, dvrr_stack+74, dvrr_stack+165, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+196, dvrr_stack+181, dvrr_stack+84, dvrr_stack+171, dvrr_stack+74, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+31, dvrr_stack+65, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+217, dvrr_stack+34, dvrr_stack+68, dvrr_stack+6, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+227, dvrr_stack+40, dvrr_stack+217, dvrr_stack+9, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+242, dvrr_stack+50, dvrr_stack+227, dvrr_stack+21, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+263, dvrr_stack+144, dvrr_stack+242, NULL, NULL, dvrr_stack+50);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+326, dvrr_stack+196, dvrr_stack+144, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+389, dvrr_stack+326, dvrr_stack+263, dvrr_stack+196, dvrr_stack+144, dvrr_stack+99);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+515, dvrr_stack+144, dvrr_stack+242, dvrr_stack+84, dvrr_stack+50, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+543, dvrr_stack+196, dvrr_stack+144, dvrr_stack+181, dvrr_stack+84, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+571, dvrr_stack+543, dvrr_stack+515, NULL, NULL, dvrr_stack+144);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+655, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+658, dvrr_stack+655, dvrr_stack+3, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+664, dvrr_stack+658, dvrr_stack+165, dvrr_stack+655, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+674, dvrr_stack+664, dvrr_stack+171, dvrr_stack+658, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+689, dvrr_stack+674, dvrr_stack+181, dvrr_stack+664, dvrr_stack+171, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+710, dvrr_stack+689, dvrr_stack+196, dvrr_stack+674, dvrr_stack+181, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+738, dvrr_stack+710, dvrr_stack+543, NULL, NULL, dvrr_stack+196);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+65, dvrr_stack+3, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+171, dvrr_stack+68, dvrr_stack+165, dvrr_stack+31, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+655, dvrr_stack+217, dvrr_stack+171, dvrr_stack+34, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+822, dvrr_stack+227, dvrr_stack+655, dvrr_stack+40, dvrr_stack+217, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+843, dvrr_stack+242, dvrr_stack+822, dvrr_stack+50, dvrr_stack+227, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+871, dvrr_stack+515, dvrr_stack+843, NULL, NULL, dvrr_stack+242);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+955, dvrr_stack+571, dvrr_stack+871, dvrr_stack+543, dvrr_stack+515, dvrr_stack+263);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1123, dvrr_stack+738, dvrr_stack+571, dvrr_stack+710, dvrr_stack+543, dvrr_stack+326);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1291, dvrr_stack+1123, dvrr_stack+955, dvrr_stack+738, dvrr_stack+571, dvrr_stack+389);
 tmp = dvrr_stack + 1291;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+738, dvrr_stack+515, dvrr_stack+843, dvrr_stack+144, dvrr_stack+242, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+774, dvrr_stack+543, dvrr_stack+515, dvrr_stack+196, dvrr_stack+144, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1571, dvrr_stack+774, dvrr_stack+738, NULL, NULL, dvrr_stack+515);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1679, dvrr_stack+710, dvrr_stack+543, dvrr_stack+689, dvrr_stack+196, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1715, dvrr_stack+1679, dvrr_stack+774, NULL, NULL, dvrr_stack+543);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+810, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+813, dvrr_stack+3, dvrr_stack+810, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+670, dvrr_stack+165, dvrr_stack+813, dvrr_stack+65, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1823, dvrr_stack+171, dvrr_stack+670, dvrr_stack+68, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1838, dvrr_stack+655, dvrr_stack+1823, dvrr_stack+217, dvrr_stack+171, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1859, dvrr_stack+822, dvrr_stack+1838, dvrr_stack+227, dvrr_stack+655, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1887, dvrr_stack+843, dvrr_stack+1859, dvrr_stack+242, dvrr_stack+822, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1923, dvrr_stack+738, dvrr_stack+1887, NULL, NULL, dvrr_stack+843);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2031, dvrr_stack+1571, dvrr_stack+1923, dvrr_stack+774, dvrr_stack+738, dvrr_stack+871);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2247, dvrr_stack+1715, dvrr_stack+1571, dvrr_stack+1679, dvrr_stack+774, dvrr_stack+571);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2463, dvrr_stack+2247, dvrr_stack+2031, dvrr_stack+1715, dvrr_stack+1571, dvrr_stack+955);
 tmp = dvrr_stack + 2463;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+2823,dvrr_stack+2463,dvrr_stack+1291,10);


 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1715, dvrr_stack+738, dvrr_stack+1887, dvrr_stack+515, dvrr_stack+843, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1760, dvrr_stack+774, dvrr_stack+738, dvrr_stack+543, dvrr_stack+515, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3663, dvrr_stack+1760, dvrr_stack+1715, NULL, NULL, dvrr_stack+738);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3798, dvrr_stack+1679, dvrr_stack+774, dvrr_stack+710, dvrr_stack+543, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3843, dvrr_stack+3798, dvrr_stack+1760, NULL, NULL, dvrr_stack+774);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+543, dvrr_stack+810, dvrr_stack+65, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+549, dvrr_stack+813, dvrr_stack+543, dvrr_stack+3, dvrr_stack+810, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+710, dvrr_stack+670, dvrr_stack+549, dvrr_stack+165, dvrr_stack+813, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3978, dvrr_stack+1823, dvrr_stack+710, dvrr_stack+171, dvrr_stack+670, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3999, dvrr_stack+1838, dvrr_stack+3978, dvrr_stack+655, dvrr_stack+1823, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4027, dvrr_stack+1859, dvrr_stack+3999, dvrr_stack+822, dvrr_stack+1838, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4063, dvrr_stack+1887, dvrr_stack+4027, dvrr_stack+843, dvrr_stack+1859, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4108, dvrr_stack+1715, dvrr_stack+4063, NULL, NULL, dvrr_stack+1887);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4243, dvrr_stack+3663, dvrr_stack+4108, dvrr_stack+1760, dvrr_stack+1715, dvrr_stack+1923);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4513, dvrr_stack+3843, dvrr_stack+3663, dvrr_stack+3798, dvrr_stack+1760, dvrr_stack+1571);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4783, dvrr_stack+4513, dvrr_stack+4243, dvrr_stack+3843, dvrr_stack+3663, dvrr_stack+2031);
 tmp = dvrr_stack + 4783;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+5233,dvrr_stack+4783,dvrr_stack+2463,10);


 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3843, dvrr_stack+1715, dvrr_stack+4063, dvrr_stack+738, dvrr_stack+1887, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3898, dvrr_stack+1760, dvrr_stack+1715, dvrr_stack+774, dvrr_stack+738, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6313, dvrr_stack+3898, dvrr_stack+3843, NULL, NULL, dvrr_stack+1715);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6478, dvrr_stack+3798, dvrr_stack+1760, dvrr_stack+1679, dvrr_stack+774, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6533, dvrr_stack+6478, dvrr_stack+3898, NULL, NULL, dvrr_stack+1760);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+65, dvrr_stack+3, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+774, dvrr_stack+543, dvrr_stack+165, dvrr_stack+810, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+784, dvrr_stack+549, dvrr_stack+774, dvrr_stack+813, dvrr_stack+543, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+799, dvrr_stack+710, dvrr_stack+784, dvrr_stack+670, dvrr_stack+549, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1679, dvrr_stack+3978, dvrr_stack+799, dvrr_stack+1823, dvrr_stack+710, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6698, dvrr_stack+3999, dvrr_stack+1679, dvrr_stack+1838, dvrr_stack+3978, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6734, dvrr_stack+4027, dvrr_stack+6698, dvrr_stack+1859, dvrr_stack+3999, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6779, dvrr_stack+4063, dvrr_stack+6734, dvrr_stack+1887, dvrr_stack+4027, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6834, dvrr_stack+3843, dvrr_stack+6779, NULL, NULL, dvrr_stack+4063);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6999, dvrr_stack+6313, dvrr_stack+6834, dvrr_stack+3898, dvrr_stack+3843, dvrr_stack+4108);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7329, dvrr_stack+6533, dvrr_stack+6313, dvrr_stack+6478, dvrr_stack+3898, dvrr_stack+3663);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7659, dvrr_stack+7329, dvrr_stack+6999, dvrr_stack+6533, dvrr_stack+6313, dvrr_stack+4243);
 tmp = dvrr_stack + 7659;
 target_ptr = Libderiv->dvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+8209,dvrr_stack+7659,dvrr_stack+4783,10);


 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6533, dvrr_stack+3843, dvrr_stack+6779, dvrr_stack+1715, dvrr_stack+4063, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6599, dvrr_stack+3898, dvrr_stack+3843, dvrr_stack+1760, dvrr_stack+1715, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9559, dvrr_stack+6599, dvrr_stack+6533, NULL, NULL, dvrr_stack+3843);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9757, dvrr_stack+6478, dvrr_stack+3898, dvrr_stack+3798, dvrr_stack+1760, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9823, dvrr_stack+9757, dvrr_stack+6599, NULL, NULL, dvrr_stack+3898);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1760, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1763, dvrr_stack+3, dvrr_stack+1760, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1769, dvrr_stack+165, dvrr_stack+1763, dvrr_stack+65, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1779, dvrr_stack+774, dvrr_stack+1769, dvrr_stack+543, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1794, dvrr_stack+784, dvrr_stack+1779, dvrr_stack+549, dvrr_stack+774, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+543, dvrr_stack+799, dvrr_stack+1794, dvrr_stack+710, dvrr_stack+784, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3798, dvrr_stack+1679, dvrr_stack+543, dvrr_stack+3978, dvrr_stack+799, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10021, dvrr_stack+6698, dvrr_stack+3798, dvrr_stack+3999, dvrr_stack+1679, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10066, dvrr_stack+6734, dvrr_stack+10021, dvrr_stack+4027, dvrr_stack+6698, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10121, dvrr_stack+6779, dvrr_stack+10066, dvrr_stack+4063, dvrr_stack+6734, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10187, dvrr_stack+6533, dvrr_stack+10121, NULL, NULL, dvrr_stack+6779);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10385, dvrr_stack+9559, dvrr_stack+10187, dvrr_stack+6599, dvrr_stack+6533, dvrr_stack+6834);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10781, dvrr_stack+9823, dvrr_stack+9559, dvrr_stack+9757, dvrr_stack+6599, dvrr_stack+6313);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11177, dvrr_stack+10781, dvrr_stack+10385, dvrr_stack+9823, dvrr_stack+9559, dvrr_stack+6999);
 tmp = dvrr_stack + 11177;
 target_ptr = Libderiv->dvrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+11837,dvrr_stack+11177,dvrr_stack+7659,10);


 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+9823, dvrr_stack+6533, dvrr_stack+10121, dvrr_stack+3843, dvrr_stack+6779, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+9901, dvrr_stack+6599, dvrr_stack+6533, dvrr_stack+3898, dvrr_stack+3843, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13487, dvrr_stack+9901, dvrr_stack+9823, NULL, NULL, dvrr_stack+6533);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13721, dvrr_stack+9757, dvrr_stack+6599, dvrr_stack+6478, dvrr_stack+3898, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13799, dvrr_stack+13721, dvrr_stack+9901, NULL, NULL, dvrr_stack+6599);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3898, dvrr_stack+1760, dvrr_stack+65, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3904, dvrr_stack+1763, dvrr_stack+3898, dvrr_stack+3, dvrr_stack+1760, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3914, dvrr_stack+1769, dvrr_stack+3904, dvrr_stack+165, dvrr_stack+1763, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3929, dvrr_stack+1779, dvrr_stack+3914, dvrr_stack+774, dvrr_stack+1769, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3950, dvrr_stack+1794, dvrr_stack+3929, dvrr_stack+784, dvrr_stack+1779, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6478, dvrr_stack+543, dvrr_stack+3950, dvrr_stack+799, dvrr_stack+1794, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+774, dvrr_stack+3798, dvrr_stack+6478, dvrr_stack+1679, dvrr_stack+543, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14033, dvrr_stack+10021, dvrr_stack+774, dvrr_stack+6698, dvrr_stack+3798, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+14088, dvrr_stack+10066, dvrr_stack+14033, dvrr_stack+6734, dvrr_stack+10021, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14154, dvrr_stack+10121, dvrr_stack+14088, dvrr_stack+6779, dvrr_stack+10066, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14232, dvrr_stack+9823, dvrr_stack+14154, NULL, NULL, dvrr_stack+10121);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14466, dvrr_stack+13487, dvrr_stack+14232, dvrr_stack+9901, dvrr_stack+9823, dvrr_stack+10187);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14934, dvrr_stack+13799, dvrr_stack+13487, dvrr_stack+13721, dvrr_stack+9901, dvrr_stack+9559);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15402, dvrr_stack+14934, dvrr_stack+14466, dvrr_stack+13799, dvrr_stack+13487, dvrr_stack+10385);
 tmp = dvrr_stack + 15402;
 target_ptr = Libderiv->dvrr_classes[3][11];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+16182,dvrr_stack+15402,dvrr_stack+11177,10);


 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+13799, dvrr_stack+9823, dvrr_stack+14154, dvrr_stack+6533, dvrr_stack+10121, NULL);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+13890, dvrr_stack+9901, dvrr_stack+9823, dvrr_stack+6599, dvrr_stack+6533, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18162, dvrr_stack+13890, dvrr_stack+13799, NULL, NULL, dvrr_stack+9823);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18435, dvrr_stack+13721, dvrr_stack+9901, dvrr_stack+9757, dvrr_stack+6599, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18526, dvrr_stack+18435, dvrr_stack+13890, NULL, NULL, dvrr_stack+9901);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+819, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+65, dvrr_stack+819, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6599, dvrr_stack+3898, dvrr_stack+165, dvrr_stack+1760, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6609, dvrr_stack+3904, dvrr_stack+6599, dvrr_stack+1763, dvrr_stack+3898, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6624, dvrr_stack+3914, dvrr_stack+6609, dvrr_stack+1769, dvrr_stack+3904, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+710, dvrr_stack+3929, dvrr_stack+6624, dvrr_stack+1779, dvrr_stack+3914, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6645, dvrr_stack+3950, dvrr_stack+710, dvrr_stack+1794, dvrr_stack+3929, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1760, dvrr_stack+6478, dvrr_stack+6645, dvrr_stack+543, dvrr_stack+3950, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9757, dvrr_stack+774, dvrr_stack+1760, dvrr_stack+3798, dvrr_stack+6478, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18799, dvrr_stack+14033, dvrr_stack+9757, dvrr_stack+10021, dvrr_stack+774, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18865, dvrr_stack+14088, dvrr_stack+18799, dvrr_stack+10066, dvrr_stack+14033, NULL);

 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18943, dvrr_stack+14154, dvrr_stack+18865, dvrr_stack+10121, dvrr_stack+14088, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19034, dvrr_stack+13799, dvrr_stack+18943, NULL, NULL, dvrr_stack+14154);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19307, dvrr_stack+18162, dvrr_stack+19034, dvrr_stack+13890, dvrr_stack+13799, dvrr_stack+14232);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19853, dvrr_stack+18526, dvrr_stack+18162, dvrr_stack+18435, dvrr_stack+13890, dvrr_stack+13487);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+20399, dvrr_stack+19853, dvrr_stack+19307, dvrr_stack+18526, dvrr_stack+18162, dvrr_stack+14466);
 tmp = dvrr_stack + 20399;
 target_ptr = Libderiv->dvrr_classes[3][12];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+21309,dvrr_stack+20399,dvrr_stack+15402,10);


 /* compute (0 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+18526, dvrr_stack+13799, dvrr_stack+18943, dvrr_stack+9823, dvrr_stack+14154, NULL);

 /* compute (0 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+18631, dvrr_stack+13890, dvrr_stack+13799, dvrr_stack+9901, dvrr_stack+9823, NULL);

 /* compute (1 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+23649, dvrr_stack+18631, dvrr_stack+18526, NULL, NULL, dvrr_stack+13799);

 /* compute (0 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+23964, dvrr_stack+18435, dvrr_stack+13890, dvrr_stack+13721, dvrr_stack+9901, NULL);

 /* compute (1 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+24069, dvrr_stack+23964, dvrr_stack+18631, NULL, NULL, dvrr_stack+13890);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+13890, dvrr_stack+819, dvrr_stack+3, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+13896, dvrr_stack+165, dvrr_stack+13890, dvrr_stack+65, dvrr_stack+819, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+13906, dvrr_stack+6599, dvrr_stack+13896, dvrr_stack+3898, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+13921, dvrr_stack+6609, dvrr_stack+13906, dvrr_stack+3904, dvrr_stack+6599, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+543, dvrr_stack+6624, dvrr_stack+13921, dvrr_stack+3914, dvrr_stack+6609, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13942, dvrr_stack+710, dvrr_stack+543, dvrr_stack+3929, dvrr_stack+6624, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3898, dvrr_stack+6645, dvrr_stack+13942, dvrr_stack+3950, dvrr_stack+710, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13978, dvrr_stack+1760, dvrr_stack+3898, dvrr_stack+6478, dvrr_stack+6645, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9901, dvrr_stack+9757, dvrr_stack+13978, dvrr_stack+774, dvrr_stack+1760, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13721, dvrr_stack+18799, dvrr_stack+9901, dvrr_stack+14033, dvrr_stack+9757, NULL);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18435, dvrr_stack+18865, dvrr_stack+13721, dvrr_stack+14088, dvrr_stack+18799, NULL);

 /* compute (0 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+24384, dvrr_stack+18943, dvrr_stack+18435, dvrr_stack+14154, dvrr_stack+18865, NULL);

 /* compute (1 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+24489, dvrr_stack+18526, dvrr_stack+24384, NULL, NULL, dvrr_stack+18943);

 /* compute (2 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+24804, dvrr_stack+23649, dvrr_stack+24489, dvrr_stack+18631, dvrr_stack+18526, dvrr_stack+19034);

 /* compute (2 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+25434, dvrr_stack+24069, dvrr_stack+23649, dvrr_stack+23964, dvrr_stack+18631, dvrr_stack+18162);

 /* compute (3 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+26064, dvrr_stack+25434, dvrr_stack+24804, dvrr_stack+24069, dvrr_stack+23649, dvrr_stack+19307);

 /* compute (3 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+27114,dvrr_stack+26064,dvrr_stack+20399,10);


 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+18631, dvrr_stack+21, dvrr_stack+40, NULL, NULL, dvrr_stack+9);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+18661, dvrr_stack+50, dvrr_stack+227, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+18706, dvrr_stack+99, dvrr_stack+18661, dvrr_stack+84, dvrr_stack+50, dvrr_stack+18631);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+23964, dvrr_stack+242, dvrr_stack+822, NULL, NULL, dvrr_stack+227);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+24027, dvrr_stack+263, dvrr_stack+23964, dvrr_stack+144, dvrr_stack+242, dvrr_stack+18661);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+24153, dvrr_stack+389, dvrr_stack+24027, dvrr_stack+326, dvrr_stack+263, dvrr_stack+18706);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+29844, dvrr_stack+843, dvrr_stack+1859, NULL, NULL, dvrr_stack+822);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+29928, dvrr_stack+871, dvrr_stack+29844, dvrr_stack+515, dvrr_stack+843, dvrr_stack+23964);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+30096, dvrr_stack+955, dvrr_stack+29928, dvrr_stack+571, dvrr_stack+871, dvrr_stack+24027);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+30376, dvrr_stack+1291, dvrr_stack+30096, dvrr_stack+1123, dvrr_stack+955, dvrr_stack+24153);
 tmp = dvrr_stack + 30376;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30796, dvrr_stack+1887, dvrr_stack+4027, NULL, NULL, dvrr_stack+1859);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30904, dvrr_stack+1923, dvrr_stack+30796, dvrr_stack+738, dvrr_stack+1887, dvrr_stack+29844);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31120, dvrr_stack+2031, dvrr_stack+30904, dvrr_stack+1571, dvrr_stack+1923, dvrr_stack+29928);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31480, dvrr_stack+2463, dvrr_stack+31120, dvrr_stack+2247, dvrr_stack+2031, dvrr_stack+30096);
 tmp = dvrr_stack + 31480;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+32020,dvrr_stack+31480,dvrr_stack+30376,15);


 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+33280, dvrr_stack+4063, dvrr_stack+6734, NULL, NULL, dvrr_stack+4027);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+33415, dvrr_stack+4108, dvrr_stack+33280, dvrr_stack+1715, dvrr_stack+4063, dvrr_stack+30796);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+33685, dvrr_stack+4243, dvrr_stack+33415, dvrr_stack+3663, dvrr_stack+4108, dvrr_stack+30904);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+34135, dvrr_stack+4783, dvrr_stack+33685, dvrr_stack+4513, dvrr_stack+4243, dvrr_stack+31120);
 tmp = dvrr_stack + 34135;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+34810,dvrr_stack+34135,dvrr_stack+31480,15);


 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36430, dvrr_stack+6779, dvrr_stack+10066, NULL, NULL, dvrr_stack+6734);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36595, dvrr_stack+6834, dvrr_stack+36430, dvrr_stack+3843, dvrr_stack+6779, dvrr_stack+33280);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36925, dvrr_stack+6999, dvrr_stack+36595, dvrr_stack+6313, dvrr_stack+6834, dvrr_stack+33415);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+37475, dvrr_stack+7659, dvrr_stack+36925, dvrr_stack+7329, dvrr_stack+6999, dvrr_stack+33685);
 tmp = dvrr_stack + 37475;
 target_ptr = Libderiv->dvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+38300,dvrr_stack+37475,dvrr_stack+34135,15);


 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6313, dvrr_stack+10121, dvrr_stack+14088, NULL, NULL, dvrr_stack+10066);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+40325, dvrr_stack+10187, dvrr_stack+6313, dvrr_stack+6533, dvrr_stack+10121, dvrr_stack+36430);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+40721, dvrr_stack+10385, dvrr_stack+40325, dvrr_stack+9559, dvrr_stack+10187, dvrr_stack+36595);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41381, dvrr_stack+11177, dvrr_stack+40721, dvrr_stack+10781, dvrr_stack+10385, dvrr_stack+36925);
 tmp = dvrr_stack + 41381;
 target_ptr = Libderiv->dvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+42371,dvrr_stack+41381,dvrr_stack+37475,15);


 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44846, dvrr_stack+14154, dvrr_stack+18865, NULL, NULL, dvrr_stack+14088);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45080, dvrr_stack+14232, dvrr_stack+44846, dvrr_stack+9823, dvrr_stack+14154, dvrr_stack+6313);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45548, dvrr_stack+14466, dvrr_stack+45080, dvrr_stack+13487, dvrr_stack+14232, dvrr_stack+40325);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+46328, dvrr_stack+15402, dvrr_stack+45548, dvrr_stack+14934, dvrr_stack+14466, dvrr_stack+40721);
 tmp = dvrr_stack + 46328;
 target_ptr = Libderiv->dvrr_classes[4][11];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+47498,dvrr_stack+46328,dvrr_stack+41381,15);


 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50468, dvrr_stack+18943, dvrr_stack+18435, NULL, NULL, dvrr_stack+18865);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50741, dvrr_stack+19034, dvrr_stack+50468, dvrr_stack+13799, dvrr_stack+18943, dvrr_stack+44846);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51287, dvrr_stack+19307, dvrr_stack+50741, dvrr_stack+18162, dvrr_stack+19034, dvrr_stack+45080);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+52197, dvrr_stack+20399, dvrr_stack+51287, dvrr_stack+19853, dvrr_stack+19307, dvrr_stack+45548);
 tmp = dvrr_stack + 52197;
 target_ptr = Libderiv->dvrr_classes[4][12];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+53562,dvrr_stack+52197,dvrr_stack+46328,15);


 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+18796, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18162, dvrr_stack+3, dvrr_stack+18796, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18168, dvrr_stack+13890, dvrr_stack+18162, dvrr_stack+819, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18178, dvrr_stack+13896, dvrr_stack+18168, dvrr_stack+165, dvrr_stack+13890, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+24363, dvrr_stack+13906, dvrr_stack+18178, dvrr_stack+6599, dvrr_stack+13896, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+515, dvrr_stack+13921, dvrr_stack+24363, dvrr_stack+6609, dvrr_stack+13906, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+738, dvrr_stack+543, dvrr_stack+515, dvrr_stack+6624, dvrr_stack+13921, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18193, dvrr_stack+13942, dvrr_stack+738, dvrr_stack+710, dvrr_stack+543, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18238, dvrr_stack+3898, dvrr_stack+18193, dvrr_stack+6645, dvrr_stack+13942, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18293, dvrr_stack+13978, dvrr_stack+18238, dvrr_stack+1760, dvrr_stack+3898, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13799, dvrr_stack+9901, dvrr_stack+18293, dvrr_stack+9757, dvrr_stack+13978, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+13487, dvrr_stack+13721, dvrr_stack+13799, dvrr_stack+18799, dvrr_stack+9901, NULL);

 /* compute (0 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+13578, dvrr_stack+18435, dvrr_stack+13487, dvrr_stack+18865, dvrr_stack+13721, NULL);

 /* compute (1 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+57072, dvrr_stack+24384, dvrr_stack+13578, NULL, NULL, dvrr_stack+18435);

 /* compute (2 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+57387, dvrr_stack+24489, dvrr_stack+57072, dvrr_stack+18526, dvrr_stack+24384, dvrr_stack+50468);

 /* compute (3 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+58017, dvrr_stack+24804, dvrr_stack+57387, dvrr_stack+23649, dvrr_stack+24489, dvrr_stack+50741);

 /* compute (4 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+59067, dvrr_stack+26064, dvrr_stack+58017, dvrr_stack+25434, dvrr_stack+24804, dvrr_stack+51287);

 /* compute (4 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+60642,dvrr_stack+59067,dvrr_stack+52197,15);


 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+25434, dvrr_stack+9, dvrr_stack+34, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+25452, dvrr_stack+40, dvrr_stack+217, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+25482, dvrr_stack+18631, dvrr_stack+25452, dvrr_stack+21, dvrr_stack+40, dvrr_stack+25434);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+25542, dvrr_stack+227, dvrr_stack+655, NULL, NULL, dvrr_stack+217);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+25587, dvrr_stack+18661, dvrr_stack+25542, dvrr_stack+50, dvrr_stack+227, dvrr_stack+25452);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+25677, dvrr_stack+18706, dvrr_stack+25587, dvrr_stack+99, dvrr_stack+18661, dvrr_stack+25482);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+25827, dvrr_stack+822, dvrr_stack+1838, NULL, NULL, dvrr_stack+655);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+25890, dvrr_stack+23964, dvrr_stack+25827, dvrr_stack+242, dvrr_stack+822, dvrr_stack+25542);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+23649, dvrr_stack+24027, dvrr_stack+25890, dvrr_stack+263, dvrr_stack+23964, dvrr_stack+25587);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+64737, dvrr_stack+24153, dvrr_stack+23649, dvrr_stack+389, dvrr_stack+24027, dvrr_stack+25677);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+242, dvrr_stack+1859, dvrr_stack+3999, NULL, NULL, dvrr_stack+1838);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+9559, dvrr_stack+29844, dvrr_stack+242, dvrr_stack+843, dvrr_stack+1859, dvrr_stack+25827);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+65052, dvrr_stack+29928, dvrr_stack+9559, dvrr_stack+871, dvrr_stack+29844, dvrr_stack+25890);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+65332, dvrr_stack+30096, dvrr_stack+65052, dvrr_stack+955, dvrr_stack+29928, dvrr_stack+23649);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+65752, dvrr_stack+30376, dvrr_stack+65332, dvrr_stack+1291, dvrr_stack+30096, dvrr_stack+64737);
 tmp = dvrr_stack + 65752;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1571, dvrr_stack+4027, dvrr_stack+6698, NULL, NULL, dvrr_stack+3999);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+843, dvrr_stack+30796, dvrr_stack+1571, dvrr_stack+1887, dvrr_stack+4027, dvrr_stack+242);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66340, dvrr_stack+30904, dvrr_stack+843, dvrr_stack+1923, dvrr_stack+30796, dvrr_stack+9559);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66700, dvrr_stack+31120, dvrr_stack+66340, dvrr_stack+2031, dvrr_stack+30904, dvrr_stack+65052);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67240, dvrr_stack+31480, dvrr_stack+66700, dvrr_stack+2463, dvrr_stack+31120, dvrr_stack+65332);
 tmp = dvrr_stack + 67240;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+67996,dvrr_stack+67240,dvrr_stack+65752,21);


 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3663, dvrr_stack+6734, dvrr_stack+10021, NULL, NULL, dvrr_stack+6698);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1887, dvrr_stack+33280, dvrr_stack+3663, dvrr_stack+4063, dvrr_stack+6734, dvrr_stack+1571);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+69760, dvrr_stack+33415, dvrr_stack+1887, dvrr_stack+4108, dvrr_stack+33280, dvrr_stack+843);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70210, dvrr_stack+33685, dvrr_stack+69760, dvrr_stack+4243, dvrr_stack+33415, dvrr_stack+66340);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70885, dvrr_stack+34135, dvrr_stack+70210, dvrr_stack+4783, dvrr_stack+33685, dvrr_stack+66700);
 tmp = dvrr_stack + 70885;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+71830,dvrr_stack+70885,dvrr_stack+67240,21);


 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4063, dvrr_stack+10066, dvrr_stack+14033, NULL, NULL, dvrr_stack+10021);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+74098, dvrr_stack+36430, dvrr_stack+4063, dvrr_stack+6779, dvrr_stack+10066, dvrr_stack+3663);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+74428, dvrr_stack+36595, dvrr_stack+74098, dvrr_stack+6834, dvrr_stack+36430, dvrr_stack+1887);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+74978, dvrr_stack+36925, dvrr_stack+74428, dvrr_stack+6999, dvrr_stack+36595, dvrr_stack+69760);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+75803, dvrr_stack+37475, dvrr_stack+74978, dvrr_stack+7659, dvrr_stack+36925, dvrr_stack+70210);
 tmp = dvrr_stack + 75803;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+76958,dvrr_stack+75803,dvrr_stack+70885,21);


 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6779, dvrr_stack+14088, dvrr_stack+18799, NULL, NULL, dvrr_stack+14033);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+79793, dvrr_stack+6313, dvrr_stack+6779, dvrr_stack+10121, dvrr_stack+14088, dvrr_stack+4063);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+80189, dvrr_stack+40325, dvrr_stack+79793, dvrr_stack+10187, dvrr_stack+6313, dvrr_stack+74098);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+80849, dvrr_stack+40721, dvrr_stack+80189, dvrr_stack+10385, dvrr_stack+40325, dvrr_stack+74428);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+81839, dvrr_stack+41381, dvrr_stack+80849, dvrr_stack+11177, dvrr_stack+40721, dvrr_stack+74978);
 tmp = dvrr_stack + 81839;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+83225,dvrr_stack+81839,dvrr_stack+75803,21);


 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+10121, dvrr_stack+18865, dvrr_stack+13721, NULL, NULL, dvrr_stack+18799);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+86690, dvrr_stack+44846, dvrr_stack+10121, dvrr_stack+14154, dvrr_stack+18865, dvrr_stack+6779);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+87158, dvrr_stack+45080, dvrr_stack+86690, dvrr_stack+14232, dvrr_stack+44846, dvrr_stack+79793);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+87938, dvrr_stack+45548, dvrr_stack+87158, dvrr_stack+14466, dvrr_stack+45080, dvrr_stack+80189);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+89108, dvrr_stack+46328, dvrr_stack+87938, dvrr_stack+15402, dvrr_stack+45548, dvrr_stack+80849);
 tmp = dvrr_stack + 89108;
 target_ptr = Libderiv->dvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+90746,dvrr_stack+89108,dvrr_stack+81839,21);


 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+14154, dvrr_stack+18435, dvrr_stack+13487, NULL, NULL, dvrr_stack+13721);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+94904, dvrr_stack+50468, dvrr_stack+14154, dvrr_stack+18943, dvrr_stack+18435, dvrr_stack+10121);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+95450, dvrr_stack+50741, dvrr_stack+94904, dvrr_stack+19034, dvrr_stack+50468, dvrr_stack+86690);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+96360, dvrr_stack+51287, dvrr_stack+95450, dvrr_stack+19307, dvrr_stack+50741, dvrr_stack+87158);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+97725, dvrr_stack+52197, dvrr_stack+96360, dvrr_stack+20399, dvrr_stack+51287, dvrr_stack+87938);

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+99636,dvrr_stack+97725,dvrr_stack+89108,21);


 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+819, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18943, dvrr_stack+18796, dvrr_stack+819, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18949, dvrr_stack+18162, dvrr_stack+18943, dvrr_stack+3, dvrr_stack+18796, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18959, dvrr_stack+18168, dvrr_stack+18949, dvrr_stack+13890, dvrr_stack+18162, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18974, dvrr_stack+18178, dvrr_stack+18959, dvrr_stack+13896, dvrr_stack+18168, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+710, dvrr_stack+24363, dvrr_stack+18974, dvrr_stack+13906, dvrr_stack+18178, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18943, dvrr_stack+515, dvrr_stack+710, dvrr_stack+13921, dvrr_stack+24363, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18979, dvrr_stack+738, dvrr_stack+18943, dvrr_stack+543, dvrr_stack+515, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+515, dvrr_stack+18193, dvrr_stack+18979, dvrr_stack+13942, dvrr_stack+738, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+570, dvrr_stack+18238, dvrr_stack+515, dvrr_stack+3898, dvrr_stack+18193, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18943, dvrr_stack+18293, dvrr_stack+570, dvrr_stack+13978, dvrr_stack+18238, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+515, dvrr_stack+13799, dvrr_stack+18943, dvrr_stack+9901, dvrr_stack+18293, NULL);

 /* compute (0 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+23859, dvrr_stack+13487, dvrr_stack+515, dvrr_stack+13721, dvrr_stack+13799, NULL);

 /* compute (1 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+18943, dvrr_stack+13578, dvrr_stack+23859, NULL, NULL, dvrr_stack+13487);

 /* compute (2 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+104550, dvrr_stack+57072, dvrr_stack+18943, dvrr_stack+24384, dvrr_stack+13578, dvrr_stack+14154);

 /* compute (3 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+105180, dvrr_stack+57387, dvrr_stack+104550, dvrr_stack+24489, dvrr_stack+57072, dvrr_stack+94904);

 /* compute (4 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+106230, dvrr_stack+58017, dvrr_stack+105180, dvrr_stack+24804, dvrr_stack+57387, dvrr_stack+95450);

 /* compute (5 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+107805, dvrr_stack+59067, dvrr_stack+106230, dvrr_stack+26064, dvrr_stack+58017, dvrr_stack+96360);

 /* compute (5 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+110010,dvrr_stack+107805,dvrr_stack+97725,21);


 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+9727, dvrr_stack+74, dvrr_stack+21, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+57072, dvrr_stack+181, dvrr_stack+84, NULL, NULL, dvrr_stack+74);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+2157, dvrr_stack+57072, dvrr_stack+99, dvrr_stack+181, dvrr_stack+84, dvrr_stack+9727);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+57117, dvrr_stack+689, dvrr_stack+196, NULL, NULL, dvrr_stack+181);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+57180, dvrr_stack+57117, dvrr_stack+326, dvrr_stack+689, dvrr_stack+196, dvrr_stack+57072);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+57306, dvrr_stack+57180, dvrr_stack+389, dvrr_stack+57117, dvrr_stack+326, dvrr_stack+2157);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+50, dvrr_stack+15, dvrr_stack+9, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+326, dvrr_stack+9727, dvrr_stack+18631, dvrr_stack+74, dvrr_stack+21, dvrr_stack+50);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+57516, dvrr_stack+2157, dvrr_stack+18706, dvrr_stack+57072, dvrr_stack+99, dvrr_stack+326);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+57666, dvrr_stack+57306, dvrr_stack+24153, dvrr_stack+57180, dvrr_stack+389, dvrr_stack+57516);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+57072, dvrr_stack+0, dvrr_stack+6, NULL, NULL, Data->F+5);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+181, dvrr_stack+50, dvrr_stack+25434, dvrr_stack+15, dvrr_stack+9, dvrr_stack+57072);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+57072, dvrr_stack+326, dvrr_stack+25482, dvrr_stack+9727, dvrr_stack+18631, dvrr_stack+181);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+57981, dvrr_stack+57516, dvrr_stack+25677, dvrr_stack+2157, dvrr_stack+18706, dvrr_stack+57072);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+58206, dvrr_stack+57666, dvrr_stack+64737, dvrr_stack+57306, dvrr_stack+24153, dvrr_stack+57981);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+57981, dvrr_stack+6, dvrr_stack+31, NULL, NULL, Data->F+6);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+50, dvrr_stack+34, dvrr_stack+68, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+181, dvrr_stack+25434, dvrr_stack+50, dvrr_stack+9, dvrr_stack+34, dvrr_stack+57981);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+9727, dvrr_stack+217, dvrr_stack+171, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+68, dvrr_stack+25452, dvrr_stack+9727, dvrr_stack+40, dvrr_stack+217, dvrr_stack+50);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+57981, dvrr_stack+25482, dvrr_stack+68, dvrr_stack+18631, dvrr_stack+25452, dvrr_stack+181);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+181, dvrr_stack+655, dvrr_stack+1823, NULL, NULL, dvrr_stack+171);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+2157, dvrr_stack+25542, dvrr_stack+181, dvrr_stack+227, dvrr_stack+655, dvrr_stack+9727);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+57516, dvrr_stack+25587, dvrr_stack+2157, dvrr_stack+18661, dvrr_stack+25542, dvrr_stack+68);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+57072, dvrr_stack+25677, dvrr_stack+57516, dvrr_stack+18706, dvrr_stack+25587, dvrr_stack+57981);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+57981, dvrr_stack+1838, dvrr_stack+3978, NULL, NULL, dvrr_stack+1823);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+58044, dvrr_stack+25827, dvrr_stack+57981, dvrr_stack+822, dvrr_stack+1838, dvrr_stack+181);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+0, dvrr_stack+25890, dvrr_stack+58044, dvrr_stack+23964, dvrr_stack+25827, dvrr_stack+2157);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+58647, dvrr_stack+23649, dvrr_stack+0, dvrr_stack+24027, dvrr_stack+25890, dvrr_stack+57516);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+104550, dvrr_stack+64737, dvrr_stack+58647, dvrr_stack+24153, dvrr_stack+23649, dvrr_stack+57072);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+57072, dvrr_stack+3999, dvrr_stack+1679, NULL, NULL, dvrr_stack+3978);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+606, dvrr_stack+242, dvrr_stack+57072, dvrr_stack+1859, dvrr_stack+3999, dvrr_stack+57981);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+23649, dvrr_stack+9559, dvrr_stack+606, dvrr_stack+29844, dvrr_stack+242, dvrr_stack+58044);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+23929, dvrr_stack+65052, dvrr_stack+23649, dvrr_stack+29928, dvrr_stack+9559, dvrr_stack+0);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+24349, dvrr_stack+65332, dvrr_stack+23929, dvrr_stack+30096, dvrr_stack+65052, dvrr_stack+58647);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+24937, dvrr_stack+65752, dvrr_stack+24349, dvrr_stack+30376, dvrr_stack+65332, dvrr_stack+104550);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+104550, dvrr_stack+6698, dvrr_stack+3798, NULL, NULL, dvrr_stack+1679);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+104658, dvrr_stack+1571, dvrr_stack+104550, dvrr_stack+4027, dvrr_stack+6698, dvrr_stack+57072);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+104874, dvrr_stack+843, dvrr_stack+104658, dvrr_stack+30796, dvrr_stack+1571, dvrr_stack+606);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+105234, dvrr_stack+66340, dvrr_stack+104874, dvrr_stack+30904, dvrr_stack+843, dvrr_stack+23649);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+105774, dvrr_stack+66700, dvrr_stack+105234, dvrr_stack+31120, dvrr_stack+66340, dvrr_stack+23929);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+106530, dvrr_stack+67240, dvrr_stack+105774, dvrr_stack+31480, dvrr_stack+66700, dvrr_stack+24349);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66340, dvrr_stack+10021, dvrr_stack+774, NULL, NULL, dvrr_stack+3798);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66475, dvrr_stack+3663, dvrr_stack+66340, dvrr_stack+6734, dvrr_stack+10021, dvrr_stack+104550);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66745, dvrr_stack+1887, dvrr_stack+66475, dvrr_stack+33280, dvrr_stack+3663, dvrr_stack+104658);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23649, dvrr_stack+69760, dvrr_stack+66745, dvrr_stack+33415, dvrr_stack+1887, dvrr_stack+104874);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+64737, dvrr_stack+70210, dvrr_stack+23649, dvrr_stack+33685, dvrr_stack+69760, dvrr_stack+105234);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+115743, dvrr_stack+70885, dvrr_stack+64737, dvrr_stack+34135, dvrr_stack+70210, dvrr_stack+105774);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+69760, dvrr_stack+14033, dvrr_stack+9757, NULL, NULL, dvrr_stack+774);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+69925, dvrr_stack+4063, dvrr_stack+69760, dvrr_stack+10066, dvrr_stack+14033, dvrr_stack+66340);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+70255, dvrr_stack+74098, dvrr_stack+69925, dvrr_stack+36430, dvrr_stack+4063, dvrr_stack+66475);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3663, dvrr_stack+74428, dvrr_stack+70255, dvrr_stack+36595, dvrr_stack+74098, dvrr_stack+66745);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104550, dvrr_stack+74978, dvrr_stack+3663, dvrr_stack+36925, dvrr_stack+74428, dvrr_stack+23649);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117003, dvrr_stack+75803, dvrr_stack+104550, dvrr_stack+37475, dvrr_stack+74978, dvrr_stack+64737);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9559, dvrr_stack+18799, dvrr_stack+9901, NULL, NULL, dvrr_stack+9757);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+64737, dvrr_stack+6779, dvrr_stack+9559, dvrr_stack+14088, dvrr_stack+18799, dvrr_stack+69760);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+23649, dvrr_stack+79793, dvrr_stack+64737, dvrr_stack+6313, dvrr_stack+6779, dvrr_stack+69925);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6313, dvrr_stack+80189, dvrr_stack+23649, dvrr_stack+40325, dvrr_stack+79793, dvrr_stack+70255);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+74098, dvrr_stack+80849, dvrr_stack+6313, dvrr_stack+40721, dvrr_stack+80189, dvrr_stack+3663);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+118543, dvrr_stack+81839, dvrr_stack+74098, dvrr_stack+41381, dvrr_stack+80849, dvrr_stack+104550);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+57072, dvrr_stack+13721, dvrr_stack+13799, NULL, NULL, dvrr_stack+9901);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+104550, dvrr_stack+10121, dvrr_stack+57072, dvrr_stack+18865, dvrr_stack+13721, dvrr_stack+9559);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+105018, dvrr_stack+86690, dvrr_stack+104550, dvrr_stack+44846, dvrr_stack+10121, dvrr_stack+64737);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+9559, dvrr_stack+87158, dvrr_stack+105018, dvrr_stack+45080, dvrr_stack+86690, dvrr_stack+23649);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+79793, dvrr_stack+87938, dvrr_stack+9559, dvrr_stack+45548, dvrr_stack+87158, dvrr_stack+6313);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+120391, dvrr_stack+89108, dvrr_stack+79793, dvrr_stack+46328, dvrr_stack+87938, dvrr_stack+74098);

 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18162, dvrr_stack+13487, dvrr_stack+515, NULL, NULL, dvrr_stack+13799);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+74098, dvrr_stack+14154, dvrr_stack+18162, dvrr_stack+18435, dvrr_stack+13487, dvrr_stack+57072);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+18162, dvrr_stack+94904, dvrr_stack+74098, dvrr_stack+50468, dvrr_stack+14154, dvrr_stack+104550);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+74098, dvrr_stack+95450, dvrr_stack+18162, dvrr_stack+50741, dvrr_stack+94904, dvrr_stack+105018);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+104550, dvrr_stack+96360, dvrr_stack+74098, dvrr_stack+51287, dvrr_stack+95450, dvrr_stack+9559);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+122575, dvrr_stack+97725, dvrr_stack+104550, dvrr_stack+52197, dvrr_stack+96360, dvrr_stack+79793);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+79793, dvrr_stack+2823, NULL);
 tmp = dvrr_stack + 79793;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+80073, dvrr_stack+5233, NULL);
 tmp = dvrr_stack + 80073;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+80433, dvrr_stack+8209, NULL);
 tmp = dvrr_stack + 80433;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+80883, dvrr_stack+11837, NULL);
 tmp = dvrr_stack + 80883;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+104550, dvrr_stack+16182, NULL);
 tmp = dvrr_stack + 104550;
 target_ptr = Libderiv->deriv_classes[3][10][11];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,780,dvrr_stack+105210, dvrr_stack+21309, NULL);
 tmp = dvrr_stack + 105210;
 target_ptr = Libderiv->deriv_classes[3][11][11];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,910,dvrr_stack+9559, dvrr_stack+27114, NULL);
 tmp = dvrr_stack + 9559;
 target_ptr = Libderiv->deriv_classes[3][12][11];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+58647, dvrr_stack+32020, NULL);
 tmp = dvrr_stack + 58647;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+105990, dvrr_stack+34810, NULL);
 tmp = dvrr_stack + 105990;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+74098, dvrr_stack+38300, NULL);
 tmp = dvrr_stack + 74098;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+74773, dvrr_stack+42371, NULL);
 tmp = dvrr_stack + 74773;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+94904, dvrr_stack+47498, NULL);
 tmp = dvrr_stack + 94904;
 target_ptr = Libderiv->deriv_classes[4][10][11];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1170,dvrr_stack+95894, dvrr_stack+53562, NULL);
 tmp = dvrr_stack + 95894;
 target_ptr = Libderiv->deriv_classes[4][11][11];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1365,dvrr_stack+18162, dvrr_stack+60642, NULL);
 tmp = dvrr_stack + 18162;
 target_ptr = Libderiv->deriv_classes[4][12][11];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+97064, dvrr_stack+67996, NULL);
 tmp = dvrr_stack + 97064;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+50468, dvrr_stack+71830, NULL);
 tmp = dvrr_stack + 50468;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+51224, dvrr_stack+76958, NULL);
 tmp = dvrr_stack + 51224;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+13487, dvrr_stack+83225, NULL);
 tmp = dvrr_stack + 13487;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+86690, dvrr_stack+90746, NULL);
 tmp = dvrr_stack + 86690;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+125123, dvrr_stack+99636, NULL);
 tmp = dvrr_stack + 125123;
 target_ptr = Libderiv->deriv_classes[5][11][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1911,dvrr_stack+126761, dvrr_stack+110010, NULL);
 tmp = dvrr_stack + 126761;
 target_ptr = Libderiv->deriv_classes[5][12][11];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+81433, dvrr_stack+2823, NULL);
 tmp = dvrr_stack + 81433;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+6313, dvrr_stack+5233, NULL);
 tmp = dvrr_stack + 6313;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+6673, dvrr_stack+8209, NULL);
 tmp = dvrr_stack + 6673;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+23649, dvrr_stack+11837, NULL);
 tmp = dvrr_stack + 23649;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+24199, dvrr_stack+16182, NULL);
 tmp = dvrr_stack + 24199;
 target_ptr = Libderiv->deriv_classes[3][10][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,780,dvrr_stack+88076, dvrr_stack+21309, NULL);
 tmp = dvrr_stack + 88076;
 target_ptr = Libderiv->deriv_classes[3][11][10];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,910,dvrr_stack+64737, dvrr_stack+27114, NULL);
 tmp = dvrr_stack + 64737;
 target_ptr = Libderiv->deriv_classes[3][12][10];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+44846, dvrr_stack+32020, NULL);
 tmp = dvrr_stack + 44846;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+45266, dvrr_stack+34810, NULL);
 tmp = dvrr_stack + 45266;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+3663, dvrr_stack+38300, NULL);
 tmp = dvrr_stack + 3663;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+40325, dvrr_stack+42371, NULL);
 tmp = dvrr_stack + 40325;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+69760, dvrr_stack+47498, NULL);
 tmp = dvrr_stack + 69760;
 target_ptr = Libderiv->deriv_classes[4][10][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1170,dvrr_stack+128672, dvrr_stack+53562, NULL);
 tmp = dvrr_stack + 128672;
 target_ptr = Libderiv->deriv_classes[4][11][10];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1365,dvrr_stack+129842, dvrr_stack+60642, NULL);
 tmp = dvrr_stack + 129842;
 target_ptr = Libderiv->deriv_classes[4][12][10];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+36430, dvrr_stack+67996, NULL);
 tmp = dvrr_stack + 36430;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+66340, dvrr_stack+71830, NULL);
 tmp = dvrr_stack + 66340;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+0, dvrr_stack+76958, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+131207, dvrr_stack+83225, NULL);
 tmp = dvrr_stack + 131207;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+132362, dvrr_stack+90746, NULL);
 tmp = dvrr_stack + 132362;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+133748, dvrr_stack+99636, NULL);
 tmp = dvrr_stack + 133748;
 target_ptr = Libderiv->deriv_classes[5][11][10];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1911,dvrr_stack+135386, dvrr_stack+110010, NULL);
 tmp = dvrr_stack + 135386;
 target_ptr = Libderiv->deriv_classes[5][12][10];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+10469, dvrr_stack+2823, NULL);
 tmp = dvrr_stack + 10469;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+2823, dvrr_stack+5233, NULL);
 tmp = dvrr_stack + 2823;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+5233, dvrr_stack+8209, NULL);
 tmp = dvrr_stack + 5233;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+8209, dvrr_stack+11837, NULL);
 tmp = dvrr_stack + 8209;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+11837, dvrr_stack+16182, NULL);
 tmp = dvrr_stack + 11837;
 target_ptr = Libderiv->deriv_classes[3][10][9];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,780,dvrr_stack+16182, dvrr_stack+21309, NULL);
 tmp = dvrr_stack + 16182;
 target_ptr = Libderiv->deriv_classes[3][11][9];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,910,dvrr_stack+21309, dvrr_stack+27114, NULL);
 tmp = dvrr_stack + 21309;
 target_ptr = Libderiv->deriv_classes[3][12][9];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+27114, dvrr_stack+32020, NULL);
 tmp = dvrr_stack + 27114;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+32020, dvrr_stack+34810, NULL);
 tmp = dvrr_stack + 32020;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+34810, dvrr_stack+38300, NULL);
 tmp = dvrr_stack + 34810;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+38300, dvrr_stack+42371, NULL);
 tmp = dvrr_stack + 38300;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+12497, dvrr_stack+47498, NULL);
 tmp = dvrr_stack + 12497;
 target_ptr = Libderiv->deriv_classes[4][10][9];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1170,dvrr_stack+47498, dvrr_stack+53562, NULL);
 tmp = dvrr_stack + 47498;
 target_ptr = Libderiv->deriv_classes[4][11][9];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1365,dvrr_stack+53562, dvrr_stack+60642, NULL);
 tmp = dvrr_stack + 53562;
 target_ptr = Libderiv->deriv_classes[4][12][9];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+60642, dvrr_stack+67996, NULL);
 tmp = dvrr_stack + 60642;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+67996, dvrr_stack+71830, NULL);
 tmp = dvrr_stack + 67996;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+35485, dvrr_stack+76958, NULL);
 tmp = dvrr_stack + 35485;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+76958, dvrr_stack+83225, NULL);
 tmp = dvrr_stack + 76958;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+83225, dvrr_stack+90746, NULL);
 tmp = dvrr_stack + 83225;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+90746, dvrr_stack+99636, NULL);
 tmp = dvrr_stack + 90746;
 target_ptr = Libderiv->deriv_classes[5][11][9];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1911,dvrr_stack+99636, dvrr_stack+110010, NULL);
 tmp = dvrr_stack + 99636;
 target_ptr = Libderiv->deriv_classes[5][12][9];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+110010, dvrr_stack+2463, dvrr_stack+57306);
 tmp = dvrr_stack + 110010;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+110290, dvrr_stack+4783, dvrr_stack+1291);
 tmp = dvrr_stack + 110290;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+110650, dvrr_stack+7659, dvrr_stack+2463);
 tmp = dvrr_stack + 110650;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+111100, dvrr_stack+11177, dvrr_stack+4783);
 tmp = dvrr_stack + 111100;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+111650, dvrr_stack+15402, dvrr_stack+7659);
 tmp = dvrr_stack + 111650;
 target_ptr = Libderiv->deriv_classes[3][10][8];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,10,1,dvrr_stack+112310, dvrr_stack+20399, dvrr_stack+11177);
 tmp = dvrr_stack + 112310;
 target_ptr = Libderiv->deriv_classes[3][11][8];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,10,1,dvrr_stack+113090, dvrr_stack+26064, dvrr_stack+15402);
 tmp = dvrr_stack + 113090;
 target_ptr = Libderiv->deriv_classes[3][12][8];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+114000, dvrr_stack+31480, dvrr_stack+57666);
 tmp = dvrr_stack + 114000;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+114420, dvrr_stack+34135, dvrr_stack+30376);
 tmp = dvrr_stack + 114420;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+114960, dvrr_stack+37475, dvrr_stack+31480);
 tmp = dvrr_stack + 114960;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+101547, dvrr_stack+41381, dvrr_stack+34135);
 tmp = dvrr_stack + 101547;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+102372, dvrr_stack+46328, dvrr_stack+37475);
 tmp = dvrr_stack + 102372;
 target_ptr = Libderiv->deriv_classes[4][10][8];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,15,1,dvrr_stack+103362, dvrr_stack+52197, dvrr_stack+41381);
 tmp = dvrr_stack + 103362;
 target_ptr = Libderiv->deriv_classes[4][11][8];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,15,1,dvrr_stack+92384, dvrr_stack+59067, dvrr_stack+46328);
 tmp = dvrr_stack + 92384;
 target_ptr = Libderiv->deriv_classes[4][12][8];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+93749, dvrr_stack+67240, dvrr_stack+58206);
 tmp = dvrr_stack + 93749;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+84611, dvrr_stack+70885, dvrr_stack+65752);
 tmp = dvrr_stack + 84611;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+85367, dvrr_stack+75803, dvrr_stack+67240);
 tmp = dvrr_stack + 85367;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+78113, dvrr_stack+81839, dvrr_stack+70885);
 tmp = dvrr_stack + 78113;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+71830, dvrr_stack+89108, dvrr_stack+75803);
 tmp = dvrr_stack + 71830;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+61230, dvrr_stack+97725, dvrr_stack+81839);
 tmp = dvrr_stack + 61230;
 target_ptr = Libderiv->deriv_classes[5][11][8];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,21,1,dvrr_stack+54927, dvrr_stack+107805, dvrr_stack+89108);
 tmp = dvrr_stack + 54927;
 target_ptr = Libderiv->deriv_classes[5][12][8];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+94337, dvrr_stack+2463, dvrr_stack+57306);
 tmp = dvrr_stack + 94337;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+86312, dvrr_stack+4783, dvrr_stack+1291);
 tmp = dvrr_stack + 86312;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+79268, dvrr_stack+7659, dvrr_stack+2463);
 tmp = dvrr_stack + 79268;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+73216, dvrr_stack+11177, dvrr_stack+4783);
 tmp = dvrr_stack + 73216;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+68752, dvrr_stack+15402, dvrr_stack+7659);
 tmp = dvrr_stack + 68752;
 target_ptr = Libderiv->deriv_classes[3][10][7];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,10,1,dvrr_stack+62868, dvrr_stack+20399, dvrr_stack+11177);
 tmp = dvrr_stack + 62868;
 target_ptr = Libderiv->deriv_classes[3][11][7];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,10,1,dvrr_stack+63648, dvrr_stack+26064, dvrr_stack+15402);
 tmp = dvrr_stack + 63648;
 target_ptr = Libderiv->deriv_classes[3][12][7];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+56838, dvrr_stack+31480, dvrr_stack+57666);
 tmp = dvrr_stack + 56838;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+48668, dvrr_stack+34135, dvrr_stack+30376);
 tmp = dvrr_stack + 48668;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+49208, dvrr_stack+37475, dvrr_stack+31480);
 tmp = dvrr_stack + 49208;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+42371, dvrr_stack+41381, dvrr_stack+34135);
 tmp = dvrr_stack + 42371;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+43196, dvrr_stack+46328, dvrr_stack+37475);
 tmp = dvrr_stack + 43196;
 target_ptr = Libderiv->deriv_classes[4][10][7];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,15,1,dvrr_stack+39125, dvrr_stack+52197, dvrr_stack+41381);
 tmp = dvrr_stack + 39125;
 target_ptr = Libderiv->deriv_classes[4][11][7];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,15,1,dvrr_stack+32560, dvrr_stack+59067, dvrr_stack+46328);
 tmp = dvrr_stack + 32560;
 target_ptr = Libderiv->deriv_classes[4][12][7];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+44186, dvrr_stack+67240, dvrr_stack+58206);
 tmp = dvrr_stack + 44186;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+27534, dvrr_stack+70885, dvrr_stack+65752);
 tmp = dvrr_stack + 27534;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+28290, dvrr_stack+75803, dvrr_stack+67240);
 tmp = dvrr_stack + 28290;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+22219, dvrr_stack+81839, dvrr_stack+70885);
 tmp = dvrr_stack + 22219;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+137297, dvrr_stack+89108, dvrr_stack+75803);
 tmp = dvrr_stack + 137297;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+138683, dvrr_stack+97725, dvrr_stack+81839);
 tmp = dvrr_stack + 138683;
 target_ptr = Libderiv->deriv_classes[5][11][7];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,21,1,dvrr_stack+140321, dvrr_stack+107805, dvrr_stack+89108);
 tmp = dvrr_stack + 140321;
 target_ptr = Libderiv->deriv_classes[5][12][7];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+94617, dvrr_stack+2463, dvrr_stack+57306);
 tmp = dvrr_stack + 94617;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+57258, dvrr_stack+4783, dvrr_stack+1291);
 tmp = dvrr_stack + 57258;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+49883, dvrr_stack+7659, dvrr_stack+2463);
 tmp = dvrr_stack + 49883;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+29235, dvrr_stack+11177, dvrr_stack+4783);
 tmp = dvrr_stack + 29235;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+16962, dvrr_stack+15402, dvrr_stack+7659);
 tmp = dvrr_stack + 16962;
 target_ptr = Libderiv->deriv_classes[3][10][6];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,10,1,dvrr_stack+8759, dvrr_stack+20399, dvrr_stack+11177);
 tmp = dvrr_stack + 8759;
 target_ptr = Libderiv->deriv_classes[3][11][6];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,10,1,dvrr_stack+142232, dvrr_stack+26064, dvrr_stack+15402);
 tmp = dvrr_stack + 142232;
 target_ptr = Libderiv->deriv_classes[3][12][6];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+29785, dvrr_stack+31480, dvrr_stack+57666);
 tmp = dvrr_stack + 29785;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+17622, dvrr_stack+34135, dvrr_stack+30376);
 tmp = dvrr_stack + 17622;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+1571, dvrr_stack+37475, dvrr_stack+31480);
 tmp = dvrr_stack + 1571;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+25721, dvrr_stack+41381, dvrr_stack+34135);
 tmp = dvrr_stack + 25721;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+143142, dvrr_stack+46328, dvrr_stack+37475);
 tmp = dvrr_stack + 143142;
 target_ptr = Libderiv->deriv_classes[4][10][6];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,15,1,dvrr_stack+144132, dvrr_stack+52197, dvrr_stack+41381);
 tmp = dvrr_stack + 144132;
 target_ptr = Libderiv->deriv_classes[4][11][6];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,15,1,dvrr_stack+145302, dvrr_stack+59067, dvrr_stack+46328);
 tmp = dvrr_stack + 145302;
 target_ptr = Libderiv->deriv_classes[4][12][6];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+57618, dvrr_stack+67240, dvrr_stack+58206);
 tmp = dvrr_stack + 57618;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+59067, dvrr_stack+70885, dvrr_stack+65752);
 tmp = dvrr_stack + 59067;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+146667, dvrr_stack+75803, dvrr_stack+67240);
 tmp = dvrr_stack + 146667;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+147612, dvrr_stack+81839, dvrr_stack+70885);
 tmp = dvrr_stack + 147612;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+148767, dvrr_stack+89108, dvrr_stack+75803);
 tmp = dvrr_stack + 148767;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+150153, dvrr_stack+97725, dvrr_stack+81839);
 tmp = dvrr_stack + 150153;
 target_ptr = Libderiv->deriv_classes[5][11][6];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,21,1,dvrr_stack+151791, dvrr_stack+107805, dvrr_stack+89108);
 tmp = dvrr_stack + 151791;
 target_ptr = Libderiv->deriv_classes[5][12][6];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+58206, dvrr_stack+30376, dvrr_stack+1123);
 tmp = dvrr_stack + 58206;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+59823, dvrr_stack+31480, dvrr_stack+2247);
 tmp = dvrr_stack + 59823;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+60183, dvrr_stack+34135, dvrr_stack+4513);
 tmp = dvrr_stack + 60183;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+5683, dvrr_stack+37475, dvrr_stack+7329);
 tmp = dvrr_stack + 5683;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+30796, dvrr_stack+41381, dvrr_stack+10781);
 tmp = dvrr_stack + 30796;
 target_ptr = Libderiv->deriv_classes[3][10][2];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,78,dvrr_stack+107538, dvrr_stack+46328, dvrr_stack+14934);
 tmp = dvrr_stack + 107538;
 target_ptr = Libderiv->deriv_classes[3][11][2];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,91,dvrr_stack+108318, dvrr_stack+52197, dvrr_stack+19853);
 tmp = dvrr_stack + 108318;
 target_ptr = Libderiv->deriv_classes[3][12][2];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+3183, dvrr_stack+65752, dvrr_stack+1291);
 tmp = dvrr_stack + 3183;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+109228, dvrr_stack+67240, dvrr_stack+2463);
 tmp = dvrr_stack + 109228;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+153702, dvrr_stack+70885, dvrr_stack+4783);
 tmp = dvrr_stack + 153702;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+154377, dvrr_stack+75803, dvrr_stack+7659);
 tmp = dvrr_stack + 154377;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+155202, dvrr_stack+81839, dvrr_stack+11177);
 tmp = dvrr_stack + 155202;
 target_ptr = Libderiv->deriv_classes[4][10][2];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,78,dvrr_stack+156192, dvrr_stack+89108, dvrr_stack+15402);
 tmp = dvrr_stack + 156192;
 target_ptr = Libderiv->deriv_classes[4][11][2];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,91,dvrr_stack+157362, dvrr_stack+97725, dvrr_stack+20399);
 tmp = dvrr_stack + 157362;
 target_ptr = Libderiv->deriv_classes[4][12][2];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+158727, dvrr_stack+24937, dvrr_stack+30376);
 tmp = dvrr_stack + 158727;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+159315, dvrr_stack+106530, dvrr_stack+31480);
 tmp = dvrr_stack + 159315;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+160071, dvrr_stack+115743, dvrr_stack+34135);
 tmp = dvrr_stack + 160071;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+161016, dvrr_stack+117003, dvrr_stack+37475);
 tmp = dvrr_stack + 161016;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+162171, dvrr_stack+118543, dvrr_stack+41381);
 tmp = dvrr_stack + 162171;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,78,dvrr_stack+163557, dvrr_stack+120391, dvrr_stack+46328);
 tmp = dvrr_stack + 163557;
 target_ptr = Libderiv->deriv_classes[5][11][2];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,91,dvrr_stack+165195, dvrr_stack+122575, dvrr_stack+52197);
 tmp = dvrr_stack + 165195;
 target_ptr = Libderiv->deriv_classes[5][12][2];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+73766, dvrr_stack+30376, dvrr_stack+1123);
 tmp = dvrr_stack + 73766;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+45806, dvrr_stack+31480, dvrr_stack+2247);
 tmp = dvrr_stack + 45806;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+37018, dvrr_stack+34135, dvrr_stack+4513);
 tmp = dvrr_stack + 37018;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+26546, dvrr_stack+37475, dvrr_stack+7329);
 tmp = dvrr_stack + 26546;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+167106, dvrr_stack+41381, dvrr_stack+10781);
 tmp = dvrr_stack + 167106;
 target_ptr = Libderiv->deriv_classes[3][10][1];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,78,dvrr_stack+167766, dvrr_stack+46328, dvrr_stack+14934);
 tmp = dvrr_stack + 167766;
 target_ptr = Libderiv->deriv_classes[3][11][1];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,91,dvrr_stack+168546, dvrr_stack+52197, dvrr_stack+19853);
 tmp = dvrr_stack + 168546;
 target_ptr = Libderiv->deriv_classes[3][12][1];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+169456, dvrr_stack+65752, dvrr_stack+1291);
 tmp = dvrr_stack + 169456;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+169876, dvrr_stack+67240, dvrr_stack+2463);
 tmp = dvrr_stack + 169876;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+170416, dvrr_stack+70885, dvrr_stack+4783);
 tmp = dvrr_stack + 170416;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+171091, dvrr_stack+75803, dvrr_stack+7659);
 tmp = dvrr_stack + 171091;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+171916, dvrr_stack+81839, dvrr_stack+11177);
 tmp = dvrr_stack + 171916;
 target_ptr = Libderiv->deriv_classes[4][10][1];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,78,dvrr_stack+172906, dvrr_stack+89108, dvrr_stack+15402);
 tmp = dvrr_stack + 172906;
 target_ptr = Libderiv->deriv_classes[4][11][1];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,91,dvrr_stack+174076, dvrr_stack+97725, dvrr_stack+20399);
 tmp = dvrr_stack + 174076;
 target_ptr = Libderiv->deriv_classes[4][12][1];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+175441, dvrr_stack+24937, dvrr_stack+30376);
 tmp = dvrr_stack + 175441;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+176029, dvrr_stack+106530, dvrr_stack+31480);
 tmp = dvrr_stack + 176029;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+176785, dvrr_stack+115743, dvrr_stack+34135);
 tmp = dvrr_stack + 176785;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+177730, dvrr_stack+117003, dvrr_stack+37475);
 tmp = dvrr_stack + 177730;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+178885, dvrr_stack+118543, dvrr_stack+41381);
 tmp = dvrr_stack + 178885;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,78,dvrr_stack+180271, dvrr_stack+120391, dvrr_stack+46328);
 tmp = dvrr_stack + 180271;
 target_ptr = Libderiv->deriv_classes[5][11][1];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,91,dvrr_stack+181909, dvrr_stack+122575, dvrr_stack+52197);
 tmp = dvrr_stack + 181909;
 target_ptr = Libderiv->deriv_classes[5][12][1];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+69412, dvrr_stack+30376, dvrr_stack+1123);
 tmp = dvrr_stack + 69412;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+183820, dvrr_stack+31480, dvrr_stack+2247);
 tmp = dvrr_stack + 183820;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+184180, dvrr_stack+34135, dvrr_stack+4513);
 tmp = dvrr_stack + 184180;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+184630, dvrr_stack+37475, dvrr_stack+7329);
 tmp = dvrr_stack + 184630;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+185180, dvrr_stack+41381, dvrr_stack+10781);
 tmp = dvrr_stack + 185180;
 target_ptr = Libderiv->deriv_classes[3][10][0];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,78,dvrr_stack+185840, dvrr_stack+46328, dvrr_stack+14934);
 tmp = dvrr_stack + 185840;
 target_ptr = Libderiv->deriv_classes[3][11][0];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,91,dvrr_stack+186620, dvrr_stack+52197, dvrr_stack+19853);
 tmp = dvrr_stack + 186620;
 target_ptr = Libderiv->deriv_classes[3][12][0];
 for(i=0;i<910;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+10749, dvrr_stack+65752, dvrr_stack+1291);
 tmp = dvrr_stack + 10749;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+19527, dvrr_stack+67240, dvrr_stack+2463);
 tmp = dvrr_stack + 19527;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+14642, dvrr_stack+70885, dvrr_stack+4783);
 tmp = dvrr_stack + 14642;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+4338, dvrr_stack+75803, dvrr_stack+7659);
 tmp = dvrr_stack + 4338;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+75598, dvrr_stack+81839, dvrr_stack+11177);
 tmp = dvrr_stack + 75598;
 target_ptr = Libderiv->deriv_classes[4][10][0];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,78,dvrr_stack+81713, dvrr_stack+89108, dvrr_stack+15402);
 tmp = dvrr_stack + 81713;
 target_ptr = Libderiv->deriv_classes[4][11][0];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,91,dvrr_stack+88856, dvrr_stack+97725, dvrr_stack+20399);
 tmp = dvrr_stack + 88856;
 target_ptr = Libderiv->deriv_classes[4][12][0];
 for(i=0;i<1365;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+11169, dvrr_stack+24937, dvrr_stack+30376);
 tmp = dvrr_stack + 11169;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+97652, dvrr_stack+106530, dvrr_stack+31480);
 tmp = dvrr_stack + 97652;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+106530, dvrr_stack+115743, dvrr_stack+34135);
 tmp = dvrr_stack + 106530;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+115635, dvrr_stack+117003, dvrr_stack+37475);
 tmp = dvrr_stack + 115635;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+116790, dvrr_stack+118543, dvrr_stack+41381);
 tmp = dvrr_stack + 116790;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,78,dvrr_stack+118176, dvrr_stack+120391, dvrr_stack+46328);
 tmp = dvrr_stack + 118176;
 target_ptr = Libderiv->deriv_classes[5][11][0];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,91,dvrr_stack+119814, dvrr_stack+122575, dvrr_stack+52197);
 tmp = dvrr_stack + 119814;
 target_ptr = Libderiv->deriv_classes[5][12][0];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];


}

