/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hd|hh) integrals */

void d1vrr_order_hdhh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+873, dvrr_stack+210, dvrr_stack+161, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+879, dvrr_stack+213, dvrr_stack+873, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+889, dvrr_stack+219, dvrr_stack+879, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+904, dvrr_stack+509, dvrr_stack+889, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+949, dvrr_stack+524, dvrr_stack+904, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1039, dvrr_stack+614, dvrr_stack+949, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1189, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1339, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1564, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1585, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1606, dvrr_stack+1585, dvrr_stack+1564, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1669, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1690, dvrr_stack+1669, dvrr_stack+1585, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1753, dvrr_stack+509, dvrr_stack+889, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1774, dvrr_stack+1564, dvrr_stack+1753, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1837, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1963, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2089, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2299, dvrr_stack+593, dvrr_stack+1669, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2362, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2488, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2299, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2302, dvrr_stack+161, dvrr_stack+2299, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+873, dvrr_stack+2302, dvrr_stack+210, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2308, dvrr_stack+879, dvrr_stack+121, dvrr_stack+213, dvrr_stack+873, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2323, dvrr_stack+889, dvrr_stack+2308, dvrr_stack+219, dvrr_stack+879, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2698, dvrr_stack+1753, dvrr_stack+2323, NULL, NULL, dvrr_stack+889);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2761, dvrr_stack+1774, dvrr_stack+2698, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+904);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2887, dvrr_stack+1837, dvrr_stack+2761, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+949);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3097, dvrr_stack+2089, dvrr_stack+2887, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1039);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3412, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+1189);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3727, dvrr_stack+3412, dvrr_stack+3097, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+1339);
 tmp = dvrr_stack + 3727;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2344, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2372, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2400, dvrr_stack+2372, dvrr_stack+2344, NULL, NULL, dvrr_stack+1564);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2484, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2512, dvrr_stack+2484, dvrr_stack+2372, NULL, NULL, dvrr_stack+1585);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+479, dvrr_stack+1753, dvrr_stack+2323, dvrr_stack+509, dvrr_stack+889, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2596, dvrr_stack+2344, dvrr_stack+479, NULL, NULL, dvrr_stack+1753);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4168, dvrr_stack+2400, dvrr_stack+2596, dvrr_stack+2372, dvrr_stack+2344, dvrr_stack+1774);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4336, dvrr_stack+2512, dvrr_stack+2400, dvrr_stack+2484, dvrr_stack+2372, dvrr_stack+1606);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4504, dvrr_stack+4336, dvrr_stack+4168, dvrr_stack+2512, dvrr_stack+2400, dvrr_stack+1837);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1606, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4784, dvrr_stack+1606, dvrr_stack+2484, NULL, NULL, dvrr_stack+1669);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4868, dvrr_stack+4784, dvrr_stack+2512, dvrr_stack+1606, dvrr_stack+2484, dvrr_stack+1690);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5036, dvrr_stack+4868, dvrr_stack+4336, dvrr_stack+4784, dvrr_stack+2512, dvrr_stack+1963);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1963, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1966, dvrr_stack+2299, dvrr_stack+1963, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1972, dvrr_stack+2302, dvrr_stack+1966, dvrr_stack+161, dvrr_stack+2299, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1982, dvrr_stack+121, dvrr_stack+1972, dvrr_stack+873, dvrr_stack+2302, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1997, dvrr_stack+2308, dvrr_stack+1982, dvrr_stack+879, dvrr_stack+121, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2018, dvrr_stack+2323, dvrr_stack+1997, dvrr_stack+889, dvrr_stack+2308, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4784, dvrr_stack+479, dvrr_stack+2018, NULL, NULL, dvrr_stack+2323);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5316, dvrr_stack+2596, dvrr_stack+4784, dvrr_stack+2344, dvrr_stack+479, dvrr_stack+2698);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5484, dvrr_stack+4168, dvrr_stack+5316, dvrr_stack+2400, dvrr_stack+2596, dvrr_stack+2761);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+5764, dvrr_stack+4504, dvrr_stack+5484, dvrr_stack+4336, dvrr_stack+4168, dvrr_stack+2887);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6184, dvrr_stack+5036, dvrr_stack+4504, dvrr_stack+4868, dvrr_stack+4336, dvrr_stack+2089);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6604, dvrr_stack+6184, dvrr_stack+5764, dvrr_stack+5036, dvrr_stack+4504, dvrr_stack+3097);
 tmp = dvrr_stack + 6604;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+7192,dvrr_stack+6604,dvrr_stack+3727,21);


 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4868, dvrr_stack+2344, dvrr_stack+479, dvrr_stack+1564, dvrr_stack+1753, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4904, dvrr_stack+2372, dvrr_stack+2344, dvrr_stack+1585, dvrr_stack+1564, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4940, dvrr_stack+4904, dvrr_stack+4868, NULL, NULL, dvrr_stack+2344);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5048, dvrr_stack+2484, dvrr_stack+2372, dvrr_stack+1669, dvrr_stack+1585, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5084, dvrr_stack+5048, dvrr_stack+4904, NULL, NULL, dvrr_stack+2372);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1564, dvrr_stack+479, dvrr_stack+2018, dvrr_stack+1753, dvrr_stack+2323, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5192, dvrr_stack+4868, dvrr_stack+1564, NULL, NULL, dvrr_stack+479);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8515, dvrr_stack+4940, dvrr_stack+5192, dvrr_stack+4904, dvrr_stack+4868, dvrr_stack+2596);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8731, dvrr_stack+5084, dvrr_stack+4940, dvrr_stack+5048, dvrr_stack+4904, dvrr_stack+2400);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8947, dvrr_stack+8731, dvrr_stack+8515, dvrr_stack+5084, dvrr_stack+4940, dvrr_stack+4168);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2400, dvrr_stack+1606, dvrr_stack+2484, dvrr_stack+593, dvrr_stack+1669, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1634, dvrr_stack+2400, dvrr_stack+5048, NULL, NULL, dvrr_stack+2484);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9307, dvrr_stack+1634, dvrr_stack+5084, dvrr_stack+2400, dvrr_stack+5048, dvrr_stack+2512);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9523, dvrr_stack+9307, dvrr_stack+8731, dvrr_stack+1634, dvrr_stack+5084, dvrr_stack+4336);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4336, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1600, dvrr_stack+1963, dvrr_stack+4336, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4339, dvrr_stack+1966, dvrr_stack+1600, dvrr_stack+2299, dvrr_stack+1963, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4349, dvrr_stack+1972, dvrr_stack+4339, dvrr_stack+2302, dvrr_stack+1966, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+1982, dvrr_stack+4349, dvrr_stack+121, dvrr_stack+1972, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4364, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+2308, dvrr_stack+1982, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4392, dvrr_stack+2018, dvrr_stack+4364, dvrr_stack+2323, dvrr_stack+1997, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1634, dvrr_stack+1564, dvrr_stack+4392, NULL, NULL, dvrr_stack+2018);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9883, dvrr_stack+5192, dvrr_stack+1634, dvrr_stack+4868, dvrr_stack+1564, dvrr_stack+4784);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10099, dvrr_stack+8515, dvrr_stack+9883, dvrr_stack+4940, dvrr_stack+5192, dvrr_stack+5316);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10459, dvrr_stack+8947, dvrr_stack+10099, dvrr_stack+8731, dvrr_stack+8515, dvrr_stack+5484);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10999, dvrr_stack+9523, dvrr_stack+8947, dvrr_stack+9307, dvrr_stack+8731, dvrr_stack+4504);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11539, dvrr_stack+10999, dvrr_stack+10459, dvrr_stack+9523, dvrr_stack+8947, dvrr_stack+5764);
 tmp = dvrr_stack + 11539;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+12295,dvrr_stack+11539,dvrr_stack+6604,21);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9307, dvrr_stack+4868, dvrr_stack+1564, dvrr_stack+2344, dvrr_stack+479, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9352, dvrr_stack+4904, dvrr_stack+4868, dvrr_stack+2372, dvrr_stack+2344, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9397, dvrr_stack+9352, dvrr_stack+9307, NULL, NULL, dvrr_stack+4868);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9532, dvrr_stack+5048, dvrr_stack+4904, dvrr_stack+2484, dvrr_stack+2372, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9577, dvrr_stack+9532, dvrr_stack+9352, NULL, NULL, dvrr_stack+4904);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2344, dvrr_stack+1564, dvrr_stack+4392, dvrr_stack+479, dvrr_stack+2018, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9712, dvrr_stack+9307, dvrr_stack+2344, NULL, NULL, dvrr_stack+1564);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14059, dvrr_stack+9397, dvrr_stack+9712, dvrr_stack+9352, dvrr_stack+9307, dvrr_stack+5192);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14329, dvrr_stack+9577, dvrr_stack+9397, dvrr_stack+9532, dvrr_stack+9352, dvrr_stack+4940);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14599, dvrr_stack+14329, dvrr_stack+14059, dvrr_stack+9577, dvrr_stack+9397, dvrr_stack+8515);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4940, dvrr_stack+2400, dvrr_stack+5048, dvrr_stack+1606, dvrr_stack+2484, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2436, dvrr_stack+4940, dvrr_stack+9532, NULL, NULL, dvrr_stack+5048);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15049, dvrr_stack+2436, dvrr_stack+9577, dvrr_stack+4940, dvrr_stack+9532, dvrr_stack+5084);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15319, dvrr_stack+15049, dvrr_stack+14329, dvrr_stack+2436, dvrr_stack+9577, dvrr_stack+8731);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2299, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8731, dvrr_stack+4336, dvrr_stack+2299, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+8737, dvrr_stack+1600, dvrr_stack+8731, dvrr_stack+1963, dvrr_stack+4336, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+8747, dvrr_stack+4339, dvrr_stack+8737, dvrr_stack+1966, dvrr_stack+1600, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+8762, dvrr_stack+4349, dvrr_stack+8747, dvrr_stack+1972, dvrr_stack+4339, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1606, dvrr_stack+593, dvrr_stack+8762, dvrr_stack+1982, dvrr_stack+4349, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9847, dvrr_stack+4364, dvrr_stack+1606, dvrr_stack+1997, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8783, dvrr_stack+4392, dvrr_stack+9847, dvrr_stack+2018, dvrr_stack+4364, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2436, dvrr_stack+2344, dvrr_stack+8783, NULL, NULL, dvrr_stack+4392);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15769, dvrr_stack+9712, dvrr_stack+2436, dvrr_stack+9307, dvrr_stack+2344, dvrr_stack+1634);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+16039, dvrr_stack+14059, dvrr_stack+15769, dvrr_stack+9397, dvrr_stack+9712, dvrr_stack+9883);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+16489, dvrr_stack+14599, dvrr_stack+16039, dvrr_stack+14329, dvrr_stack+14059, dvrr_stack+10099);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+17164, dvrr_stack+15319, dvrr_stack+14599, dvrr_stack+15049, dvrr_stack+14329, dvrr_stack+8947);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+17839, dvrr_stack+17164, dvrr_stack+16489, dvrr_stack+15319, dvrr_stack+14599, dvrr_stack+10459);
 tmp = dvrr_stack + 17839;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+18784,dvrr_stack+17839,dvrr_stack+11539,21);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15049, dvrr_stack+9307, dvrr_stack+2344, dvrr_stack+4868, dvrr_stack+1564, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15104, dvrr_stack+9352, dvrr_stack+9307, dvrr_stack+4904, dvrr_stack+4868, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15159, dvrr_stack+15104, dvrr_stack+15049, NULL, NULL, dvrr_stack+9307);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15324, dvrr_stack+9532, dvrr_stack+9352, dvrr_stack+5048, dvrr_stack+4904, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15379, dvrr_stack+15324, dvrr_stack+15104, NULL, NULL, dvrr_stack+9352);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4868, dvrr_stack+2344, dvrr_stack+8783, dvrr_stack+1564, dvrr_stack+4392, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15544, dvrr_stack+15049, dvrr_stack+4868, NULL, NULL, dvrr_stack+2344);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21052, dvrr_stack+15159, dvrr_stack+15544, dvrr_stack+15104, dvrr_stack+15049, dvrr_stack+9712);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21382, dvrr_stack+15379, dvrr_stack+15159, dvrr_stack+15324, dvrr_stack+15104, dvrr_stack+9397);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21712, dvrr_stack+21382, dvrr_stack+21052, dvrr_stack+15379, dvrr_stack+15159, dvrr_stack+14059);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9397, dvrr_stack+4940, dvrr_stack+9532, dvrr_stack+2400, dvrr_stack+5048, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4985, dvrr_stack+9397, dvrr_stack+15324, NULL, NULL, dvrr_stack+9532);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22262, dvrr_stack+4985, dvrr_stack+15379, dvrr_stack+9397, dvrr_stack+15324, dvrr_stack+9577);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22592, dvrr_stack+22262, dvrr_stack+21382, dvrr_stack+4985, dvrr_stack+15379, dvrr_stack+14329);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+14329, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+14332, dvrr_stack+2299, dvrr_stack+14329, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+14338, dvrr_stack+8731, dvrr_stack+14332, dvrr_stack+4336, dvrr_stack+2299, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+14348, dvrr_stack+8737, dvrr_stack+14338, dvrr_stack+1600, dvrr_stack+8731, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+14363, dvrr_stack+8747, dvrr_stack+14348, dvrr_stack+4339, dvrr_stack+8737, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+14384, dvrr_stack+8762, dvrr_stack+14363, dvrr_stack+4349, dvrr_stack+8747, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14412, dvrr_stack+1606, dvrr_stack+14384, dvrr_stack+593, dvrr_stack+8762, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14448, dvrr_stack+9847, dvrr_stack+14412, dvrr_stack+4364, dvrr_stack+1606, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14493, dvrr_stack+8783, dvrr_stack+14448, dvrr_stack+4392, dvrr_stack+9847, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4985, dvrr_stack+4868, dvrr_stack+14493, NULL, NULL, dvrr_stack+8783);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23142, dvrr_stack+15544, dvrr_stack+4985, dvrr_stack+15049, dvrr_stack+4868, dvrr_stack+2436);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23472, dvrr_stack+21052, dvrr_stack+23142, dvrr_stack+15159, dvrr_stack+15544, dvrr_stack+15769);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+24022, dvrr_stack+21712, dvrr_stack+23472, dvrr_stack+21382, dvrr_stack+21052, dvrr_stack+16039);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+24847, dvrr_stack+22592, dvrr_stack+21712, dvrr_stack+22262, dvrr_stack+21382, dvrr_stack+14599);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+25672, dvrr_stack+24847, dvrr_stack+24022, dvrr_stack+22592, dvrr_stack+21712, dvrr_stack+16489);
 tmp = dvrr_stack + 25672;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+26827,dvrr_stack+25672,dvrr_stack+17839,21);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22262, dvrr_stack+15049, dvrr_stack+4868, dvrr_stack+9307, dvrr_stack+2344, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22328, dvrr_stack+15104, dvrr_stack+15049, dvrr_stack+9352, dvrr_stack+9307, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22394, dvrr_stack+22328, dvrr_stack+22262, NULL, NULL, dvrr_stack+15049);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22592, dvrr_stack+15324, dvrr_stack+15104, dvrr_stack+9532, dvrr_stack+9352, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22658, dvrr_stack+22592, dvrr_stack+22328, NULL, NULL, dvrr_stack+15104);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9307, dvrr_stack+4868, dvrr_stack+14493, dvrr_stack+2344, dvrr_stack+8783, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22856, dvrr_stack+22262, dvrr_stack+9307, NULL, NULL, dvrr_stack+4868);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29662, dvrr_stack+22394, dvrr_stack+22856, dvrr_stack+22328, dvrr_stack+22262, dvrr_stack+15544);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30058, dvrr_stack+22658, dvrr_stack+22394, dvrr_stack+22592, dvrr_stack+22328, dvrr_stack+15159);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30454, dvrr_stack+30058, dvrr_stack+29662, dvrr_stack+22658, dvrr_stack+22394, dvrr_stack+21052);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+15159, dvrr_stack+9397, dvrr_stack+15324, dvrr_stack+4940, dvrr_stack+9532, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9452, dvrr_stack+15159, dvrr_stack+22592, NULL, NULL, dvrr_stack+15324);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31114, dvrr_stack+9452, dvrr_stack+22658, dvrr_stack+15159, dvrr_stack+22592, dvrr_stack+15379);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31510, dvrr_stack+31114, dvrr_stack+30058, dvrr_stack+9452, dvrr_stack+22658, dvrr_stack+21382);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21382, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1600, dvrr_stack+14329, dvrr_stack+21382, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21385, dvrr_stack+14332, dvrr_stack+1600, dvrr_stack+2299, dvrr_stack+14329, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+21395, dvrr_stack+14338, dvrr_stack+21385, dvrr_stack+8731, dvrr_stack+14332, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+21410, dvrr_stack+14348, dvrr_stack+21395, dvrr_stack+8737, dvrr_stack+14338, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+21431, dvrr_stack+14363, dvrr_stack+21410, dvrr_stack+8747, dvrr_stack+14348, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+21459, dvrr_stack+14384, dvrr_stack+21431, dvrr_stack+8762, dvrr_stack+14363, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21495, dvrr_stack+14412, dvrr_stack+21459, dvrr_stack+1606, dvrr_stack+14384, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21540, dvrr_stack+14448, dvrr_stack+21495, dvrr_stack+9847, dvrr_stack+14412, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21595, dvrr_stack+14493, dvrr_stack+21540, dvrr_stack+8783, dvrr_stack+14448, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9452, dvrr_stack+9307, dvrr_stack+21595, NULL, NULL, dvrr_stack+14493);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32170, dvrr_stack+22856, dvrr_stack+9452, dvrr_stack+22262, dvrr_stack+9307, dvrr_stack+4985);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32566, dvrr_stack+29662, dvrr_stack+32170, dvrr_stack+22394, dvrr_stack+22856, dvrr_stack+23142);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33226, dvrr_stack+30454, dvrr_stack+32566, dvrr_stack+30058, dvrr_stack+29662, dvrr_stack+23472);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34216, dvrr_stack+31510, dvrr_stack+30454, dvrr_stack+31114, dvrr_stack+30058, dvrr_stack+21712);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35206, dvrr_stack+34216, dvrr_stack+33226, dvrr_stack+31510, dvrr_stack+30454, dvrr_stack+24022);
 tmp = dvrr_stack + 35206;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+36592,dvrr_stack+35206,dvrr_stack+25672,21);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31114, dvrr_stack+22262, dvrr_stack+9307, dvrr_stack+15049, dvrr_stack+4868, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31192, dvrr_stack+22328, dvrr_stack+22262, dvrr_stack+15104, dvrr_stack+15049, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31270, dvrr_stack+31192, dvrr_stack+31114, NULL, NULL, dvrr_stack+22262);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31504, dvrr_stack+22592, dvrr_stack+22328, dvrr_stack+15324, dvrr_stack+15104, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31582, dvrr_stack+31504, dvrr_stack+31192, NULL, NULL, dvrr_stack+22328);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22262, dvrr_stack+9307, dvrr_stack+21595, dvrr_stack+4868, dvrr_stack+14493, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31816, dvrr_stack+31114, dvrr_stack+22262, NULL, NULL, dvrr_stack+9307);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40057, dvrr_stack+31270, dvrr_stack+31816, dvrr_stack+31192, dvrr_stack+31114, dvrr_stack+22856);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40525, dvrr_stack+31582, dvrr_stack+31270, dvrr_stack+31504, dvrr_stack+31192, dvrr_stack+22394);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40993, dvrr_stack+40525, dvrr_stack+40057, dvrr_stack+31582, dvrr_stack+31270, dvrr_stack+29662);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31192, dvrr_stack+15159, dvrr_stack+22592, dvrr_stack+9397, dvrr_stack+15324, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22340, dvrr_stack+31192, dvrr_stack+31504, NULL, NULL, dvrr_stack+22592);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15049, dvrr_stack+22340, dvrr_stack+31582, dvrr_stack+31192, dvrr_stack+31504, dvrr_stack+22658);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41773, dvrr_stack+15049, dvrr_stack+40525, dvrr_stack+22340, dvrr_stack+31582, dvrr_stack+30058);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2299, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+30058, dvrr_stack+21382, dvrr_stack+2299, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30064, dvrr_stack+1600, dvrr_stack+30058, dvrr_stack+14329, dvrr_stack+21382, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+30074, dvrr_stack+21385, dvrr_stack+30064, dvrr_stack+14332, dvrr_stack+1600, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+30089, dvrr_stack+21395, dvrr_stack+30074, dvrr_stack+14338, dvrr_stack+21385, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+30110, dvrr_stack+21410, dvrr_stack+30089, dvrr_stack+14348, dvrr_stack+21395, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30138, dvrr_stack+21431, dvrr_stack+30110, dvrr_stack+14363, dvrr_stack+21410, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14329, dvrr_stack+21459, dvrr_stack+30138, dvrr_stack+14384, dvrr_stack+21431, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30174, dvrr_stack+21495, dvrr_stack+14329, dvrr_stack+14412, dvrr_stack+21459, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30229, dvrr_stack+21540, dvrr_stack+30174, dvrr_stack+14448, dvrr_stack+21495, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31192, dvrr_stack+21595, dvrr_stack+30229, dvrr_stack+14493, dvrr_stack+21540, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22340, dvrr_stack+22262, dvrr_stack+31192, NULL, NULL, dvrr_stack+21595);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42553, dvrr_stack+31816, dvrr_stack+22340, dvrr_stack+31114, dvrr_stack+22262, dvrr_stack+9452);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43021, dvrr_stack+40057, dvrr_stack+42553, dvrr_stack+31270, dvrr_stack+31816, dvrr_stack+32170);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43801, dvrr_stack+40993, dvrr_stack+43021, dvrr_stack+40525, dvrr_stack+40057, dvrr_stack+32566);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44971, dvrr_stack+41773, dvrr_stack+40993, dvrr_stack+15049, dvrr_stack+40525, dvrr_stack+30454);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+46141, dvrr_stack+44971, dvrr_stack+43801, dvrr_stack+41773, dvrr_stack+40993, dvrr_stack+33226);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+47779,dvrr_stack+46141,dvrr_stack+35206,21);


 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+41773, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1963, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+2680, dvrr_stack+6, dvrr_stack+1963, dvrr_stack+3, dvrr_stack+0, dvrr_stack+41773);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+41776, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+41794, dvrr_stack+39, dvrr_stack+41776, dvrr_stack+15, dvrr_stack+33, dvrr_stack+1963);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+15709, dvrr_stack+75, dvrr_stack+41794, dvrr_stack+57, dvrr_stack+39, dvrr_stack+2680);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+41830, dvrr_stack+219, dvrr_stack+879, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+41860, dvrr_stack+229, dvrr_stack+41830, dvrr_stack+111, dvrr_stack+219, dvrr_stack+41776);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+41920, dvrr_stack+259, dvrr_stack+41860, dvrr_stack+131, dvrr_stack+229, dvrr_stack+41794);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+42020, dvrr_stack+379, dvrr_stack+41920, dvrr_stack+319, dvrr_stack+259, dvrr_stack+15709);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+42170, dvrr_stack+889, dvrr_stack+2308, NULL, NULL, dvrr_stack+879);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+42215, dvrr_stack+904, dvrr_stack+42170, dvrr_stack+509, dvrr_stack+889, dvrr_stack+41830);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+42305, dvrr_stack+949, dvrr_stack+42215, dvrr_stack+524, dvrr_stack+904, dvrr_stack+41860);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+40525, dvrr_stack+1039, dvrr_stack+42305, dvrr_stack+614, dvrr_stack+949, dvrr_stack+41920);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+15049, dvrr_stack+1339, dvrr_stack+40525, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+42020);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2323, dvrr_stack+1997, NULL, NULL, dvrr_stack+2308);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+40750, dvrr_stack+2698, dvrr_stack+614, dvrr_stack+1753, dvrr_stack+2323, dvrr_stack+42170);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+31270, dvrr_stack+2761, dvrr_stack+40750, dvrr_stack+1774, dvrr_stack+2698, dvrr_stack+42215);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+31480, dvrr_stack+2887, dvrr_stack+31270, dvrr_stack+1837, dvrr_stack+2761, dvrr_stack+42305);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+51937, dvrr_stack+3097, dvrr_stack+31480, dvrr_stack+2089, dvrr_stack+2887, dvrr_stack+40525);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+52378, dvrr_stack+3727, dvrr_stack+51937, dvrr_stack+3412, dvrr_stack+3097, dvrr_stack+15049);
 tmp = dvrr_stack + 52378;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+42455, dvrr_stack+2018, dvrr_stack+4364, NULL, NULL, dvrr_stack+1997);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+15364, dvrr_stack+4784, dvrr_stack+42455, dvrr_stack+479, dvrr_stack+2018, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+22574, dvrr_stack+5316, dvrr_stack+15364, dvrr_stack+2596, dvrr_stack+4784, dvrr_stack+40750);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+52966, dvrr_stack+5484, dvrr_stack+22574, dvrr_stack+4168, dvrr_stack+5316, dvrr_stack+31270);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+53386, dvrr_stack+5764, dvrr_stack+52966, dvrr_stack+4504, dvrr_stack+5484, dvrr_stack+31480);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+53974, dvrr_stack+6604, dvrr_stack+53386, dvrr_stack+6184, dvrr_stack+5764, dvrr_stack+51937);
 tmp = dvrr_stack + 53974;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+54758,dvrr_stack+53974,dvrr_stack+52378,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4168, dvrr_stack+4392, dvrr_stack+9847, NULL, NULL, dvrr_stack+4364);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4428, dvrr_stack+1634, dvrr_stack+4168, dvrr_stack+1564, dvrr_stack+4392, dvrr_stack+42455);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+56522, dvrr_stack+9883, dvrr_stack+4428, dvrr_stack+5192, dvrr_stack+1634, dvrr_stack+15364);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+56882, dvrr_stack+10099, dvrr_stack+56522, dvrr_stack+8515, dvrr_stack+9883, dvrr_stack+22574);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+57422, dvrr_stack+10459, dvrr_stack+56882, dvrr_stack+8947, dvrr_stack+10099, dvrr_stack+52966);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+58178, dvrr_stack+11539, dvrr_stack+57422, dvrr_stack+10999, dvrr_stack+10459, dvrr_stack+53386);
 tmp = dvrr_stack + 58178;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+59186,dvrr_stack+58178,dvrr_stack+53974,28);


 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8515, dvrr_stack+8783, dvrr_stack+14448, NULL, NULL, dvrr_stack+9847);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8828, dvrr_stack+2436, dvrr_stack+8515, dvrr_stack+2344, dvrr_stack+8783, dvrr_stack+4168);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+61538, dvrr_stack+15769, dvrr_stack+8828, dvrr_stack+9712, dvrr_stack+2436, dvrr_stack+4428);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+61988, dvrr_stack+16039, dvrr_stack+61538, dvrr_stack+14059, dvrr_stack+15769, dvrr_stack+56522);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+62663, dvrr_stack+16489, dvrr_stack+61988, dvrr_stack+14599, dvrr_stack+16039, dvrr_stack+56882);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+63608, dvrr_stack+17839, dvrr_stack+62663, dvrr_stack+17164, dvrr_stack+16489, dvrr_stack+57422);
 tmp = dvrr_stack + 63608;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+64868,dvrr_stack+63608,dvrr_stack+58178,28);


 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14059, dvrr_stack+14493, dvrr_stack+21540, NULL, NULL, dvrr_stack+14448);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14548, dvrr_stack+4985, dvrr_stack+14059, dvrr_stack+4868, dvrr_stack+14493, dvrr_stack+8515);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67892, dvrr_stack+23142, dvrr_stack+14548, dvrr_stack+15544, dvrr_stack+4985, dvrr_stack+8828);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+68442, dvrr_stack+23472, dvrr_stack+67892, dvrr_stack+21052, dvrr_stack+23142, dvrr_stack+61538);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+69267, dvrr_stack+24022, dvrr_stack+68442, dvrr_stack+21712, dvrr_stack+23472, dvrr_stack+61988);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+70422, dvrr_stack+25672, dvrr_stack+69267, dvrr_stack+24847, dvrr_stack+24022, dvrr_stack+62663);
 tmp = dvrr_stack + 70422;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+71962,dvrr_stack+70422,dvrr_stack+63608,28);


 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21052, dvrr_stack+21595, dvrr_stack+30229, NULL, NULL, dvrr_stack+21540);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21661, dvrr_stack+9452, dvrr_stack+21052, dvrr_stack+9307, dvrr_stack+21595, dvrr_stack+14059);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+75742, dvrr_stack+32170, dvrr_stack+21661, dvrr_stack+22856, dvrr_stack+9452, dvrr_stack+14548);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+76402, dvrr_stack+32566, dvrr_stack+75742, dvrr_stack+29662, dvrr_stack+32170, dvrr_stack+67892);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+77392, dvrr_stack+33226, dvrr_stack+76402, dvrr_stack+30454, dvrr_stack+32566, dvrr_stack+68442);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+78778, dvrr_stack+35206, dvrr_stack+77392, dvrr_stack+34216, dvrr_stack+33226, dvrr_stack+69267);
 tmp = dvrr_stack + 78778;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+80626,dvrr_stack+78778,dvrr_stack+70422,28);


 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+29662, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+2299, dvrr_stack+29662, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+30058, dvrr_stack+15, dvrr_stack+21382, dvrr_stack+2299, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+29665, dvrr_stack+30064, dvrr_stack+111, dvrr_stack+1600, dvrr_stack+30058, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+31795, dvrr_stack+30074, dvrr_stack+29665, dvrr_stack+21385, dvrr_stack+30064, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+29680, dvrr_stack+30089, dvrr_stack+31795, dvrr_stack+21395, dvrr_stack+30074, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+677, dvrr_stack+30110, dvrr_stack+29680, dvrr_stack+21410, dvrr_stack+30089, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+29708, dvrr_stack+30138, dvrr_stack+677, dvrr_stack+21431, dvrr_stack+30110, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29753, dvrr_stack+14329, dvrr_stack+29708, dvrr_stack+21459, dvrr_stack+30138, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29808, dvrr_stack+30174, dvrr_stack+29753, dvrr_stack+21495, dvrr_stack+14329, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29874, dvrr_stack+30229, dvrr_stack+29808, dvrr_stack+21540, dvrr_stack+30174, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30295, dvrr_stack+31192, dvrr_stack+29874, NULL, NULL, dvrr_stack+30229);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30529, dvrr_stack+22340, dvrr_stack+30295, dvrr_stack+22262, dvrr_stack+31192, dvrr_stack+21052);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+85246, dvrr_stack+42553, dvrr_stack+30529, dvrr_stack+31816, dvrr_stack+22340, dvrr_stack+21661);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+86026, dvrr_stack+43021, dvrr_stack+85246, dvrr_stack+40057, dvrr_stack+42553, dvrr_stack+75742);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+87196, dvrr_stack+43801, dvrr_stack+86026, dvrr_stack+40993, dvrr_stack+43021, dvrr_stack+76402);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+88834, dvrr_stack+46141, dvrr_stack+87196, dvrr_stack+44971, dvrr_stack+43801, dvrr_stack+77392);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+91018,dvrr_stack+88834,dvrr_stack+78778,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+44971, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+44974, dvrr_stack+41773, dvrr_stack+44971, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+44980, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+44989, dvrr_stack+1963, dvrr_stack+44980, dvrr_stack+0, dvrr_stack+30, dvrr_stack+44971);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+2680, dvrr_stack+44989, dvrr_stack+6, dvrr_stack+1963, dvrr_stack+44974);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+45007, dvrr_stack+213, dvrr_stack+873, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+45025, dvrr_stack+41776, dvrr_stack+45007, dvrr_stack+33, dvrr_stack+213, dvrr_stack+44980);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+45061, dvrr_stack+41794, dvrr_stack+45025, dvrr_stack+39, dvrr_stack+41776, dvrr_stack+44989);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+45121, dvrr_stack+15709, dvrr_stack+45061, dvrr_stack+75, dvrr_stack+41794, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+45211, dvrr_stack+879, dvrr_stack+121, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+45241, dvrr_stack+41830, dvrr_stack+45211, dvrr_stack+219, dvrr_stack+879, dvrr_stack+45007);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+45301, dvrr_stack+41860, dvrr_stack+45241, dvrr_stack+229, dvrr_stack+41830, dvrr_stack+45025);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+45401, dvrr_stack+41920, dvrr_stack+45301, dvrr_stack+259, dvrr_stack+41860, dvrr_stack+45061);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+45551, dvrr_stack+42020, dvrr_stack+45401, dvrr_stack+379, dvrr_stack+41920, dvrr_stack+45121);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2308, dvrr_stack+1982, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+45761, dvrr_stack+42170, dvrr_stack+219, dvrr_stack+889, dvrr_stack+2308, dvrr_stack+45211);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+45851, dvrr_stack+42215, dvrr_stack+45761, dvrr_stack+904, dvrr_stack+42170, dvrr_stack+45241);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+40057, dvrr_stack+42305, dvrr_stack+45851, dvrr_stack+949, dvrr_stack+42215, dvrr_stack+45301);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+31816, dvrr_stack+40525, dvrr_stack+40057, dvrr_stack+1039, dvrr_stack+42305, dvrr_stack+45401);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+40876, dvrr_stack+15049, dvrr_stack+31816, dvrr_stack+1339, dvrr_stack+40525, dvrr_stack+45551);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+889, dvrr_stack+1997, dvrr_stack+593, NULL, NULL, dvrr_stack+1982);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+952, dvrr_stack+614, dvrr_stack+889, dvrr_stack+2323, dvrr_stack+1997, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+40282, dvrr_stack+40750, dvrr_stack+952, dvrr_stack+2698, dvrr_stack+614, dvrr_stack+45761);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+41296, dvrr_stack+31270, dvrr_stack+40282, dvrr_stack+2761, dvrr_stack+40750, dvrr_stack+45851);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+96562, dvrr_stack+31480, dvrr_stack+41296, dvrr_stack+2887, dvrr_stack+31270, dvrr_stack+40057);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+97003, dvrr_stack+51937, dvrr_stack+96562, dvrr_stack+3097, dvrr_stack+31480, dvrr_stack+31816);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+97591, dvrr_stack+52378, dvrr_stack+97003, dvrr_stack+3727, dvrr_stack+51937, dvrr_stack+40876);
 tmp = dvrr_stack + 97591;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2698, dvrr_stack+4364, dvrr_stack+1606, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2782, dvrr_stack+42455, dvrr_stack+2698, dvrr_stack+2018, dvrr_stack+4364, dvrr_stack+889);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2018, dvrr_stack+15364, dvrr_stack+2782, dvrr_stack+4784, dvrr_stack+42455, dvrr_stack+952);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+2950, dvrr_stack+22574, dvrr_stack+2018, dvrr_stack+5316, dvrr_stack+15364, dvrr_stack+40282);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+98347, dvrr_stack+52966, dvrr_stack+2950, dvrr_stack+5484, dvrr_stack+22574, dvrr_stack+41296);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+98935, dvrr_stack+53386, dvrr_stack+98347, dvrr_stack+5764, dvrr_stack+52966, dvrr_stack+96562);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+5150, dvrr_stack+53974, dvrr_stack+98935, dvrr_stack+6604, dvrr_stack+53386, dvrr_stack+97003);
 tmp = dvrr_stack + 5150;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+99719,dvrr_stack+5150,dvrr_stack+97591,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2323, dvrr_stack+9847, dvrr_stack+14412, NULL, NULL, dvrr_stack+1606);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22854, dvrr_stack+4168, dvrr_stack+2323, dvrr_stack+4392, dvrr_stack+9847, dvrr_stack+2698);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+101987, dvrr_stack+4428, dvrr_stack+22854, dvrr_stack+1634, dvrr_stack+4168, dvrr_stack+2782);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+102347, dvrr_stack+56522, dvrr_stack+101987, dvrr_stack+9883, dvrr_stack+4428, dvrr_stack+2018);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+102887, dvrr_stack+56882, dvrr_stack+102347, dvrr_stack+10099, dvrr_stack+56522, dvrr_stack+2950);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103643, dvrr_stack+57422, dvrr_stack+102887, dvrr_stack+10459, dvrr_stack+56882, dvrr_stack+98347);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+104651, dvrr_stack+58178, dvrr_stack+103643, dvrr_stack+11539, dvrr_stack+57422, dvrr_stack+98935);
 tmp = dvrr_stack + 104651;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+105947,dvrr_stack+104651,dvrr_stack+5150,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9883, dvrr_stack+14448, dvrr_stack+21495, NULL, NULL, dvrr_stack+14412);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10018, dvrr_stack+8515, dvrr_stack+9883, dvrr_stack+8783, dvrr_stack+14448, dvrr_stack+2323);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10288, dvrr_stack+8828, dvrr_stack+10018, dvrr_stack+2436, dvrr_stack+8515, dvrr_stack+22854);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+108971, dvrr_stack+61538, dvrr_stack+10288, dvrr_stack+15769, dvrr_stack+8828, dvrr_stack+101987);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+109646, dvrr_stack+61988, dvrr_stack+108971, dvrr_stack+16039, dvrr_stack+61538, dvrr_stack+102347);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+110591, dvrr_stack+62663, dvrr_stack+109646, dvrr_stack+16489, dvrr_stack+61988, dvrr_stack+102887);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+111851, dvrr_stack+63608, dvrr_stack+110591, dvrr_stack+17839, dvrr_stack+62663, dvrr_stack+103643);
 tmp = dvrr_stack + 111851;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+113471,dvrr_stack+111851,dvrr_stack+104651,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15769, dvrr_stack+21540, dvrr_stack+30174, NULL, NULL, dvrr_stack+21495);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15934, dvrr_stack+14059, dvrr_stack+15769, dvrr_stack+14493, dvrr_stack+21540, dvrr_stack+9883);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+16264, dvrr_stack+14548, dvrr_stack+15934, dvrr_stack+4985, dvrr_stack+14059, dvrr_stack+10018);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117359, dvrr_stack+67892, dvrr_stack+16264, dvrr_stack+23142, dvrr_stack+14548, dvrr_stack+10288);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+118184, dvrr_stack+68442, dvrr_stack+117359, dvrr_stack+23472, dvrr_stack+67892, dvrr_stack+108971);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+119339, dvrr_stack+69267, dvrr_stack+118184, dvrr_stack+24022, dvrr_stack+68442, dvrr_stack+109646);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120879, dvrr_stack+70422, dvrr_stack+119339, dvrr_stack+25672, dvrr_stack+69267, dvrr_stack+110591);
 tmp = dvrr_stack + 120879;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+122859,dvrr_stack+120879,dvrr_stack+111851,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+16814, dvrr_stack+30229, dvrr_stack+29808, NULL, NULL, dvrr_stack+30174);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+23070, dvrr_stack+21052, dvrr_stack+16814, dvrr_stack+21595, dvrr_stack+30229, dvrr_stack+15769);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+23466, dvrr_stack+21661, dvrr_stack+23070, dvrr_stack+9452, dvrr_stack+21052, dvrr_stack+15934);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+127719, dvrr_stack+75742, dvrr_stack+23466, dvrr_stack+32170, dvrr_stack+21661, dvrr_stack+16264);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+128709, dvrr_stack+76402, dvrr_stack+127719, dvrr_stack+32566, dvrr_stack+75742, dvrr_stack+117359);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+130095, dvrr_stack+77392, dvrr_stack+128709, dvrr_stack+33226, dvrr_stack+76402, dvrr_stack+118184);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+131943, dvrr_stack+78778, dvrr_stack+130095, dvrr_stack+35206, dvrr_stack+77392, dvrr_stack+119339);

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+134319,dvrr_stack+131943,dvrr_stack+120879,36);


 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+21595, dvrr_stack+29662, dvrr_stack+0, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+14374, dvrr_stack+15, dvrr_stack+21595, dvrr_stack+2299, dvrr_stack+29662, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+21595, dvrr_stack+111, dvrr_stack+14374, dvrr_stack+30058, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+21610, dvrr_stack+29665, dvrr_stack+21595, dvrr_stack+30064, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+21631, dvrr_stack+31795, dvrr_stack+21610, dvrr_stack+30074, dvrr_stack+29665, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+21595, dvrr_stack+29680, dvrr_stack+21631, dvrr_stack+30089, dvrr_stack+31795, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8783, dvrr_stack+677, dvrr_stack+21595, dvrr_stack+30110, dvrr_stack+29680, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14493, dvrr_stack+29708, dvrr_stack+8783, dvrr_stack+30138, dvrr_stack+677, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21595, dvrr_stack+29753, dvrr_stack+14493, dvrr_stack+14329, dvrr_stack+29708, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29662, dvrr_stack+29808, dvrr_stack+21595, dvrr_stack+30174, dvrr_stack+29753, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+10738, dvrr_stack+29874, dvrr_stack+29662, NULL, NULL, dvrr_stack+29808);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32131, dvrr_stack+30295, dvrr_stack+10738, dvrr_stack+31192, dvrr_stack+29874, dvrr_stack+16814);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32599, dvrr_stack+30529, dvrr_stack+32131, dvrr_stack+22340, dvrr_stack+30295, dvrr_stack+23070);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+140259, dvrr_stack+85246, dvrr_stack+32599, dvrr_stack+42553, dvrr_stack+30529, dvrr_stack+23466);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32131, dvrr_stack+86026, dvrr_stack+140259, dvrr_stack+43021, dvrr_stack+85246, dvrr_stack+127719);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+140259, dvrr_stack+87196, dvrr_stack+32131, dvrr_stack+43801, dvrr_stack+86026, dvrr_stack+128709);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+142443, dvrr_stack+88834, dvrr_stack+140259, dvrr_stack+46141, dvrr_stack+87196, dvrr_stack+130095);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+145251,dvrr_stack+142443,dvrr_stack+131943,36);


 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+140259, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+140268, dvrr_stack+140259, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+140286, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+677, dvrr_stack+140286, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+140259);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+140304, dvrr_stack+677, dvrr_stack+75, dvrr_stack+140286, dvrr_stack+57, dvrr_stack+140268);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+140364, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+140394, dvrr_stack+140364, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+140286);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+140454, dvrr_stack+140394, dvrr_stack+319, dvrr_stack+140364, dvrr_stack+180, dvrr_stack+677);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+140554, dvrr_stack+140454, dvrr_stack+379, dvrr_stack+140394, dvrr_stack+319, dvrr_stack+140304);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8783, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+140704, dvrr_stack+8783, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+140364);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+140794, dvrr_stack+140704, dvrr_stack+783, dvrr_stack+8783, dvrr_stack+738, dvrr_stack+140394);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+140944, dvrr_stack+140794, dvrr_stack+1189, dvrr_stack+140704, dvrr_stack+783, dvrr_stack+140454);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+141169, dvrr_stack+140944, dvrr_stack+1339, dvrr_stack+140794, dvrr_stack+1189, dvrr_stack+140554);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+140704, dvrr_stack+0, dvrr_stack+41773, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+140710, dvrr_stack+140268, dvrr_stack+2680, dvrr_stack+140259, dvrr_stack+6, dvrr_stack+140704);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+140364, dvrr_stack+140304, dvrr_stack+15709, dvrr_stack+677, dvrr_stack+75, dvrr_stack+140710);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+141484, dvrr_stack+140554, dvrr_stack+42020, dvrr_stack+140454, dvrr_stack+379, dvrr_stack+140364);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+141694, dvrr_stack+141169, dvrr_stack+15049, dvrr_stack+140944, dvrr_stack+1339, dvrr_stack+141484);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+14374, dvrr_stack+140704, dvrr_stack+44974, dvrr_stack+0, dvrr_stack+41773, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+8783, dvrr_stack+140710, dvrr_stack+131, dvrr_stack+140268, dvrr_stack+2680, dvrr_stack+14374);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+140704, dvrr_stack+140364, dvrr_stack+45121, dvrr_stack+140304, dvrr_stack+15709, dvrr_stack+8783);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+140830, dvrr_stack+141484, dvrr_stack+45551, dvrr_stack+140554, dvrr_stack+42020, dvrr_stack+140704);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+140259, dvrr_stack+141694, dvrr_stack+40876, dvrr_stack+141169, dvrr_stack+15049, dvrr_stack+140830);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+141484, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+141487, dvrr_stack+44971, dvrr_stack+141484, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+14374, dvrr_stack+44974, dvrr_stack+141487, dvrr_stack+41773, dvrr_stack+44971, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+141493, dvrr_stack+210, dvrr_stack+161, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+141502, dvrr_stack+44980, dvrr_stack+141493, dvrr_stack+30, dvrr_stack+210, dvrr_stack+141484);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+141520, dvrr_stack+44989, dvrr_stack+141502, dvrr_stack+1963, dvrr_stack+44980, dvrr_stack+141487);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+8783, dvrr_stack+131, dvrr_stack+141520, dvrr_stack+2680, dvrr_stack+44989, dvrr_stack+14374);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+131, dvrr_stack+873, dvrr_stack+2302, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+4392, dvrr_stack+45007, dvrr_stack+131, dvrr_stack+213, dvrr_stack+873, dvrr_stack+141493);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+149, dvrr_stack+45025, dvrr_stack+4392, dvrr_stack+41776, dvrr_stack+45007, dvrr_stack+141502);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+141550, dvrr_stack+45061, dvrr_stack+149, dvrr_stack+41794, dvrr_stack+45025, dvrr_stack+141520);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+677, dvrr_stack+45121, dvrr_stack+141550, dvrr_stack+15709, dvrr_stack+45061, dvrr_stack+8783);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+8783, dvrr_stack+121, dvrr_stack+1972, NULL, NULL, dvrr_stack+2302);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+141484, dvrr_stack+45211, dvrr_stack+8783, dvrr_stack+879, dvrr_stack+121, dvrr_stack+131);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+0, dvrr_stack+45241, dvrr_stack+141484, dvrr_stack+41830, dvrr_stack+45211, dvrr_stack+4392);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+140799, dvrr_stack+45301, dvrr_stack+0, dvrr_stack+41860, dvrr_stack+45241, dvrr_stack+149);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+140949, dvrr_stack+45401, dvrr_stack+140799, dvrr_stack+41920, dvrr_stack+45301, dvrr_stack+141550);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+142114, dvrr_stack+45551, dvrr_stack+140949, dvrr_stack+42020, dvrr_stack+45401, dvrr_stack+677);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+677, dvrr_stack+1982, dvrr_stack+4349, NULL, NULL, dvrr_stack+1972);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+722, dvrr_stack+219, dvrr_stack+677, dvrr_stack+2308, dvrr_stack+1982, dvrr_stack+8783);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+141544, dvrr_stack+45761, dvrr_stack+722, dvrr_stack+42170, dvrr_stack+219, dvrr_stack+141484);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+100, dvrr_stack+45851, dvrr_stack+141544, dvrr_stack+42215, dvrr_stack+45761, dvrr_stack+0);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+32131, dvrr_stack+40057, dvrr_stack+100, dvrr_stack+42305, dvrr_stack+45851, dvrr_stack+140799);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+32446, dvrr_stack+31816, dvrr_stack+32131, dvrr_stack+40525, dvrr_stack+40057, dvrr_stack+140949);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+32866, dvrr_stack+40876, dvrr_stack+32446, dvrr_stack+15049, dvrr_stack+31816, dvrr_stack+142114);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+142114, dvrr_stack+593, dvrr_stack+8762, NULL, NULL, dvrr_stack+4349);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+142177, dvrr_stack+889, dvrr_stack+142114, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+677);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+40876, dvrr_stack+952, dvrr_stack+142177, dvrr_stack+614, dvrr_stack+889, dvrr_stack+722);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+140799, dvrr_stack+40282, dvrr_stack+40876, dvrr_stack+40750, dvrr_stack+952, dvrr_stack+141544);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+325, dvrr_stack+41296, dvrr_stack+140799, dvrr_stack+31270, dvrr_stack+40282, dvrr_stack+100);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+40057, dvrr_stack+96562, dvrr_stack+325, dvrr_stack+31480, dvrr_stack+41296, dvrr_stack+32131);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+41086, dvrr_stack+97003, dvrr_stack+40057, dvrr_stack+51937, dvrr_stack+96562, dvrr_stack+32446);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+85246, dvrr_stack+97591, dvrr_stack+41086, dvrr_stack+52378, dvrr_stack+97003, dvrr_stack+32866);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+96562, dvrr_stack+1606, dvrr_stack+14384, NULL, NULL, dvrr_stack+8762);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+96646, dvrr_stack+2698, dvrr_stack+96562, dvrr_stack+4364, dvrr_stack+1606, dvrr_stack+142114);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+96814, dvrr_stack+2782, dvrr_stack+96646, dvrr_stack+42455, dvrr_stack+2698, dvrr_stack+142177);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+97094, dvrr_stack+2018, dvrr_stack+96814, dvrr_stack+15364, dvrr_stack+2782, dvrr_stack+40876);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+41842, dvrr_stack+2950, dvrr_stack+97094, dvrr_stack+22574, dvrr_stack+2018, dvrr_stack+140799);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+42430, dvrr_stack+98347, dvrr_stack+41842, dvrr_stack+52966, dvrr_stack+2950, dvrr_stack+325);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+43214, dvrr_stack+98935, dvrr_stack+42430, dvrr_stack+53386, dvrr_stack+98347, dvrr_stack+40057);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+44222, dvrr_stack+5150, dvrr_stack+43214, dvrr_stack+53974, dvrr_stack+98935, dvrr_stack+41086);

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+40057, dvrr_stack+14412, dvrr_stack+21459, NULL, NULL, dvrr_stack+14384);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+40165, dvrr_stack+2323, dvrr_stack+40057, dvrr_stack+9847, dvrr_stack+14412, dvrr_stack+96562);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+40381, dvrr_stack+22854, dvrr_stack+40165, dvrr_stack+4168, dvrr_stack+2323, dvrr_stack+96646);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+40741, dvrr_stack+101987, dvrr_stack+40381, dvrr_stack+4428, dvrr_stack+22854, dvrr_stack+96814);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4168, dvrr_stack+102347, dvrr_stack+40741, dvrr_stack+56522, dvrr_stack+101987, dvrr_stack+97094);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+52966, dvrr_stack+102887, dvrr_stack+4168, dvrr_stack+56882, dvrr_stack+102347, dvrr_stack+41842);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+98347, dvrr_stack+103643, dvrr_stack+52966, dvrr_stack+57422, dvrr_stack+102887, dvrr_stack+42430);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+101987, dvrr_stack+104651, dvrr_stack+98347, dvrr_stack+58178, dvrr_stack+103643, dvrr_stack+43214);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+103607, dvrr_stack+21495, dvrr_stack+14329, NULL, NULL, dvrr_stack+21459);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+103742, dvrr_stack+9883, dvrr_stack+103607, dvrr_stack+14448, dvrr_stack+21495, dvrr_stack+40057);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+104012, dvrr_stack+10018, dvrr_stack+103742, dvrr_stack+8515, dvrr_stack+9883, dvrr_stack+40165);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+56522, dvrr_stack+10288, dvrr_stack+104012, dvrr_stack+8828, dvrr_stack+10018, dvrr_stack+40381);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8515, dvrr_stack+108971, dvrr_stack+56522, dvrr_stack+61538, dvrr_stack+10288, dvrr_stack+40741);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9460, dvrr_stack+109646, dvrr_stack+8515, dvrr_stack+61988, dvrr_stack+108971, dvrr_stack+4168);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+40057, dvrr_stack+110591, dvrr_stack+9460, dvrr_stack+62663, dvrr_stack+109646, dvrr_stack+52966);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+61538, dvrr_stack+111851, dvrr_stack+40057, dvrr_stack+63608, dvrr_stack+110591, dvrr_stack+98347);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+98347, dvrr_stack+30174, dvrr_stack+29753, NULL, NULL, dvrr_stack+14329);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+98512, dvrr_stack+15769, dvrr_stack+98347, dvrr_stack+21540, dvrr_stack+30174, dvrr_stack+103607);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+98842, dvrr_stack+15934, dvrr_stack+98512, dvrr_stack+14059, dvrr_stack+15769, dvrr_stack+103742);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52966, dvrr_stack+16264, dvrr_stack+98842, dvrr_stack+14548, dvrr_stack+15934, dvrr_stack+104012);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14059, dvrr_stack+117359, dvrr_stack+52966, dvrr_stack+67892, dvrr_stack+16264, dvrr_stack+56522);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+56522, dvrr_stack+118184, dvrr_stack+14059, dvrr_stack+68442, dvrr_stack+117359, dvrr_stack+8515);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+108971, dvrr_stack+119339, dvrr_stack+56522, dvrr_stack+69267, dvrr_stack+118184, dvrr_stack+9460);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8515, dvrr_stack+120879, dvrr_stack+108971, dvrr_stack+70422, dvrr_stack+119339, dvrr_stack+40057);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+40057, dvrr_stack+29808, dvrr_stack+21595, NULL, NULL, dvrr_stack+29753);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+40255, dvrr_stack+16814, dvrr_stack+40057, dvrr_stack+30229, dvrr_stack+29808, dvrr_stack+98347);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+40651, dvrr_stack+23070, dvrr_stack+40255, dvrr_stack+21052, dvrr_stack+16814, dvrr_stack+98512);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41311, dvrr_stack+23466, dvrr_stack+40651, dvrr_stack+21661, dvrr_stack+23070, dvrr_stack+98842);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21052, dvrr_stack+127719, dvrr_stack+41311, dvrr_stack+75742, dvrr_stack+23466, dvrr_stack+52966);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22438, dvrr_stack+128709, dvrr_stack+21052, dvrr_stack+76402, dvrr_stack+127719, dvrr_stack+14059);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+14059, dvrr_stack+130095, dvrr_stack+22438, dvrr_stack+77392, dvrr_stack+128709, dvrr_stack+56522);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21052, dvrr_stack+131943, dvrr_stack+14059, dvrr_stack+78778, dvrr_stack+130095, dvrr_stack+108971);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+51937, dvrr_stack+7192, NULL);
 tmp = dvrr_stack + 51937;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+108971, dvrr_stack+12295, NULL);
 tmp = dvrr_stack + 108971;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+109559, dvrr_stack+18784, NULL);
 tmp = dvrr_stack + 109559;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+110315, dvrr_stack+26827, NULL);
 tmp = dvrr_stack + 110315;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+14059, dvrr_stack+36592, NULL);
 tmp = dvrr_stack + 14059;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+15214, dvrr_stack+47779, NULL);
 tmp = dvrr_stack + 15214;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+111260, dvrr_stack+54758, NULL);
 tmp = dvrr_stack + 111260;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+56522, dvrr_stack+59186, NULL);
 tmp = dvrr_stack + 56522;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+52966, dvrr_stack+64868, NULL);
 tmp = dvrr_stack + 52966;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+127719, dvrr_stack+71962, NULL);
 tmp = dvrr_stack + 127719;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+128979, dvrr_stack+80626, NULL);
 tmp = dvrr_stack + 128979;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+75742, dvrr_stack+91018, NULL);
 tmp = dvrr_stack + 75742;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+57306, dvrr_stack+99719, NULL);
 tmp = dvrr_stack + 57306;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+130519, dvrr_stack+105947, NULL);
 tmp = dvrr_stack + 130519;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+98347, dvrr_stack+113471, NULL);
 tmp = dvrr_stack + 98347;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+40057, dvrr_stack+122859, NULL);
 tmp = dvrr_stack + 40057;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+41677, dvrr_stack+134319, NULL);
 tmp = dvrr_stack + 41677;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+117359, dvrr_stack+145251, NULL);
 tmp = dvrr_stack + 117359;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+16600, dvrr_stack+7192, NULL);
 tmp = dvrr_stack + 16600;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+24022, dvrr_stack+12295, NULL);
 tmp = dvrr_stack + 24022;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+77590, dvrr_stack+18784, NULL);
 tmp = dvrr_stack + 77590;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+119735, dvrr_stack+26827, NULL);
 tmp = dvrr_stack + 119735;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+67892, dvrr_stack+36592, NULL);
 tmp = dvrr_stack + 67892;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+0, dvrr_stack+47779, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+69047, dvrr_stack+54758, NULL);
 tmp = dvrr_stack + 69047;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+69635, dvrr_stack+59186, NULL);
 tmp = dvrr_stack + 69635;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+103607, dvrr_stack+64868, NULL);
 tmp = dvrr_stack + 103607;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+1386, dvrr_stack+71962, NULL);
 tmp = dvrr_stack + 1386;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+86191, dvrr_stack+80626, NULL);
 tmp = dvrr_stack + 86191;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+29662, dvrr_stack+91018, NULL);
 tmp = dvrr_stack + 29662;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+4168, dvrr_stack+99719, NULL);
 tmp = dvrr_stack + 4168;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+96562, dvrr_stack+105947, NULL);
 tmp = dvrr_stack + 96562;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+31510, dvrr_stack+113471, NULL);
 tmp = dvrr_stack + 31510;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+152379, dvrr_stack+122859, NULL);
 tmp = dvrr_stack + 152379;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+153999, dvrr_stack+134319, NULL);
 tmp = dvrr_stack + 153999;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+155979, dvrr_stack+145251, NULL);
 tmp = dvrr_stack + 155979;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+43657, dvrr_stack+7192, NULL);
 tmp = dvrr_stack + 43657;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+7192, dvrr_stack+12295, NULL);
 tmp = dvrr_stack + 7192;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+12295, dvrr_stack+18784, NULL);
 tmp = dvrr_stack + 12295;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+18784, dvrr_stack+26827, NULL);
 tmp = dvrr_stack + 18784;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+26827, dvrr_stack+36592, NULL);
 tmp = dvrr_stack + 26827;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+36592, dvrr_stack+47779, NULL);
 tmp = dvrr_stack + 36592;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+47779, dvrr_stack+54758, NULL);
 tmp = dvrr_stack + 47779;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+54758, dvrr_stack+59186, NULL);
 tmp = dvrr_stack + 54758;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+13051, dvrr_stack+64868, NULL);
 tmp = dvrr_stack + 13051;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+64868, dvrr_stack+71962, NULL);
 tmp = dvrr_stack + 64868;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+71962, dvrr_stack+80626, NULL);
 tmp = dvrr_stack + 71962;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+80626, dvrr_stack+91018, NULL);
 tmp = dvrr_stack + 80626;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+91018, dvrr_stack+99719, NULL);
 tmp = dvrr_stack + 91018;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+91774, dvrr_stack+105947, NULL);
 tmp = dvrr_stack + 91774;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+105947, dvrr_stack+113471, NULL);
 tmp = dvrr_stack + 105947;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+113471, dvrr_stack+122859, NULL);
 tmp = dvrr_stack + 113471;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+122859, dvrr_stack+134319, NULL);
 tmp = dvrr_stack + 122859;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+134319, dvrr_stack+145251, NULL);
 tmp = dvrr_stack + 134319;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+145251, dvrr_stack+6604, dvrr_stack+141169);
 tmp = dvrr_stack + 145251;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+145692, dvrr_stack+11539, dvrr_stack+3727);
 tmp = dvrr_stack + 145692;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+146280, dvrr_stack+17839, dvrr_stack+6604);
 tmp = dvrr_stack + 146280;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+147036, dvrr_stack+25672, dvrr_stack+11539);
 tmp = dvrr_stack + 147036;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+147981, dvrr_stack+35206, dvrr_stack+17839);
 tmp = dvrr_stack + 147981;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+149136, dvrr_stack+46141, dvrr_stack+25672);
 tmp = dvrr_stack + 149136;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+150522, dvrr_stack+53974, dvrr_stack+141694);
 tmp = dvrr_stack + 150522;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+151110, dvrr_stack+58178, dvrr_stack+52378);
 tmp = dvrr_stack + 151110;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+136695, dvrr_stack+63608, dvrr_stack+53974);
 tmp = dvrr_stack + 136695;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+137703, dvrr_stack+70422, dvrr_stack+58178);
 tmp = dvrr_stack + 137703;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+124839, dvrr_stack+78778, dvrr_stack+63608);
 tmp = dvrr_stack + 124839;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+115091, dvrr_stack+88834, dvrr_stack+70422);
 tmp = dvrr_stack + 115091;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+138963, dvrr_stack+5150, dvrr_stack+140259);
 tmp = dvrr_stack + 138963;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+126379, dvrr_stack+104651, dvrr_stack+97591);
 tmp = dvrr_stack + 126379;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+107243, dvrr_stack+111851, dvrr_stack+5150);
 tmp = dvrr_stack + 107243;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+92782, dvrr_stack+120879, dvrr_stack+104651);
 tmp = dvrr_stack + 92782;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+94402, dvrr_stack+131943, dvrr_stack+111851);
 tmp = dvrr_stack + 94402;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+82474, dvrr_stack+142443, dvrr_stack+120879);
 tmp = dvrr_stack + 82474;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+151894, dvrr_stack+6604, dvrr_stack+141169);
 tmp = dvrr_stack + 151894;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+73502, dvrr_stack+11539, dvrr_stack+3727);
 tmp = dvrr_stack + 73502;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+74090, dvrr_stack+17839, dvrr_stack+6604);
 tmp = dvrr_stack + 74090;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+66128, dvrr_stack+25672, dvrr_stack+11539);
 tmp = dvrr_stack + 66128;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+59186, dvrr_stack+35206, dvrr_stack+17839);
 tmp = dvrr_stack + 59186;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+48367, dvrr_stack+46141, dvrr_stack+25672);
 tmp = dvrr_stack + 48367;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+74846, dvrr_stack+53974, dvrr_stack+141694);
 tmp = dvrr_stack + 74846;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+67073, dvrr_stack+58178, dvrr_stack+52378);
 tmp = dvrr_stack + 67073;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+60341, dvrr_stack+63608, dvrr_stack+53974);
 tmp = dvrr_stack + 60341;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+49753, dvrr_stack+70422, dvrr_stack+58178);
 tmp = dvrr_stack + 49753;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+37978, dvrr_stack+78778, dvrr_stack+63608);
 tmp = dvrr_stack + 37978;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+99643, dvrr_stack+88834, dvrr_stack+70422);
 tmp = dvrr_stack + 99643;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+55542, dvrr_stack+5150, dvrr_stack+140259);
 tmp = dvrr_stack + 55542;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+27982, dvrr_stack+104651, dvrr_stack+97591);
 tmp = dvrr_stack + 27982;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+19729, dvrr_stack+111851, dvrr_stack+5150);
 tmp = dvrr_stack + 19729;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+158355, dvrr_stack+120879, dvrr_stack+104651);
 tmp = dvrr_stack + 158355;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+159975, dvrr_stack+131943, dvrr_stack+111851);
 tmp = dvrr_stack + 159975;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+161955, dvrr_stack+142443, dvrr_stack+120879);
 tmp = dvrr_stack + 161955;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+139719, dvrr_stack+6604, dvrr_stack+141169);
 tmp = dvrr_stack + 139719;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+51013, dvrr_stack+11539, dvrr_stack+3727);
 tmp = dvrr_stack + 51013;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+140799, dvrr_stack+17839, dvrr_stack+6604);
 tmp = dvrr_stack + 140799;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+87731, dvrr_stack+25672, dvrr_stack+11539);
 tmp = dvrr_stack + 87731;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+32806, dvrr_stack+35206, dvrr_stack+17839);
 tmp = dvrr_stack + 32806;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+164331, dvrr_stack+46141, dvrr_stack+25672);
 tmp = dvrr_stack + 164331;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+28990, dvrr_stack+53974, dvrr_stack+141694);
 tmp = dvrr_stack + 28990;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+141555, dvrr_stack+58178, dvrr_stack+52378);
 tmp = dvrr_stack + 141555;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+45482, dvrr_stack+63608, dvrr_stack+53974);
 tmp = dvrr_stack + 45482;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+46490, dvrr_stack+70422, dvrr_stack+58178);
 tmp = dvrr_stack + 46490;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+165717, dvrr_stack+78778, dvrr_stack+63608);
 tmp = dvrr_stack + 165717;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+167257, dvrr_stack+88834, dvrr_stack+70422);
 tmp = dvrr_stack + 167257;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+2646, dvrr_stack+5150, dvrr_stack+140259);
 tmp = dvrr_stack + 2646;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+88676, dvrr_stack+104651, dvrr_stack+97591);
 tmp = dvrr_stack + 88676;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+89684, dvrr_stack+111851, dvrr_stack+5150);
 tmp = dvrr_stack + 89684;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+169105, dvrr_stack+120879, dvrr_stack+104651);
 tmp = dvrr_stack + 169105;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+170725, dvrr_stack+131943, dvrr_stack+111851);
 tmp = dvrr_stack + 170725;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+172705, dvrr_stack+142443, dvrr_stack+120879);
 tmp = dvrr_stack + 172705;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+140160, dvrr_stack+52378, dvrr_stack+3412);
 tmp = dvrr_stack + 140160;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+7780, dvrr_stack+53974, dvrr_stack+6184);
 tmp = dvrr_stack + 7780;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+142339, dvrr_stack+58178, dvrr_stack+10999);
 tmp = dvrr_stack + 142339;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+143095, dvrr_stack+63608, dvrr_stack+17164);
 tmp = dvrr_stack + 143095;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+144040, dvrr_stack+70422, dvrr_stack+24847);
 tmp = dvrr_stack + 144040;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+175081, dvrr_stack+78778, dvrr_stack+34216);
 tmp = dvrr_stack + 175081;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+176467, dvrr_stack+97591, dvrr_stack+3727);
 tmp = dvrr_stack + 176467;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+177055, dvrr_stack+5150, dvrr_stack+6604);
 tmp = dvrr_stack + 177055;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+177839, dvrr_stack+104651, dvrr_stack+11539);
 tmp = dvrr_stack + 177839;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+178847, dvrr_stack+111851, dvrr_stack+17839);
 tmp = dvrr_stack + 178847;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+180107, dvrr_stack+120879, dvrr_stack+25672);
 tmp = dvrr_stack + 180107;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+181647, dvrr_stack+131943, dvrr_stack+35206);
 tmp = dvrr_stack + 181647;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+183495, dvrr_stack+85246, dvrr_stack+52378);
 tmp = dvrr_stack + 183495;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+184251, dvrr_stack+44222, dvrr_stack+53974);
 tmp = dvrr_stack + 184251;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+185259, dvrr_stack+101987, dvrr_stack+58178);
 tmp = dvrr_stack + 185259;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+186555, dvrr_stack+61538, dvrr_stack+63608);
 tmp = dvrr_stack + 186555;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+188175, dvrr_stack+8515, dvrr_stack+70422);
 tmp = dvrr_stack + 188175;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+190155, dvrr_stack+21052, dvrr_stack+78778);
 tmp = dvrr_stack + 190155;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+39518, dvrr_stack+52378, dvrr_stack+3412);
 tmp = dvrr_stack + 39518;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+192531, dvrr_stack+53974, dvrr_stack+6184);
 tmp = dvrr_stack + 192531;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+193119, dvrr_stack+58178, dvrr_stack+10999);
 tmp = dvrr_stack + 193119;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+193875, dvrr_stack+63608, dvrr_stack+17164);
 tmp = dvrr_stack + 193875;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+194820, dvrr_stack+70422, dvrr_stack+24847);
 tmp = dvrr_stack + 194820;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+195975, dvrr_stack+78778, dvrr_stack+34216);
 tmp = dvrr_stack + 195975;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+197361, dvrr_stack+97591, dvrr_stack+3727);
 tmp = dvrr_stack + 197361;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+197949, dvrr_stack+5150, dvrr_stack+6604);
 tmp = dvrr_stack + 197949;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+198733, dvrr_stack+104651, dvrr_stack+11539);
 tmp = dvrr_stack + 198733;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+199741, dvrr_stack+111851, dvrr_stack+17839);
 tmp = dvrr_stack + 199741;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+201001, dvrr_stack+120879, dvrr_stack+25672);
 tmp = dvrr_stack + 201001;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+202541, dvrr_stack+131943, dvrr_stack+35206);
 tmp = dvrr_stack + 202541;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+204389, dvrr_stack+85246, dvrr_stack+52378);
 tmp = dvrr_stack + 204389;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+205145, dvrr_stack+44222, dvrr_stack+53974);
 tmp = dvrr_stack + 205145;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+206153, dvrr_stack+101987, dvrr_stack+58178);
 tmp = dvrr_stack + 206153;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+207449, dvrr_stack+61538, dvrr_stack+63608);
 tmp = dvrr_stack + 207449;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+209069, dvrr_stack+8515, dvrr_stack+70422);
 tmp = dvrr_stack + 209069;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+211049, dvrr_stack+21052, dvrr_stack+78778);
 tmp = dvrr_stack + 211049;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+101491, dvrr_stack+52378, dvrr_stack+3412);
 tmp = dvrr_stack + 101491;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+213425, dvrr_stack+53974, dvrr_stack+6184);
 tmp = dvrr_stack + 213425;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+214013, dvrr_stack+58178, dvrr_stack+10999);
 tmp = dvrr_stack + 214013;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+214769, dvrr_stack+63608, dvrr_stack+17164);
 tmp = dvrr_stack + 214769;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+215714, dvrr_stack+70422, dvrr_stack+24847);
 tmp = dvrr_stack + 215714;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+216869, dvrr_stack+78778, dvrr_stack+34216);
 tmp = dvrr_stack + 216869;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+17041, dvrr_stack+97591, dvrr_stack+3727);
 tmp = dvrr_stack + 17041;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+24610, dvrr_stack+5150, dvrr_stack+6604);
 tmp = dvrr_stack + 24610;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+4924, dvrr_stack+104651, dvrr_stack+11539);
 tmp = dvrr_stack + 4924;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+5932, dvrr_stack+111851, dvrr_stack+17839);
 tmp = dvrr_stack + 5932;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+111848, dvrr_stack+120879, dvrr_stack+25672);
 tmp = dvrr_stack + 111848;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+120680, dvrr_stack+131943, dvrr_stack+35206);
 tmp = dvrr_stack + 120680;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+17629, dvrr_stack+85246, dvrr_stack+52378);
 tmp = dvrr_stack + 17629;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+84850, dvrr_stack+44222, dvrr_stack+53974);
 tmp = dvrr_stack + 84850;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+131527, dvrr_stack+101987, dvrr_stack+58178);
 tmp = dvrr_stack + 131527;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+101932, dvrr_stack+61538, dvrr_stack+63608);
 tmp = dvrr_stack + 101932;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+61349, dvrr_stack+8515, dvrr_stack+70422);
 tmp = dvrr_stack + 61349;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+8368, dvrr_stack+21052, dvrr_stack+78778);
 tmp = dvrr_stack + 8368;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];


}

