/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (ih|ii) integrals */

void d1vrr_order_ihii(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+6);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+873, dvrr_stack+210, dvrr_stack+161, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+879, dvrr_stack+213, dvrr_stack+873, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+889, dvrr_stack+219, dvrr_stack+879, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+904, dvrr_stack+509, dvrr_stack+889, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+949, dvrr_stack+524, dvrr_stack+904, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1039, dvrr_stack+614, dvrr_stack+949, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1189, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1339, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1564, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1585, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1606, dvrr_stack+1585, dvrr_stack+1564, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1669, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1690, dvrr_stack+1669, dvrr_stack+1585, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1753, dvrr_stack+509, dvrr_stack+889, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1774, dvrr_stack+1564, dvrr_stack+1753, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1837, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1963, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2089, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2299, dvrr_stack+593, dvrr_stack+1669, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2362, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2488, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+161, dvrr_stack+704, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2698, dvrr_stack+873, dvrr_stack+707, dvrr_stack+210, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2708, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+213, dvrr_stack+873, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2723, dvrr_stack+889, dvrr_stack+2708, dvrr_stack+219, dvrr_stack+879, NULL);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2744, dvrr_stack+1753, dvrr_stack+2723, NULL, NULL, dvrr_stack+889);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2807, dvrr_stack+1774, dvrr_stack+2744, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+904);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2933, dvrr_stack+1837, dvrr_stack+2807, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+949);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3143, dvrr_stack+2089, dvrr_stack+2933, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1039);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3458, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+1189);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3773, dvrr_stack+3458, dvrr_stack+3143, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+1339);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4214, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4242, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4270, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4298, dvrr_stack+4214, dvrr_stack+4270, NULL, NULL, dvrr_stack+1564);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4382, dvrr_stack+4242, dvrr_stack+4214, NULL, NULL, dvrr_stack+1585);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4466, dvrr_stack+4382, dvrr_stack+4298, dvrr_stack+4242, dvrr_stack+4214, dvrr_stack+1606);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1606, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4634, dvrr_stack+1606, dvrr_stack+4242, NULL, NULL, dvrr_stack+1669);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4718, dvrr_stack+4634, dvrr_stack+4382, dvrr_stack+1606, dvrr_stack+4242, dvrr_stack+1690);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1690, dvrr_stack+1753, dvrr_stack+2723, dvrr_stack+509, dvrr_stack+889, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4886, dvrr_stack+4270, dvrr_stack+1690, NULL, NULL, dvrr_stack+1753);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4970, dvrr_stack+4298, dvrr_stack+4886, dvrr_stack+4214, dvrr_stack+4270, dvrr_stack+1774);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5138, dvrr_stack+4466, dvrr_stack+4970, dvrr_stack+4382, dvrr_stack+4298, dvrr_stack+1837);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5418, dvrr_stack+4718, dvrr_stack+4466, dvrr_stack+4634, dvrr_stack+4382, dvrr_stack+1963);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+5698, dvrr_stack+5418, dvrr_stack+5138, dvrr_stack+4718, dvrr_stack+4466, dvrr_stack+2089);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1963, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1966, dvrr_stack+1963, dvrr_stack+569, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1972, dvrr_stack+1966, dvrr_stack+572, dvrr_stack+1963, dvrr_stack+569, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1982, dvrr_stack+1972, dvrr_stack+121, dvrr_stack+1966, dvrr_stack+572, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1997, dvrr_stack+1982, dvrr_stack+578, dvrr_stack+1972, dvrr_stack+121, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2018, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+1982, dvrr_stack+578, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+6118, dvrr_stack+2018, dvrr_stack+1606, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+6202, dvrr_stack+6118, dvrr_stack+4634, dvrr_stack+2018, dvrr_stack+1606, dvrr_stack+2299);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+6370, dvrr_stack+6202, dvrr_stack+4718, dvrr_stack+6118, dvrr_stack+4634, dvrr_stack+2362);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6650, dvrr_stack+6370, dvrr_stack+5418, dvrr_stack+6202, dvrr_stack+4718, dvrr_stack+2488);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6118, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6121, dvrr_stack+704, dvrr_stack+6118, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+707, dvrr_stack+6121, dvrr_stack+161, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6127, dvrr_stack+2698, dvrr_stack+121, dvrr_stack+873, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6142, dvrr_stack+2708, dvrr_stack+6127, dvrr_stack+879, dvrr_stack+2698, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6163, dvrr_stack+2723, dvrr_stack+6142, dvrr_stack+889, dvrr_stack+2708, NULL);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+6191, dvrr_stack+1690, dvrr_stack+6163, NULL, NULL, dvrr_stack+2723);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+7070, dvrr_stack+4886, dvrr_stack+6191, dvrr_stack+4270, dvrr_stack+1690, dvrr_stack+2744);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+7238, dvrr_stack+4970, dvrr_stack+7070, dvrr_stack+4298, dvrr_stack+4886, dvrr_stack+2807);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+7518, dvrr_stack+5138, dvrr_stack+7238, dvrr_stack+4466, dvrr_stack+4970, dvrr_stack+2933);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+7938, dvrr_stack+5698, dvrr_stack+7518, dvrr_stack+5418, dvrr_stack+5138, dvrr_stack+3143);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+8526, dvrr_stack+6650, dvrr_stack+5698, dvrr_stack+6370, dvrr_stack+5418, dvrr_stack+3458);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+9114, dvrr_stack+8526, dvrr_stack+7938, dvrr_stack+6650, dvrr_stack+5698, dvrr_stack+3773);
 tmp = dvrr_stack + 9114;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6275, dvrr_stack+4214, dvrr_stack+4270, dvrr_stack+1585, dvrr_stack+1564, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6311, dvrr_stack+4242, dvrr_stack+4214, dvrr_stack+1669, dvrr_stack+1585, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6347, dvrr_stack+4270, dvrr_stack+1690, dvrr_stack+1564, dvrr_stack+1753, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6383, dvrr_stack+6275, dvrr_stack+6347, NULL, NULL, dvrr_stack+4270);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6491, dvrr_stack+6311, dvrr_stack+6275, NULL, NULL, dvrr_stack+4214);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6599, dvrr_stack+6491, dvrr_stack+6383, dvrr_stack+6311, dvrr_stack+6275, dvrr_stack+4298);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4298, dvrr_stack+1606, dvrr_stack+4242, dvrr_stack+593, dvrr_stack+1669, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6815, dvrr_stack+4298, dvrr_stack+6311, NULL, NULL, dvrr_stack+4242);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+6815, dvrr_stack+6491, dvrr_stack+4298, dvrr_stack+6311, dvrr_stack+4382);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4334, dvrr_stack+1690, dvrr_stack+6163, dvrr_stack+1753, dvrr_stack+2723, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6923, dvrr_stack+6347, dvrr_stack+4334, NULL, NULL, dvrr_stack+1690);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10114, dvrr_stack+6383, dvrr_stack+6923, dvrr_stack+6275, dvrr_stack+6347, dvrr_stack+4886);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10330, dvrr_stack+6599, dvrr_stack+10114, dvrr_stack+6491, dvrr_stack+6383, dvrr_stack+4970);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10690, dvrr_stack+9898, dvrr_stack+6599, dvrr_stack+6815, dvrr_stack+6491, dvrr_stack+4466);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11050, dvrr_stack+10690, dvrr_stack+10330, dvrr_stack+9898, dvrr_stack+6599, dvrr_stack+5138);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4370, dvrr_stack+2018, dvrr_stack+1606, dvrr_stack+1997, dvrr_stack+593, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+4370, dvrr_stack+4298, NULL, NULL, dvrr_stack+1606);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11590, dvrr_stack+4406, dvrr_stack+6815, dvrr_stack+4370, dvrr_stack+4298, dvrr_stack+4634);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11806, dvrr_stack+11590, dvrr_stack+9898, dvrr_stack+4406, dvrr_stack+6815, dvrr_stack+4718);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12166, dvrr_stack+11806, dvrr_stack+10690, dvrr_stack+11590, dvrr_stack+9898, dvrr_stack+5418);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+5418, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+5421, dvrr_stack+6118, dvrr_stack+5418, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+5427, dvrr_stack+6121, dvrr_stack+5421, dvrr_stack+704, dvrr_stack+6118, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+5437, dvrr_stack+121, dvrr_stack+5427, dvrr_stack+707, dvrr_stack+6121, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5452, dvrr_stack+6127, dvrr_stack+5437, dvrr_stack+2698, dvrr_stack+121, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+5473, dvrr_stack+6142, dvrr_stack+5452, dvrr_stack+2708, dvrr_stack+6127, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5501, dvrr_stack+6163, dvrr_stack+5473, dvrr_stack+2723, dvrr_stack+6142, NULL);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5537, dvrr_stack+4334, dvrr_stack+5501, NULL, NULL, dvrr_stack+6163);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11590, dvrr_stack+6923, dvrr_stack+5537, dvrr_stack+6347, dvrr_stack+4334, dvrr_stack+6191);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+10114, dvrr_stack+11590, dvrr_stack+6383, dvrr_stack+6923, dvrr_stack+7070);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12706, dvrr_stack+10330, dvrr_stack+4406, dvrr_stack+6599, dvrr_stack+10114, dvrr_stack+7238);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13246, dvrr_stack+11050, dvrr_stack+12706, dvrr_stack+10690, dvrr_stack+10330, dvrr_stack+7518);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14002, dvrr_stack+12166, dvrr_stack+11050, dvrr_stack+11806, dvrr_stack+10690, dvrr_stack+5698);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14758, dvrr_stack+14002, dvrr_stack+13246, dvrr_stack+12166, dvrr_stack+11050, dvrr_stack+7938);
 tmp = dvrr_stack + 14758;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+15766,dvrr_stack+14758,dvrr_stack+9114,28);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11806, dvrr_stack+6275, dvrr_stack+6347, dvrr_stack+4214, dvrr_stack+4270, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11851, dvrr_stack+6311, dvrr_stack+6275, dvrr_stack+4242, dvrr_stack+4214, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11896, dvrr_stack+6347, dvrr_stack+4334, dvrr_stack+4270, dvrr_stack+1690, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11941, dvrr_stack+11806, dvrr_stack+11896, NULL, NULL, dvrr_stack+6347);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12076, dvrr_stack+11851, dvrr_stack+11806, NULL, NULL, dvrr_stack+6275);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12211, dvrr_stack+12076, dvrr_stack+11941, dvrr_stack+11851, dvrr_stack+11806, dvrr_stack+6383);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6383, dvrr_stack+4298, dvrr_stack+6311, dvrr_stack+1606, dvrr_stack+4242, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12481, dvrr_stack+6383, dvrr_stack+11851, NULL, NULL, dvrr_stack+6311);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+12481, dvrr_stack+12076, dvrr_stack+6383, dvrr_stack+11851, dvrr_stack+6491);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6428, dvrr_stack+4334, dvrr_stack+5501, dvrr_stack+1690, dvrr_stack+6163, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18388, dvrr_stack+11896, dvrr_stack+6428, NULL, NULL, dvrr_stack+4334);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18523, dvrr_stack+11941, dvrr_stack+18388, dvrr_stack+11806, dvrr_stack+11896, dvrr_stack+6923);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18793, dvrr_stack+12211, dvrr_stack+18523, dvrr_stack+12076, dvrr_stack+11941, dvrr_stack+10114);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19243, dvrr_stack+18118, dvrr_stack+12211, dvrr_stack+12481, dvrr_stack+12076, dvrr_stack+6599);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19693, dvrr_stack+19243, dvrr_stack+18793, dvrr_stack+18118, dvrr_stack+12211, dvrr_stack+10330);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6473, dvrr_stack+4370, dvrr_stack+4298, dvrr_stack+2018, dvrr_stack+1606, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6518, dvrr_stack+6473, dvrr_stack+6383, NULL, NULL, dvrr_stack+4298);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20368, dvrr_stack+6518, dvrr_stack+12481, dvrr_stack+6473, dvrr_stack+6383, dvrr_stack+6815);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20638, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+6518, dvrr_stack+12481, dvrr_stack+9898);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21088, dvrr_stack+20638, dvrr_stack+19243, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+10690);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+10690, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+10693, dvrr_stack+5418, dvrr_stack+10690, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10699, dvrr_stack+5421, dvrr_stack+10693, dvrr_stack+6118, dvrr_stack+5418, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10709, dvrr_stack+5427, dvrr_stack+10699, dvrr_stack+6121, dvrr_stack+5421, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10724, dvrr_stack+5437, dvrr_stack+10709, dvrr_stack+121, dvrr_stack+5427, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10745, dvrr_stack+5452, dvrr_stack+10724, dvrr_stack+6127, dvrr_stack+5437, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10773, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+6142, dvrr_stack+5452, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10809, dvrr_stack+5501, dvrr_stack+10773, dvrr_stack+6163, dvrr_stack+5473, NULL);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10854, dvrr_stack+6428, dvrr_stack+10809, NULL, NULL, dvrr_stack+5501);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20368, dvrr_stack+18388, dvrr_stack+10854, dvrr_stack+11896, dvrr_stack+6428, dvrr_stack+5537);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21763, dvrr_stack+18523, dvrr_stack+20368, dvrr_stack+11941, dvrr_stack+18388, dvrr_stack+11590);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22213, dvrr_stack+18793, dvrr_stack+21763, dvrr_stack+12211, dvrr_stack+18523, dvrr_stack+4406);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22888, dvrr_stack+19693, dvrr_stack+22213, dvrr_stack+19243, dvrr_stack+18793, dvrr_stack+12706);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23833, dvrr_stack+21088, dvrr_stack+19693, dvrr_stack+20638, dvrr_stack+19243, dvrr_stack+11050);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+24778, dvrr_stack+23833, dvrr_stack+22888, dvrr_stack+21088, dvrr_stack+19693, dvrr_stack+13246);
 tmp = dvrr_stack + 24778;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+26038,dvrr_stack+24778,dvrr_stack+14758,28);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20638, dvrr_stack+11806, dvrr_stack+11896, dvrr_stack+6275, dvrr_stack+6347, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20693, dvrr_stack+11851, dvrr_stack+11806, dvrr_stack+6311, dvrr_stack+6275, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20748, dvrr_stack+11896, dvrr_stack+6428, dvrr_stack+6347, dvrr_stack+4334, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20803, dvrr_stack+20638, dvrr_stack+20748, NULL, NULL, dvrr_stack+11896);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20968, dvrr_stack+20693, dvrr_stack+20638, NULL, NULL, dvrr_stack+11806);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+20968, dvrr_stack+20803, dvrr_stack+20693, dvrr_stack+20638, dvrr_stack+11941);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11941, dvrr_stack+6383, dvrr_stack+11851, dvrr_stack+4298, dvrr_stack+6311, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21463, dvrr_stack+11941, dvrr_stack+20693, NULL, NULL, dvrr_stack+11851);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6518, dvrr_stack+21463, dvrr_stack+20968, dvrr_stack+11941, dvrr_stack+20693, dvrr_stack+12076);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11996, dvrr_stack+6428, dvrr_stack+10809, dvrr_stack+4334, dvrr_stack+5501, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+20748, dvrr_stack+11996, NULL, NULL, dvrr_stack+6428);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+20803, dvrr_stack+9898, dvrr_stack+20638, dvrr_stack+20748, dvrr_stack+18388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29392, dvrr_stack+21133, dvrr_stack+29062, dvrr_stack+20968, dvrr_stack+20803, dvrr_stack+18523);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29942, dvrr_stack+6518, dvrr_stack+21133, dvrr_stack+21463, dvrr_stack+20968, dvrr_stack+12211);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30492, dvrr_stack+29942, dvrr_stack+29392, dvrr_stack+6518, dvrr_stack+21133, dvrr_stack+18793);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12051, dvrr_stack+6473, dvrr_stack+6383, dvrr_stack+4370, dvrr_stack+4298, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+12051, dvrr_stack+11941, NULL, NULL, dvrr_stack+6383);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31317, dvrr_stack+12106, dvrr_stack+21463, dvrr_stack+12051, dvrr_stack+11941, dvrr_stack+12481);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31647, dvrr_stack+31317, dvrr_stack+6518, dvrr_stack+12106, dvrr_stack+21463, dvrr_stack+18118);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32197, dvrr_stack+31647, dvrr_stack+29942, dvrr_stack+31317, dvrr_stack+6518, dvrr_stack+19243);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19243, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+19246, dvrr_stack+10690, dvrr_stack+19243, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19252, dvrr_stack+10693, dvrr_stack+19246, dvrr_stack+5418, dvrr_stack+10690, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19262, dvrr_stack+10699, dvrr_stack+19252, dvrr_stack+5421, dvrr_stack+10693, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19277, dvrr_stack+10709, dvrr_stack+19262, dvrr_stack+5427, dvrr_stack+10699, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19298, dvrr_stack+10724, dvrr_stack+19277, dvrr_stack+5437, dvrr_stack+10709, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4370, dvrr_stack+10745, dvrr_stack+19298, dvrr_stack+5452, dvrr_stack+10724, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19326, dvrr_stack+10773, dvrr_stack+4370, dvrr_stack+5473, dvrr_stack+10745, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19371, dvrr_stack+10809, dvrr_stack+19326, dvrr_stack+5501, dvrr_stack+10773, NULL);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19426, dvrr_stack+11996, dvrr_stack+19371, NULL, NULL, dvrr_stack+10809);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31317, dvrr_stack+9898, dvrr_stack+19426, dvrr_stack+20748, dvrr_stack+11996, dvrr_stack+10854);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+29062, dvrr_stack+31317, dvrr_stack+20803, dvrr_stack+9898, dvrr_stack+20368);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33022, dvrr_stack+29392, dvrr_stack+12106, dvrr_stack+21133, dvrr_stack+29062, dvrr_stack+21763);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33847, dvrr_stack+30492, dvrr_stack+33022, dvrr_stack+29942, dvrr_stack+29392, dvrr_stack+22213);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35002, dvrr_stack+32197, dvrr_stack+30492, dvrr_stack+31647, dvrr_stack+29942, dvrr_stack+19693);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36157, dvrr_stack+35002, dvrr_stack+33847, dvrr_stack+32197, dvrr_stack+30492, dvrr_stack+22888);
 tmp = dvrr_stack + 36157;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37697,dvrr_stack+36157,dvrr_stack+24778,28);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31647, dvrr_stack+20638, dvrr_stack+20748, dvrr_stack+11806, dvrr_stack+11896, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31713, dvrr_stack+20693, dvrr_stack+20638, dvrr_stack+11851, dvrr_stack+11806, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31779, dvrr_stack+20748, dvrr_stack+11996, dvrr_stack+11896, dvrr_stack+6428, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31845, dvrr_stack+31647, dvrr_stack+31779, NULL, NULL, dvrr_stack+20748);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32043, dvrr_stack+31713, dvrr_stack+31647, NULL, NULL, dvrr_stack+20638);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32241, dvrr_stack+32043, dvrr_stack+31845, dvrr_stack+31713, dvrr_stack+31647, dvrr_stack+20803);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20803, dvrr_stack+11941, dvrr_stack+20693, dvrr_stack+6383, dvrr_stack+11851, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32637, dvrr_stack+20803, dvrr_stack+31713, NULL, NULL, dvrr_stack+20693);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41477, dvrr_stack+32637, dvrr_stack+32043, dvrr_stack+20803, dvrr_stack+31713, dvrr_stack+20968);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20869, dvrr_stack+11996, dvrr_stack+19371, dvrr_stack+6428, dvrr_stack+10809, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20935, dvrr_stack+31779, dvrr_stack+20869, NULL, NULL, dvrr_stack+11996);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41873, dvrr_stack+31845, dvrr_stack+20935, dvrr_stack+31647, dvrr_stack+31779, dvrr_stack+9898);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42269, dvrr_stack+32241, dvrr_stack+41873, dvrr_stack+32043, dvrr_stack+31845, dvrr_stack+29062);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42929, dvrr_stack+41477, dvrr_stack+32241, dvrr_stack+32637, dvrr_stack+32043, dvrr_stack+21133);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+43589, dvrr_stack+42929, dvrr_stack+42269, dvrr_stack+41477, dvrr_stack+32241, dvrr_stack+29392);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+12051, dvrr_stack+11941, dvrr_stack+6473, dvrr_stack+6383, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21199, dvrr_stack+21133, dvrr_stack+20803, NULL, NULL, dvrr_stack+11941);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44579, dvrr_stack+21199, dvrr_stack+32637, dvrr_stack+21133, dvrr_stack+20803, dvrr_stack+21463);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+21199, dvrr_stack+32637, dvrr_stack+6518);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+45635, dvrr_stack+44975, dvrr_stack+42929, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+29942);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+29942, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+29945, dvrr_stack+19243, dvrr_stack+29942, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+29951, dvrr_stack+19246, dvrr_stack+29945, dvrr_stack+10690, dvrr_stack+19243, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+29961, dvrr_stack+19252, dvrr_stack+29951, dvrr_stack+10693, dvrr_stack+19246, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+29976, dvrr_stack+19262, dvrr_stack+29961, dvrr_stack+10699, dvrr_stack+19252, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+29997, dvrr_stack+19277, dvrr_stack+29976, dvrr_stack+10709, dvrr_stack+19262, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30025, dvrr_stack+19298, dvrr_stack+29997, dvrr_stack+10724, dvrr_stack+19277, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30061, dvrr_stack+4370, dvrr_stack+30025, dvrr_stack+10745, dvrr_stack+19298, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30106, dvrr_stack+19326, dvrr_stack+30061, dvrr_stack+10773, dvrr_stack+4370, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30161, dvrr_stack+19371, dvrr_stack+30106, dvrr_stack+10809, dvrr_stack+19326, NULL);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30227, dvrr_stack+20869, dvrr_stack+30161, NULL, NULL, dvrr_stack+19371);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44579, dvrr_stack+20935, dvrr_stack+30227, dvrr_stack+31779, dvrr_stack+20869, dvrr_stack+19426);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+46625, dvrr_stack+41873, dvrr_stack+44579, dvrr_stack+31845, dvrr_stack+20935, dvrr_stack+31317);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47285, dvrr_stack+42269, dvrr_stack+46625, dvrr_stack+32241, dvrr_stack+41873, dvrr_stack+12106);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48275, dvrr_stack+43589, dvrr_stack+47285, dvrr_stack+42929, dvrr_stack+42269, dvrr_stack+33022);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49661, dvrr_stack+45635, dvrr_stack+43589, dvrr_stack+44975, dvrr_stack+42929, dvrr_stack+30492);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51047, dvrr_stack+49661, dvrr_stack+48275, dvrr_stack+45635, dvrr_stack+43589, dvrr_stack+33847);
 tmp = dvrr_stack + 51047;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+52895,dvrr_stack+51047,dvrr_stack+36157,28);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+31647, dvrr_stack+31779, dvrr_stack+20638, dvrr_stack+20748, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45053, dvrr_stack+31713, dvrr_stack+31647, dvrr_stack+20693, dvrr_stack+20638, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45131, dvrr_stack+31779, dvrr_stack+20869, dvrr_stack+20748, dvrr_stack+11996, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45209, dvrr_stack+44975, dvrr_stack+45131, NULL, NULL, dvrr_stack+31779);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45443, dvrr_stack+45053, dvrr_stack+44975, NULL, NULL, dvrr_stack+31647);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45677, dvrr_stack+45443, dvrr_stack+45209, dvrr_stack+45053, dvrr_stack+44975, dvrr_stack+31845);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31845, dvrr_stack+20803, dvrr_stack+31713, dvrr_stack+11941, dvrr_stack+20693, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+46145, dvrr_stack+31845, dvrr_stack+45053, NULL, NULL, dvrr_stack+31713);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+21199, dvrr_stack+46145, dvrr_stack+45443, dvrr_stack+31845, dvrr_stack+45053, dvrr_stack+32043);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31923, dvrr_stack+20869, dvrr_stack+30161, dvrr_stack+11996, dvrr_stack+19371, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32001, dvrr_stack+45131, dvrr_stack+31923, NULL, NULL, dvrr_stack+20869);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+57515, dvrr_stack+45209, dvrr_stack+32001, dvrr_stack+44975, dvrr_stack+45131, dvrr_stack+20935);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+57983, dvrr_stack+45677, dvrr_stack+57515, dvrr_stack+45443, dvrr_stack+45209, dvrr_stack+41873);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+58763, dvrr_stack+21199, dvrr_stack+45677, dvrr_stack+46145, dvrr_stack+45443, dvrr_stack+32241);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59543, dvrr_stack+58763, dvrr_stack+57983, dvrr_stack+21199, dvrr_stack+45677, dvrr_stack+42269);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32235, dvrr_stack+21133, dvrr_stack+20803, dvrr_stack+12051, dvrr_stack+11941, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32313, dvrr_stack+32235, dvrr_stack+31845, NULL, NULL, dvrr_stack+20803);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60713, dvrr_stack+32313, dvrr_stack+46145, dvrr_stack+32235, dvrr_stack+31845, dvrr_stack+32637);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+61181, dvrr_stack+60713, dvrr_stack+21199, dvrr_stack+32313, dvrr_stack+46145, dvrr_stack+41477);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+61961, dvrr_stack+61181, dvrr_stack+58763, dvrr_stack+60713, dvrr_stack+21199, dvrr_stack+42929);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+10690, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+42929, dvrr_stack+29942, dvrr_stack+10690, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+42935, dvrr_stack+29945, dvrr_stack+42929, dvrr_stack+19243, dvrr_stack+29942, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+42945, dvrr_stack+29951, dvrr_stack+42935, dvrr_stack+19246, dvrr_stack+29945, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+42960, dvrr_stack+29961, dvrr_stack+42945, dvrr_stack+19252, dvrr_stack+29951, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+42981, dvrr_stack+29976, dvrr_stack+42960, dvrr_stack+19262, dvrr_stack+29961, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43009, dvrr_stack+29997, dvrr_stack+42981, dvrr_stack+19277, dvrr_stack+29976, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+43045, dvrr_stack+30025, dvrr_stack+43009, dvrr_stack+19298, dvrr_stack+29997, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12051, dvrr_stack+30061, dvrr_stack+43045, dvrr_stack+4370, dvrr_stack+30025, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+43090, dvrr_stack+30106, dvrr_stack+12051, dvrr_stack+19326, dvrr_stack+30061, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43156, dvrr_stack+30161, dvrr_stack+43090, dvrr_stack+19371, dvrr_stack+30106, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43234, dvrr_stack+31923, dvrr_stack+43156, NULL, NULL, dvrr_stack+30161);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60713, dvrr_stack+32001, dvrr_stack+43234, dvrr_stack+45131, dvrr_stack+31923, dvrr_stack+30227);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+63131, dvrr_stack+57515, dvrr_stack+60713, dvrr_stack+45209, dvrr_stack+32001, dvrr_stack+44579);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+63911, dvrr_stack+57983, dvrr_stack+63131, dvrr_stack+45677, dvrr_stack+57515, dvrr_stack+46625);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+65081, dvrr_stack+59543, dvrr_stack+63911, dvrr_stack+58763, dvrr_stack+57983, dvrr_stack+47285);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66719, dvrr_stack+61961, dvrr_stack+59543, dvrr_stack+61181, dvrr_stack+58763, dvrr_stack+43589);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68357, dvrr_stack+66719, dvrr_stack+65081, dvrr_stack+61961, dvrr_stack+59543, dvrr_stack+48275);
 tmp = dvrr_stack + 68357;
 target_ptr = Libderiv->dvrr_classes[6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+70541,dvrr_stack+68357,dvrr_stack+51047,28);


 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+61181, dvrr_stack+44975, dvrr_stack+45131, dvrr_stack+31647, dvrr_stack+31779, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+61272, dvrr_stack+45053, dvrr_stack+44975, dvrr_stack+31713, dvrr_stack+31647, NULL);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+61363, dvrr_stack+45131, dvrr_stack+31923, dvrr_stack+31779, dvrr_stack+20869, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+61454, dvrr_stack+61181, dvrr_stack+61363, NULL, NULL, dvrr_stack+45131);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+61727, dvrr_stack+61272, dvrr_stack+61181, NULL, NULL, dvrr_stack+44975);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+62000, dvrr_stack+61727, dvrr_stack+61454, dvrr_stack+61272, dvrr_stack+61181, dvrr_stack+45209);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45209, dvrr_stack+31845, dvrr_stack+45053, dvrr_stack+20803, dvrr_stack+31713, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+62546, dvrr_stack+45209, dvrr_stack+61272, NULL, NULL, dvrr_stack+45053);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+32313, dvrr_stack+62546, dvrr_stack+61727, dvrr_stack+45209, dvrr_stack+61272, dvrr_stack+45443);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45300, dvrr_stack+31923, dvrr_stack+43156, dvrr_stack+20869, dvrr_stack+30161, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45391, dvrr_stack+61363, dvrr_stack+45300, NULL, NULL, dvrr_stack+31923);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76085, dvrr_stack+61454, dvrr_stack+45391, dvrr_stack+61181, dvrr_stack+61363, dvrr_stack+32001);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76631, dvrr_stack+62000, dvrr_stack+76085, dvrr_stack+61727, dvrr_stack+61454, dvrr_stack+57515);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+77541, dvrr_stack+32313, dvrr_stack+62000, dvrr_stack+62546, dvrr_stack+61727, dvrr_stack+45677);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+78451, dvrr_stack+77541, dvrr_stack+76631, dvrr_stack+32313, dvrr_stack+62000, dvrr_stack+57983);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45664, dvrr_stack+32235, dvrr_stack+31845, dvrr_stack+21133, dvrr_stack+20803, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45755, dvrr_stack+45664, dvrr_stack+45209, NULL, NULL, dvrr_stack+31845);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+79816, dvrr_stack+45755, dvrr_stack+62546, dvrr_stack+45664, dvrr_stack+45209, dvrr_stack+46145);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+80362, dvrr_stack+79816, dvrr_stack+32313, dvrr_stack+45755, dvrr_stack+62546, dvrr_stack+21199);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+81272, dvrr_stack+80362, dvrr_stack+77541, dvrr_stack+79816, dvrr_stack+32313, dvrr_stack+58763);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+58763, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+58766, dvrr_stack+10690, dvrr_stack+58763, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58772, dvrr_stack+42929, dvrr_stack+58766, dvrr_stack+29942, dvrr_stack+10690, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+58782, dvrr_stack+42935, dvrr_stack+58772, dvrr_stack+29945, dvrr_stack+42929, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+58797, dvrr_stack+42945, dvrr_stack+58782, dvrr_stack+29951, dvrr_stack+42935, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+58818, dvrr_stack+42960, dvrr_stack+58797, dvrr_stack+29961, dvrr_stack+42945, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+58846, dvrr_stack+42981, dvrr_stack+58818, dvrr_stack+29976, dvrr_stack+42960, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+58882, dvrr_stack+43009, dvrr_stack+58846, dvrr_stack+29997, dvrr_stack+42981, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+58927, dvrr_stack+43045, dvrr_stack+58882, dvrr_stack+30025, dvrr_stack+43009, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+58982, dvrr_stack+12051, dvrr_stack+58927, dvrr_stack+30061, dvrr_stack+43045, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59048, dvrr_stack+43090, dvrr_stack+58982, dvrr_stack+30106, dvrr_stack+12051, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+59126, dvrr_stack+43156, dvrr_stack+59048, dvrr_stack+30161, dvrr_stack+43090, NULL);

 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+59217, dvrr_stack+45300, dvrr_stack+59126, NULL, NULL, dvrr_stack+43156);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+79816, dvrr_stack+45391, dvrr_stack+59217, dvrr_stack+61363, dvrr_stack+45300, dvrr_stack+43234);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+82637, dvrr_stack+76085, dvrr_stack+79816, dvrr_stack+61454, dvrr_stack+45391, dvrr_stack+60713);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+83547, dvrr_stack+76631, dvrr_stack+82637, dvrr_stack+62000, dvrr_stack+76085, dvrr_stack+63131);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+84912, dvrr_stack+78451, dvrr_stack+83547, dvrr_stack+77541, dvrr_stack+76631, dvrr_stack+63911);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+86823, dvrr_stack+81272, dvrr_stack+78451, dvrr_stack+80362, dvrr_stack+77541, dvrr_stack+59543);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+88734, dvrr_stack+86823, dvrr_stack+84912, dvrr_stack+81272, dvrr_stack+78451, dvrr_stack+65081);
 tmp = dvrr_stack + 88734;
 target_ptr = Libderiv->dvrr_classes[6][12];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+91282,dvrr_stack+88734,dvrr_stack+68357,28);


 /* compute (0 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80362, dvrr_stack+61181, dvrr_stack+61363, dvrr_stack+44975, dvrr_stack+45131, NULL);

 /* compute (0 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80467, dvrr_stack+61272, dvrr_stack+61181, dvrr_stack+45053, dvrr_stack+44975, NULL);

 /* compute (0 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80572, dvrr_stack+61363, dvrr_stack+45300, dvrr_stack+45131, dvrr_stack+31923, NULL);

 /* compute (1 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80677, dvrr_stack+80362, dvrr_stack+80572, NULL, NULL, dvrr_stack+61363);

 /* compute (1 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80992, dvrr_stack+80467, dvrr_stack+80362, NULL, NULL, dvrr_stack+61181);

 /* compute (2 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+80992, dvrr_stack+80677, dvrr_stack+80467, dvrr_stack+80362, dvrr_stack+61454);

 /* compute (0 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+61363, dvrr_stack+45209, dvrr_stack+61272, dvrr_stack+31845, dvrr_stack+45053, NULL);

 /* compute (1 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+81307, dvrr_stack+61363, dvrr_stack+80467, NULL, NULL, dvrr_stack+61272);

 /* compute (2 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+81622, dvrr_stack+81307, dvrr_stack+80992, dvrr_stack+61363, dvrr_stack+80467, dvrr_stack+61727);

 /* compute (0 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80467, dvrr_stack+45300, dvrr_stack+59126, dvrr_stack+31923, dvrr_stack+43156, NULL);

 /* compute (1 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+61468, dvrr_stack+80572, dvrr_stack+80467, NULL, NULL, dvrr_stack+45300);

 /* compute (2 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+45755, dvrr_stack+80677, dvrr_stack+61468, dvrr_stack+80362, dvrr_stack+80572, dvrr_stack+45391);

 /* compute (3 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+97834, dvrr_stack+21133, dvrr_stack+45755, dvrr_stack+80992, dvrr_stack+80677, dvrr_stack+76085);

 /* compute (3 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+98884, dvrr_stack+81622, dvrr_stack+21133, dvrr_stack+81307, dvrr_stack+80992, dvrr_stack+62000);

 /* compute (4 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+99934, dvrr_stack+98884, dvrr_stack+97834, dvrr_stack+81622, dvrr_stack+21133, dvrr_stack+76631);

 /* compute (0 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80362, dvrr_stack+45664, dvrr_stack+45209, dvrr_stack+32235, dvrr_stack+31845, NULL);

 /* compute (1 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80992, dvrr_stack+80362, dvrr_stack+61363, NULL, NULL, dvrr_stack+45209);

 /* compute (2 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+61783, dvrr_stack+80992, dvrr_stack+81307, dvrr_stack+80362, dvrr_stack+61363, dvrr_stack+62546);

 /* compute (3 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+101509, dvrr_stack+61783, dvrr_stack+81622, dvrr_stack+80992, dvrr_stack+81307, dvrr_stack+32313);

 /* compute (4 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+102559, dvrr_stack+101509, dvrr_stack+98884, dvrr_stack+61783, dvrr_stack+81622, dvrr_stack+77541);

 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+77541, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+77544, dvrr_stack+58763, dvrr_stack+77541, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77550, dvrr_stack+58766, dvrr_stack+77544, dvrr_stack+10690, dvrr_stack+58763, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+77560, dvrr_stack+58772, dvrr_stack+77550, dvrr_stack+42929, dvrr_stack+58766, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+77575, dvrr_stack+58782, dvrr_stack+77560, dvrr_stack+42935, dvrr_stack+58772, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+77596, dvrr_stack+58797, dvrr_stack+77575, dvrr_stack+42945, dvrr_stack+58782, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+77624, dvrr_stack+58818, dvrr_stack+77596, dvrr_stack+42960, dvrr_stack+58797, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+77660, dvrr_stack+58846, dvrr_stack+77624, dvrr_stack+42981, dvrr_stack+58818, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+77705, dvrr_stack+58882, dvrr_stack+77660, dvrr_stack+43009, dvrr_stack+58846, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+77760, dvrr_stack+58927, dvrr_stack+77705, dvrr_stack+43045, dvrr_stack+58882, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+77826, dvrr_stack+58982, dvrr_stack+77760, dvrr_stack+12051, dvrr_stack+58927, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+45664, dvrr_stack+59048, dvrr_stack+77826, dvrr_stack+43090, dvrr_stack+58982, NULL);

 /* compute (0 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80362, dvrr_stack+59126, dvrr_stack+45664, dvrr_stack+43156, dvrr_stack+59048, NULL);

 /* compute (1 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+77904, dvrr_stack+80467, dvrr_stack+80362, NULL, NULL, dvrr_stack+59126);

 /* compute (2 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+61783, dvrr_stack+61468, dvrr_stack+77904, dvrr_stack+80572, dvrr_stack+80467, dvrr_stack+59217);

 /* compute (3 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80992, dvrr_stack+45755, dvrr_stack+61783, dvrr_stack+80677, dvrr_stack+61468, dvrr_stack+79816);

 /* compute (4 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+104134, dvrr_stack+97834, dvrr_stack+80992, dvrr_stack+21133, dvrr_stack+45755, dvrr_stack+82637);

 /* compute (5 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+105709, dvrr_stack+99934, dvrr_stack+104134, dvrr_stack+98884, dvrr_stack+97834, dvrr_stack+83547);

 /* compute (5 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+107914, dvrr_stack+102559, dvrr_stack+99934, dvrr_stack+101509, dvrr_stack+98884, dvrr_stack+78451);

 /* compute (6 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+110119, dvrr_stack+107914, dvrr_stack+105709, dvrr_stack+102559, dvrr_stack+99934, dvrr_stack+84912);

 /* compute (6 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+113059,dvrr_stack+110119,dvrr_stack+88734,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+10690, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+19243, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+98884, dvrr_stack+6, dvrr_stack+19243, dvrr_stack+3, dvrr_stack+0, dvrr_stack+10690);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+98902, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+98920, dvrr_stack+39, dvrr_stack+98902, dvrr_stack+15, dvrr_stack+33, dvrr_stack+19243);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+98956, dvrr_stack+75, dvrr_stack+98920, dvrr_stack+57, dvrr_stack+39, dvrr_stack+98884);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+479, dvrr_stack+219, dvrr_stack+879, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+99016, dvrr_stack+229, dvrr_stack+479, dvrr_stack+111, dvrr_stack+219, dvrr_stack+98902);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+99076, dvrr_stack+259, dvrr_stack+99016, dvrr_stack+131, dvrr_stack+229, dvrr_stack+98920);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+99176, dvrr_stack+379, dvrr_stack+99076, dvrr_stack+319, dvrr_stack+259, dvrr_stack+98956);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+99326, dvrr_stack+889, dvrr_stack+2708, NULL, NULL, dvrr_stack+879);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+99371, dvrr_stack+904, dvrr_stack+99326, dvrr_stack+509, dvrr_stack+889, dvrr_stack+479);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+99461, dvrr_stack+949, dvrr_stack+99371, dvrr_stack+524, dvrr_stack+904, dvrr_stack+99016);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+99611, dvrr_stack+1039, dvrr_stack+99461, dvrr_stack+614, dvrr_stack+949, dvrr_stack+99076);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+101509, dvrr_stack+1339, dvrr_stack+99611, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+99176);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2723, dvrr_stack+6142, NULL, NULL, dvrr_stack+2708);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1564, dvrr_stack+2744, dvrr_stack+614, dvrr_stack+1753, dvrr_stack+2723, dvrr_stack+99326);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+101824, dvrr_stack+2807, dvrr_stack+1564, dvrr_stack+1774, dvrr_stack+2744, dvrr_stack+99371);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+102034, dvrr_stack+2933, dvrr_stack+101824, dvrr_stack+1837, dvrr_stack+2807, dvrr_stack+99461);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+102349, dvrr_stack+3143, dvrr_stack+102034, dvrr_stack+2089, dvrr_stack+2933, dvrr_stack+99611);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+102790, dvrr_stack+3773, dvrr_stack+102349, dvrr_stack+3458, dvrr_stack+3143, dvrr_stack+101509);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+99836, dvrr_stack+6163, dvrr_stack+5473, NULL, NULL, dvrr_stack+6142);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+103378, dvrr_stack+6191, dvrr_stack+99836, dvrr_stack+1690, dvrr_stack+6163, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1690, dvrr_stack+7070, dvrr_stack+103378, dvrr_stack+4886, dvrr_stack+6191, dvrr_stack+1564);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+80572, dvrr_stack+7238, dvrr_stack+1690, dvrr_stack+4970, dvrr_stack+7070, dvrr_stack+101824);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+103546, dvrr_stack+7518, dvrr_stack+80572, dvrr_stack+5138, dvrr_stack+7238, dvrr_stack+102034);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+32235, dvrr_stack+7938, dvrr_stack+103546, dvrr_stack+5698, dvrr_stack+7518, dvrr_stack+102349);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+120703, dvrr_stack+9114, dvrr_stack+32235, dvrr_stack+8526, dvrr_stack+7938, dvrr_stack+102790);
 tmp = dvrr_stack + 120703;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+5501, dvrr_stack+10773, NULL, NULL, dvrr_stack+5473);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+21241, dvrr_stack+5537, dvrr_stack+21133, dvrr_stack+4334, dvrr_stack+5501, dvrr_stack+99836);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62413, dvrr_stack+11590, dvrr_stack+21241, dvrr_stack+6923, dvrr_stack+5537, dvrr_stack+103378);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+82042, dvrr_stack+4406, dvrr_stack+62413, dvrr_stack+10114, dvrr_stack+11590, dvrr_stack+1690);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121711, dvrr_stack+12706, dvrr_stack+82042, dvrr_stack+10330, dvrr_stack+4406, dvrr_stack+80572);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122467, dvrr_stack+13246, dvrr_stack+121711, dvrr_stack+11050, dvrr_stack+12706, dvrr_stack+103546);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+123475, dvrr_stack+14758, dvrr_stack+122467, dvrr_stack+14002, dvrr_stack+13246, dvrr_stack+32235);
 tmp = dvrr_stack + 123475;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+124771,dvrr_stack+123475,dvrr_stack+120703,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21457, dvrr_stack+10809, dvrr_stack+19326, NULL, NULL, dvrr_stack+10773);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+10854, dvrr_stack+21457, dvrr_stack+6428, dvrr_stack+10809, dvrr_stack+21133);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6275, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+18388, dvrr_stack+10854, dvrr_stack+21241);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127795, dvrr_stack+21763, dvrr_stack+6275, dvrr_stack+18523, dvrr_stack+20368, dvrr_stack+62413);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+128470, dvrr_stack+22213, dvrr_stack+127795, dvrr_stack+18793, dvrr_stack+21763, dvrr_stack+82042);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+129415, dvrr_stack+22888, dvrr_stack+128470, dvrr_stack+19693, dvrr_stack+22213, dvrr_stack+121711);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+130675, dvrr_stack+24778, dvrr_stack+129415, dvrr_stack+23833, dvrr_stack+22888, dvrr_stack+122467);
 tmp = dvrr_stack + 130675;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+132295,dvrr_stack+130675,dvrr_stack+123475,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18388, dvrr_stack+19371, dvrr_stack+30106, NULL, NULL, dvrr_stack+19326);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18553, dvrr_stack+19426, dvrr_stack+18388, dvrr_stack+11996, dvrr_stack+19371, dvrr_stack+21457);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19591, dvrr_stack+31317, dvrr_stack+18553, dvrr_stack+9898, dvrr_stack+19426, dvrr_stack+18118);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+136183, dvrr_stack+12106, dvrr_stack+19591, dvrr_stack+29062, dvrr_stack+31317, dvrr_stack+6275);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+137008, dvrr_stack+33022, dvrr_stack+136183, dvrr_stack+29392, dvrr_stack+12106, dvrr_stack+127795);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+138163, dvrr_stack+33847, dvrr_stack+137008, dvrr_stack+30492, dvrr_stack+33022, dvrr_stack+128470);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+139703, dvrr_stack+36157, dvrr_stack+138163, dvrr_stack+35002, dvrr_stack+33847, dvrr_stack+129415);
 tmp = dvrr_stack + 139703;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+141683,dvrr_stack+139703,dvrr_stack+130675,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+30161, dvrr_stack+43090, NULL, NULL, dvrr_stack+30106);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41477, dvrr_stack+30227, dvrr_stack+29062, dvrr_stack+20869, dvrr_stack+30161, dvrr_stack+18388);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29260, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+20935, dvrr_stack+30227, dvrr_stack+18553);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+146543, dvrr_stack+46625, dvrr_stack+29260, dvrr_stack+41873, dvrr_stack+44579, dvrr_stack+19591);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+147533, dvrr_stack+47285, dvrr_stack+146543, dvrr_stack+42269, dvrr_stack+46625, dvrr_stack+136183);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+148919, dvrr_stack+48275, dvrr_stack+147533, dvrr_stack+43589, dvrr_stack+47285, dvrr_stack+137008);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+150767, dvrr_stack+51047, dvrr_stack+148919, dvrr_stack+49661, dvrr_stack+48275, dvrr_stack+138163);
 tmp = dvrr_stack + 150767;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+153143,dvrr_stack+150767,dvrr_stack+139703,36);


 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41873, dvrr_stack+43156, dvrr_stack+59048, NULL, NULL, dvrr_stack+43090);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42107, dvrr_stack+43234, dvrr_stack+41873, dvrr_stack+31923, dvrr_stack+43156, dvrr_stack+29062);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+60713, dvrr_stack+42107, dvrr_stack+32001, dvrr_stack+43234, dvrr_stack+41477);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+159083, dvrr_stack+63131, dvrr_stack+9898, dvrr_stack+57515, dvrr_stack+60713, dvrr_stack+29260);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+160253, dvrr_stack+63911, dvrr_stack+159083, dvrr_stack+57983, dvrr_stack+63131, dvrr_stack+146543);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+161891, dvrr_stack+65081, dvrr_stack+160253, dvrr_stack+59543, dvrr_stack+63911, dvrr_stack+147533);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+164075, dvrr_stack+68357, dvrr_stack+161891, dvrr_stack+66719, dvrr_stack+65081, dvrr_stack+148919);
 tmp = dvrr_stack + 164075;
 target_ptr = Libderiv->dvrr_classes[7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+166883,dvrr_stack+164075,dvrr_stack+150767,36);


 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57515, dvrr_stack+59126, dvrr_stack+45664, NULL, NULL, dvrr_stack+59048);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57788, dvrr_stack+59217, dvrr_stack+57515, dvrr_stack+45300, dvrr_stack+59126, dvrr_stack+41873);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+59490, dvrr_stack+79816, dvrr_stack+57788, dvrr_stack+45391, dvrr_stack+59217, dvrr_stack+42107);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+174011, dvrr_stack+82637, dvrr_stack+59490, dvrr_stack+76085, dvrr_stack+79816, dvrr_stack+9898);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+175376, dvrr_stack+83547, dvrr_stack+174011, dvrr_stack+76631, dvrr_stack+82637, dvrr_stack+159083);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+177287, dvrr_stack+84912, dvrr_stack+175376, dvrr_stack+78451, dvrr_stack+83547, dvrr_stack+160253);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+179835, dvrr_stack+88734, dvrr_stack+177287, dvrr_stack+86823, dvrr_stack+84912, dvrr_stack+161891);
 tmp = dvrr_stack + 179835;
 target_ptr = Libderiv->dvrr_classes[7][12];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+183111,dvrr_stack+179835,dvrr_stack+164075,36);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+33019, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+77541, dvrr_stack+33019, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+77544, dvrr_stack+15, dvrr_stack+58763, dvrr_stack+77541, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+76085, dvrr_stack+77550, dvrr_stack+111, dvrr_stack+58766, dvrr_stack+77544, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+76100, dvrr_stack+77560, dvrr_stack+76085, dvrr_stack+58772, dvrr_stack+77550, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+76121, dvrr_stack+77575, dvrr_stack+76100, dvrr_stack+58782, dvrr_stack+77560, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+76149, dvrr_stack+77596, dvrr_stack+76121, dvrr_stack+58797, dvrr_stack+77575, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+76185, dvrr_stack+77624, dvrr_stack+76149, dvrr_stack+58818, dvrr_stack+77596, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82582, dvrr_stack+77660, dvrr_stack+76185, dvrr_stack+58846, dvrr_stack+77624, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+76230, dvrr_stack+77705, dvrr_stack+82582, dvrr_stack+58882, dvrr_stack+77660, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+76296, dvrr_stack+77760, dvrr_stack+76230, dvrr_stack+58927, dvrr_stack+77705, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76374, dvrr_stack+77826, dvrr_stack+76296, dvrr_stack+58982, dvrr_stack+77760, NULL);

 /* compute (0 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+76465, dvrr_stack+45664, dvrr_stack+76374, dvrr_stack+59048, dvrr_stack+77826, NULL);

 /* compute (1 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+76570, dvrr_stack+80362, dvrr_stack+76465, NULL, NULL, dvrr_stack+45664);

 /* compute (2 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+76885, dvrr_stack+77904, dvrr_stack+76570, dvrr_stack+80467, dvrr_stack+80362, dvrr_stack+57515);

 /* compute (3 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+78219, dvrr_stack+61783, dvrr_stack+76885, dvrr_stack+61468, dvrr_stack+77904, dvrr_stack+57788);

 /* compute (4 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+191535, dvrr_stack+80992, dvrr_stack+78219, dvrr_stack+45755, dvrr_stack+61783, dvrr_stack+59490);

 /* compute (5 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+193110, dvrr_stack+104134, dvrr_stack+191535, dvrr_stack+97834, dvrr_stack+80992, dvrr_stack+174011);

 /* compute (6 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+195315, dvrr_stack+105709, dvrr_stack+193110, dvrr_stack+99934, dvrr_stack+104134, dvrr_stack+175376);

 /* compute (7 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+198255, dvrr_stack+110119, dvrr_stack+195315, dvrr_stack+107914, dvrr_stack+105709, dvrr_stack+177287);

 /* compute (7 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+202035,dvrr_stack+198255,dvrr_stack+179835,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+107914, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+107917, dvrr_stack+10690, dvrr_stack+107914, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+107923, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+107932, dvrr_stack+19243, dvrr_stack+107923, dvrr_stack+0, dvrr_stack+30, dvrr_stack+107914);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+98884, dvrr_stack+107932, dvrr_stack+6, dvrr_stack+19243, dvrr_stack+107917);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+107950, dvrr_stack+213, dvrr_stack+873, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+107968, dvrr_stack+98902, dvrr_stack+107950, dvrr_stack+33, dvrr_stack+213, dvrr_stack+107923);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+108004, dvrr_stack+98920, dvrr_stack+107968, dvrr_stack+39, dvrr_stack+98902, dvrr_stack+107932);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+108064, dvrr_stack+98956, dvrr_stack+108004, dvrr_stack+75, dvrr_stack+98920, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+108154, dvrr_stack+879, dvrr_stack+2698, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+108184, dvrr_stack+479, dvrr_stack+108154, dvrr_stack+219, dvrr_stack+879, dvrr_stack+107950);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+108244, dvrr_stack+99016, dvrr_stack+108184, dvrr_stack+229, dvrr_stack+479, dvrr_stack+107968);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+108344, dvrr_stack+99076, dvrr_stack+108244, dvrr_stack+259, dvrr_stack+99016, dvrr_stack+108004);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+108494, dvrr_stack+99176, dvrr_stack+108344, dvrr_stack+379, dvrr_stack+99076, dvrr_stack+108064);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2708, dvrr_stack+6127, NULL, NULL, dvrr_stack+2698);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+108704, dvrr_stack+99326, dvrr_stack+219, dvrr_stack+889, dvrr_stack+2708, dvrr_stack+108154);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+108794, dvrr_stack+99371, dvrr_stack+108704, dvrr_stack+904, dvrr_stack+99326, dvrr_stack+108184);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+108944, dvrr_stack+99461, dvrr_stack+108794, dvrr_stack+949, dvrr_stack+99371, dvrr_stack+108244);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+109169, dvrr_stack+99611, dvrr_stack+108944, dvrr_stack+1039, dvrr_stack+99461, dvrr_stack+108344);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+109484, dvrr_stack+101509, dvrr_stack+109169, dvrr_stack+1339, dvrr_stack+99611, dvrr_stack+108494);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+889, dvrr_stack+6142, dvrr_stack+5452, NULL, NULL, dvrr_stack+6127);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+952, dvrr_stack+614, dvrr_stack+889, dvrr_stack+2723, dvrr_stack+6142, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+109904, dvrr_stack+1564, dvrr_stack+952, dvrr_stack+2744, dvrr_stack+614, dvrr_stack+108704);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+97834, dvrr_stack+101824, dvrr_stack+109904, dvrr_stack+2807, dvrr_stack+1564, dvrr_stack+108794);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+98149, dvrr_stack+102034, dvrr_stack+97834, dvrr_stack+2933, dvrr_stack+101824, dvrr_stack+108944);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+31647, dvrr_stack+102349, dvrr_stack+98149, dvrr_stack+3143, dvrr_stack+102034, dvrr_stack+109169);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+45755, dvrr_stack+102790, dvrr_stack+31647, dvrr_stack+3773, dvrr_stack+102349, dvrr_stack+109484);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2723, dvrr_stack+5473, dvrr_stack+10745, NULL, NULL, dvrr_stack+5452);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2807, dvrr_stack+99836, dvrr_stack+2723, dvrr_stack+6163, dvrr_stack+5473, dvrr_stack+889);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2975, dvrr_stack+103378, dvrr_stack+2807, dvrr_stack+6191, dvrr_stack+99836, dvrr_stack+952);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+58334, dvrr_stack+1690, dvrr_stack+2975, dvrr_stack+7070, dvrr_stack+103378, dvrr_stack+109904);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+99920, dvrr_stack+80572, dvrr_stack+58334, dvrr_stack+7238, dvrr_stack+1690, dvrr_stack+97834);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+100508, dvrr_stack+103546, dvrr_stack+99920, dvrr_stack+7518, dvrr_stack+80572, dvrr_stack+98149);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+43468, dvrr_stack+32235, dvrr_stack+100508, dvrr_stack+7938, dvrr_stack+103546, dvrr_stack+31647);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+6725, dvrr_stack+120703, dvrr_stack+43468, dvrr_stack+9114, dvrr_stack+32235, dvrr_stack+45755);
 tmp = dvrr_stack + 6725;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6163, dvrr_stack+10773, dvrr_stack+4370, NULL, NULL, dvrr_stack+10745);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+98590, dvrr_stack+21133, dvrr_stack+6163, dvrr_stack+5501, dvrr_stack+10773, dvrr_stack+2723);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18883, dvrr_stack+21241, dvrr_stack+98590, dvrr_stack+5537, dvrr_stack+21133, dvrr_stack+2807);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5501, dvrr_stack+62413, dvrr_stack+18883, dvrr_stack+11590, dvrr_stack+21241, dvrr_stack+2975);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30425, dvrr_stack+82042, dvrr_stack+5501, dvrr_stack+4406, dvrr_stack+62413, dvrr_stack+58334);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+121711, dvrr_stack+30425, dvrr_stack+12706, dvrr_stack+82042, dvrr_stack+99920);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+211863, dvrr_stack+122467, dvrr_stack+4406, dvrr_stack+13246, dvrr_stack+121711, dvrr_stack+100508);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+213159, dvrr_stack+123475, dvrr_stack+211863, dvrr_stack+14758, dvrr_stack+122467, dvrr_stack+43468);
 tmp = dvrr_stack + 213159;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+214779,dvrr_stack+213159,dvrr_stack+6725,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3255, dvrr_stack+19326, dvrr_stack+30061, NULL, NULL, dvrr_stack+4370);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+42575, dvrr_stack+21457, dvrr_stack+3255, dvrr_stack+10809, dvrr_stack+19326, dvrr_stack+6163);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+79269, dvrr_stack+18118, dvrr_stack+42575, dvrr_stack+10854, dvrr_stack+21457, dvrr_stack+98590);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10809, dvrr_stack+6275, dvrr_stack+79269, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+18883);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20141, dvrr_stack+127795, dvrr_stack+10809, dvrr_stack+21763, dvrr_stack+6275, dvrr_stack+5501);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12656, dvrr_stack+128470, dvrr_stack+20141, dvrr_stack+22213, dvrr_stack+127795, dvrr_stack+30425);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+218559, dvrr_stack+129415, dvrr_stack+12656, dvrr_stack+22888, dvrr_stack+128470, dvrr_stack+4406);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21592, dvrr_stack+130675, dvrr_stack+218559, dvrr_stack+24778, dvrr_stack+129415, dvrr_stack+211863);
 tmp = dvrr_stack + 21592;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+220179,dvrr_stack+21592,dvrr_stack+213159,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11484, dvrr_stack+30106, dvrr_stack+12051, NULL, NULL, dvrr_stack+30061);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11649, dvrr_stack+18388, dvrr_stack+11484, dvrr_stack+19371, dvrr_stack+30106, dvrr_stack+3255);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+61181, dvrr_stack+18553, dvrr_stack+11649, dvrr_stack+19426, dvrr_stack+18388, dvrr_stack+42575);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+225039, dvrr_stack+19591, dvrr_stack+61181, dvrr_stack+31317, dvrr_stack+18553, dvrr_stack+79269);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+225864, dvrr_stack+136183, dvrr_stack+225039, dvrr_stack+12106, dvrr_stack+19591, dvrr_stack+10809);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+227019, dvrr_stack+137008, dvrr_stack+225864, dvrr_stack+33022, dvrr_stack+136183, dvrr_stack+20141);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+228559, dvrr_stack+138163, dvrr_stack+227019, dvrr_stack+33847, dvrr_stack+137008, dvrr_stack+12656);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+230539, dvrr_stack+139703, dvrr_stack+228559, dvrr_stack+36157, dvrr_stack+138163, dvrr_stack+218559);
 tmp = dvrr_stack + 230539;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+233014,dvrr_stack+230539,dvrr_stack+21592,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33022, dvrr_stack+43090, dvrr_stack+58982, NULL, NULL, dvrr_stack+12051);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33220, dvrr_stack+29062, dvrr_stack+33022, dvrr_stack+30161, dvrr_stack+43090, dvrr_stack+11484);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33616, dvrr_stack+41477, dvrr_stack+33220, dvrr_stack+30227, dvrr_stack+29062, dvrr_stack+11649);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+239089, dvrr_stack+29260, dvrr_stack+33616, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+61181);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+240079, dvrr_stack+146543, dvrr_stack+239089, dvrr_stack+46625, dvrr_stack+29260, dvrr_stack+225039);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+241465, dvrr_stack+147533, dvrr_stack+240079, dvrr_stack+47285, dvrr_stack+146543, dvrr_stack+225864);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+243313, dvrr_stack+148919, dvrr_stack+241465, dvrr_stack+48275, dvrr_stack+147533, dvrr_stack+227019);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+46511, dvrr_stack+150767, dvrr_stack+243313, dvrr_stack+51047, dvrr_stack+148919, dvrr_stack+228559);
 tmp = dvrr_stack + 46511;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+245689,dvrr_stack+46511,dvrr_stack+230539,45);


 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30161, dvrr_stack+59048, dvrr_stack+77826, NULL, NULL, dvrr_stack+58982);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+34276, dvrr_stack+41873, dvrr_stack+30161, dvrr_stack+43156, dvrr_stack+59048, dvrr_stack+33022);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44476, dvrr_stack+42107, dvrr_stack+34276, dvrr_stack+43234, dvrr_stack+41873, dvrr_stack+33220);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+253114, dvrr_stack+9898, dvrr_stack+44476, dvrr_stack+60713, dvrr_stack+42107, dvrr_stack+33616);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+254284, dvrr_stack+159083, dvrr_stack+253114, dvrr_stack+63131, dvrr_stack+9898, dvrr_stack+239089);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+255922, dvrr_stack+160253, dvrr_stack+254284, dvrr_stack+63911, dvrr_stack+159083, dvrr_stack+240079);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+258106, dvrr_stack+161891, dvrr_stack+255922, dvrr_stack+65081, dvrr_stack+160253, dvrr_stack+241465);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+62773, dvrr_stack+164075, dvrr_stack+258106, dvrr_stack+68357, dvrr_stack+161891, dvrr_stack+243313);
 tmp = dvrr_stack + 62773;
 target_ptr = Libderiv->dvrr_classes[8][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+260914,dvrr_stack+62773,dvrr_stack+46511,45);


 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+43156, dvrr_stack+45664, dvrr_stack+76374, NULL, NULL, dvrr_stack+77826);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+57515, dvrr_stack+43156, dvrr_stack+59126, dvrr_stack+45664, dvrr_stack+30161);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+269824, dvrr_stack+57788, dvrr_stack+12106, dvrr_stack+59217, dvrr_stack+57515, dvrr_stack+34276);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+270734, dvrr_stack+59490, dvrr_stack+269824, dvrr_stack+79816, dvrr_stack+57788, dvrr_stack+44476);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+272099, dvrr_stack+174011, dvrr_stack+270734, dvrr_stack+82637, dvrr_stack+59490, dvrr_stack+253114);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+274010, dvrr_stack+175376, dvrr_stack+272099, dvrr_stack+83547, dvrr_stack+174011, dvrr_stack+254284);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+276558, dvrr_stack+177287, dvrr_stack+274010, dvrr_stack+84912, dvrr_stack+175376, dvrr_stack+255922);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+82637, dvrr_stack+179835, dvrr_stack+276558, dvrr_stack+88734, dvrr_stack+177287, dvrr_stack+258106);
 tmp = dvrr_stack + 82637;
 target_ptr = Libderiv->dvrr_classes[8][12];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+279834,dvrr_stack+82637,dvrr_stack+62773,45);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+86732, dvrr_stack+33019, dvrr_stack+0, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+86738, dvrr_stack+15, dvrr_stack+86732, dvrr_stack+77541, dvrr_stack+33019, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+86748, dvrr_stack+111, dvrr_stack+86738, dvrr_stack+77544, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+86763, dvrr_stack+76085, dvrr_stack+86748, dvrr_stack+77550, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+86784, dvrr_stack+76100, dvrr_stack+86763, dvrr_stack+77560, dvrr_stack+76085, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+59126, dvrr_stack+76121, dvrr_stack+86784, dvrr_stack+77575, dvrr_stack+76100, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+59162, dvrr_stack+76149, dvrr_stack+59126, dvrr_stack+77596, dvrr_stack+76121, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+76185, dvrr_stack+59162, dvrr_stack+77624, dvrr_stack+76149, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+59207, dvrr_stack+82582, dvrr_stack+264, dvrr_stack+77660, dvrr_stack+76185, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+98806, dvrr_stack+76230, dvrr_stack+59207, dvrr_stack+77705, dvrr_stack+82582, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+59273, dvrr_stack+76296, dvrr_stack+98806, dvrr_stack+77760, dvrr_stack+76230, NULL);

 /* compute (0 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+80467, dvrr_stack+76374, dvrr_stack+59273, dvrr_stack+77826, dvrr_stack+76296, NULL);

 /* compute (1 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+79719, dvrr_stack+76465, dvrr_stack+80467, NULL, NULL, dvrr_stack+76374);

 /* compute (2 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+60400, dvrr_stack+76570, dvrr_stack+79719, dvrr_stack+80362, dvrr_stack+76465, dvrr_stack+43156);

 /* compute (3 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+290364, dvrr_stack+76885, dvrr_stack+60400, dvrr_stack+77904, dvrr_stack+76570, dvrr_stack+12106);

 /* compute (4 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+291414, dvrr_stack+78219, dvrr_stack+290364, dvrr_stack+61783, dvrr_stack+76885, dvrr_stack+269824);

 /* compute (5 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+292989, dvrr_stack+191535, dvrr_stack+291414, dvrr_stack+80992, dvrr_stack+78219, dvrr_stack+270734);

 /* compute (6 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+295194, dvrr_stack+193110, dvrr_stack+292989, dvrr_stack+104134, dvrr_stack+191535, dvrr_stack+272099);

 /* compute (7 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+298134, dvrr_stack+195315, dvrr_stack+295194, dvrr_stack+105709, dvrr_stack+193110, dvrr_stack+274010);

 /* compute (8 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+301914, dvrr_stack+198255, dvrr_stack+298134, dvrr_stack+110119, dvrr_stack+195315, dvrr_stack+276558);

 /* compute (8 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+306639,dvrr_stack+301914,dvrr_stack+82637,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+104134, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+104137, dvrr_stack+107914, dvrr_stack+104134, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+104143, dvrr_stack+107917, dvrr_stack+104137, dvrr_stack+10690, dvrr_stack+107914, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+104153, dvrr_stack+210, dvrr_stack+161, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+104162, dvrr_stack+107923, dvrr_stack+104153, dvrr_stack+30, dvrr_stack+210, dvrr_stack+104134);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+30395, dvrr_stack+107932, dvrr_stack+104162, dvrr_stack+19243, dvrr_stack+107923, dvrr_stack+104137);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+104180, dvrr_stack+131, dvrr_stack+30395, dvrr_stack+98884, dvrr_stack+107932, dvrr_stack+104143);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+873, dvrr_stack+707, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+104225, dvrr_stack+107950, dvrr_stack+30, dvrr_stack+213, dvrr_stack+873, dvrr_stack+104153);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+104261, dvrr_stack+107968, dvrr_stack+104225, dvrr_stack+98902, dvrr_stack+107950, dvrr_stack+104162);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+104321, dvrr_stack+108004, dvrr_stack+104261, dvrr_stack+98920, dvrr_stack+107968, dvrr_stack+30395);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+59364, dvrr_stack+108064, dvrr_stack+104321, dvrr_stack+98956, dvrr_stack+108004, dvrr_stack+104180);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+98902, dvrr_stack+2698, dvrr_stack+121, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+104411, dvrr_stack+108154, dvrr_stack+98902, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+104471, dvrr_stack+108184, dvrr_stack+104411, dvrr_stack+479, dvrr_stack+108154, dvrr_stack+104225);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+104571, dvrr_stack+108244, dvrr_stack+104471, dvrr_stack+99016, dvrr_stack+108184, dvrr_stack+104261);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+104721, dvrr_stack+108344, dvrr_stack+104571, dvrr_stack+99076, dvrr_stack+108244, dvrr_stack+104321);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+104931, dvrr_stack+108494, dvrr_stack+104721, dvrr_stack+99176, dvrr_stack+108344, dvrr_stack+59364);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+99016, dvrr_stack+6127, dvrr_stack+5437, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+99061, dvrr_stack+219, dvrr_stack+99016, dvrr_stack+2708, dvrr_stack+6127, dvrr_stack+98902);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+105211, dvrr_stack+108704, dvrr_stack+99061, dvrr_stack+99326, dvrr_stack+219, dvrr_stack+104411);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+105361, dvrr_stack+108794, dvrr_stack+105211, dvrr_stack+99371, dvrr_stack+108704, dvrr_stack+104471);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+77904, dvrr_stack+108944, dvrr_stack+105361, dvrr_stack+99461, dvrr_stack+108794, dvrr_stack+104571);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+105586, dvrr_stack+109169, dvrr_stack+77904, dvrr_stack+99611, dvrr_stack+108944, dvrr_stack+104721);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+106006, dvrr_stack+109484, dvrr_stack+105586, dvrr_stack+101509, dvrr_stack+109169, dvrr_stack+104931);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+99326, dvrr_stack+5452, dvrr_stack+10724, NULL, NULL, dvrr_stack+5437);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+99389, dvrr_stack+889, dvrr_stack+99326, dvrr_stack+6142, dvrr_stack+5452, dvrr_stack+99016);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+99515, dvrr_stack+952, dvrr_stack+99389, dvrr_stack+614, dvrr_stack+889, dvrr_stack+99061);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+106546, dvrr_stack+109904, dvrr_stack+99515, dvrr_stack+1564, dvrr_stack+952, dvrr_stack+105211);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+106861, dvrr_stack+97834, dvrr_stack+106546, dvrr_stack+101824, dvrr_stack+109904, dvrr_stack+105361);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+107302, dvrr_stack+98149, dvrr_stack+106861, dvrr_stack+102034, dvrr_stack+97834, dvrr_stack+77904);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+80992, dvrr_stack+31647, dvrr_stack+107302, dvrr_stack+102349, dvrr_stack+98149, dvrr_stack+105586);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+101824, dvrr_stack+45755, dvrr_stack+80992, dvrr_stack+102790, dvrr_stack+31647, dvrr_stack+106006);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1564, dvrr_stack+10745, dvrr_stack+19298, NULL, NULL, dvrr_stack+10724);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+81748, dvrr_stack+2723, dvrr_stack+1564, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+99326);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+80034, dvrr_stack+2807, dvrr_stack+81748, dvrr_stack+99836, dvrr_stack+2723, dvrr_stack+99389);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+66283, dvrr_stack+2975, dvrr_stack+80034, dvrr_stack+103378, dvrr_stack+2807, dvrr_stack+99515);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+61731, dvrr_stack+58334, dvrr_stack+66283, dvrr_stack+1690, dvrr_stack+2975, dvrr_stack+106546);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+318924, dvrr_stack+99920, dvrr_stack+61731, dvrr_stack+80572, dvrr_stack+58334, dvrr_stack+106861);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+319708, dvrr_stack+100508, dvrr_stack+318924, dvrr_stack+103546, dvrr_stack+99920, dvrr_stack+107302);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+320716, dvrr_stack+43468, dvrr_stack+319708, dvrr_stack+32235, dvrr_stack+100508, dvrr_stack+80992);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+321976, dvrr_stack+6725, dvrr_stack+320716, dvrr_stack+120703, dvrr_stack+43468, dvrr_stack+101824);
 tmp = dvrr_stack + 321976;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32235, dvrr_stack+4370, dvrr_stack+30025, NULL, NULL, dvrr_stack+19298);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+23617, dvrr_stack+6163, dvrr_stack+32235, dvrr_stack+10773, dvrr_stack+4370, dvrr_stack+1564);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32343, dvrr_stack+98590, dvrr_stack+23617, dvrr_stack+21133, dvrr_stack+6163, dvrr_stack+81748);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103378, dvrr_stack+18883, dvrr_stack+32343, dvrr_stack+21241, dvrr_stack+98590, dvrr_stack+80034);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+323516, dvrr_stack+5501, dvrr_stack+103378, dvrr_stack+62413, dvrr_stack+18883, dvrr_stack+66283);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+324272, dvrr_stack+30425, dvrr_stack+323516, dvrr_stack+82042, dvrr_stack+5501, dvrr_stack+61731);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+325280, dvrr_stack+4406, dvrr_stack+324272, dvrr_stack+121711, dvrr_stack+30425, dvrr_stack+318924);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+326576, dvrr_stack+211863, dvrr_stack+325280, dvrr_stack+122467, dvrr_stack+4406, dvrr_stack+319708);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+328196, dvrr_stack+213159, dvrr_stack+326576, dvrr_stack+123475, dvrr_stack+211863, dvrr_stack+320716);
 tmp = dvrr_stack + 328196;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+330176,dvrr_stack+328196,dvrr_stack+321976,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+121711, dvrr_stack+30061, dvrr_stack+43045, NULL, NULL, dvrr_stack+30025);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+121846, dvrr_stack+3255, dvrr_stack+121711, dvrr_stack+19326, dvrr_stack+30061, dvrr_stack+32235);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+122116, dvrr_stack+42575, dvrr_stack+121846, dvrr_stack+21457, dvrr_stack+3255, dvrr_stack+23617);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+122566, dvrr_stack+79269, dvrr_stack+122116, dvrr_stack+18118, dvrr_stack+42575, dvrr_stack+32343);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+334796, dvrr_stack+10809, dvrr_stack+122566, dvrr_stack+6275, dvrr_stack+79269, dvrr_stack+103378);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+335741, dvrr_stack+20141, dvrr_stack+334796, dvrr_stack+127795, dvrr_stack+10809, dvrr_stack+323516);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+337001, dvrr_stack+12656, dvrr_stack+335741, dvrr_stack+128470, dvrr_stack+20141, dvrr_stack+324272);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+338621, dvrr_stack+218559, dvrr_stack+337001, dvrr_stack+129415, dvrr_stack+12656, dvrr_stack+325280);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127795, dvrr_stack+21592, dvrr_stack+338621, dvrr_stack+130675, dvrr_stack+218559, dvrr_stack+326576);
 tmp = dvrr_stack + 127795;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+340646,dvrr_stack+127795,dvrr_stack+328196,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+130270, dvrr_stack+12051, dvrr_stack+58927, NULL, NULL, dvrr_stack+43045);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+80572, dvrr_stack+11484, dvrr_stack+130270, dvrr_stack+30106, dvrr_stack+12051, dvrr_stack+121711);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+81916, dvrr_stack+11649, dvrr_stack+80572, dvrr_stack+18388, dvrr_stack+11484, dvrr_stack+121846);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+346586, dvrr_stack+61181, dvrr_stack+81916, dvrr_stack+18553, dvrr_stack+11649, dvrr_stack+122116);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+347411, dvrr_stack+225039, dvrr_stack+346586, dvrr_stack+19591, dvrr_stack+61181, dvrr_stack+122566);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+348566, dvrr_stack+225864, dvrr_stack+347411, dvrr_stack+136183, dvrr_stack+225039, dvrr_stack+334796);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+350106, dvrr_stack+227019, dvrr_stack+348566, dvrr_stack+137008, dvrr_stack+225864, dvrr_stack+335741);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+352086, dvrr_stack+228559, dvrr_stack+350106, dvrr_stack+138163, dvrr_stack+227019, dvrr_stack+337001);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+136183, dvrr_stack+230539, dvrr_stack+352086, dvrr_stack+139703, dvrr_stack+228559, dvrr_stack+338621);
 tmp = dvrr_stack + 136183;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+354561,dvrr_stack+136183,dvrr_stack+127795,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+139208, dvrr_stack+58982, dvrr_stack+77760, NULL, NULL, dvrr_stack+58927);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+33022, dvrr_stack+139208, dvrr_stack+43090, dvrr_stack+58982, dvrr_stack+130270);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19326, dvrr_stack+33220, dvrr_stack+18118, dvrr_stack+29062, dvrr_stack+33022, dvrr_stack+80572);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+361986, dvrr_stack+33616, dvrr_stack+19326, dvrr_stack+41477, dvrr_stack+33220, dvrr_stack+81916);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+362976, dvrr_stack+239089, dvrr_stack+361986, dvrr_stack+29260, dvrr_stack+33616, dvrr_stack+346586);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+364362, dvrr_stack+240079, dvrr_stack+362976, dvrr_stack+146543, dvrr_stack+239089, dvrr_stack+347411);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+366210, dvrr_stack+241465, dvrr_stack+364362, dvrr_stack+147533, dvrr_stack+240079, dvrr_stack+348566);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368586, dvrr_stack+243313, dvrr_stack+366210, dvrr_stack+148919, dvrr_stack+241465, dvrr_stack+350106);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+146543, dvrr_stack+46511, dvrr_stack+368586, dvrr_stack+150767, dvrr_stack+243313, dvrr_stack+352086);
 tmp = dvrr_stack + 146543;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+371556,dvrr_stack+146543,dvrr_stack+136183,55);


 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+123241, dvrr_stack+77826, dvrr_stack+76296, NULL, NULL, dvrr_stack+77760);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+150173, dvrr_stack+30161, dvrr_stack+123241, dvrr_stack+59048, dvrr_stack+77826, dvrr_stack+139208);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+34276, dvrr_stack+150173, dvrr_stack+41873, dvrr_stack+30161, dvrr_stack+18118);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+380631, dvrr_stack+44476, dvrr_stack+29062, dvrr_stack+42107, dvrr_stack+34276, dvrr_stack+19326);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+381801, dvrr_stack+253114, dvrr_stack+380631, dvrr_stack+9898, dvrr_stack+44476, dvrr_stack+361986);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+383439, dvrr_stack+254284, dvrr_stack+381801, dvrr_stack+159083, dvrr_stack+253114, dvrr_stack+362976);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+385623, dvrr_stack+255922, dvrr_stack+383439, dvrr_stack+160253, dvrr_stack+254284, dvrr_stack+364362);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+388431, dvrr_stack+258106, dvrr_stack+385623, dvrr_stack+161891, dvrr_stack+255922, dvrr_stack+366210);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+159083, dvrr_stack+62773, dvrr_stack+388431, dvrr_stack+164075, dvrr_stack+258106, dvrr_stack+368586);
 tmp = dvrr_stack + 159083;
 target_ptr = Libderiv->dvrr_classes[9][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+391941,dvrr_stack+159083,dvrr_stack+146543,55);


 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+163373, dvrr_stack+76374, dvrr_stack+59273, NULL, NULL, dvrr_stack+76296);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+43156, dvrr_stack+163373, dvrr_stack+45664, dvrr_stack+76374, dvrr_stack+123241);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+41477, dvrr_stack+12106, dvrr_stack+9898, dvrr_stack+57515, dvrr_stack+43156, dvrr_stack+150173);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+402831, dvrr_stack+269824, dvrr_stack+41477, dvrr_stack+57788, dvrr_stack+12106, dvrr_stack+29062);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+404196, dvrr_stack+270734, dvrr_stack+402831, dvrr_stack+59490, dvrr_stack+269824, dvrr_stack+380631);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+406107, dvrr_stack+272099, dvrr_stack+404196, dvrr_stack+174011, dvrr_stack+270734, dvrr_stack+381801);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+408655, dvrr_stack+274010, dvrr_stack+406107, dvrr_stack+175376, dvrr_stack+272099, dvrr_stack+383439);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+411931, dvrr_stack+276558, dvrr_stack+408655, dvrr_stack+177287, dvrr_stack+274010, dvrr_stack+385623);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+174011, dvrr_stack+82637, dvrr_stack+411931, dvrr_stack+179835, dvrr_stack+276558, dvrr_stack+388431);
 tmp = dvrr_stack + 174011;
 target_ptr = Libderiv->dvrr_classes[9][12];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+416026,dvrr_stack+174011,dvrr_stack+159083,55);


 /* compute (0 0 | 1 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+179016, Data->F+21, Data->F+22, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+179016, Data->F+20, Data->F+21, NULL);

 /* compute (0 0 | 3 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+879, dvrr_stack+86732, dvrr_stack+213, dvrr_stack+33019, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2708, dvrr_stack+86738, dvrr_stack+879, dvrr_stack+15, dvrr_stack+86732, NULL);

 /* compute (0 0 | 5 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+102769, dvrr_stack+86748, dvrr_stack+2708, dvrr_stack+111, dvrr_stack+86738, NULL);

 /* compute (0 0 | 6 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+5473, dvrr_stack+86763, dvrr_stack+102769, dvrr_stack+76085, dvrr_stack+86748, NULL);

 /* compute (0 0 | 7 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10773, dvrr_stack+86784, dvrr_stack+5473, dvrr_stack+76100, dvrr_stack+86763, NULL);

 /* compute (0 0 | 8 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+179019, dvrr_stack+59126, dvrr_stack+10773, dvrr_stack+76121, dvrr_stack+86784, NULL);

 /* compute (0 0 | 9 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30106, dvrr_stack+59162, dvrr_stack+179019, dvrr_stack+76149, dvrr_stack+59126, NULL);

 /* compute (0 0 | 10 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+43090, dvrr_stack+264, dvrr_stack+30106, dvrr_stack+76185, dvrr_stack+59162, NULL);

 /* compute (0 0 | 11 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59048, dvrr_stack+59207, dvrr_stack+43090, dvrr_stack+82582, dvrr_stack+264, NULL);

 /* compute (0 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76085, dvrr_stack+98806, dvrr_stack+59048, dvrr_stack+76230, dvrr_stack+59207, NULL);

 /* compute (0 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+179064, dvrr_stack+59273, dvrr_stack+76085, dvrr_stack+76296, dvrr_stack+98806, NULL);

 /* compute (1 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+179169, dvrr_stack+80467, dvrr_stack+179064, NULL, NULL, dvrr_stack+59273);

 /* compute (2 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+59490, dvrr_stack+79719, dvrr_stack+179169, dvrr_stack+76465, dvrr_stack+80467, dvrr_stack+163373);

 /* compute (3 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+428896, dvrr_stack+60400, dvrr_stack+59490, dvrr_stack+76570, dvrr_stack+79719, dvrr_stack+9898);

 /* compute (4 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+429946, dvrr_stack+290364, dvrr_stack+428896, dvrr_stack+76885, dvrr_stack+60400, dvrr_stack+41477);

 /* compute (5 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+431521, dvrr_stack+291414, dvrr_stack+429946, dvrr_stack+78219, dvrr_stack+290364, dvrr_stack+402831);

 /* compute (6 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+433726, dvrr_stack+292989, dvrr_stack+431521, dvrr_stack+191535, dvrr_stack+291414, dvrr_stack+404196);

 /* compute (7 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+436666, dvrr_stack+295194, dvrr_stack+433726, dvrr_stack+193110, dvrr_stack+292989, dvrr_stack+406107);

 /* compute (8 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+440446, dvrr_stack+298134, dvrr_stack+436666, dvrr_stack+195315, dvrr_stack+295194, dvrr_stack+408655);

 /* compute (9 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+191535, dvrr_stack+301914, dvrr_stack+440446, dvrr_stack+198255, dvrr_stack+298134, dvrr_stack+411931);

 /* compute (9 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+445171,dvrr_stack+191535,dvrr_stack+174011,55);


 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+197310, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+15, dvrr_stack+104134, dvrr_stack+197310, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+111, dvrr_stack+104137, dvrr_stack+15, dvrr_stack+107914, dvrr_stack+104134, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+197313, dvrr_stack+104143, dvrr_stack+111, dvrr_stack+107917, dvrr_stack+104137, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+76176, dvrr_stack+161, dvrr_stack+704, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+197328, dvrr_stack+104153, dvrr_stack+76176, dvrr_stack+210, dvrr_stack+161, dvrr_stack+197310);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+197346, dvrr_stack+104162, dvrr_stack+197328, dvrr_stack+107923, dvrr_stack+104153, dvrr_stack+15);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+197376, dvrr_stack+30395, dvrr_stack+197346, dvrr_stack+107932, dvrr_stack+104162, dvrr_stack+111);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+197421, dvrr_stack+104180, dvrr_stack+197376, dvrr_stack+131, dvrr_stack+30395, dvrr_stack+197313);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+107923, dvrr_stack+707, dvrr_stack+6121, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+197484, dvrr_stack+30, dvrr_stack+107923, dvrr_stack+873, dvrr_stack+707, dvrr_stack+76176);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+197520, dvrr_stack+104225, dvrr_stack+197484, dvrr_stack+107950, dvrr_stack+30, dvrr_stack+197328);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+80902, dvrr_stack+104261, dvrr_stack+197520, dvrr_stack+107968, dvrr_stack+104225, dvrr_stack+197346);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+150641, dvrr_stack+104321, dvrr_stack+80902, dvrr_stack+108004, dvrr_stack+104261, dvrr_stack+197376);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+197580, dvrr_stack+59364, dvrr_stack+150641, dvrr_stack+108064, dvrr_stack+104321, dvrr_stack+197421);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+107941, dvrr_stack+121, dvrr_stack+5427, NULL, NULL, dvrr_stack+6121);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+107971, dvrr_stack+98902, dvrr_stack+107941, dvrr_stack+2698, dvrr_stack+121, dvrr_stack+107923);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+197748, dvrr_stack+104411, dvrr_stack+107971, dvrr_stack+108154, dvrr_stack+98902, dvrr_stack+197484);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+197848, dvrr_stack+104471, dvrr_stack+197748, dvrr_stack+108184, dvrr_stack+104411, dvrr_stack+197520);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+197998, dvrr_stack+104571, dvrr_stack+197848, dvrr_stack+108244, dvrr_stack+104471, dvrr_stack+80902);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+60120, dvrr_stack+104721, dvrr_stack+197998, dvrr_stack+108344, dvrr_stack+104571, dvrr_stack+150641);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+78219, dvrr_stack+104931, dvrr_stack+60120, dvrr_stack+108494, dvrr_stack+104721, dvrr_stack+197580);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+108154, dvrr_stack+5437, dvrr_stack+10709, NULL, NULL, dvrr_stack+5427);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+99016, dvrr_stack+108154, dvrr_stack+6127, dvrr_stack+5437, dvrr_stack+107941);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+108199, dvrr_stack+99061, dvrr_stack+614, dvrr_stack+219, dvrr_stack+99016, dvrr_stack+107971);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+78579, dvrr_stack+105211, dvrr_stack+108199, dvrr_stack+108704, dvrr_stack+99061, dvrr_stack+197748);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+460186, dvrr_stack+105361, dvrr_stack+78579, dvrr_stack+108794, dvrr_stack+105211, dvrr_stack+197848);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+78804, dvrr_stack+77904, dvrr_stack+460186, dvrr_stack+108944, dvrr_stack+105361, dvrr_stack+197998);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+76465, dvrr_stack+105586, dvrr_stack+78804, dvrr_stack+109169, dvrr_stack+77904, dvrr_stack+60120);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+108704, dvrr_stack+106006, dvrr_stack+76465, dvrr_stack+109484, dvrr_stack+105586, dvrr_stack+78219);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+109379, dvrr_stack+10724, dvrr_stack+19277, NULL, NULL, dvrr_stack+10709);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+108349, dvrr_stack+99326, dvrr_stack+109379, dvrr_stack+5452, dvrr_stack+10724, dvrr_stack+108154);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+77005, dvrr_stack+99389, dvrr_stack+108349, dvrr_stack+889, dvrr_stack+99326, dvrr_stack+614);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+77215, dvrr_stack+99515, dvrr_stack+77005, dvrr_stack+952, dvrr_stack+99389, dvrr_stack+108199);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+57515, dvrr_stack+106546, dvrr_stack+77215, dvrr_stack+109904, dvrr_stack+99515, dvrr_stack+78579);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+460501, dvrr_stack+106861, dvrr_stack+57515, dvrr_stack+97834, dvrr_stack+106546, dvrr_stack+460186);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+461089, dvrr_stack+107302, dvrr_stack+460501, dvrr_stack+98149, dvrr_stack+106861, dvrr_stack+78804);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+461845, dvrr_stack+80992, dvrr_stack+461089, dvrr_stack+31647, dvrr_stack+107302, dvrr_stack+76465);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+462790, dvrr_stack+101824, dvrr_stack+461845, dvrr_stack+45755, dvrr_stack+80992, dvrr_stack+108704);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+97834, dvrr_stack+19298, dvrr_stack+29997, NULL, NULL, dvrr_stack+19277);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+97918, dvrr_stack+1564, dvrr_stack+97834, dvrr_stack+10745, dvrr_stack+19298, dvrr_stack+109379);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+98086, dvrr_stack+81748, dvrr_stack+97918, dvrr_stack+2723, dvrr_stack+1564, dvrr_stack+108349);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+163646, dvrr_stack+80034, dvrr_stack+98086, dvrr_stack+2807, dvrr_stack+81748, dvrr_stack+77005);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+31181, dvrr_stack+66283, dvrr_stack+163646, dvrr_stack+2975, dvrr_stack+80034, dvrr_stack+77215);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+463945, dvrr_stack+61731, dvrr_stack+31181, dvrr_stack+58334, dvrr_stack+66283, dvrr_stack+57515);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+464729, dvrr_stack+318924, dvrr_stack+463945, dvrr_stack+99920, dvrr_stack+61731, dvrr_stack+460501);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+465737, dvrr_stack+319708, dvrr_stack+464729, dvrr_stack+100508, dvrr_stack+318924, dvrr_stack+461089);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+99725, dvrr_stack+320716, dvrr_stack+465737, dvrr_stack+43468, dvrr_stack+319708, dvrr_stack+461845);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+466997, dvrr_stack+321976, dvrr_stack+99725, dvrr_stack+6725, dvrr_stack+320716, dvrr_stack+462790);
 tmp = dvrr_stack + 466997;
 target_ptr = Libderiv->dvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2723, dvrr_stack+30025, dvrr_stack+43009, NULL, NULL, dvrr_stack+29997);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103918, dvrr_stack+32235, dvrr_stack+2723, dvrr_stack+4370, dvrr_stack+30025, dvrr_stack+97834);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2831, dvrr_stack+23617, dvrr_stack+103918, dvrr_stack+6163, dvrr_stack+32235, dvrr_stack+97918);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6127, dvrr_stack+32343, dvrr_stack+2831, dvrr_stack+98590, dvrr_stack+23617, dvrr_stack+98086);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+57956, dvrr_stack+103378, dvrr_stack+6127, dvrr_stack+18883, dvrr_stack+32343, dvrr_stack+163646);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43429, dvrr_stack+323516, dvrr_stack+57956, dvrr_stack+5501, dvrr_stack+103378, dvrr_stack+31181);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+468845, dvrr_stack+324272, dvrr_stack+43429, dvrr_stack+30425, dvrr_stack+323516, dvrr_stack+463945);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+470141, dvrr_stack+325280, dvrr_stack+468845, dvrr_stack+4406, dvrr_stack+324272, dvrr_stack+464729);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+471761, dvrr_stack+326576, dvrr_stack+470141, dvrr_stack+211863, dvrr_stack+325280, dvrr_stack+465737);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+473741, dvrr_stack+328196, dvrr_stack+471761, dvrr_stack+213159, dvrr_stack+326576, dvrr_stack+99725);
 tmp = dvrr_stack + 473741;
 target_ptr = Libderiv->dvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+476117,dvrr_stack+473741,dvrr_stack+466997,66);


 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+211863, dvrr_stack+43045, dvrr_stack+58882, NULL, NULL, dvrr_stack+43009);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+211998, dvrr_stack+121711, dvrr_stack+211863, dvrr_stack+30061, dvrr_stack+43045, dvrr_stack+2723);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+212268, dvrr_stack+121846, dvrr_stack+211998, dvrr_stack+3255, dvrr_stack+121711, dvrr_stack+103918);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30425, dvrr_stack+122116, dvrr_stack+212268, dvrr_stack+42575, dvrr_stack+121846, dvrr_stack+2831);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4214, dvrr_stack+122566, dvrr_stack+30425, dvrr_stack+79269, dvrr_stack+122116, dvrr_stack+6127);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+481661, dvrr_stack+334796, dvrr_stack+4214, dvrr_stack+10809, dvrr_stack+122566, dvrr_stack+57956);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+482921, dvrr_stack+335741, dvrr_stack+481661, dvrr_stack+20141, dvrr_stack+334796, dvrr_stack+43429);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+484541, dvrr_stack+337001, dvrr_stack+482921, dvrr_stack+12656, dvrr_stack+335741, dvrr_stack+468845);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+486566, dvrr_stack+338621, dvrr_stack+484541, dvrr_stack+218559, dvrr_stack+337001, dvrr_stack+470141);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+489041, dvrr_stack+127795, dvrr_stack+486566, dvrr_stack+21592, dvrr_stack+338621, dvrr_stack+471761);
 tmp = dvrr_stack + 489041;
 target_ptr = Libderiv->dvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+492011,dvrr_stack+489041,dvrr_stack+473741,66);


 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+218559, dvrr_stack+58927, dvrr_stack+77705, NULL, NULL, dvrr_stack+58882);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+218724, dvrr_stack+130270, dvrr_stack+218559, dvrr_stack+12051, dvrr_stack+58927, dvrr_stack+211863);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+219054, dvrr_stack+80572, dvrr_stack+218724, dvrr_stack+11484, dvrr_stack+130270, dvrr_stack+211998);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10809, dvrr_stack+81916, dvrr_stack+219054, dvrr_stack+11649, dvrr_stack+80572, dvrr_stack+212268);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19986, dvrr_stack+346586, dvrr_stack+10809, dvrr_stack+61181, dvrr_stack+81916, dvrr_stack+30425);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+499139, dvrr_stack+347411, dvrr_stack+19986, dvrr_stack+225039, dvrr_stack+346586, dvrr_stack+4214);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+500679, dvrr_stack+348566, dvrr_stack+499139, dvrr_stack+225864, dvrr_stack+347411, dvrr_stack+481661);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+502659, dvrr_stack+350106, dvrr_stack+500679, dvrr_stack+227019, dvrr_stack+348566, dvrr_stack+482921);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+225039, dvrr_stack+352086, dvrr_stack+502659, dvrr_stack+228559, dvrr_stack+350106, dvrr_stack+484541);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+505134, dvrr_stack+136183, dvrr_stack+225039, dvrr_stack+230539, dvrr_stack+352086, dvrr_stack+486566);
 tmp = dvrr_stack + 505134;
 target_ptr = Libderiv->dvrr_classes[10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+508764,dvrr_stack+505134,dvrr_stack+489041,66);


 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+228064, dvrr_stack+77760, dvrr_stack+76230, NULL, NULL, dvrr_stack+77705);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+228262, dvrr_stack+139208, dvrr_stack+228064, dvrr_stack+58982, dvrr_stack+77760, dvrr_stack+218559);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+228658, dvrr_stack+18118, dvrr_stack+228262, dvrr_stack+33022, dvrr_stack+139208, dvrr_stack+218724);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+229318, dvrr_stack+19326, dvrr_stack+228658, dvrr_stack+33220, dvrr_stack+18118, dvrr_stack+219054);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+517674, dvrr_stack+361986, dvrr_stack+229318, dvrr_stack+33616, dvrr_stack+19326, dvrr_stack+10809);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+519060, dvrr_stack+362976, dvrr_stack+517674, dvrr_stack+239089, dvrr_stack+361986, dvrr_stack+19986);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+520908, dvrr_stack+364362, dvrr_stack+519060, dvrr_stack+240079, dvrr_stack+362976, dvrr_stack+499139);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+523284, dvrr_stack+366210, dvrr_stack+520908, dvrr_stack+241465, dvrr_stack+364362, dvrr_stack+500679);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+239089, dvrr_stack+368586, dvrr_stack+523284, dvrr_stack+243313, dvrr_stack+366210, dvrr_stack+502659);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+526254, dvrr_stack+146543, dvrr_stack+239089, dvrr_stack+46511, dvrr_stack+368586, dvrr_stack+225039);
 tmp = dvrr_stack + 526254;
 target_ptr = Libderiv->dvrr_classes[10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+530610,dvrr_stack+526254,dvrr_stack+505134,66);


 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+242719, dvrr_stack+76296, dvrr_stack+98806, NULL, NULL, dvrr_stack+76230);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+242953, dvrr_stack+123241, dvrr_stack+242719, dvrr_stack+77826, dvrr_stack+76296, dvrr_stack+228064);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+243421, dvrr_stack+150173, dvrr_stack+242953, dvrr_stack+30161, dvrr_stack+123241, dvrr_stack+228262);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+244201, dvrr_stack+29062, dvrr_stack+243421, dvrr_stack+34276, dvrr_stack+150173, dvrr_stack+228658);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32703, dvrr_stack+380631, dvrr_stack+244201, dvrr_stack+44476, dvrr_stack+29062, dvrr_stack+229318);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+541500, dvrr_stack+381801, dvrr_stack+32703, dvrr_stack+253114, dvrr_stack+380631, dvrr_stack+517674);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+543684, dvrr_stack+383439, dvrr_stack+541500, dvrr_stack+254284, dvrr_stack+381801, dvrr_stack+519060);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+546492, dvrr_stack+385623, dvrr_stack+543684, dvrr_stack+255922, dvrr_stack+383439, dvrr_stack+520908);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+253114, dvrr_stack+388431, dvrr_stack+546492, dvrr_stack+258106, dvrr_stack+385623, dvrr_stack+523284);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+550002, dvrr_stack+159083, dvrr_stack+253114, dvrr_stack+62773, dvrr_stack+388431, dvrr_stack+239089);
 tmp = dvrr_stack + 550002;
 target_ptr = Libderiv->dvrr_classes[10][11];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+555150,dvrr_stack+550002,dvrr_stack+526254,66);


 /* compute (1 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+257404, dvrr_stack+59273, dvrr_stack+76085, NULL, NULL, dvrr_stack+98806);

 /* compute (2 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+257677, dvrr_stack+163373, dvrr_stack+257404, dvrr_stack+76374, dvrr_stack+59273, dvrr_stack+242719);

 /* compute (3 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+258223, dvrr_stack+9898, dvrr_stack+257677, dvrr_stack+43156, dvrr_stack+163373, dvrr_stack+242953);

 /* compute (4 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+259133, dvrr_stack+41477, dvrr_stack+258223, dvrr_stack+12106, dvrr_stack+9898, dvrr_stack+243421);

 /* compute (5 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+11634, dvrr_stack+402831, dvrr_stack+259133, dvrr_stack+269824, dvrr_stack+41477, dvrr_stack+244201);

 /* compute (6 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+568218, dvrr_stack+404196, dvrr_stack+11634, dvrr_stack+270734, dvrr_stack+402831, dvrr_stack+32703);

 /* compute (7 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+570766, dvrr_stack+406107, dvrr_stack+568218, dvrr_stack+272099, dvrr_stack+404196, dvrr_stack+541500);

 /* compute (8 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+269824, dvrr_stack+408655, dvrr_stack+570766, dvrr_stack+274010, dvrr_stack+406107, dvrr_stack+543684);

 /* compute (9 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+574042, dvrr_stack+411931, dvrr_stack+269824, dvrr_stack+276558, dvrr_stack+408655, dvrr_stack+546492);

 /* compute (10 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+579047, dvrr_stack+174011, dvrr_stack+574042, dvrr_stack+82637, dvrr_stack+411931, dvrr_stack+253114);
 tmp = dvrr_stack + 579047;
 target_ptr = Libderiv->dvrr_classes[10][12];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+585053,dvrr_stack+579047,dvrr_stack+550002,66);


 /* compute (0 0 | 1 0) m=22 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+22, Data->F+23, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+873, dvrr_stack+179016, dvrr_stack+210, Data->F+21, Data->F+22, NULL);

 /* compute (0 0 | 3 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2698, dvrr_stack+213, dvrr_stack+873, dvrr_stack+0, dvrr_stack+179016, NULL);

 /* compute (0 0 | 4 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+273919, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+86732, dvrr_stack+213, NULL);

 /* compute (0 0 | 5 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5452, dvrr_stack+2708, dvrr_stack+273919, dvrr_stack+86738, dvrr_stack+879, NULL);

 /* compute (0 0 | 6 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10745, dvrr_stack+102769, dvrr_stack+5452, dvrr_stack+86748, dvrr_stack+2708, NULL);

 /* compute (0 0 | 7 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+273934, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+86763, dvrr_stack+102769, NULL);

 /* compute (0 0 | 8 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30061, dvrr_stack+10773, dvrr_stack+273934, dvrr_stack+86784, dvrr_stack+5473, NULL);

 /* compute (0 0 | 9 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+86732, dvrr_stack+179019, dvrr_stack+30061, dvrr_stack+59126, dvrr_stack+10773, NULL);

 /* compute (0 0 | 10 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+58982, dvrr_stack+30106, dvrr_stack+86732, dvrr_stack+59162, dvrr_stack+179019, NULL);

 /* compute (0 0 | 11 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+77826, dvrr_stack+43090, dvrr_stack+58982, dvrr_stack+264, dvrr_stack+30106, NULL);

 /* compute (0 0 | 12 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76374, dvrr_stack+59048, dvrr_stack+77826, dvrr_stack+59207, dvrr_stack+43090, NULL);

 /* compute (0 0 | 13 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+273970, dvrr_stack+76085, dvrr_stack+76374, dvrr_stack+98806, dvrr_stack+59048, NULL);

 /* compute (1 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+274075, dvrr_stack+179064, dvrr_stack+273970, NULL, NULL, dvrr_stack+76085);

 /* compute (2 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+274390, dvrr_stack+179169, dvrr_stack+274075, dvrr_stack+80467, dvrr_stack+179064, dvrr_stack+257404);

 /* compute (3 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+275020, dvrr_stack+59490, dvrr_stack+274390, dvrr_stack+79719, dvrr_stack+179169, dvrr_stack+257677);

 /* compute (4 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+276070, dvrr_stack+428896, dvrr_stack+275020, dvrr_stack+60400, dvrr_stack+59490, dvrr_stack+258223);

 /* compute (5 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+600497, dvrr_stack+429946, dvrr_stack+276070, dvrr_stack+290364, dvrr_stack+428896, dvrr_stack+259133);

 /* compute (6 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+602702, dvrr_stack+431521, dvrr_stack+600497, dvrr_stack+291414, dvrr_stack+429946, dvrr_stack+11634);

 /* compute (7 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+605642, dvrr_stack+433726, dvrr_stack+602702, dvrr_stack+292989, dvrr_stack+431521, dvrr_stack+568218);

 /* compute (8 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+290364, dvrr_stack+436666, dvrr_stack+605642, dvrr_stack+295194, dvrr_stack+433726, dvrr_stack+570766);

 /* compute (9 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+609422, dvrr_stack+440446, dvrr_stack+290364, dvrr_stack+298134, dvrr_stack+436666, dvrr_stack+269824);

 /* compute (10 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+615197, dvrr_stack+191535, dvrr_stack+609422, dvrr_stack+301914, dvrr_stack+440446, dvrr_stack+574042);

 /* compute (10 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+622127,dvrr_stack+615197,dvrr_stack+579047,66);


 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+295089, dvrr_stack+197310, dvrr_stack+0, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+295095, dvrr_stack+15, dvrr_stack+295089, dvrr_stack+104134, dvrr_stack+197310, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+295105, dvrr_stack+111, dvrr_stack+295095, dvrr_stack+104137, dvrr_stack+15, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+295120, dvrr_stack+197313, dvrr_stack+295105, dvrr_stack+104143, dvrr_stack+111, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+104134, dvrr_stack+704, dvrr_stack+6118, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+295141, dvrr_stack+76176, dvrr_stack+104134, dvrr_stack+161, dvrr_stack+704, dvrr_stack+0);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+295159, dvrr_stack+197328, dvrr_stack+295141, dvrr_stack+104153, dvrr_stack+76176, dvrr_stack+295089);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+219, dvrr_stack+197346, dvrr_stack+295159, dvrr_stack+104162, dvrr_stack+197328, dvrr_stack+295095);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+295189, dvrr_stack+197376, dvrr_stack+219, dvrr_stack+30395, dvrr_stack+197346, dvrr_stack+295105);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+295252, dvrr_stack+197421, dvrr_stack+295189, dvrr_stack+104180, dvrr_stack+197376, dvrr_stack+295120);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+104153, dvrr_stack+6121, dvrr_stack+5421, NULL, NULL, dvrr_stack+6118);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+86787, dvrr_stack+107923, dvrr_stack+104153, dvrr_stack+707, dvrr_stack+6121, dvrr_stack+104134);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+295336, dvrr_stack+197484, dvrr_stack+86787, dvrr_stack+30, dvrr_stack+107923, dvrr_stack+295141);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+295396, dvrr_stack+197520, dvrr_stack+295336, dvrr_stack+104225, dvrr_stack+197484, dvrr_stack+295159);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+295486, dvrr_stack+80902, dvrr_stack+295396, dvrr_stack+104261, dvrr_stack+197520, dvrr_stack+219);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+295612, dvrr_stack+150641, dvrr_stack+295486, dvrr_stack+104321, dvrr_stack+80902, dvrr_stack+295189);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+295780, dvrr_stack+197580, dvrr_stack+295612, dvrr_stack+59364, dvrr_stack+150641, dvrr_stack+295252);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+104225, dvrr_stack+5427, dvrr_stack+10699, NULL, NULL, dvrr_stack+5421);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+104255, dvrr_stack+107941, dvrr_stack+104225, dvrr_stack+121, dvrr_stack+5427, dvrr_stack+104153);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+295996, dvrr_stack+107971, dvrr_stack+104255, dvrr_stack+98902, dvrr_stack+107941, dvrr_stack+86787);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+296096, dvrr_stack+197748, dvrr_stack+295996, dvrr_stack+104411, dvrr_stack+107971, dvrr_stack+295336);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+296246, dvrr_stack+197848, dvrr_stack+296096, dvrr_stack+104471, dvrr_stack+197748, dvrr_stack+295396);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+296456, dvrr_stack+197998, dvrr_stack+296246, dvrr_stack+104571, dvrr_stack+197848, dvrr_stack+295486);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+104315, dvrr_stack+60120, dvrr_stack+296456, dvrr_stack+104721, dvrr_stack+197998, dvrr_stack+295612);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+296736, dvrr_stack+78219, dvrr_stack+104315, dvrr_stack+104931, dvrr_stack+60120, dvrr_stack+295780);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+98902, dvrr_stack+10709, dvrr_stack+19262, NULL, NULL, dvrr_stack+10699);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+104675, dvrr_stack+108154, dvrr_stack+98902, dvrr_stack+5437, dvrr_stack+10709, dvrr_stack+104225);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+104765, dvrr_stack+614, dvrr_stack+104675, dvrr_stack+99016, dvrr_stack+108154, dvrr_stack+104255);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+297186, dvrr_stack+108199, dvrr_stack+104765, dvrr_stack+99061, dvrr_stack+614, dvrr_stack+295996);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+297411, dvrr_stack+78579, dvrr_stack+297186, dvrr_stack+105211, dvrr_stack+108199, dvrr_stack+296096);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+297726, dvrr_stack+460186, dvrr_stack+297411, dvrr_stack+105361, dvrr_stack+78579, dvrr_stack+296246);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+298146, dvrr_stack+78804, dvrr_stack+297726, dvrr_stack+77904, dvrr_stack+460186, dvrr_stack+296456);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+298686, dvrr_stack+76465, dvrr_stack+298146, dvrr_stack+105586, dvrr_stack+78804, dvrr_stack+104315);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+299361, dvrr_stack+108704, dvrr_stack+298686, dvrr_stack+106006, dvrr_stack+76465, dvrr_stack+296736);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+77904, dvrr_stack+19277, dvrr_stack+29976, NULL, NULL, dvrr_stack+19262);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+77967, dvrr_stack+109379, dvrr_stack+77904, dvrr_stack+10724, dvrr_stack+19277, dvrr_stack+98902);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+105211, dvrr_stack+108349, dvrr_stack+77967, dvrr_stack+99326, dvrr_stack+109379, dvrr_stack+104675);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+105421, dvrr_stack+77005, dvrr_stack+105211, dvrr_stack+99389, dvrr_stack+108349, dvrr_stack+104765);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+212718, dvrr_stack+77215, dvrr_stack+105421, dvrr_stack+99515, dvrr_stack+77005, dvrr_stack+297186);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+300186, dvrr_stack+57515, dvrr_stack+212718, dvrr_stack+106546, dvrr_stack+77215, dvrr_stack+297411);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+300774, dvrr_stack+460501, dvrr_stack+300186, dvrr_stack+106861, dvrr_stack+57515, dvrr_stack+297726);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+60400, dvrr_stack+461089, dvrr_stack+300774, dvrr_stack+107302, dvrr_stack+460501, dvrr_stack+298146);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+106546, dvrr_stack+461845, dvrr_stack+60400, dvrr_stack+80992, dvrr_stack+461089, dvrr_stack+298686);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+277645, dvrr_stack+462790, dvrr_stack+106546, dvrr_stack+101824, dvrr_stack+461845, dvrr_stack+299361);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+80992, dvrr_stack+29997, dvrr_stack+42981, NULL, NULL, dvrr_stack+29976);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+81076, dvrr_stack+97834, dvrr_stack+80992, dvrr_stack+19298, dvrr_stack+29997, dvrr_stack+77904);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+81244, dvrr_stack+97918, dvrr_stack+81076, dvrr_stack+1564, dvrr_stack+97834, dvrr_stack+77967);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+1564, dvrr_stack+98086, dvrr_stack+81244, dvrr_stack+81748, dvrr_stack+97918, dvrr_stack+105211);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+279031, dvrr_stack+163646, dvrr_stack+1564, dvrr_stack+80034, dvrr_stack+98086, dvrr_stack+105421);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+79224, dvrr_stack+31181, dvrr_stack+279031, dvrr_stack+66283, dvrr_stack+163646, dvrr_stack+212718);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+44437, dvrr_stack+463945, dvrr_stack+79224, dvrr_stack+61731, dvrr_stack+31181, dvrr_stack+300186);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+61345, dvrr_stack+464729, dvrr_stack+44437, dvrr_stack+318924, dvrr_stack+463945, dvrr_stack+300774);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+640145, dvrr_stack+465737, dvrr_stack+61345, dvrr_stack+319708, dvrr_stack+464729, dvrr_stack+60400);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+641685, dvrr_stack+99725, dvrr_stack+640145, dvrr_stack+320716, dvrr_stack+465737, dvrr_stack+106546);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+318924, dvrr_stack+466997, dvrr_stack+641685, dvrr_stack+321976, dvrr_stack+99725, dvrr_stack+277645);
 tmp = dvrr_stack + 318924;
 target_ptr = Libderiv->dvrr_classes[11][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+321108, dvrr_stack+43009, dvrr_stack+58846, NULL, NULL, dvrr_stack+42981);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+107701, dvrr_stack+2723, dvrr_stack+321108, dvrr_stack+30025, dvrr_stack+43009, dvrr_stack+80992);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+321216, dvrr_stack+103918, dvrr_stack+107701, dvrr_stack+32235, dvrr_stack+2723, dvrr_stack+81076);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+219604, dvrr_stack+2831, dvrr_stack+321216, dvrr_stack+23617, dvrr_stack+103918, dvrr_stack+81244);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+643533, dvrr_stack+6127, dvrr_stack+219604, dvrr_stack+32343, dvrr_stack+2831, dvrr_stack+1564);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+644289, dvrr_stack+57956, dvrr_stack+643533, dvrr_stack+103378, dvrr_stack+6127, dvrr_stack+279031);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+645297, dvrr_stack+43429, dvrr_stack+644289, dvrr_stack+323516, dvrr_stack+57956, dvrr_stack+79224);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+646593, dvrr_stack+468845, dvrr_stack+645297, dvrr_stack+324272, dvrr_stack+43429, dvrr_stack+44437);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+648213, dvrr_stack+470141, dvrr_stack+646593, dvrr_stack+325280, dvrr_stack+468845, dvrr_stack+61345);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+323516, dvrr_stack+471761, dvrr_stack+648213, dvrr_stack+326576, dvrr_stack+470141, dvrr_stack+640145);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+650193, dvrr_stack+473741, dvrr_stack+323516, dvrr_stack+328196, dvrr_stack+471761, dvrr_stack+641685);
 tmp = dvrr_stack + 650193;
 target_ptr = Libderiv->dvrr_classes[11][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+653001,dvrr_stack+650193,dvrr_stack+318924,78);


 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+325892, dvrr_stack+58882, dvrr_stack+77660, NULL, NULL, dvrr_stack+58846);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+105736, dvrr_stack+211863, dvrr_stack+325892, dvrr_stack+43045, dvrr_stack+58882, dvrr_stack+321108);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+326027, dvrr_stack+211998, dvrr_stack+105736, dvrr_stack+121711, dvrr_stack+211863, dvrr_stack+107701);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+326477, dvrr_stack+212268, dvrr_stack+326027, dvrr_stack+121846, dvrr_stack+211998, dvrr_stack+321216);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+327152, dvrr_stack+30425, dvrr_stack+326477, dvrr_stack+122116, dvrr_stack+212268, dvrr_stack+219604);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+659553, dvrr_stack+4214, dvrr_stack+327152, dvrr_stack+122566, dvrr_stack+30425, dvrr_stack+643533);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+660813, dvrr_stack+481661, dvrr_stack+659553, dvrr_stack+334796, dvrr_stack+4214, dvrr_stack+644289);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+662433, dvrr_stack+482921, dvrr_stack+660813, dvrr_stack+335741, dvrr_stack+481661, dvrr_stack+645297);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+664458, dvrr_stack+484541, dvrr_stack+662433, dvrr_stack+337001, dvrr_stack+482921, dvrr_stack+646593);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+334796, dvrr_stack+486566, dvrr_stack+664458, dvrr_stack+338621, dvrr_stack+484541, dvrr_stack+648213);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+666933, dvrr_stack+489041, dvrr_stack+334796, dvrr_stack+127795, dvrr_stack+486566, dvrr_stack+323516);
 tmp = dvrr_stack + 666933;
 target_ptr = Libderiv->dvrr_classes[11][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+670443,dvrr_stack+666933,dvrr_stack+650193,78);


 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+337766, dvrr_stack+77705, dvrr_stack+82582, NULL, NULL, dvrr_stack+77660);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+337931, dvrr_stack+218559, dvrr_stack+337766, dvrr_stack+58927, dvrr_stack+77705, dvrr_stack+325892);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+338261, dvrr_stack+218724, dvrr_stack+337931, dvrr_stack+130270, dvrr_stack+218559, dvrr_stack+105736);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+338811, dvrr_stack+219054, dvrr_stack+338261, dvrr_stack+80572, dvrr_stack+218724, dvrr_stack+326027);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+121711, dvrr_stack+10809, dvrr_stack+338811, dvrr_stack+81916, dvrr_stack+219054, dvrr_stack+326477);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+19986, dvrr_stack+121711, dvrr_stack+346586, dvrr_stack+10809, dvrr_stack+327152);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+680407, dvrr_stack+499139, dvrr_stack+678867, dvrr_stack+347411, dvrr_stack+19986, dvrr_stack+659553);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+682387, dvrr_stack+500679, dvrr_stack+680407, dvrr_stack+348566, dvrr_stack+499139, dvrr_stack+660813);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+346586, dvrr_stack+502659, dvrr_stack+682387, dvrr_stack+350106, dvrr_stack+500679, dvrr_stack+662433);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+684862, dvrr_stack+225039, dvrr_stack+346586, dvrr_stack+352086, dvrr_stack+502659, dvrr_stack+664458);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+349611, dvrr_stack+505134, dvrr_stack+684862, dvrr_stack+136183, dvrr_stack+225039, dvrr_stack+334796);
 tmp = dvrr_stack + 349611;
 target_ptr = Libderiv->dvrr_classes[11][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+688492,dvrr_stack+349611,dvrr_stack+666933,78);


 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+353901, dvrr_stack+76230, dvrr_stack+59207, NULL, NULL, dvrr_stack+82582);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+354099, dvrr_stack+228064, dvrr_stack+353901, dvrr_stack+77760, dvrr_stack+76230, dvrr_stack+337766);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+339636, dvrr_stack+228262, dvrr_stack+354099, dvrr_stack+139208, dvrr_stack+228064, dvrr_stack+337931);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+81524, dvrr_stack+228658, dvrr_stack+339636, dvrr_stack+18118, dvrr_stack+228262, dvrr_stack+338261);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+699022, dvrr_stack+229318, dvrr_stack+81524, dvrr_stack+19326, dvrr_stack+228658, dvrr_stack+338811);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+700408, dvrr_stack+517674, dvrr_stack+699022, dvrr_stack+361986, dvrr_stack+229318, dvrr_stack+121711);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+702256, dvrr_stack+519060, dvrr_stack+700408, dvrr_stack+362976, dvrr_stack+517674, dvrr_stack+678867);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+704632, dvrr_stack+520908, dvrr_stack+702256, dvrr_stack+364362, dvrr_stack+519060, dvrr_stack+680407);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+361986, dvrr_stack+523284, dvrr_stack+704632, dvrr_stack+366210, dvrr_stack+520908, dvrr_stack+682387);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+707602, dvrr_stack+239089, dvrr_stack+361986, dvrr_stack+368586, dvrr_stack+523284, dvrr_stack+346586);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+365616, dvrr_stack+526254, dvrr_stack+707602, dvrr_stack+146543, dvrr_stack+239089, dvrr_stack+684862);
 tmp = dvrr_stack + 365616;
 target_ptr = Libderiv->dvrr_classes[11][10];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+711958,dvrr_stack+365616,dvrr_stack+349611,78);


 /* compute (1 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+370764, dvrr_stack+98806, dvrr_stack+59048, NULL, NULL, dvrr_stack+59207);

 /* compute (2 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+370998, dvrr_stack+242719, dvrr_stack+370764, dvrr_stack+76296, dvrr_stack+98806, dvrr_stack+353901);

 /* compute (3 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+242953, dvrr_stack+370998, dvrr_stack+123241, dvrr_stack+242719, dvrr_stack+354099);

 /* compute (4 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+724828, dvrr_stack+243421, dvrr_stack+18118, dvrr_stack+150173, dvrr_stack+242953, dvrr_stack+339636);

 /* compute (5 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+725998, dvrr_stack+244201, dvrr_stack+724828, dvrr_stack+29062, dvrr_stack+243421, dvrr_stack+81524);

 /* compute (6 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+727636, dvrr_stack+32703, dvrr_stack+725998, dvrr_stack+380631, dvrr_stack+244201, dvrr_stack+699022);

 /* compute (7 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+729820, dvrr_stack+541500, dvrr_stack+727636, dvrr_stack+381801, dvrr_stack+32703, dvrr_stack+700408);

 /* compute (8 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+732628, dvrr_stack+543684, dvrr_stack+729820, dvrr_stack+383439, dvrr_stack+541500, dvrr_stack+702256);

 /* compute (9 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+380631, dvrr_stack+546492, dvrr_stack+732628, dvrr_stack+385623, dvrr_stack+543684, dvrr_stack+704632);

 /* compute (10 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+736138, dvrr_stack+253114, dvrr_stack+380631, dvrr_stack+388431, dvrr_stack+546492, dvrr_stack+361986);

 /* compute (11 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+384921, dvrr_stack+550002, dvrr_stack+736138, dvrr_stack+159083, dvrr_stack+253114, dvrr_stack+707602);
 tmp = dvrr_stack + 384921;
 target_ptr = Libderiv->dvrr_classes[11][11];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+741286,dvrr_stack+384921,dvrr_stack+365616,78);


 /* compute (1 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+43156, dvrr_stack+76085, dvrr_stack+76374, NULL, NULL, dvrr_stack+59048);

 /* compute (2 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+391005, dvrr_stack+257404, dvrr_stack+43156, dvrr_stack+59273, dvrr_stack+76085, dvrr_stack+370764);

 /* compute (3 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+31769, dvrr_stack+257677, dvrr_stack+391005, dvrr_stack+163373, dvrr_stack+257404, dvrr_stack+370998);

 /* compute (4 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+756730, dvrr_stack+258223, dvrr_stack+31769, dvrr_stack+9898, dvrr_stack+257677, dvrr_stack+18118);

 /* compute (5 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+758095, dvrr_stack+259133, dvrr_stack+756730, dvrr_stack+41477, dvrr_stack+258223, dvrr_stack+724828);

 /* compute (6 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+760006, dvrr_stack+11634, dvrr_stack+758095, dvrr_stack+402831, dvrr_stack+259133, dvrr_stack+725998);

 /* compute (7 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+762554, dvrr_stack+568218, dvrr_stack+760006, dvrr_stack+404196, dvrr_stack+11634, dvrr_stack+727636);

 /* compute (8 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+765830, dvrr_stack+570766, dvrr_stack+762554, dvrr_stack+406107, dvrr_stack+568218, dvrr_stack+729820);

 /* compute (9 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+402831, dvrr_stack+269824, dvrr_stack+765830, dvrr_stack+408655, dvrr_stack+570766, dvrr_stack+732628);

 /* compute (10 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+769925, dvrr_stack+574042, dvrr_stack+402831, dvrr_stack+411931, dvrr_stack+269824, dvrr_stack+380631);

 /* compute (11 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+407836, dvrr_stack+579047, dvrr_stack+769925, dvrr_stack+174011, dvrr_stack+574042, dvrr_stack+736138);

 /* compute (11 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+775931,dvrr_stack+407836,dvrr_stack+384921,78);


 /* compute (0 0 | 1 0) m=23 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+23, Data->F+24, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=22 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+210, dvrr_stack+161, Data->F+22, Data->F+23, NULL);

 /* compute (0 0 | 3 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+873, dvrr_stack+707, dvrr_stack+179016, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+5437, dvrr_stack+2698, dvrr_stack+121, dvrr_stack+213, dvrr_stack+873, NULL);

 /* compute (0 0 | 5 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10724, dvrr_stack+273919, dvrr_stack+5437, dvrr_stack+879, dvrr_stack+2698, NULL);

 /* compute (0 0 | 6 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+873, dvrr_stack+5452, dvrr_stack+10724, dvrr_stack+2708, dvrr_stack+273919, NULL);

 /* compute (0 0 | 7 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30025, dvrr_stack+10745, dvrr_stack+873, dvrr_stack+102769, dvrr_stack+5452, NULL);

 /* compute (0 0 | 8 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+43045, dvrr_stack+273934, dvrr_stack+30025, dvrr_stack+5473, dvrr_stack+10745, NULL);

 /* compute (0 0 | 9 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+58927, dvrr_stack+30061, dvrr_stack+43045, dvrr_stack+10773, dvrr_stack+273934, NULL);

 /* compute (0 0 | 10 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+77760, dvrr_stack+86732, dvrr_stack+58927, dvrr_stack+179019, dvrr_stack+30061, NULL);

 /* compute (0 0 | 11 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+76296, dvrr_stack+58982, dvrr_stack+77760, dvrr_stack+30106, dvrr_stack+86732, NULL);

 /* compute (0 0 | 12 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+59273, dvrr_stack+77826, dvrr_stack+76296, dvrr_stack+43090, dvrr_stack+58982, NULL);

 /* compute (0 0 | 13 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+58927, dvrr_stack+76374, dvrr_stack+59273, dvrr_stack+59048, dvrr_stack+77826, NULL);

 /* compute (1 0 | 13 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+30025, dvrr_stack+273970, dvrr_stack+58927, NULL, NULL, dvrr_stack+76374);

 /* compute (2 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+5437, dvrr_stack+274075, dvrr_stack+30025, dvrr_stack+179064, dvrr_stack+273970, dvrr_stack+43156);

 /* compute (3 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+414934, dvrr_stack+274390, dvrr_stack+5437, dvrr_stack+179169, dvrr_stack+274075, dvrr_stack+391005);

 /* compute (4 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+794183, dvrr_stack+275020, dvrr_stack+414934, dvrr_stack+59490, dvrr_stack+274390, dvrr_stack+31769);

 /* compute (5 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+795758, dvrr_stack+276070, dvrr_stack+794183, dvrr_stack+428896, dvrr_stack+275020, dvrr_stack+756730);

 /* compute (6 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+797963, dvrr_stack+600497, dvrr_stack+795758, dvrr_stack+429946, dvrr_stack+276070, dvrr_stack+758095);

 /* compute (7 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+794183, dvrr_stack+602702, dvrr_stack+797963, dvrr_stack+431521, dvrr_stack+600497, dvrr_stack+760006);

 /* compute (8 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+428896, dvrr_stack+605642, dvrr_stack+794183, dvrr_stack+433726, dvrr_stack+602702, dvrr_stack+762554);

 /* compute (9 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+794183, dvrr_stack+290364, dvrr_stack+428896, dvrr_stack+436666, dvrr_stack+605642, dvrr_stack+765830);

 /* compute (10 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+428896, dvrr_stack+609422, dvrr_stack+794183, dvrr_stack+440446, dvrr_stack+290364, dvrr_stack+402831);

 /* compute (11 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+435826, dvrr_stack+615197, dvrr_stack+428896, dvrr_stack+191535, dvrr_stack+609422, dvrr_stack+769925);

 /* compute (11 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+794183,dvrr_stack+435826,dvrr_stack+407836,78);


 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+161, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+210, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+5);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+428896, dvrr_stack+210, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+161);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+428914, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+428932, dvrr_stack+428914, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+210);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+428968, dvrr_stack+428932, dvrr_stack+75, dvrr_stack+428914, dvrr_stack+57, dvrr_stack+428896);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+21, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+429028, dvrr_stack+21, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+428914);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+429088, dvrr_stack+429028, dvrr_stack+319, dvrr_stack+21, dvrr_stack+180, dvrr_stack+428932);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+429188, dvrr_stack+429088, dvrr_stack+379, dvrr_stack+429028, dvrr_stack+319, dvrr_stack+428968);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+43045, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+371466, dvrr_stack+43045, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+21);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+429338, dvrr_stack+371466, dvrr_stack+783, dvrr_stack+43045, dvrr_stack+738, dvrr_stack+429028);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+429488, dvrr_stack+429338, dvrr_stack+1189, dvrr_stack+371466, dvrr_stack+783, dvrr_stack+429088);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+429713, dvrr_stack+429488, dvrr_stack+1339, dvrr_stack+429338, dvrr_stack+1189, dvrr_stack+429188);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+430028, dvrr_stack+1997, dvrr_stack+593, NULL, NULL, dvrr_stack+578);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+78093, dvrr_stack+430028, dvrr_stack+2299, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+43045);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+430091, dvrr_stack+78093, dvrr_stack+2362, dvrr_stack+430028, dvrr_stack+2299, dvrr_stack+371466);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+430301, dvrr_stack+430091, dvrr_stack+2488, dvrr_stack+78093, dvrr_stack+2362, dvrr_stack+429338);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+430616, dvrr_stack+430301, dvrr_stack+3458, dvrr_stack+430091, dvrr_stack+2488, dvrr_stack+429488);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+431057, dvrr_stack+430616, dvrr_stack+3773, dvrr_stack+430301, dvrr_stack+3458, dvrr_stack+429713);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+429338, dvrr_stack+161, dvrr_stack+10690, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+429344, dvrr_stack+428896, dvrr_stack+98884, dvrr_stack+210, dvrr_stack+6, dvrr_stack+429338);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+371466, dvrr_stack+428968, dvrr_stack+98956, dvrr_stack+428932, dvrr_stack+75, dvrr_stack+429344);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+430028, dvrr_stack+429188, dvrr_stack+99176, dvrr_stack+429088, dvrr_stack+379, dvrr_stack+371466);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+431645, dvrr_stack+429713, dvrr_stack+101509, dvrr_stack+429488, dvrr_stack+1339, dvrr_stack+430028);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+432065, dvrr_stack+431057, dvrr_stack+102790, dvrr_stack+430616, dvrr_stack+3773, dvrr_stack+431645);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+121, dvrr_stack+429338, dvrr_stack+107917, dvrr_stack+161, dvrr_stack+10690, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+43045, dvrr_stack+429344, dvrr_stack+131, dvrr_stack+428896, dvrr_stack+98884, dvrr_stack+121);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+78093, dvrr_stack+371466, dvrr_stack+108064, dvrr_stack+428968, dvrr_stack+98956, dvrr_stack+43045);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+428896, dvrr_stack+430028, dvrr_stack+108494, dvrr_stack+429188, dvrr_stack+99176, dvrr_stack+78093);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+103378, dvrr_stack+431645, dvrr_stack+109484, dvrr_stack+429713, dvrr_stack+101509, dvrr_stack+428896);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+432821, dvrr_stack+432065, dvrr_stack+45755, dvrr_stack+431057, dvrr_stack+102790, dvrr_stack+103378);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+98884, dvrr_stack+121, dvrr_stack+104143, dvrr_stack+429338, dvrr_stack+107917, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+429176, dvrr_stack+43045, dvrr_stack+104180, dvrr_stack+429344, dvrr_stack+131, dvrr_stack+98884);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+62605, dvrr_stack+78093, dvrr_stack+59364, dvrr_stack+371466, dvrr_stack+108064, dvrr_stack+429176);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+429239, dvrr_stack+428896, dvrr_stack+104931, dvrr_stack+430028, dvrr_stack+108494, dvrr_stack+62605);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+429599, dvrr_stack+103378, dvrr_stack+106006, dvrr_stack+431645, dvrr_stack+109484, dvrr_stack+429239);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+444016, dvrr_stack+432821, dvrr_stack+101824, dvrr_stack+432065, dvrr_stack+45755, dvrr_stack+429599);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+431645, dvrr_stack+98884, dvrr_stack+197313, dvrr_stack+121, dvrr_stack+104143, NULL);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+121, dvrr_stack+429176, dvrr_stack+197421, dvrr_stack+43045, dvrr_stack+104180, dvrr_stack+431645);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+23617, dvrr_stack+62605, dvrr_stack+197580, dvrr_stack+78093, dvrr_stack+59364, dvrr_stack+121);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+59364, dvrr_stack+429239, dvrr_stack+78219, dvrr_stack+428896, dvrr_stack+104931, dvrr_stack+23617);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+433766, dvrr_stack+429599, dvrr_stack+108704, dvrr_stack+103378, dvrr_stack+106006, dvrr_stack+59364);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+290364, dvrr_stack+444016, dvrr_stack+462790, dvrr_stack+432821, dvrr_stack+101824, dvrr_stack+433766);

 /* compute (6 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+106006, dvrr_stack+431645, dvrr_stack+295120, dvrr_stack+98884, dvrr_stack+197313, NULL);

 /* compute (7 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+431645, dvrr_stack+121, dvrr_stack+295252, dvrr_stack+429176, dvrr_stack+197421, dvrr_stack+106006);

 /* compute (8 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+106006, dvrr_stack+23617, dvrr_stack+295780, dvrr_stack+62605, dvrr_stack+197580, dvrr_stack+431645);

 /* compute (9 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+430274, dvrr_stack+59364, dvrr_stack+296736, dvrr_stack+429239, dvrr_stack+78219, dvrr_stack+106006);

 /* compute (10 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+434591, dvrr_stack+433766, dvrr_stack+299361, dvrr_stack+429599, dvrr_stack+108704, dvrr_stack+430274);

 /* compute (11 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+428896, dvrr_stack+290364, dvrr_stack+277645, dvrr_stack+444016, dvrr_stack+462790, dvrr_stack+434591);

 /* compute (1 0 | 0 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+433766, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+107917, dvrr_stack+0, dvrr_stack+433766, Data->F+10, Data->F+11, NULL);

 /* compute (3 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+104143, dvrr_stack+295089, dvrr_stack+107917, dvrr_stack+197310, dvrr_stack+0, NULL);

 /* compute (4 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+295095, dvrr_stack+104143, dvrr_stack+15, dvrr_stack+295089, NULL);

 /* compute (5 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+15, dvrr_stack+295105, dvrr_stack+0, dvrr_stack+111, dvrr_stack+295095, NULL);

 /* compute (6 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i000(Data,dvrr_stack+36, dvrr_stack+295120, dvrr_stack+15, dvrr_stack+197313, dvrr_stack+295105, NULL);

 /* compute (1 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+164066, dvrr_stack+6118, dvrr_stack+5418, NULL, NULL, Data->F+12);

 /* compute (2 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+197310, dvrr_stack+104134, dvrr_stack+164066, dvrr_stack+704, dvrr_stack+6118, dvrr_stack+433766);

 /* compute (3 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+433766, dvrr_stack+295141, dvrr_stack+197310, dvrr_stack+76176, dvrr_stack+104134, dvrr_stack+107917);

 /* compute (4 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+43045, dvrr_stack+295159, dvrr_stack+433766, dvrr_stack+197328, dvrr_stack+295141, dvrr_stack+104143);

 /* compute (5 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+433796, dvrr_stack+219, dvrr_stack+43045, dvrr_stack+197346, dvrr_stack+295159, dvrr_stack+0);

 /* compute (6 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+433859, dvrr_stack+295189, dvrr_stack+433796, dvrr_stack+197376, dvrr_stack+219, dvrr_stack+15);

 /* compute (7 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,dvrr_stack+433943, dvrr_stack+295252, dvrr_stack+433859, dvrr_stack+197421, dvrr_stack+295189, dvrr_stack+36);

 /* compute (1 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+98884, dvrr_stack+5421, dvrr_stack+10693, NULL, NULL, dvrr_stack+5418);

 /* compute (2 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+0, dvrr_stack+104153, dvrr_stack+98884, dvrr_stack+6121, dvrr_stack+5421, dvrr_stack+164066);

 /* compute (3 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+36, dvrr_stack+86787, dvrr_stack+0, dvrr_stack+107923, dvrr_stack+104153, dvrr_stack+197310);

 /* compute (4 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+371466, dvrr_stack+295336, dvrr_stack+36, dvrr_stack+197484, dvrr_stack+86787, dvrr_stack+433766);

 /* compute (5 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+78093, dvrr_stack+295396, dvrr_stack+371466, dvrr_stack+197520, dvrr_stack+295336, dvrr_stack+43045);

 /* compute (6 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+96, dvrr_stack+295486, dvrr_stack+78093, dvrr_stack+80902, dvrr_stack+295396, dvrr_stack+433796);

 /* compute (7 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+23617, dvrr_stack+295612, dvrr_stack+96, dvrr_stack+150641, dvrr_stack+295486, dvrr_stack+433859);

 /* compute (8 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+197310, dvrr_stack+295780, dvrr_stack+23617, dvrr_stack+197580, dvrr_stack+295612, dvrr_stack+433943);

 /* compute (1 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+197580, dvrr_stack+10699, dvrr_stack+19252, NULL, NULL, dvrr_stack+10693);

 /* compute (2 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+197610, dvrr_stack+104225, dvrr_stack+197580, dvrr_stack+5427, dvrr_stack+10699, dvrr_stack+98884);

 /* compute (3 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+433766, dvrr_stack+104255, dvrr_stack+197610, dvrr_stack+107941, dvrr_stack+104225, dvrr_stack+0);

 /* compute (4 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+433866, dvrr_stack+295996, dvrr_stack+433766, dvrr_stack+107971, dvrr_stack+104255, dvrr_stack+36);

 /* compute (5 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+434016, dvrr_stack+296096, dvrr_stack+433866, dvrr_stack+197748, dvrr_stack+295996, dvrr_stack+371466);

 /* compute (6 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+434226, dvrr_stack+296246, dvrr_stack+434016, dvrr_stack+197848, dvrr_stack+296096, dvrr_stack+78093);

 /* compute (7 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+434506, dvrr_stack+296456, dvrr_stack+434226, dvrr_stack+197998, dvrr_stack+296246, dvrr_stack+96);

 /* compute (8 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+197670, dvrr_stack+104315, dvrr_stack+434506, dvrr_stack+60120, dvrr_stack+296456, dvrr_stack+23617);

 /* compute (9 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+434866, dvrr_stack+296736, dvrr_stack+197670, dvrr_stack+78219, dvrr_stack+104315, dvrr_stack+197310);

 /* compute (1 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+43045, dvrr_stack+19262, dvrr_stack+29961, NULL, NULL, dvrr_stack+19252);

 /* compute (2 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+371466, dvrr_stack+98902, dvrr_stack+43045, dvrr_stack+10709, dvrr_stack+19262, dvrr_stack+197580);

 /* compute (3 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+197310, dvrr_stack+104675, dvrr_stack+371466, dvrr_stack+108154, dvrr_stack+98902, dvrr_stack+197610);

 /* compute (4 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+78093, dvrr_stack+104765, dvrr_stack+197310, dvrr_stack+614, dvrr_stack+104675, dvrr_stack+433766);

 /* compute (5 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+98884, dvrr_stack+297186, dvrr_stack+78093, dvrr_stack+108199, dvrr_stack+104765, dvrr_stack+433866);

 /* compute (6 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+431645, dvrr_stack+297411, dvrr_stack+98884, dvrr_stack+78579, dvrr_stack+297186, dvrr_stack+434016);

 /* compute (7 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+106006, dvrr_stack+297726, dvrr_stack+431645, dvrr_stack+460186, dvrr_stack+297411, dvrr_stack+434226);

 /* compute (8 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+433766, dvrr_stack+298146, dvrr_stack+106006, dvrr_stack+78804, dvrr_stack+297726, dvrr_stack+434506);

 /* compute (9 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+78318, dvrr_stack+298686, dvrr_stack+433766, dvrr_stack+76465, dvrr_stack+298146, dvrr_stack+197670);

 /* compute (10 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+104134, dvrr_stack+299361, dvrr_stack+78318, dvrr_stack+108704, dvrr_stack+298686, dvrr_stack+434866);

 /* compute (1 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+76465, dvrr_stack+29976, dvrr_stack+42960, NULL, NULL, dvrr_stack+29961);

 /* compute (2 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+76528, dvrr_stack+77904, dvrr_stack+76465, dvrr_stack+19277, dvrr_stack+29976, dvrr_stack+43045);

 /* compute (3 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+76654, dvrr_stack+77967, dvrr_stack+76528, dvrr_stack+109379, dvrr_stack+77904, dvrr_stack+371466);

 /* compute (4 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+460186, dvrr_stack+105211, dvrr_stack+76654, dvrr_stack+108349, dvrr_stack+77967, dvrr_stack+197310);

 /* compute (5 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+197310, dvrr_stack+105421, dvrr_stack+460186, dvrr_stack+77005, dvrr_stack+105211, dvrr_stack+78093);

 /* compute (6 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+434441, dvrr_stack+212718, dvrr_stack+197310, dvrr_stack+77215, dvrr_stack+105421, dvrr_stack+98884);

 /* compute (7 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+98884, dvrr_stack+300186, dvrr_stack+434441, dvrr_stack+57515, dvrr_stack+212718, dvrr_stack+431645);

 /* compute (8 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+107917, dvrr_stack+300774, dvrr_stack+98884, dvrr_stack+460501, dvrr_stack+300186, dvrr_stack+106006);

 /* compute (9 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+108862, dvrr_stack+60400, dvrr_stack+107917, dvrr_stack+461089, dvrr_stack+300774, dvrr_stack+433766);

 /* compute (10 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+291750, dvrr_stack+106546, dvrr_stack+108862, dvrr_stack+461845, dvrr_stack+60400, dvrr_stack+78318);

 /* compute (11 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+460501, dvrr_stack+277645, dvrr_stack+291750, dvrr_stack+462790, dvrr_stack+106546, dvrr_stack+104134);

 /* compute (1 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+104134, dvrr_stack+42981, dvrr_stack+58818, NULL, NULL, dvrr_stack+42960);

 /* compute (2 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+62605, dvrr_stack+80992, dvrr_stack+104134, dvrr_stack+29997, dvrr_stack+42981, dvrr_stack+76465);

 /* compute (3 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+104218, dvrr_stack+81076, dvrr_stack+62605, dvrr_stack+97834, dvrr_stack+80992, dvrr_stack+76528);

 /* compute (4 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+431645, dvrr_stack+81244, dvrr_stack+104218, dvrr_stack+97918, dvrr_stack+81076, dvrr_stack+76654);

 /* compute (5 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+76465, dvrr_stack+1564, dvrr_stack+431645, dvrr_stack+98086, dvrr_stack+81244, dvrr_stack+460186);

 /* compute (6 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+97834, dvrr_stack+279031, dvrr_stack+76465, dvrr_stack+163646, dvrr_stack+1564, dvrr_stack+197310);

 /* compute (7 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+104498, dvrr_stack+79224, dvrr_stack+97834, dvrr_stack+31181, dvrr_stack+279031, dvrr_stack+434441);

 /* compute (8 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+433766, dvrr_stack+44437, dvrr_stack+104498, dvrr_stack+463945, dvrr_stack+79224, dvrr_stack+98884);

 /* compute (9 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+106006, dvrr_stack+61345, dvrr_stack+433766, dvrr_stack+464729, dvrr_stack+44437, dvrr_stack+107917);

 /* compute (10 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+44437, dvrr_stack+640145, dvrr_stack+106006, dvrr_stack+465737, dvrr_stack+61345, dvrr_stack+108862);

 /* compute (11 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+107917, dvrr_stack+641685, dvrr_stack+44437, dvrr_stack+99725, dvrr_stack+640145, dvrr_stack+291750);

 /* compute (12 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+291750, dvrr_stack+318924, dvrr_stack+107917, dvrr_stack+466997, dvrr_stack+641685, dvrr_stack+460501);

 /* compute (1 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+294298, dvrr_stack+58846, dvrr_stack+77624, NULL, NULL, dvrr_stack+58818);

 /* compute (2 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+23617, dvrr_stack+321108, dvrr_stack+294298, dvrr_stack+43009, dvrr_stack+58846, dvrr_stack+104134);

 /* compute (3 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+294406, dvrr_stack+107701, dvrr_stack+23617, dvrr_stack+2723, dvrr_stack+321108, dvrr_stack+62605);

 /* compute (4 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+294766, dvrr_stack+321216, dvrr_stack+294406, dvrr_stack+103918, dvrr_stack+107701, dvrr_stack+104218);

 /* compute (5 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+295306, dvrr_stack+219604, dvrr_stack+294766, dvrr_stack+2831, dvrr_stack+321216, dvrr_stack+431645);

 /* compute (6 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+296062, dvrr_stack+643533, dvrr_stack+295306, dvrr_stack+6127, dvrr_stack+219604, dvrr_stack+76465);

 /* compute (7 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+297070, dvrr_stack+644289, dvrr_stack+296062, dvrr_stack+57956, dvrr_stack+643533, dvrr_stack+97834);

 /* compute (8 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+298366, dvrr_stack+645297, dvrr_stack+297070, dvrr_stack+43429, dvrr_stack+644289, dvrr_stack+104498);

 /* compute (9 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+640145, dvrr_stack+646593, dvrr_stack+298366, dvrr_stack+468845, dvrr_stack+645297, dvrr_stack+433766);

 /* compute (10 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+642125, dvrr_stack+648213, dvrr_stack+640145, dvrr_stack+470141, dvrr_stack+646593, dvrr_stack+106006);

 /* compute (11 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+468845, dvrr_stack+323516, dvrr_stack+642125, dvrr_stack+471761, dvrr_stack+648213, dvrr_stack+44437);

 /* compute (12 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+644501, dvrr_stack+650193, dvrr_stack+468845, dvrr_stack+473741, dvrr_stack+323516, dvrr_stack+107917);

 /* compute (1 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+323516, dvrr_stack+77660, dvrr_stack+76185, NULL, NULL, dvrr_stack+77624);

 /* compute (2 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+323651, dvrr_stack+325892, dvrr_stack+323516, dvrr_stack+58882, dvrr_stack+77660, dvrr_stack+294298);

 /* compute (3 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+323921, dvrr_stack+105736, dvrr_stack+323651, dvrr_stack+211863, dvrr_stack+325892, dvrr_stack+23617);

 /* compute (4 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+324371, dvrr_stack+326027, dvrr_stack+323921, dvrr_stack+211998, dvrr_stack+105736, dvrr_stack+294406);

 /* compute (5 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+197310, dvrr_stack+326477, dvrr_stack+324371, dvrr_stack+212268, dvrr_stack+326027, dvrr_stack+294766);

 /* compute (6 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+211863, dvrr_stack+327152, dvrr_stack+197310, dvrr_stack+30425, dvrr_stack+326477, dvrr_stack+295306);

 /* compute (7 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+294298, dvrr_stack+659553, dvrr_stack+211863, dvrr_stack+4214, dvrr_stack+327152, dvrr_stack+296062);

 /* compute (8 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+325046, dvrr_stack+660813, dvrr_stack+294298, dvrr_stack+481661, dvrr_stack+659553, dvrr_stack+297070);

 /* compute (9 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+43429, dvrr_stack+662433, dvrr_stack+325046, dvrr_stack+482921, dvrr_stack+660813, dvrr_stack+298366);

 /* compute (10 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+295918, dvrr_stack+664458, dvrr_stack+43429, dvrr_stack+484541, dvrr_stack+662433, dvrr_stack+640145);

 /* compute (11 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+659553, dvrr_stack+334796, dvrr_stack+295918, dvrr_stack+486566, dvrr_stack+664458, dvrr_stack+642125);

 /* compute (12 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+640145, dvrr_stack+666933, dvrr_stack+659553, dvrr_stack+489041, dvrr_stack+334796, dvrr_stack+468845);

 /* compute (1 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+468845, dvrr_stack+82582, dvrr_stack+264, NULL, NULL, dvrr_stack+76185);

 /* compute (2 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+469010, dvrr_stack+337766, dvrr_stack+468845, dvrr_stack+77705, dvrr_stack+82582, dvrr_stack+323516);

 /* compute (3 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+469340, dvrr_stack+337931, dvrr_stack+469010, dvrr_stack+218559, dvrr_stack+337766, dvrr_stack+323651);

 /* compute (4 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+469890, dvrr_stack+338261, dvrr_stack+469340, dvrr_stack+218724, dvrr_stack+337931, dvrr_stack+323921);

 /* compute (5 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+470715, dvrr_stack+338811, dvrr_stack+469890, dvrr_stack+219054, dvrr_stack+338261, dvrr_stack+324371);

 /* compute (6 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+218559, dvrr_stack+121711, dvrr_stack+470715, dvrr_stack+10809, dvrr_stack+338811, dvrr_stack+197310);

 /* compute (7 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+334796, dvrr_stack+678867, dvrr_stack+218559, dvrr_stack+19986, dvrr_stack+121711, dvrr_stack+211863);

 /* compute (8 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+336776, dvrr_stack+680407, dvrr_stack+334796, dvrr_stack+499139, dvrr_stack+678867, dvrr_stack+294298);

 /* compute (9 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+663063, dvrr_stack+682387, dvrr_stack+336776, dvrr_stack+500679, dvrr_stack+680407, dvrr_stack+325046);

 /* compute (10 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+323516, dvrr_stack+346586, dvrr_stack+663063, dvrr_stack+502659, dvrr_stack+682387, dvrr_stack+43429);

 /* compute (11 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+684862, dvrr_stack+323516, dvrr_stack+225039, dvrr_stack+346586, dvrr_stack+295918);

 /* compute (12 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+294298, dvrr_stack+349611, dvrr_stack+678867, dvrr_stack+505134, dvrr_stack+684862, dvrr_stack+659553);

 /* compute (1 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+659553, dvrr_stack+59207, dvrr_stack+43090, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+659751, dvrr_stack+353901, dvrr_stack+659553, dvrr_stack+76230, dvrr_stack+59207, dvrr_stack+468845);

 /* compute (3 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+660147, dvrr_stack+354099, dvrr_stack+659751, dvrr_stack+228064, dvrr_stack+353901, dvrr_stack+469010);

 /* compute (4 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+660807, dvrr_stack+339636, dvrr_stack+660147, dvrr_stack+228262, dvrr_stack+354099, dvrr_stack+469340);

 /* compute (5 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+346586, dvrr_stack+81524, dvrr_stack+660807, dvrr_stack+228658, dvrr_stack+339636, dvrr_stack+469890);

 /* compute (6 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+468845, dvrr_stack+699022, dvrr_stack+346586, dvrr_stack+229318, dvrr_stack+81524, dvrr_stack+470715);

 /* compute (7 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+470693, dvrr_stack+700408, dvrr_stack+468845, dvrr_stack+517674, dvrr_stack+699022, dvrr_stack+218559);

 /* compute (8 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+225039, dvrr_stack+702256, dvrr_stack+470693, dvrr_stack+519060, dvrr_stack+700408, dvrr_stack+334796);

 /* compute (9 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+683157, dvrr_stack+704632, dvrr_stack+225039, dvrr_stack+520908, dvrr_stack+702256, dvrr_stack+336776);

 /* compute (10 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+334796, dvrr_stack+361986, dvrr_stack+683157, dvrr_stack+523284, dvrr_stack+704632, dvrr_stack+663063);

 /* compute (11 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+699022, dvrr_stack+707602, dvrr_stack+334796, dvrr_stack+239089, dvrr_stack+361986, dvrr_stack+323516);

 /* compute (12 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+517674, dvrr_stack+365616, dvrr_stack+699022, dvrr_stack+526254, dvrr_stack+707602, dvrr_stack+678867);

 /* compute (1 0 | 11 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+59048, dvrr_stack+77826, NULL, NULL, dvrr_stack+43090);

 /* compute (2 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+679101, dvrr_stack+370764, dvrr_stack+678867, dvrr_stack+98806, dvrr_stack+59048, dvrr_stack+659553);

 /* compute (3 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+679569, dvrr_stack+370998, dvrr_stack+679101, dvrr_stack+242719, dvrr_stack+370764, dvrr_stack+659751);

 /* compute (4 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+680349, dvrr_stack+18118, dvrr_stack+679569, dvrr_stack+242953, dvrr_stack+370998, dvrr_stack+660147);

 /* compute (5 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+681519, dvrr_stack+724828, dvrr_stack+680349, dvrr_stack+243421, dvrr_stack+18118, dvrr_stack+660807);

 /* compute (6 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+725998, dvrr_stack+681519, dvrr_stack+244201, dvrr_stack+724828, dvrr_stack+346586);

 /* compute (7 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+346586, dvrr_stack+727636, dvrr_stack+18118, dvrr_stack+32703, dvrr_stack+725998, dvrr_stack+468845);

 /* compute (8 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+659553, dvrr_stack+729820, dvrr_stack+346586, dvrr_stack+541500, dvrr_stack+727636, dvrr_stack+470693);

 /* compute (9 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+468845, dvrr_stack+732628, dvrr_stack+659553, dvrr_stack+543684, dvrr_stack+729820, dvrr_stack+225039);

 /* compute (10 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+225039, dvrr_stack+380631, dvrr_stack+468845, dvrr_stack+546492, dvrr_stack+732628, dvrr_stack+683157);

 /* compute (11 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+541500, dvrr_stack+736138, dvrr_stack+225039, dvrr_stack+253114, dvrr_stack+380631, dvrr_stack+334796);

 /* compute (12 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+724828, dvrr_stack+384921, dvrr_stack+541500, dvrr_stack+550002, dvrr_stack+736138, dvrr_stack+699022);

 /* compute (1 0 | 12 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+699022, dvrr_stack+76374, dvrr_stack+59273, NULL, NULL, dvrr_stack+77826);

 /* compute (2 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+699295, dvrr_stack+43156, dvrr_stack+699022, dvrr_stack+76085, dvrr_stack+76374, dvrr_stack+678867);

 /* compute (3 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76085, dvrr_stack+391005, dvrr_stack+699295, dvrr_stack+257404, dvrr_stack+43156, dvrr_stack+679101);

 /* compute (4 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76995, dvrr_stack+31769, dvrr_stack+76085, dvrr_stack+257677, dvrr_stack+391005, dvrr_stack+679569);

 /* compute (5 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+78360, dvrr_stack+756730, dvrr_stack+76995, dvrr_stack+258223, dvrr_stack+31769, dvrr_stack+680349);

 /* compute (6 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+758095, dvrr_stack+78360, dvrr_stack+259133, dvrr_stack+756730, dvrr_stack+681519);

 /* compute (7 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76085, dvrr_stack+760006, dvrr_stack+678867, dvrr_stack+11634, dvrr_stack+758095, dvrr_stack+18118);

 /* compute (8 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+762554, dvrr_stack+76085, dvrr_stack+568218, dvrr_stack+760006, dvrr_stack+346586);

 /* compute (9 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+76085, dvrr_stack+765830, dvrr_stack+678867, dvrr_stack+570766, dvrr_stack+762554, dvrr_stack+659553);

 /* compute (10 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+659553, dvrr_stack+402831, dvrr_stack+76085, dvrr_stack+269824, dvrr_stack+765830, dvrr_stack+468845);

 /* compute (11 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+269824, dvrr_stack+769925, dvrr_stack+659553, dvrr_stack+574042, dvrr_stack+402831, dvrr_stack+225039);

 /* compute (12 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 12;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+678867, dvrr_stack+407836, dvrr_stack+269824, dvrr_stack+579047, dvrr_stack+769925, dvrr_stack+541500);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+541500, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 541500;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+542284, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 542284;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+543292, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 543292;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+544552, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 544552;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+546092, dvrr_stack+70541, NULL);
 tmp = dvrr_stack + 546092;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+269824, dvrr_stack+91282, NULL);
 tmp = dvrr_stack + 269824;
 target_ptr = Libderiv->deriv_classes[6][11][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2548,dvrr_stack+272008, dvrr_stack+113059, NULL);
 tmp = dvrr_stack + 272008;
 target_ptr = Libderiv->deriv_classes[6][12][11];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+547940, dvrr_stack+124771, NULL);
 tmp = dvrr_stack + 547940;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+211863, dvrr_stack+132295, NULL);
 tmp = dvrr_stack + 211863;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+218559, dvrr_stack+141683, NULL);
 tmp = dvrr_stack + 218559;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+274556, dvrr_stack+153143, NULL);
 tmp = dvrr_stack + 274556;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+276536, dvrr_stack+166883, NULL);
 tmp = dvrr_stack + 276536;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+225039, dvrr_stack+183111, NULL);
 tmp = dvrr_stack + 225039;
 target_ptr = Libderiv->deriv_classes[7][11][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3276,dvrr_stack+402831, dvrr_stack+202035, NULL);
 tmp = dvrr_stack + 402831;
 target_ptr = Libderiv->deriv_classes[7][12][11];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+227847, dvrr_stack+214779, NULL);
 tmp = dvrr_stack + 227847;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+406107, dvrr_stack+220179, NULL);
 tmp = dvrr_stack + 406107;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+659553, dvrr_stack+233014, NULL);
 tmp = dvrr_stack + 659553;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+661578, dvrr_stack+245689, NULL);
 tmp = dvrr_stack + 661578;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+468845, dvrr_stack+260914, NULL);
 tmp = dvrr_stack + 468845;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+76085, dvrr_stack+279834, NULL);
 tmp = dvrr_stack + 76085;
 target_ptr = Libderiv->deriv_classes[8][11][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4095,dvrr_stack+568218, dvrr_stack+306639, NULL);
 tmp = dvrr_stack + 568218;
 target_ptr = Libderiv->deriv_classes[8][12][11];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+664053, dvrr_stack+330176, NULL);
 tmp = dvrr_stack + 664053;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+79595, dvrr_stack+340646, NULL);
 tmp = dvrr_stack + 79595;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+346586, dvrr_stack+354561, NULL);
 tmp = dvrr_stack + 346586;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+572313, dvrr_stack+371556, NULL);
 tmp = dvrr_stack + 572313;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+361986, dvrr_stack+391941, NULL);
 tmp = dvrr_stack + 361986;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+380631, dvrr_stack+416026, NULL);
 tmp = dvrr_stack + 380631;
 target_ptr = Libderiv->deriv_classes[9][11][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5005,dvrr_stack+756730, dvrr_stack+445171, NULL);
 tmp = dvrr_stack + 756730;
 target_ptr = Libderiv->deriv_classes[9][12][11];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+471815, dvrr_stack+476117, NULL);
 tmp = dvrr_stack + 471815;
 target_ptr = Libderiv->deriv_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+575338, dvrr_stack+492011, NULL);
 tmp = dvrr_stack + 575338;
 target_ptr = Libderiv->deriv_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+18118, dvrr_stack+508764, NULL);
 tmp = dvrr_stack + 18118;
 target_ptr = Libderiv->deriv_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+761735, dvrr_stack+530610, NULL);
 tmp = dvrr_stack + 761735;
 target_ptr = Libderiv->deriv_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+765365, dvrr_stack+555150, NULL);
 tmp = dvrr_stack + 765365;
 target_ptr = Libderiv->deriv_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5148,dvrr_stack+769721, dvrr_stack+585053, NULL);
 tmp = dvrr_stack + 769721;
 target_ptr = Libderiv->deriv_classes[10][11][11];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,6006,dvrr_stack+699022, dvrr_stack+622127, NULL);
 tmp = dvrr_stack + 699022;
 target_ptr = Libderiv->deriv_classes[10][12][11];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+705028, dvrr_stack+653001, NULL);
 tmp = dvrr_stack + 705028;
 target_ptr = Libderiv->deriv_classes[11][6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+707212, dvrr_stack+670443, NULL);
 tmp = dvrr_stack + 707212;
 target_ptr = Libderiv->deriv_classes[11][7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+334796, dvrr_stack+688492, NULL);
 tmp = dvrr_stack + 334796;
 target_ptr = Libderiv->deriv_classes[11][8][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+253114, dvrr_stack+711958, NULL);
 tmp = dvrr_stack + 253114;
 target_ptr = Libderiv->deriv_classes[11][9][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5148,dvrr_stack+731926, dvrr_stack+741286, NULL);
 tmp = dvrr_stack + 731926;
 target_ptr = Libderiv->deriv_classes[11][10][11];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,6084,dvrr_stack+239089, dvrr_stack+775931, NULL);
 tmp = dvrr_stack + 239089;
 target_ptr = Libderiv->deriv_classes[11][11][11];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,7098,dvrr_stack+481661, dvrr_stack+794183, NULL);
 tmp = dvrr_stack + 481661;
 target_ptr = Libderiv->deriv_classes[11][12][11];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+548948, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 548948;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+229107, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 229107;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+665593, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 665593;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+710020, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 710020;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+338306, dvrr_stack+70541, NULL);
 tmp = dvrr_stack + 338306;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+257404, dvrr_stack+91282, NULL);
 tmp = dvrr_stack + 257404;
 target_ptr = Libderiv->deriv_classes[6][11][10];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2548,dvrr_stack+737074, dvrr_stack+113059, NULL);
 tmp = dvrr_stack + 737074;
 target_ptr = Libderiv->deriv_classes[6][12][10];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+81575, dvrr_stack+124771, NULL);
 tmp = dvrr_stack + 81575;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+687148, dvrr_stack+132295, NULL);
 tmp = dvrr_stack + 687148;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+739622, dvrr_stack+141683, NULL);
 tmp = dvrr_stack + 739622;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+323516, dvrr_stack+153143, NULL);
 tmp = dvrr_stack + 323516;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+325496, dvrr_stack+166883, NULL);
 tmp = dvrr_stack + 325496;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+499139, dvrr_stack+183111, NULL);
 tmp = dvrr_stack + 499139;
 target_ptr = Libderiv->deriv_classes[7][11][10];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3276,dvrr_stack+97834, dvrr_stack+202035, NULL);
 tmp = dvrr_stack + 97834;
 target_ptr = Libderiv->deriv_classes[7][12][10];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+577714, dvrr_stack+214779, NULL);
 tmp = dvrr_stack + 577714;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+523680, dvrr_stack+220179, NULL);
 tmp = dvrr_stack + 523680;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+299303, dvrr_stack+233014, NULL);
 tmp = dvrr_stack + 299303;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+501947, dvrr_stack+245689, NULL);
 tmp = dvrr_stack + 501947;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+101110, dvrr_stack+260914, NULL);
 tmp = dvrr_stack + 101110;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+104080, dvrr_stack+279834, NULL);
 tmp = dvrr_stack + 104080;
 target_ptr = Libderiv->deriv_classes[8][11][10];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4095,dvrr_stack+460186, dvrr_stack+306639, NULL);
 tmp = dvrr_stack + 460186;
 target_ptr = Libderiv->deriv_classes[8][12][10];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+121711, dvrr_stack+330176, NULL);
 tmp = dvrr_stack + 121711;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+433766, dvrr_stack+340646, NULL);
 tmp = dvrr_stack + 433766;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+107590, dvrr_stack+354561, NULL);
 tmp = dvrr_stack + 107590;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+57515, dvrr_stack+371556, NULL);
 tmp = dvrr_stack + 57515;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+0, dvrr_stack+391941, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+600497, dvrr_stack+416026, NULL);
 tmp = dvrr_stack + 600497;
 target_ptr = Libderiv->deriv_classes[9][11][10];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5005,dvrr_stack+604787, dvrr_stack+445171, NULL);
 tmp = dvrr_stack + 604787;
 target_ptr = Libderiv->deriv_classes[9][12][10];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+647777, dvrr_stack+476117, NULL);
 tmp = dvrr_stack + 647777;
 target_ptr = Libderiv->deriv_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+464281, dvrr_stack+492011, NULL);
 tmp = dvrr_stack + 464281;
 target_ptr = Libderiv->deriv_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+3630, dvrr_stack+508764, NULL);
 tmp = dvrr_stack + 3630;
 target_ptr = Libderiv->deriv_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+609792, dvrr_stack+530610, NULL);
 tmp = dvrr_stack + 609792;
 target_ptr = Libderiv->deriv_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+41477, dvrr_stack+555150, NULL);
 tmp = dvrr_stack + 41477;
 target_ptr = Libderiv->deriv_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5148,dvrr_stack+29062, dvrr_stack+585053, NULL);
 tmp = dvrr_stack + 29062;
 target_ptr = Libderiv->deriv_classes[10][11][10];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,6006,dvrr_stack+815477, dvrr_stack+622127, NULL);
 tmp = dvrr_stack + 815477;
 target_ptr = Libderiv->deriv_classes[10][12][10];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+60540, dvrr_stack+653001, NULL);
 tmp = dvrr_stack + 60540;
 target_ptr = Libderiv->deriv_classes[11][6][10];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+9898, dvrr_stack+670443, NULL);
 tmp = dvrr_stack + 9898;
 target_ptr = Libderiv->deriv_classes[11][7][10];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+821483, dvrr_stack+688492, NULL);
 tmp = dvrr_stack + 821483;
 target_ptr = Libderiv->deriv_classes[11][8][10];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+824993, dvrr_stack+711958, NULL);
 tmp = dvrr_stack + 824993;
 target_ptr = Libderiv->deriv_classes[11][9][10];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5148,dvrr_stack+829283, dvrr_stack+741286, NULL);
 tmp = dvrr_stack + 829283;
 target_ptr = Libderiv->deriv_classes[11][10][10];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,6084,dvrr_stack+834431, dvrr_stack+775931, NULL);
 tmp = dvrr_stack + 834431;
 target_ptr = Libderiv->deriv_classes[11][11][10];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,7098,dvrr_stack+840515, dvrr_stack+794183, NULL);
 tmp = dvrr_stack + 840515;
 target_ptr = Libderiv->deriv_classes[11][12][10];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+278912, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 278912;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+15766, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 15766;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+26038, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 26038;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+37697, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 37697;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+52895, dvrr_stack+70541, NULL);
 tmp = dvrr_stack + 52895;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+70541, dvrr_stack+91282, NULL);
 tmp = dvrr_stack + 70541;
 target_ptr = Libderiv->deriv_classes[6][11][9];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2548,dvrr_stack+91282, dvrr_stack+113059, NULL);
 tmp = dvrr_stack + 91282;
 target_ptr = Libderiv->deriv_classes[6][12][9];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+113059, dvrr_stack+124771, NULL);
 tmp = dvrr_stack + 113059;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+12706, dvrr_stack+132295, NULL);
 tmp = dvrr_stack + 12706;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+132295, dvrr_stack+141683, NULL);
 tmp = dvrr_stack + 132295;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+141683, dvrr_stack+153143, NULL);
 tmp = dvrr_stack + 141683;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+153143, dvrr_stack+166883, NULL);
 tmp = dvrr_stack + 153143;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+166883, dvrr_stack+183111, NULL);
 tmp = dvrr_stack + 166883;
 target_ptr = Libderiv->deriv_classes[7][11][9];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3276,dvrr_stack+183111, dvrr_stack+202035, NULL);
 tmp = dvrr_stack + 183111;
 target_ptr = Libderiv->deriv_classes[7][12][9];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+202035, dvrr_stack+214779, NULL);
 tmp = dvrr_stack + 202035;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+214779, dvrr_stack+220179, NULL);
 tmp = dvrr_stack + 214779;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+220179, dvrr_stack+233014, NULL);
 tmp = dvrr_stack + 220179;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+233014, dvrr_stack+245689, NULL);
 tmp = dvrr_stack + 233014;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+235489, dvrr_stack+260914, NULL);
 tmp = dvrr_stack + 235489;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+203295, dvrr_stack+279834, NULL);
 tmp = dvrr_stack + 203295;
 target_ptr = Libderiv->deriv_classes[8][11][9];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4095,dvrr_stack+206805, dvrr_stack+306639, NULL);
 tmp = dvrr_stack + 206805;
 target_ptr = Libderiv->deriv_classes[8][12][9];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+306639, dvrr_stack+330176, NULL);
 tmp = dvrr_stack + 306639;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+330176, dvrr_stack+340646, NULL);
 tmp = dvrr_stack + 330176;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+332156, dvrr_stack+354561, NULL);
 tmp = dvrr_stack + 332156;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+308179, dvrr_stack+371556, NULL);
 tmp = dvrr_stack + 308179;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+311204, dvrr_stack+391941, NULL);
 tmp = dvrr_stack + 311204;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+186387, dvrr_stack+416026, NULL);
 tmp = dvrr_stack + 186387;
 target_ptr = Libderiv->deriv_classes[9][11][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5005,dvrr_stack+114067, dvrr_stack+445171, NULL);
 tmp = dvrr_stack + 114067;
 target_ptr = Libderiv->deriv_classes[9][12][9];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+445171, dvrr_stack+476117, NULL);
 tmp = dvrr_stack + 445171;
 target_ptr = Libderiv->deriv_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+476117, dvrr_stack+492011, NULL);
 tmp = dvrr_stack + 476117;
 target_ptr = Libderiv->deriv_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+492011, dvrr_stack+508764, NULL);
 tmp = dvrr_stack + 492011;
 target_ptr = Libderiv->deriv_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+508764, dvrr_stack+530610, NULL);
 tmp = dvrr_stack + 508764;
 target_ptr = Libderiv->deriv_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+530610, dvrr_stack+555150, NULL);
 tmp = dvrr_stack + 530610;
 target_ptr = Libderiv->deriv_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5148,dvrr_stack+555150, dvrr_stack+585053, NULL);
 tmp = dvrr_stack + 555150;
 target_ptr = Libderiv->deriv_classes[10][11][9];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,6006,dvrr_stack+585053, dvrr_stack+622127, NULL);
 tmp = dvrr_stack + 585053;
 target_ptr = Libderiv->deriv_classes[10][12][9];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+622127, dvrr_stack+653001, NULL);
 tmp = dvrr_stack + 622127;
 target_ptr = Libderiv->deriv_classes[11][6][9];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+653001, dvrr_stack+670443, NULL);
 tmp = dvrr_stack + 653001;
 target_ptr = Libderiv->deriv_classes[11][7][9];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+670443, dvrr_stack+688492, NULL);
 tmp = dvrr_stack + 670443;
 target_ptr = Libderiv->deriv_classes[11][8][9];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+673953, dvrr_stack+711958, NULL);
 tmp = dvrr_stack + 673953;
 target_ptr = Libderiv->deriv_classes[11][9][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5148,dvrr_stack+624311, dvrr_stack+741286, NULL);
 tmp = dvrr_stack + 624311;
 target_ptr = Libderiv->deriv_classes[11][10][9];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,6084,dvrr_stack+629459, dvrr_stack+775931, NULL);
 tmp = dvrr_stack + 629459;
 target_ptr = Libderiv->deriv_classes[11][11][9];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,7098,dvrr_stack+591059, dvrr_stack+794183, NULL);
 tmp = dvrr_stack + 591059;
 target_ptr = Libderiv->deriv_classes[11][12][9];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+655809, dvrr_stack+14758, dvrr_stack+431057);
 tmp = dvrr_stack + 655809;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+656593, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 656593;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+657601, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 657601;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+635543, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 635543;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+637083, dvrr_stack+68357, dvrr_stack+36157);
 tmp = dvrr_stack + 637083;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+598157, dvrr_stack+88734, dvrr_stack+51047);
 tmp = dvrr_stack + 598157;
 target_ptr = Libderiv->deriv_classes[6][11][8];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,28,1,dvrr_stack+560298, dvrr_stack+110119, dvrr_stack+68357);
 tmp = dvrr_stack + 560298;
 target_ptr = Libderiv->deriv_classes[6][12][8];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+638931, dvrr_stack+123475, dvrr_stack+432065);
 tmp = dvrr_stack + 638931;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+562846, dvrr_stack+130675, dvrr_stack+120703);
 tmp = dvrr_stack + 562846;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+564142, dvrr_stack+139703, dvrr_stack+123475);
 tmp = dvrr_stack + 564142;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+565762, dvrr_stack+150767, dvrr_stack+130675);
 tmp = dvrr_stack + 565762;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+534966, dvrr_stack+164075, dvrr_stack+139703);
 tmp = dvrr_stack + 534966;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+537342, dvrr_stack+179835, dvrr_stack+150767);
 tmp = dvrr_stack + 537342;
 target_ptr = Libderiv->deriv_classes[7][11][8];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,36,1,dvrr_stack+512394, dvrr_stack+198255, dvrr_stack+164075);
 tmp = dvrr_stack + 512394;
 target_ptr = Libderiv->deriv_classes[7][12][8];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+540150, dvrr_stack+213159, dvrr_stack+432821);
 tmp = dvrr_stack + 540150;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+515670, dvrr_stack+21592, dvrr_stack+6725);
 tmp = dvrr_stack + 515670;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+494981, dvrr_stack+230539, dvrr_stack+213159);
 tmp = dvrr_stack + 494981;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+478493, dvrr_stack+46511, dvrr_stack+21592);
 tmp = dvrr_stack + 478493;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+447019, dvrr_stack+62773, dvrr_stack+230539);
 tmp = dvrr_stack + 447019;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+449989, dvrr_stack+82637, dvrr_stack+46511);
 tmp = dvrr_stack + 449989;
 target_ptr = Libderiv->deriv_classes[8][11][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,45,1,dvrr_stack+453499, dvrr_stack+301914, dvrr_stack+62773);
 tmp = dvrr_stack + 453499;
 target_ptr = Libderiv->deriv_classes[8][12][8];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+497006, dvrr_stack+328196, dvrr_stack+444016);
 tmp = dvrr_stack + 497006;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+457594, dvrr_stack+127795, dvrr_stack+321976);
 tmp = dvrr_stack + 457594;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+314834, dvrr_stack+136183, dvrr_stack+328196);
 tmp = dvrr_stack + 314834;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+169691, dvrr_stack+146543, dvrr_stack+127795);
 tmp = dvrr_stack + 169691;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+93830, dvrr_stack+159083, dvrr_stack+136183);
 tmp = dvrr_stack + 93830;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+279696, dvrr_stack+174011, dvrr_stack+146543);
 tmp = dvrr_stack + 279696;
 target_ptr = Libderiv->deriv_classes[9][11][8];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,55,1,dvrr_stack+283986, dvrr_stack+191535, dvrr_stack+159083);
 tmp = dvrr_stack + 283986;
 target_ptr = Libderiv->deriv_classes[9][12][8];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+222204, dvrr_stack+473741, dvrr_stack+290364);
 tmp = dvrr_stack + 222204;
 target_ptr = Libderiv->deriv_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+155519, dvrr_stack+489041, dvrr_stack+466997);
 tmp = dvrr_stack + 155519;
 target_ptr = Libderiv->deriv_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+124771, dvrr_stack+505134, dvrr_stack+473741);
 tmp = dvrr_stack + 124771;
 target_ptr = Libderiv->deriv_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+688444, dvrr_stack+526254, dvrr_stack+489041);
 tmp = dvrr_stack + 688444;
 target_ptr = Libderiv->deriv_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+692074, dvrr_stack+550002, dvrr_stack+505134);
 tmp = dvrr_stack + 692074;
 target_ptr = Libderiv->deriv_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,66,1,dvrr_stack+774869, dvrr_stack+579047, dvrr_stack+526254);
 tmp = dvrr_stack + 774869;
 target_ptr = Libderiv->deriv_classes[10][11][8];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,66,1,dvrr_stack+780017, dvrr_stack+615197, dvrr_stack+550002);
 tmp = dvrr_stack + 780017;
 target_ptr = Libderiv->deriv_classes[10][12][8];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,78,1,dvrr_stack+143663, dvrr_stack+650193, dvrr_stack+428896);
 tmp = dvrr_stack + 143663;
 target_ptr = Libderiv->deriv_classes[11][6][8];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,78,1,dvrr_stack+72725, dvrr_stack+666933, dvrr_stack+318924);
 tmp = dvrr_stack + 72725;
 target_ptr = Libderiv->deriv_classes[11][7][8];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,78,1,dvrr_stack+786023, dvrr_stack+349611, dvrr_stack+650193);
 tmp = dvrr_stack + 786023;
 target_ptr = Libderiv->deriv_classes[11][8][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,78,1,dvrr_stack+789533, dvrr_stack+365616, dvrr_stack+666933);
 tmp = dvrr_stack + 789533;
 target_ptr = Libderiv->deriv_classes[11][9][8];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,78,1,dvrr_stack+793823, dvrr_stack+384921, dvrr_stack+349611);
 tmp = dvrr_stack + 793823;
 target_ptr = Libderiv->deriv_classes[11][10][8];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,78,1,dvrr_stack+798971, dvrr_stack+407836, dvrr_stack+365616);
 tmp = dvrr_stack + 798971;
 target_ptr = Libderiv->deriv_classes[11][11][8];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,78,1,dvrr_stack+805055, dvrr_stack+435826, dvrr_stack+384921);
 tmp = dvrr_stack + 805055;
 target_ptr = Libderiv->deriv_classes[11][12][8];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+317309, dvrr_stack+14758, dvrr_stack+431057);
 tmp = dvrr_stack + 317309;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+216399, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 216399;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+172716, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 172716;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+133915, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 133915;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+54743, dvrr_stack+68357, dvrr_stack+36157);
 tmp = dvrr_stack + 54743;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+39237, dvrr_stack+88734, dvrr_stack+51047);
 tmp = dvrr_stack + 39237;
 target_ptr = Libderiv->deriv_classes[6][11][7];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,28,1,dvrr_stack+696430, dvrr_stack+110119, dvrr_stack+68357);
 tmp = dvrr_stack + 696430;
 target_ptr = Libderiv->deriv_classes[6][12][7];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+217407, dvrr_stack+123475, dvrr_stack+432065);
 tmp = dvrr_stack + 217407;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+119072, dvrr_stack+130675, dvrr_stack+120703);
 tmp = dvrr_stack + 119072;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+27298, dvrr_stack+139703, dvrr_stack+123475);
 tmp = dvrr_stack + 27298;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+812153, dvrr_stack+150767, dvrr_stack+130675);
 tmp = dvrr_stack + 812153;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+391005, dvrr_stack+164075, dvrr_stack+139703);
 tmp = dvrr_stack + 391005;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+393381, dvrr_stack+179835, dvrr_stack+150767);
 tmp = dvrr_stack + 393381;
 target_ptr = Libderiv->deriv_classes[7][11][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,36,1,dvrr_stack+396189, dvrr_stack+198255, dvrr_stack+164075);
 tmp = dvrr_stack + 396189;
 target_ptr = Libderiv->deriv_classes[7][12][7];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+16774, dvrr_stack+213159, dvrr_stack+432821);
 tmp = dvrr_stack + 16774;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+399465, dvrr_stack+21592, dvrr_stack+6725);
 tmp = dvrr_stack + 399465;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+711560, dvrr_stack+230539, dvrr_stack+213159);
 tmp = dvrr_stack + 711560;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+713585, dvrr_stack+46511, dvrr_stack+21592);
 tmp = dvrr_stack + 713585;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+716060, dvrr_stack+62773, dvrr_stack+230539);
 tmp = dvrr_stack + 716060;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+719030, dvrr_stack+82637, dvrr_stack+46511);
 tmp = dvrr_stack + 719030;
 target_ptr = Libderiv->deriv_classes[8][11][7];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,45,1,dvrr_stack+340154, dvrr_stack+301914, dvrr_stack+62773);
 tmp = dvrr_stack + 340154;
 target_ptr = Libderiv->deriv_classes[8][12][7];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+401085, dvrr_stack+328196, dvrr_stack+444016);
 tmp = dvrr_stack + 401085;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+722540, dvrr_stack+127795, dvrr_stack+321976);
 tmp = dvrr_stack + 722540;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+259588, dvrr_stack+136183, dvrr_stack+328196);
 tmp = dvrr_stack + 259588;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+262063, dvrr_stack+146543, dvrr_stack+127795);
 tmp = dvrr_stack + 262063;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+265088, dvrr_stack+159083, dvrr_stack+136183);
 tmp = dvrr_stack + 265088;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+741242, dvrr_stack+174011, dvrr_stack+146543);
 tmp = dvrr_stack + 741242;
 target_ptr = Libderiv->deriv_classes[9][11][7];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,55,1,dvrr_stack+745532, dvrr_stack+191535, dvrr_stack+159083);
 tmp = dvrr_stack + 745532;
 target_ptr = Libderiv->deriv_classes[9][12][7];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+344249, dvrr_stack+473741, dvrr_stack+290364);
 tmp = dvrr_stack + 344249;
 target_ptr = Libderiv->deriv_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+750537, dvrr_stack+489041, dvrr_stack+466997);
 tmp = dvrr_stack + 750537;
 target_ptr = Libderiv->deriv_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+752913, dvrr_stack+505134, dvrr_stack+473741);
 tmp = dvrr_stack + 752913;
 target_ptr = Libderiv->deriv_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+370764, dvrr_stack+526254, dvrr_stack+489041);
 tmp = dvrr_stack + 370764;
 target_ptr = Libderiv->deriv_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+374394, dvrr_stack+550002, dvrr_stack+505134);
 tmp = dvrr_stack + 374394;
 target_ptr = Libderiv->deriv_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,66,1,dvrr_stack+245173, dvrr_stack+579047, dvrr_stack+526254);
 tmp = dvrr_stack + 245173;
 target_ptr = Libderiv->deriv_classes[10][11][7];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,66,1,dvrr_stack+353901, dvrr_stack+615197, dvrr_stack+550002);
 tmp = dvrr_stack + 353901;
 target_ptr = Libderiv->deriv_classes[10][12][7];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,78,1,dvrr_stack+250321, dvrr_stack+650193, dvrr_stack+428896);
 tmp = dvrr_stack + 250321;
 target_ptr = Libderiv->deriv_classes[11][6][7];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,78,1,dvrr_stack+414934, dvrr_stack+666933, dvrr_stack+318924);
 tmp = dvrr_stack + 414934;
 target_ptr = Libderiv->deriv_classes[11][7][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,78,1,dvrr_stack+417742, dvrr_stack+349611, dvrr_stack+650193);
 tmp = dvrr_stack + 417742;
 target_ptr = Libderiv->deriv_classes[11][8][7];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,78,1,dvrr_stack+421252, dvrr_stack+365616, dvrr_stack+666933);
 tmp = dvrr_stack + 421252;
 target_ptr = Libderiv->deriv_classes[11][9][7];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,78,1,dvrr_stack+847613, dvrr_stack+384921, dvrr_stack+349611);
 tmp = dvrr_stack + 847613;
 target_ptr = Libderiv->deriv_classes[11][10][7];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,78,1,dvrr_stack+852761, dvrr_stack+407836, dvrr_stack+365616);
 tmp = dvrr_stack + 852761;
 target_ptr = Libderiv->deriv_classes[11][11][7];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,78,1,dvrr_stack+858845, dvrr_stack+435826, dvrr_stack+384921);
 tmp = dvrr_stack + 858845;
 target_ptr = Libderiv->deriv_classes[11][12][7];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+318093, dvrr_stack+14758, dvrr_stack+431057);
 tmp = dvrr_stack + 318093;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+157895, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 157895;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+288991, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 288991;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+378750, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 378750;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+359907, dvrr_stack+68357, dvrr_stack+36157);
 tmp = dvrr_stack + 359907;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+425542, dvrr_stack+88734, dvrr_stack+51047);
 tmp = dvrr_stack + 425542;
 target_ptr = Libderiv->deriv_classes[6][11][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,28,1,dvrr_stack+865943, dvrr_stack+110119, dvrr_stack+68357);
 tmp = dvrr_stack + 865943;
 target_ptr = Libderiv->deriv_classes[6][12][6];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+814133, dvrr_stack+123475, dvrr_stack+432065);
 tmp = dvrr_stack + 814133;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+110065, dvrr_stack+130675, dvrr_stack+120703);
 tmp = dvrr_stack + 110065;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+111361, dvrr_stack+139703, dvrr_stack+123475);
 tmp = dvrr_stack + 111361;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+430534, dvrr_stack+150767, dvrr_stack+130675);
 tmp = dvrr_stack + 430534;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+868491, dvrr_stack+164075, dvrr_stack+139703);
 tmp = dvrr_stack + 868491;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+870867, dvrr_stack+179835, dvrr_stack+150767);
 tmp = dvrr_stack + 870867;
 target_ptr = Libderiv->deriv_classes[7][11][6];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,36,1,dvrr_stack+873675, dvrr_stack+198255, dvrr_stack+164075);
 tmp = dvrr_stack + 873675;
 target_ptr = Libderiv->deriv_classes[7][12][6];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+197310, dvrr_stack+213159, dvrr_stack+432821);
 tmp = dvrr_stack + 197310;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+198570, dvrr_stack+21592, dvrr_stack+6725);
 tmp = dvrr_stack + 198570;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+876951, dvrr_stack+230539, dvrr_stack+213159);
 tmp = dvrr_stack + 876951;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+878976, dvrr_stack+46511, dvrr_stack+21592);
 tmp = dvrr_stack + 878976;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+881451, dvrr_stack+62773, dvrr_stack+230539);
 tmp = dvrr_stack + 881451;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+884421, dvrr_stack+82637, dvrr_stack+46511);
 tmp = dvrr_stack + 884421;
 target_ptr = Libderiv->deriv_classes[8][11][6];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,45,1,dvrr_stack+887931, dvrr_stack+301914, dvrr_stack+62773);
 tmp = dvrr_stack + 887931;
 target_ptr = Libderiv->deriv_classes[8][12][6];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+301328, dvrr_stack+328196, dvrr_stack+444016);
 tmp = dvrr_stack + 301328;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+302868, dvrr_stack+127795, dvrr_stack+321976);
 tmp = dvrr_stack + 302868;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+892026, dvrr_stack+136183, dvrr_stack+328196);
 tmp = dvrr_stack + 892026;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+894501, dvrr_stack+146543, dvrr_stack+127795);
 tmp = dvrr_stack + 894501;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+897526, dvrr_stack+159083, dvrr_stack+136183);
 tmp = dvrr_stack + 897526;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+901156, dvrr_stack+174011, dvrr_stack+146543);
 tmp = dvrr_stack + 901156;
 target_ptr = Libderiv->deriv_classes[9][11][6];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,55,1,dvrr_stack+905446, dvrr_stack+191535, dvrr_stack+159083);
 tmp = dvrr_stack + 905446;
 target_ptr = Libderiv->deriv_classes[9][12][6];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+190677, dvrr_stack+473741, dvrr_stack+290364);
 tmp = dvrr_stack + 190677;
 target_ptr = Libderiv->deriv_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+192525, dvrr_stack+489041, dvrr_stack+466997);
 tmp = dvrr_stack + 192525;
 target_ptr = Libderiv->deriv_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+910451, dvrr_stack+505134, dvrr_stack+473741);
 tmp = dvrr_stack + 910451;
 target_ptr = Libderiv->deriv_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+913421, dvrr_stack+526254, dvrr_stack+489041);
 tmp = dvrr_stack + 913421;
 target_ptr = Libderiv->deriv_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+917051, dvrr_stack+550002, dvrr_stack+505134);
 tmp = dvrr_stack + 917051;
 target_ptr = Libderiv->deriv_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,66,1,dvrr_stack+921407, dvrr_stack+579047, dvrr_stack+526254);
 tmp = dvrr_stack + 921407;
 target_ptr = Libderiv->deriv_classes[10][11][6];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,66,1,dvrr_stack+926555, dvrr_stack+615197, dvrr_stack+550002);
 tmp = dvrr_stack + 926555;
 target_ptr = Libderiv->deriv_classes[10][12][6];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,78,1,dvrr_stack+194901, dvrr_stack+650193, dvrr_stack+428896);
 tmp = dvrr_stack + 194901;
 target_ptr = Libderiv->deriv_classes[11][6][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,78,1,dvrr_stack+427726, dvrr_stack+666933, dvrr_stack+318924);
 tmp = dvrr_stack + 427726;
 target_ptr = Libderiv->deriv_classes[11][7][6];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,78,1,dvrr_stack+613422, dvrr_stack+349611, dvrr_stack+650193);
 tmp = dvrr_stack + 613422;
 target_ptr = Libderiv->deriv_classes[11][8][6];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,78,1,dvrr_stack+616932, dvrr_stack+365616, dvrr_stack+666933);
 tmp = dvrr_stack + 616932;
 target_ptr = Libderiv->deriv_classes[11][9][6];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,78,1,dvrr_stack+932561, dvrr_stack+384921, dvrr_stack+349611);
 tmp = dvrr_stack + 932561;
 target_ptr = Libderiv->deriv_classes[11][10][6];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,78,1,dvrr_stack+937709, dvrr_stack+407836, dvrr_stack+365616);
 tmp = dvrr_stack + 937709;
 target_ptr = Libderiv->deriv_classes[11][11][6];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,78,1,dvrr_stack+943793, dvrr_stack+435826, dvrr_stack+384921);
 tmp = dvrr_stack + 943793;
 target_ptr = Libderiv->deriv_classes[11][12][6];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+224052, dvrr_stack+120703, dvrr_stack+8526);
 tmp = dvrr_stack + 224052;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+290251, dvrr_stack+123475, dvrr_stack+14002);
 tmp = dvrr_stack + 290251;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+304848, dvrr_stack+130675, dvrr_stack+23833);
 tmp = dvrr_stack + 304848;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+200190, dvrr_stack+139703, dvrr_stack+35002);
 tmp = dvrr_stack + 200190;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+435746, dvrr_stack+150767, dvrr_stack+49661);
 tmp = dvrr_stack + 435746;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,78,dvrr_stack+437594, dvrr_stack+164075, dvrr_stack+66719);
 tmp = dvrr_stack + 437594;
 target_ptr = Libderiv->deriv_classes[6][11][2];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,91,dvrr_stack+439778, dvrr_stack+179835, dvrr_stack+86823);
 tmp = dvrr_stack + 439778;
 target_ptr = Libderiv->deriv_classes[6][12][2];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+268718, dvrr_stack+6725, dvrr_stack+9114);
 tmp = dvrr_stack + 268718;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+442326, dvrr_stack+213159, dvrr_stack+14758);
 tmp = dvrr_stack + 442326;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+950891, dvrr_stack+21592, dvrr_stack+24778);
 tmp = dvrr_stack + 950891;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+952511, dvrr_stack+230539, dvrr_stack+36157);
 tmp = dvrr_stack + 952511;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+954491, dvrr_stack+46511, dvrr_stack+51047);
 tmp = dvrr_stack + 954491;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,78,dvrr_stack+956867, dvrr_stack+62773, dvrr_stack+68357);
 tmp = dvrr_stack + 956867;
 target_ptr = Libderiv->deriv_classes[7][11][2];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,91,dvrr_stack+959675, dvrr_stack+82637, dvrr_stack+88734);
 tmp = dvrr_stack + 959675;
 target_ptr = Libderiv->deriv_classes[7][12][2];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+443622, dvrr_stack+321976, dvrr_stack+120703);
 tmp = dvrr_stack + 443622;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+962951, dvrr_stack+328196, dvrr_stack+123475);
 tmp = dvrr_stack + 962951;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+964571, dvrr_stack+127795, dvrr_stack+130675);
 tmp = dvrr_stack + 964571;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+966596, dvrr_stack+136183, dvrr_stack+139703);
 tmp = dvrr_stack + 966596;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+969071, dvrr_stack+146543, dvrr_stack+150767);
 tmp = dvrr_stack + 969071;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,78,dvrr_stack+972041, dvrr_stack+159083, dvrr_stack+164075);
 tmp = dvrr_stack + 972041;
 target_ptr = Libderiv->deriv_classes[8][11][2];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,91,dvrr_stack+975551, dvrr_stack+174011, dvrr_stack+179835);
 tmp = dvrr_stack + 975551;
 target_ptr = Libderiv->deriv_classes[8][12][2];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+979646, dvrr_stack+466997, dvrr_stack+6725);
 tmp = dvrr_stack + 979646;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+981186, dvrr_stack+473741, dvrr_stack+213159);
 tmp = dvrr_stack + 981186;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+983166, dvrr_stack+489041, dvrr_stack+21592);
 tmp = dvrr_stack + 983166;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+985641, dvrr_stack+505134, dvrr_stack+230539);
 tmp = dvrr_stack + 985641;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+988666, dvrr_stack+526254, dvrr_stack+46511);
 tmp = dvrr_stack + 988666;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,78,dvrr_stack+992296, dvrr_stack+550002, dvrr_stack+62773);
 tmp = dvrr_stack + 992296;
 target_ptr = Libderiv->deriv_classes[9][11][2];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,91,dvrr_stack+996586, dvrr_stack+579047, dvrr_stack+82637);
 tmp = dvrr_stack + 996586;
 target_ptr = Libderiv->deriv_classes[9][12][2];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+1001591, dvrr_stack+318924, dvrr_stack+321976);
 tmp = dvrr_stack + 1001591;
 target_ptr = Libderiv->deriv_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+1003439, dvrr_stack+650193, dvrr_stack+328196);
 tmp = dvrr_stack + 1003439;
 target_ptr = Libderiv->deriv_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+1005815, dvrr_stack+666933, dvrr_stack+127795);
 tmp = dvrr_stack + 1005815;
 target_ptr = Libderiv->deriv_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+1008785, dvrr_stack+349611, dvrr_stack+136183);
 tmp = dvrr_stack + 1008785;
 target_ptr = Libderiv->deriv_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+1012415, dvrr_stack+365616, dvrr_stack+146543);
 tmp = dvrr_stack + 1012415;
 target_ptr = Libderiv->deriv_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,78,dvrr_stack+1016771, dvrr_stack+384921, dvrr_stack+159083);
 tmp = dvrr_stack + 1016771;
 target_ptr = Libderiv->deriv_classes[10][11][2];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,91,dvrr_stack+1021919, dvrr_stack+407836, dvrr_stack+174011);
 tmp = dvrr_stack + 1021919;
 target_ptr = Libderiv->deriv_classes[10][12][2];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,28,dvrr_stack+1027925, dvrr_stack+291750, dvrr_stack+466997);
 tmp = dvrr_stack + 1027925;
 target_ptr = Libderiv->deriv_classes[11][6][2];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,36,dvrr_stack+1030109, dvrr_stack+644501, dvrr_stack+473741);
 tmp = dvrr_stack + 1030109;
 target_ptr = Libderiv->deriv_classes[11][7][2];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,45,dvrr_stack+1032917, dvrr_stack+640145, dvrr_stack+489041);
 tmp = dvrr_stack + 1032917;
 target_ptr = Libderiv->deriv_classes[11][8][2];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,55,dvrr_stack+1036427, dvrr_stack+294298, dvrr_stack+505134);
 tmp = dvrr_stack + 1036427;
 target_ptr = Libderiv->deriv_classes[11][9][2];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,66,dvrr_stack+1040717, dvrr_stack+517674, dvrr_stack+526254);
 tmp = dvrr_stack + 1040717;
 target_ptr = Libderiv->deriv_classes[11][10][2];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,78,dvrr_stack+1045865, dvrr_stack+724828, dvrr_stack+550002);
 tmp = dvrr_stack + 1045865;
 target_ptr = Libderiv->deriv_classes[11][11][2];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_o(Data,91,dvrr_stack+1051949, dvrr_stack+678867, dvrr_stack+579047);
 tmp = dvrr_stack + 1051949;
 target_ptr = Libderiv->deriv_classes[11][12][2];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+210900, dvrr_stack+120703, dvrr_stack+8526);
 tmp = dvrr_stack + 210900;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+432514, dvrr_stack+123475, dvrr_stack+14002);
 tmp = dvrr_stack + 432514;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1059047, dvrr_stack+130675, dvrr_stack+23833);
 tmp = dvrr_stack + 1059047;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1060307, dvrr_stack+139703, dvrr_stack+35002);
 tmp = dvrr_stack + 1060307;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+1061847, dvrr_stack+150767, dvrr_stack+49661);
 tmp = dvrr_stack + 1061847;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,78,dvrr_stack+1063695, dvrr_stack+164075, dvrr_stack+66719);
 tmp = dvrr_stack + 1063695;
 target_ptr = Libderiv->deriv_classes[6][11][1];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,91,dvrr_stack+1065879, dvrr_stack+179835, dvrr_stack+86823);
 tmp = dvrr_stack + 1065879;
 target_ptr = Libderiv->deriv_classes[6][12][1];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1068427, dvrr_stack+6725, dvrr_stack+9114);
 tmp = dvrr_stack + 1068427;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1069435, dvrr_stack+213159, dvrr_stack+14758);
 tmp = dvrr_stack + 1069435;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1070731, dvrr_stack+21592, dvrr_stack+24778);
 tmp = dvrr_stack + 1070731;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1072351, dvrr_stack+230539, dvrr_stack+36157);
 tmp = dvrr_stack + 1072351;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+1074331, dvrr_stack+46511, dvrr_stack+51047);
 tmp = dvrr_stack + 1074331;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,78,dvrr_stack+1076707, dvrr_stack+62773, dvrr_stack+68357);
 tmp = dvrr_stack + 1076707;
 target_ptr = Libderiv->deriv_classes[7][11][1];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,91,dvrr_stack+1079515, dvrr_stack+82637, dvrr_stack+88734);
 tmp = dvrr_stack + 1079515;
 target_ptr = Libderiv->deriv_classes[7][12][1];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1082791, dvrr_stack+321976, dvrr_stack+120703);
 tmp = dvrr_stack + 1082791;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1084051, dvrr_stack+328196, dvrr_stack+123475);
 tmp = dvrr_stack + 1084051;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1085671, dvrr_stack+127795, dvrr_stack+130675);
 tmp = dvrr_stack + 1085671;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1087696, dvrr_stack+136183, dvrr_stack+139703);
 tmp = dvrr_stack + 1087696;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+1090171, dvrr_stack+146543, dvrr_stack+150767);
 tmp = dvrr_stack + 1090171;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,78,dvrr_stack+1093141, dvrr_stack+159083, dvrr_stack+164075);
 tmp = dvrr_stack + 1093141;
 target_ptr = Libderiv->deriv_classes[8][11][1];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,91,dvrr_stack+1096651, dvrr_stack+174011, dvrr_stack+179835);
 tmp = dvrr_stack + 1096651;
 target_ptr = Libderiv->deriv_classes[8][12][1];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+1100746, dvrr_stack+466997, dvrr_stack+6725);
 tmp = dvrr_stack + 1100746;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+1102286, dvrr_stack+473741, dvrr_stack+213159);
 tmp = dvrr_stack + 1102286;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+1104266, dvrr_stack+489041, dvrr_stack+21592);
 tmp = dvrr_stack + 1104266;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+1106741, dvrr_stack+505134, dvrr_stack+230539);
 tmp = dvrr_stack + 1106741;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+1109766, dvrr_stack+526254, dvrr_stack+46511);
 tmp = dvrr_stack + 1109766;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,78,dvrr_stack+1113396, dvrr_stack+550002, dvrr_stack+62773);
 tmp = dvrr_stack + 1113396;
 target_ptr = Libderiv->deriv_classes[9][11][1];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,91,dvrr_stack+1117686, dvrr_stack+579047, dvrr_stack+82637);
 tmp = dvrr_stack + 1117686;
 target_ptr = Libderiv->deriv_classes[9][12][1];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+1122691, dvrr_stack+318924, dvrr_stack+321976);
 tmp = dvrr_stack + 1122691;
 target_ptr = Libderiv->deriv_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+1124539, dvrr_stack+650193, dvrr_stack+328196);
 tmp = dvrr_stack + 1124539;
 target_ptr = Libderiv->deriv_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+1126915, dvrr_stack+666933, dvrr_stack+127795);
 tmp = dvrr_stack + 1126915;
 target_ptr = Libderiv->deriv_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+1129885, dvrr_stack+349611, dvrr_stack+136183);
 tmp = dvrr_stack + 1129885;
 target_ptr = Libderiv->deriv_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+1133515, dvrr_stack+365616, dvrr_stack+146543);
 tmp = dvrr_stack + 1133515;
 target_ptr = Libderiv->deriv_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,78,dvrr_stack+1137871, dvrr_stack+384921, dvrr_stack+159083);
 tmp = dvrr_stack + 1137871;
 target_ptr = Libderiv->deriv_classes[10][11][1];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,91,dvrr_stack+1143019, dvrr_stack+407836, dvrr_stack+174011);
 tmp = dvrr_stack + 1143019;
 target_ptr = Libderiv->deriv_classes[10][12][1];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,28,dvrr_stack+1149025, dvrr_stack+291750, dvrr_stack+466997);
 tmp = dvrr_stack + 1149025;
 target_ptr = Libderiv->deriv_classes[11][6][1];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,36,dvrr_stack+1151209, dvrr_stack+644501, dvrr_stack+473741);
 tmp = dvrr_stack + 1151209;
 target_ptr = Libderiv->deriv_classes[11][7][1];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,45,dvrr_stack+1154017, dvrr_stack+640145, dvrr_stack+489041);
 tmp = dvrr_stack + 1154017;
 target_ptr = Libderiv->deriv_classes[11][8][1];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,55,dvrr_stack+1157527, dvrr_stack+294298, dvrr_stack+505134);
 tmp = dvrr_stack + 1157527;
 target_ptr = Libderiv->deriv_classes[11][9][1];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,66,dvrr_stack+1161817, dvrr_stack+517674, dvrr_stack+526254);
 tmp = dvrr_stack + 1161817;
 target_ptr = Libderiv->deriv_classes[11][10][1];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,78,dvrr_stack+1166965, dvrr_stack+724828, dvrr_stack+550002);
 tmp = dvrr_stack + 1166965;
 target_ptr = Libderiv->deriv_classes[11][11][1];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_o(Data,91,dvrr_stack+1173049, dvrr_stack+678867, dvrr_stack+579047);
 tmp = dvrr_stack + 1173049;
 target_ptr = Libderiv->deriv_classes[11][12][1];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+56591, dvrr_stack+120703, dvrr_stack+8526);
 tmp = dvrr_stack + 56591;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+7985, dvrr_stack+123475, dvrr_stack+14002);
 tmp = dvrr_stack + 7985;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+1180147, dvrr_stack+130675, dvrr_stack+23833);
 tmp = dvrr_stack + 1180147;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+1181407, dvrr_stack+139703, dvrr_stack+35002);
 tmp = dvrr_stack + 1181407;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+34210, dvrr_stack+150767, dvrr_stack+49661);
 tmp = dvrr_stack + 34210;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,78,dvrr_stack+1182947, dvrr_stack+164075, dvrr_stack+66719);
 tmp = dvrr_stack + 1182947;
 target_ptr = Libderiv->deriv_classes[6][11][0];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,91,dvrr_stack+1185131, dvrr_stack+179835, dvrr_stack+86823);
 tmp = dvrr_stack + 1185131;
 target_ptr = Libderiv->deriv_classes[6][12][0];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+23617, dvrr_stack+6725, dvrr_stack+9114);
 tmp = dvrr_stack + 23617;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+86732, dvrr_stack+213159, dvrr_stack+14758);
 tmp = dvrr_stack + 86732;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+14002, dvrr_stack+21592, dvrr_stack+24778);
 tmp = dvrr_stack + 14002;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+66283, dvrr_stack+230539, dvrr_stack+36157);
 tmp = dvrr_stack + 66283;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+1187679, dvrr_stack+46511, dvrr_stack+51047);
 tmp = dvrr_stack + 1187679;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,78,dvrr_stack+49481, dvrr_stack+62773, dvrr_stack+68357);
 tmp = dvrr_stack + 49481;
 target_ptr = Libderiv->deriv_classes[7][11][0];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,91,dvrr_stack+1190055, dvrr_stack+82637, dvrr_stack+88734);
 tmp = dvrr_stack + 1190055;
 target_ptr = Libderiv->deriv_classes[7][12][0];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+24625, dvrr_stack+321976, dvrr_stack+120703);
 tmp = dvrr_stack + 24625;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+88028, dvrr_stack+328196, dvrr_stack+123475);
 tmp = dvrr_stack + 88028;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+68263, dvrr_stack+127795, dvrr_stack+130675);
 tmp = dvrr_stack + 68263;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+1193331, dvrr_stack+136183, dvrr_stack+139703);
 tmp = dvrr_stack + 1193331;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+1195806, dvrr_stack+146543, dvrr_stack+150767);
 tmp = dvrr_stack + 1195806;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,78,dvrr_stack+1198776, dvrr_stack+159083, dvrr_stack+164075);
 tmp = dvrr_stack + 1198776;
 target_ptr = Libderiv->deriv_classes[8][11][0];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,91,dvrr_stack+1202286, dvrr_stack+174011, dvrr_stack+179835);
 tmp = dvrr_stack + 1202286;
 target_ptr = Libderiv->deriv_classes[8][12][0];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+89648, dvrr_stack+466997, dvrr_stack+6725);
 tmp = dvrr_stack + 89648;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+179016, dvrr_stack+473741, dvrr_stack+213159);
 tmp = dvrr_stack + 179016;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+139208, dvrr_stack+489041, dvrr_stack+21592);
 tmp = dvrr_stack + 139208;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+163373, dvrr_stack+505134, dvrr_stack+230539);
 tmp = dvrr_stack + 163373;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+1206381, dvrr_stack+526254, dvrr_stack+46511);
 tmp = dvrr_stack + 1206381;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,78,dvrr_stack+1210011, dvrr_stack+550002, dvrr_stack+62773);
 tmp = dvrr_stack + 1210011;
 target_ptr = Libderiv->deriv_classes[9][11][0];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,91,dvrr_stack+1214301, dvrr_stack+579047, dvrr_stack+82637);
 tmp = dvrr_stack + 1214301;
 target_ptr = Libderiv->deriv_classes[9][12][0];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+230115, dvrr_stack+318924, dvrr_stack+321976);
 tmp = dvrr_stack + 230115;
 target_ptr = Libderiv->deriv_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+318877, dvrr_stack+650193, dvrr_stack+328196);
 tmp = dvrr_stack + 318877;
 target_ptr = Libderiv->deriv_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+150173, dvrr_stack+666933, dvrr_stack+127795);
 tmp = dvrr_stack + 150173;
 target_ptr = Libderiv->deriv_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+127741, dvrr_stack+349611, dvrr_stack+136183);
 tmp = dvrr_stack + 127741;
 target_ptr = Libderiv->deriv_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+349061, dvrr_stack+365616, dvrr_stack+146543);
 tmp = dvrr_stack + 349061;
 target_ptr = Libderiv->deriv_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,78,dvrr_stack+365616, dvrr_stack+384921, dvrr_stack+159083);
 tmp = dvrr_stack + 365616;
 target_ptr = Libderiv->deriv_classes[10][11][0];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,91,dvrr_stack+384921, dvrr_stack+407836, dvrr_stack+174011);
 tmp = dvrr_stack + 384921;
 target_ptr = Libderiv->deriv_classes[10][12][0];
 for(i=0;i<6006;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,28,dvrr_stack+321253, dvrr_stack+291750, dvrr_stack+466997);
 tmp = dvrr_stack + 321253;
 target_ptr = Libderiv->deriv_classes[11][6][0];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,36,dvrr_stack+173976, dvrr_stack+644501, dvrr_stack+473741);
 tmp = dvrr_stack + 173976;
 target_ptr = Libderiv->deriv_classes[11][7][0];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,45,dvrr_stack+158903, dvrr_stack+640145, dvrr_stack+489041);
 tmp = dvrr_stack + 158903;
 target_ptr = Libderiv->deriv_classes[11][8][0];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,55,dvrr_stack+639939, dvrr_stack+294298, dvrr_stack+505134);
 tmp = dvrr_stack + 639939;
 target_ptr = Libderiv->deriv_classes[11][9][0];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,66,dvrr_stack+291259, dvrr_stack+517674, dvrr_stack+526254);
 tmp = dvrr_stack + 291259;
 target_ptr = Libderiv->deriv_classes[11][10][0];
 for(i=0;i<5148;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,78,dvrr_stack+517290, dvrr_stack+724828, dvrr_stack+550002);
 tmp = dvrr_stack + 517290;
 target_ptr = Libderiv->deriv_classes[11][11][0];
 for(i=0;i<6084;i++)
   target_ptr[i] += tmp[i];

 /* compute (11 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_o(Data,91,dvrr_stack+407727, dvrr_stack+678867, dvrr_stack+579047);
 tmp = dvrr_stack + 407727;
 target_ptr = Libderiv->deriv_classes[11][12][0];
 for(i=0;i<7098;i++)
   target_ptr[i] += tmp[i];


}

