/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gghg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+4);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+521, r12vrr_stack+476, r12vrr_stack+506, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+611, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+131);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+24, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+701, r12vrr_stack+24, r12vrr_stack+161, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+170, r12vrr_stack+701, r12vrr_stack+164, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+732, r12vrr_stack+717, r12vrr_stack+491, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+180);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+180, r12vrr_stack+21, r12vrr_stack+27, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+186, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+882, r12vrr_stack+506, r12vrr_stack+867, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+927, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+226);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1017, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+256);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1167, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+316);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1317, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+376);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+196, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+161, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1542, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+196);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1560, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1578, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+161);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1614, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+1542);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1674, r12vrr_stack+216, r12vrr_stack+186, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1704, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+1560);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1764, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+1578);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1864, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+1614);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+27, r12vrr_stack+3, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+326, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+210, r12vrr_stack+180, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2014, r12vrr_stack+867, r12vrr_stack+326, NULL, NULL, r12vrr_stack+186);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2059, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+1674);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2149, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+1704);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2299, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+1764);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2524, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+1864);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+341, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+131, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2839, r12vrr_stack+131, r12vrr_stack+341, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2902, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2923, r12vrr_stack+2902, r12vrr_stack+131, NULL, NULL, r12vrr_stack+476);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2986, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+216, r12vrr_stack+186, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3007, r12vrr_stack+341, r12vrr_stack+2986, NULL, NULL, r12vrr_stack+867);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3070, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+882);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3196, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+521);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3322, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+927);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+707, r12vrr_stack+170, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+2902, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+566);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+611);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+170, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+173, r12vrr_stack+3, r12vrr_stack+170, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+542, r12vrr_stack+15, r12vrr_stack+173, r12vrr_stack+27, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+552, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+180, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+567, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+186, r12vrr_stack+316, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+588, r12vrr_stack+2986, r12vrr_stack+567, NULL, NULL, r12vrr_stack+326);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3931, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+2014);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4057, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+2059);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4267, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2149);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+1017);
 tmp = r12vrr_stack + 4582;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+2299);
 tmp = r12vrr_stack + 4897;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+651, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+476, r12vrr_stack+506, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5338, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+491, r12vrr_stack+476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5366, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+506, r12vrr_stack+867, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5394, r12vrr_stack+651, r12vrr_stack+5366, NULL, NULL, r12vrr_stack+341);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5478, r12vrr_stack+5338, r12vrr_stack+651, NULL, NULL, r12vrr_stack+131);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5562, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2839);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+717, r12vrr_stack+491, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+5338, NULL, NULL, r12vrr_stack+2902);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+2923);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2923, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+867, r12vrr_stack+326, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5982, r12vrr_stack+5366, r12vrr_stack+2923, NULL, NULL, r12vrr_stack+2986);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6066, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+3007);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6234, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+3070);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+3196);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+3322);
 tmp = r12vrr_stack + 6794;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3196, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3199, r12vrr_stack+170, r12vrr_stack+3196, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3205, r12vrr_stack+173, r12vrr_stack+3199, r12vrr_stack+3, r12vrr_stack+170, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3215, r12vrr_stack+542, r12vrr_stack+3205, r12vrr_stack+15, r12vrr_stack+173, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3230, r12vrr_stack+552, r12vrr_stack+3215, r12vrr_stack+316, r12vrr_stack+542, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3251, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+326, r12vrr_stack+552, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7214, r12vrr_stack+2923, r12vrr_stack+3251, NULL, NULL, r12vrr_stack+567);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7298, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+588);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7466, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+3931);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7746, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+4057);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+4267);
 tmp = r12vrr_stack + 8166;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3279, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+131, r12vrr_stack+341, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2902, r12vrr_stack+131, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+111, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+341, r12vrr_stack+2986, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+3279, r12vrr_stack+111, NULL, NULL, r12vrr_stack+5366);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8862, r12vrr_stack+476, r12vrr_stack+3279, NULL, NULL, r12vrr_stack+651);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8970, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5394);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+521, r12vrr_stack+2902, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+476, NULL, NULL, r12vrr_stack+5338);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+5478);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5430, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+2986, r12vrr_stack+567, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+111, r12vrr_stack+5430, NULL, NULL, r12vrr_stack+2923);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9618, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+5982);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9834, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+6066);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5562);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+6234);
 tmp = r12vrr_stack + 10554;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5466, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5469, r12vrr_stack+3196, r12vrr_stack+5466, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5475, r12vrr_stack+3199, r12vrr_stack+5469, r12vrr_stack+170, r12vrr_stack+3196, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5485, r12vrr_stack+3205, r12vrr_stack+5475, r12vrr_stack+173, r12vrr_stack+3199, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5500, r12vrr_stack+3215, r12vrr_stack+5485, r12vrr_stack+542, r12vrr_stack+3205, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5521, r12vrr_stack+3230, r12vrr_stack+5500, r12vrr_stack+552, r12vrr_stack+3215, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5549, r12vrr_stack+3251, r12vrr_stack+5521, r12vrr_stack+567, r12vrr_stack+3230, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5585, r12vrr_stack+5430, r12vrr_stack+5549, NULL, NULL, r12vrr_stack+3251);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11094, r12vrr_stack+9510, r12vrr_stack+5585, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+7214);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11310, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+7298);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11670, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+7466);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+7746);
 tmp = r12vrr_stack + 12210;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2867, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+651, r12vrr_stack+5366, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5338, r12vrr_stack+651, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+651, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+5366, r12vrr_stack+2923, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+2867, r12vrr_stack+651, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13146, r12vrr_stack+12966, r12vrr_stack+2867, NULL, NULL, r12vrr_stack+3279);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13281, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+8754);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+2839, r12vrr_stack+5338, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+12966, NULL, NULL, r12vrr_stack+476);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+8862);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+5430, r12vrr_stack+5549, r12vrr_stack+2923, r12vrr_stack+3251, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8799, r12vrr_stack+651, r12vrr_stack+13956, NULL, NULL, r12vrr_stack+5430);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14001, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+9510);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14271, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+9618);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8970);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+9834);
 tmp = r12vrr_stack + 15171;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5338, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5341, r12vrr_stack+5466, r12vrr_stack+5338, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5347, r12vrr_stack+5469, r12vrr_stack+5341, r12vrr_stack+3196, r12vrr_stack+5466, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5357, r12vrr_stack+5475, r12vrr_stack+5347, r12vrr_stack+3199, r12vrr_stack+5469, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5372, r12vrr_stack+5485, r12vrr_stack+5357, r12vrr_stack+3205, r12vrr_stack+5475, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8934, r12vrr_stack+5500, r12vrr_stack+5372, r12vrr_stack+3215, r12vrr_stack+5485, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8962, r12vrr_stack+5521, r12vrr_stack+8934, r12vrr_stack+3230, r12vrr_stack+5500, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8998, r12vrr_stack+5549, r12vrr_stack+8962, r12vrr_stack+3251, r12vrr_stack+5521, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9043, r12vrr_stack+13956, r12vrr_stack+8998, NULL, NULL, r12vrr_stack+5549);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15846, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+5585);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16116, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+11094);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16566, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+11310);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+11670);
 tmp = r12vrr_stack + 17241;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+3279, r12vrr_stack+111, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18241, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+476, r12vrr_stack+3279, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18296, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+111, r12vrr_stack+5430, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18351, r12vrr_stack+18186, r12vrr_stack+18296, NULL, NULL, r12vrr_stack+651);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18516, r12vrr_stack+18241, r12vrr_stack+18186, NULL, NULL, r12vrr_stack+2867);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18681, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+18241, r12vrr_stack+18186, r12vrr_stack+13011);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+5394, r12vrr_stack+476, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19011, r12vrr_stack+13011, r12vrr_stack+18241, NULL, NULL, r12vrr_stack+12966);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13011, r12vrr_stack+18241, r12vrr_stack+13146);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13066, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5430, r12vrr_stack+5549, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+18296, r12vrr_stack+13066, NULL, NULL, r12vrr_stack+13956);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19671, r12vrr_stack+18351, r12vrr_stack+19506, r12vrr_stack+18186, r12vrr_stack+18296, r12vrr_stack+8799);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20001, r12vrr_stack+18681, r12vrr_stack+19671, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+14001);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13281);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+20001, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+14271);
 tmp = r12vrr_stack + 21101;
 target_ptr = Libr12->gvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3196, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+476, r12vrr_stack+5338, r12vrr_stack+3196, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+482, r12vrr_stack+5341, r12vrr_stack+476, r12vrr_stack+5466, r12vrr_stack+5338, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+492, r12vrr_stack+5347, r12vrr_stack+482, r12vrr_stack+5469, r12vrr_stack+5341, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+13121, r12vrr_stack+5357, r12vrr_stack+492, r12vrr_stack+5475, r12vrr_stack+5347, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+13142, r12vrr_stack+5372, r12vrr_stack+13121, r12vrr_stack+5485, r12vrr_stack+5357, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13170, r12vrr_stack+8934, r12vrr_stack+13142, r12vrr_stack+5500, r12vrr_stack+5372, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13206, r12vrr_stack+8962, r12vrr_stack+13170, r12vrr_stack+5521, r12vrr_stack+8934, NULL);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13251, r12vrr_stack+8998, r12vrr_stack+13206, r12vrr_stack+5549, r12vrr_stack+8962, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13306, r12vrr_stack+13066, r12vrr_stack+13251, NULL, NULL, r12vrr_stack+8998);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21926, r12vrr_stack+19506, r12vrr_stack+13306, r12vrr_stack+18296, r12vrr_stack+13066, r12vrr_stack+9043);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22256, r12vrr_stack+19671, r12vrr_stack+21926, r12vrr_stack+18351, r12vrr_stack+19506, r12vrr_stack+15846);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22806, r12vrr_stack+20001, r12vrr_stack+22256, r12vrr_stack+18681, r12vrr_stack+19671, r12vrr_stack+16116);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+22806, r12vrr_stack+20551, r12vrr_stack+20001, r12vrr_stack+16566);
 tmp = r12vrr_stack + 23631;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+13471, r12vrr_stack+18186, r12vrr_stack+18296, r12vrr_stack+2867, r12vrr_stack+651, NULL);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24786, r12vrr_stack+18241, r12vrr_stack+18186, r12vrr_stack+12966, r12vrr_stack+2867, NULL);

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24852, r12vrr_stack+18296, r12vrr_stack+13066, r12vrr_stack+651, r12vrr_stack+13956, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24918, r12vrr_stack+13471, r12vrr_stack+24852, NULL, NULL, r12vrr_stack+18296);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25116, r12vrr_stack+24786, r12vrr_stack+13471, NULL, NULL, r12vrr_stack+18186);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25314, r12vrr_stack+25116, r12vrr_stack+24918, r12vrr_stack+24786, r12vrr_stack+13471, r12vrr_stack+18351);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18296, r12vrr_stack+13011, r12vrr_stack+18241, r12vrr_stack+8754, r12vrr_stack+12966, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25710, r12vrr_stack+18296, r12vrr_stack+24786, NULL, NULL, r12vrr_stack+18241);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25908, r12vrr_stack+25710, r12vrr_stack+25116, r12vrr_stack+18296, r12vrr_stack+24786, r12vrr_stack+18516);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24786, r12vrr_stack+13066, r12vrr_stack+13251, r12vrr_stack+13956, r12vrr_stack+8998, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+24852, r12vrr_stack+24786, NULL, NULL, r12vrr_stack+13066);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+26304, r12vrr_stack+24918, r12vrr_stack+18186, r12vrr_stack+13471, r12vrr_stack+24852, r12vrr_stack+19506);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+26700, r12vrr_stack+25314, r12vrr_stack+26304, r12vrr_stack+25116, r12vrr_stack+24918, r12vrr_stack+19671);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+27360, r12vrr_stack+25908, r12vrr_stack+25314, r12vrr_stack+25710, r12vrr_stack+25116, r12vrr_stack+18681);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+26700, r12vrr_stack+25908, r12vrr_stack+25314, r12vrr_stack+20001);
 tmp = r12vrr_stack + 28020;
 target_ptr = Libr12->gvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+25116, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+25119, r12vrr_stack+196, r12vrr_stack+25116, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+5466, r12vrr_stack+30, r12vrr_stack+21, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+57, r12vrr_stack+161, r12vrr_stack+5466, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+25116);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+25125, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+25119);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+25155, r12vrr_stack+210, r12vrr_stack+180, NULL, NULL, r12vrr_stack+21);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+25173, r12vrr_stack+1560, r12vrr_stack+25155, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+5466);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+25209, r12vrr_stack+1578, r12vrr_stack+25173, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+57);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+25710, r12vrr_stack+1614, r12vrr_stack+25209, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+25125);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+75, r12vrr_stack+186, r12vrr_stack+316, NULL, NULL, r12vrr_stack+180);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+25800, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+25155);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+25860, r12vrr_stack+1704, r12vrr_stack+25800, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+25173);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+25960, r12vrr_stack+1764, r12vrr_stack+25860, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+25209);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+18384, r12vrr_stack+1864, r12vrr_stack+25960, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+25710);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+25269, r12vrr_stack+326, r12vrr_stack+552, NULL, NULL, r12vrr_stack+316);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+216, r12vrr_stack+2014, r12vrr_stack+25269, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+75);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+26110, r12vrr_stack+2059, r12vrr_stack+216, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+25800);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+18594, r12vrr_stack+2149, r12vrr_stack+26110, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+25860);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+29010, r12vrr_stack+2299, r12vrr_stack+18594, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+25960);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+29325, r12vrr_stack+2524, r12vrr_stack+29010, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+18384);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+867, r12vrr_stack+567, r12vrr_stack+3230, NULL, NULL, r12vrr_stack+552);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+930, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+25269);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+29745, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+216);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+29955, r12vrr_stack+4057, r12vrr_stack+29745, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+26110);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+30270, r12vrr_stack+4267, r12vrr_stack+29955, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+18594);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+30711, r12vrr_stack+4897, r12vrr_stack+30270, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+29010);
 tmp = r12vrr_stack + 30711;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1056, r12vrr_stack+3251, r12vrr_stack+5521, NULL, NULL, r12vrr_stack+3230);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+18819, r12vrr_stack+7214, r12vrr_stack+1056, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+867);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2867, r12vrr_stack+7298, r12vrr_stack+18819, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+930);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+31299, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+29745);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+31719, r12vrr_stack+7746, r12vrr_stack+31299, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+29955);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+32307, r12vrr_stack+8166, r12vrr_stack+31719, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+30270);
 tmp = r12vrr_stack + 32307;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5982, r12vrr_stack+5549, r12vrr_stack+8962, NULL, NULL, r12vrr_stack+5521);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6090, r12vrr_stack+5585, r12vrr_stack+5982, r12vrr_stack+5430, r12vrr_stack+5549, r12vrr_stack+1056);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+33091, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+9510, r12vrr_stack+5585, r12vrr_stack+18819);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+33451, r12vrr_stack+11310, r12vrr_stack+33091, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+2867);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+33991, r12vrr_stack+11670, r12vrr_stack+33451, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+31299);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+34747, r12vrr_stack+12210, r12vrr_stack+33991, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+31719);
 tmp = r12vrr_stack + 34747;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+341, r12vrr_stack+8998, r12vrr_stack+13206, NULL, NULL, r12vrr_stack+8962);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+9043, r12vrr_stack+341, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5982);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+35755, r12vrr_stack+15846, r12vrr_stack+9510, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+6090);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+36205, r12vrr_stack+16116, r12vrr_stack+35755, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+33091);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+36880, r12vrr_stack+16566, r12vrr_stack+36205, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+33451);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+37825, r12vrr_stack+17241, r12vrr_stack+36880, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+33991);
 tmp = r12vrr_stack + 37825;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+8799, r12vrr_stack+3196, r12vrr_stack+0, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+306, r12vrr_stack+476, r12vrr_stack+8799, r12vrr_stack+5338, r12vrr_stack+3196, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+8805, r12vrr_stack+482, r12vrr_stack+306, r12vrr_stack+5341, r12vrr_stack+476, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+8820, r12vrr_stack+492, r12vrr_stack+8805, r12vrr_stack+5347, r12vrr_stack+482, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8841, r12vrr_stack+13121, r12vrr_stack+8820, r12vrr_stack+5357, r12vrr_stack+492, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5430, r12vrr_stack+13142, r12vrr_stack+8841, r12vrr_stack+5372, r12vrr_stack+13121, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+13170, r12vrr_stack+5430, r12vrr_stack+8934, r12vrr_stack+13142, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+8869, r12vrr_stack+13206, r12vrr_stack+12966, r12vrr_stack+8962, r12vrr_stack+13170, NULL);

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+13251, r12vrr_stack+8869, NULL, NULL, r12vrr_stack+13206);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14121, r12vrr_stack+13306, r12vrr_stack+13956, r12vrr_stack+13066, r12vrr_stack+13251, r12vrr_stack+341);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+39085, r12vrr_stack+21926, r12vrr_stack+14121, r12vrr_stack+19506, r12vrr_stack+13306, r12vrr_stack+9510);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+39635, r12vrr_stack+22256, r12vrr_stack+39085, r12vrr_stack+19671, r12vrr_stack+21926, r12vrr_stack+35755);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+40460, r12vrr_stack+22806, r12vrr_stack+39635, r12vrr_stack+20001, r12vrr_stack+22256, r12vrr_stack+36205);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+41615, r12vrr_stack+23631, r12vrr_stack+40460, r12vrr_stack+21101, r12vrr_stack+22806, r12vrr_stack+36880);
 tmp = r12vrr_stack + 41615;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+13251, r12vrr_stack+8869, r12vrr_stack+8998, r12vrr_stack+13206, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19572, r12vrr_stack+24786, r12vrr_stack+19506, NULL, NULL, r12vrr_stack+13251);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19770, r12vrr_stack+18186, r12vrr_stack+19572, r12vrr_stack+24852, r12vrr_stack+24786, r12vrr_stack+13306);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+43155, r12vrr_stack+26304, r12vrr_stack+19770, r12vrr_stack+24918, r12vrr_stack+18186, r12vrr_stack+21926);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+43815, r12vrr_stack+26700, r12vrr_stack+43155, r12vrr_stack+25314, r12vrr_stack+26304, r12vrr_stack+22256);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+44805, r12vrr_stack+28020, r12vrr_stack+43815, r12vrr_stack+27360, r12vrr_stack+26700, r12vrr_stack+22806);
 tmp = r12vrr_stack + 44805;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+25314, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+25317, r12vrr_stack+25116, r12vrr_stack+25314, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+8924, r12vrr_stack+25119, r12vrr_stack+25317, r12vrr_stack+196, r12vrr_stack+25116, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+27, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+25323, r12vrr_stack+5466, r12vrr_stack+6, r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+25314);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+25341, r12vrr_stack+57, r12vrr_stack+25323, r12vrr_stack+161, r12vrr_stack+5466, r12vrr_stack+25317);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+25371, r12vrr_stack+25125, r12vrr_stack+25341, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+8924);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1542, r12vrr_stack+180, r12vrr_stack+15, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+25416, r12vrr_stack+25155, r12vrr_stack+1542, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+6);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+25452, r12vrr_stack+25173, r12vrr_stack+25416, r12vrr_stack+1560, r12vrr_stack+25155, r12vrr_stack+25323);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+25512, r12vrr_stack+25209, r12vrr_stack+25452, r12vrr_stack+1578, r12vrr_stack+25173, r12vrr_stack+25341);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+24852, r12vrr_stack+25710, r12vrr_stack+25512, r12vrr_stack+1614, r12vrr_stack+25209, r12vrr_stack+25371);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1560, r12vrr_stack+316, r12vrr_stack+542, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1590, r12vrr_stack+75, r12vrr_stack+1560, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+1542);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+25602, r12vrr_stack+25800, r12vrr_stack+1590, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+25416);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+20166, r12vrr_stack+25860, r12vrr_stack+25602, r12vrr_stack+1704, r12vrr_stack+25800, r12vrr_stack+25452);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+20316, r12vrr_stack+25960, r12vrr_stack+20166, r12vrr_stack+1764, r12vrr_stack+25860, r12vrr_stack+25512);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+9780, r12vrr_stack+18384, r12vrr_stack+20316, r12vrr_stack+1864, r12vrr_stack+25960, r12vrr_stack+24852);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1650, r12vrr_stack+552, r12vrr_stack+3215, NULL, NULL, r12vrr_stack+542);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1695, r12vrr_stack+25269, r12vrr_stack+1650, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+1560);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1785, r12vrr_stack+216, r12vrr_stack+1695, r12vrr_stack+2014, r12vrr_stack+25269, r12vrr_stack+1590);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+14451, r12vrr_stack+26110, r12vrr_stack+1785, r12vrr_stack+2059, r12vrr_stack+216, r12vrr_stack+25602);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+46191, r12vrr_stack+18594, r12vrr_stack+14451, r12vrr_stack+2149, r12vrr_stack+26110, r12vrr_stack+20166);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+46506, r12vrr_stack+29010, r12vrr_stack+46191, r12vrr_stack+2299, r12vrr_stack+18594, r12vrr_stack+20316);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+1935, r12vrr_stack+29325, r12vrr_stack+46506, r12vrr_stack+2524, r12vrr_stack+29010, r12vrr_stack+9780);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+24978, r12vrr_stack+3230, r12vrr_stack+5500, NULL, NULL, r12vrr_stack+3215);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+10060, r12vrr_stack+867, r12vrr_stack+24978, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+1650);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3279, r12vrr_stack+930, r12vrr_stack+10060, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+1695);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+46926, r12vrr_stack+29745, r12vrr_stack+3279, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+1785);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+47241, r12vrr_stack+29955, r12vrr_stack+46926, r12vrr_stack+4057, r12vrr_stack+29745, r12vrr_stack+14451);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+47682, r12vrr_stack+30270, r12vrr_stack+47241, r12vrr_stack+4267, r12vrr_stack+29955, r12vrr_stack+46191);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+48270, r12vrr_stack+30711, r12vrr_stack+47682, r12vrr_stack+4897, r12vrr_stack+30270, r12vrr_stack+46506);
 tmp = r12vrr_stack + 48270;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3931, r12vrr_stack+5521, r12vrr_stack+8934, NULL, NULL, r12vrr_stack+5500);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4015, r12vrr_stack+1056, r12vrr_stack+3931, r12vrr_stack+3251, r12vrr_stack+5521, r12vrr_stack+24978);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4183, r12vrr_stack+18819, r12vrr_stack+4015, r12vrr_stack+7214, r12vrr_stack+1056, r12vrr_stack+10060);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+49026, r12vrr_stack+2867, r12vrr_stack+4183, r12vrr_stack+7298, r12vrr_stack+18819, r12vrr_stack+3279);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+49446, r12vrr_stack+31299, r12vrr_stack+49026, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+46926);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+50034, r12vrr_stack+31719, r12vrr_stack+49446, r12vrr_stack+7746, r12vrr_stack+31299, r12vrr_stack+47241);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+50818, r12vrr_stack+32307, r12vrr_stack+50034, r12vrr_stack+8166, r12vrr_stack+31719, r12vrr_stack+47682);
 tmp = r12vrr_stack + 50818;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7214, r12vrr_stack+8962, r12vrr_stack+13170, NULL, NULL, r12vrr_stack+8934);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7322, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5549, r12vrr_stack+8962, r12vrr_stack+3931);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7538, r12vrr_stack+6090, r12vrr_stack+7322, r12vrr_stack+5585, r12vrr_stack+5982, r12vrr_stack+4015);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+51826, r12vrr_stack+33091, r12vrr_stack+7538, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+4183);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+52366, r12vrr_stack+33451, r12vrr_stack+51826, r12vrr_stack+11310, r12vrr_stack+33091, r12vrr_stack+49026);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+53122, r12vrr_stack+33991, r12vrr_stack+52366, r12vrr_stack+11670, r12vrr_stack+33451, r12vrr_stack+49446);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+54130, r12vrr_stack+34747, r12vrr_stack+53122, r12vrr_stack+12210, r12vrr_stack+33991, r12vrr_stack+50034);
 tmp = r12vrr_stack + 54130;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11094, r12vrr_stack+13206, r12vrr_stack+12966, NULL, NULL, r12vrr_stack+13170);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11229, r12vrr_stack+341, r12vrr_stack+11094, r12vrr_stack+8998, r12vrr_stack+13206, r12vrr_stack+7214);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11499, r12vrr_stack+9510, r12vrr_stack+11229, r12vrr_stack+9043, r12vrr_stack+341, r12vrr_stack+7322);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+55426, r12vrr_stack+35755, r12vrr_stack+11499, r12vrr_stack+15846, r12vrr_stack+9510, r12vrr_stack+7538);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+56101, r12vrr_stack+36205, r12vrr_stack+55426, r12vrr_stack+16116, r12vrr_stack+35755, r12vrr_stack+51826);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+57046, r12vrr_stack+36880, r12vrr_stack+56101, r12vrr_stack+16566, r12vrr_stack+36205, r12vrr_stack+52366);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+58306, r12vrr_stack+37825, r12vrr_stack+57046, r12vrr_stack+17241, r12vrr_stack+36880, r12vrr_stack+53122);
 tmp = r12vrr_stack + 58306;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15846, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15849, r12vrr_stack+0, r12vrr_stack+15846, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+15855, r12vrr_stack+8799, r12vrr_stack+15849, r12vrr_stack+3196, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+326, r12vrr_stack+306, r12vrr_stack+15855, r12vrr_stack+476, r12vrr_stack+8799, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+15865, r12vrr_stack+8805, r12vrr_stack+326, r12vrr_stack+482, r12vrr_stack+306, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3251, r12vrr_stack+8820, r12vrr_stack+15865, r12vrr_stack+492, r12vrr_stack+8805, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+8841, r12vrr_stack+3251, r12vrr_stack+13121, r12vrr_stack+8820, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14676, r12vrr_stack+5430, r12vrr_stack+476, r12vrr_stack+13142, r12vrr_stack+8841, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13066, r12vrr_stack+12966, r12vrr_stack+14676, r12vrr_stack+13170, r12vrr_stack+5430, NULL);

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15886, r12vrr_stack+8869, r12vrr_stack+13066, NULL, NULL, r12vrr_stack+12966);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+16051, r12vrr_stack+13956, r12vrr_stack+15886, r12vrr_stack+13251, r12vrr_stack+8869, r12vrr_stack+11094);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+16381, r12vrr_stack+14121, r12vrr_stack+16051, r12vrr_stack+13306, r12vrr_stack+13956, r12vrr_stack+11229);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+59926, r12vrr_stack+39085, r12vrr_stack+16381, r12vrr_stack+21926, r12vrr_stack+14121, r12vrr_stack+11499);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+60751, r12vrr_stack+39635, r12vrr_stack+59926, r12vrr_stack+22256, r12vrr_stack+39085, r12vrr_stack+55426);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+61906, r12vrr_stack+40460, r12vrr_stack+60751, r12vrr_stack+22806, r12vrr_stack+39635, r12vrr_stack+56101);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+63446, r12vrr_stack+41615, r12vrr_stack+61906, r12vrr_stack+23631, r12vrr_stack+40460, r12vrr_stack+57046);
 tmp = r12vrr_stack + 63446;
 target_ptr = Libr12->gvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21926, r12vrr_stack+8869, r12vrr_stack+13066, r12vrr_stack+13206, r12vrr_stack+12966, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21992, r12vrr_stack+19506, r12vrr_stack+21926, NULL, NULL, r12vrr_stack+8869);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22190, r12vrr_stack+19572, r12vrr_stack+21992, r12vrr_stack+24786, r12vrr_stack+19506, r12vrr_stack+13956);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22586, r12vrr_stack+19770, r12vrr_stack+22190, r12vrr_stack+18186, r12vrr_stack+19572, r12vrr_stack+14121);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+65426, r12vrr_stack+43155, r12vrr_stack+22586, r12vrr_stack+26304, r12vrr_stack+19770, r12vrr_stack+39085);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+66416, r12vrr_stack+43815, r12vrr_stack+65426, r12vrr_stack+26700, r12vrr_stack+43155, r12vrr_stack+39635);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+67802, r12vrr_stack+44805, r12vrr_stack+66416, r12vrr_stack+28020, r12vrr_stack+43815, r12vrr_stack+40460);
 tmp = r12vrr_stack + 67802;
 target_ptr = Libr12->gvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^7 ---*/
 _BUILD_p000(Data,r12vrr_stack+18186, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (d0|00)^6 ---*/
 _BUILD_d000(Data,r12vrr_stack+18189, r12vrr_stack+25314, r12vrr_stack+18186, Data->F+6, Data->F+7, NULL);

 /*--- compute (f0|00)^5 ---*/
 _BUILD_f000(Data,r12vrr_stack+18195, r12vrr_stack+25317, r12vrr_stack+18189, r12vrr_stack+25116, r12vrr_stack+25314, NULL);

 /*--- compute (g0|00)^4 ---*/
 _BUILD_g000(Data,r12vrr_stack+18205, r12vrr_stack+8924, r12vrr_stack+18195, r12vrr_stack+25119, r12vrr_stack+25317, NULL);

 /*--- compute (p0|p0)^7 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+512, r12vrr_stack+27, r12vrr_stack+3, NULL, NULL, Data->F+8);

 /*--- compute (d0|p0)^6 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+18220, r12vrr_stack+6, r12vrr_stack+512, r12vrr_stack+21, r12vrr_stack+27, r12vrr_stack+18186);

 /*--- compute (f0|p0)^5 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+186, r12vrr_stack+25323, r12vrr_stack+18220, r12vrr_stack+5466, r12vrr_stack+6, r12vrr_stack+18189);

 /*--- compute (g0|p0)^4 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+18238, r12vrr_stack+25341, r12vrr_stack+186, r12vrr_stack+57, r12vrr_stack+25323, r12vrr_stack+18195);

 /*--- compute (h0|p0)^3 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+18283, r12vrr_stack+25371, r12vrr_stack+18238, r12vrr_stack+25125, r12vrr_stack+25341, r12vrr_stack+18205);

 /*--- compute (p0|d0)^7 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+18346, r12vrr_stack+15, r12vrr_stack+173, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^6 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+24786, r12vrr_stack+1542, r12vrr_stack+18346, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+512);

 /*--- compute (f0|d0)^5 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+23246, r12vrr_stack+25416, r12vrr_stack+24786, r12vrr_stack+25155, r12vrr_stack+1542, r12vrr_stack+18220);

 /*--- compute (g0|d0)^4 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+23306, r12vrr_stack+25452, r12vrr_stack+23246, r12vrr_stack+25173, r12vrr_stack+25416, r12vrr_stack+186);

 /*--- compute (h0|d0)^3 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+23396, r12vrr_stack+25512, r12vrr_stack+23306, r12vrr_stack+25209, r12vrr_stack+25452, r12vrr_stack+18238);

 /*--- compute (i0|d0)^2 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+13251, r12vrr_stack+24852, r12vrr_stack+23396, r12vrr_stack+25710, r12vrr_stack+25512, r12vrr_stack+18283);

 /*--- compute (p0|f0)^7 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+24822, r12vrr_stack+542, r12vrr_stack+3205, NULL, NULL, r12vrr_stack+173);

 /*--- compute (d0|f0)^6 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+23522, r12vrr_stack+1560, r12vrr_stack+24822, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+18346);

 /*--- compute (f0|f0)^5 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+13419, r12vrr_stack+1590, r12vrr_stack+23522, r12vrr_stack+75, r12vrr_stack+1560, r12vrr_stack+24786);

 /*--- compute (g0|f0)^4 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+16931, r12vrr_stack+25602, r12vrr_stack+13419, r12vrr_stack+25800, r12vrr_stack+1590, r12vrr_stack+23246);

 /*--- compute (h0|f0)^3 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+11949, r12vrr_stack+20166, r12vrr_stack+16931, r12vrr_stack+25860, r12vrr_stack+25602, r12vrr_stack+23306);

 /*--- compute (i0|f0)^2 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+26260, r12vrr_stack+20316, r12vrr_stack+11949, r12vrr_stack+25960, r12vrr_stack+20166, r12vrr_stack+23396);

 /*--- compute (k0|f0)^1 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+25702, r12vrr_stack+9780, r12vrr_stack+26260, r12vrr_stack+18384, r12vrr_stack+20316, r12vrr_stack+13251);

 /*--- compute (p0|g0)^7 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+18364, r12vrr_stack+3215, r12vrr_stack+5485, NULL, NULL, r12vrr_stack+3205);

 /*--- compute (d0|g0)^6 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+18409, r12vrr_stack+1650, r12vrr_stack+18364, r12vrr_stack+552, r12vrr_stack+3215, r12vrr_stack+24822);

 /*--- compute (f0|g0)^5 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+17081, r12vrr_stack+1695, r12vrr_stack+18409, r12vrr_stack+25269, r12vrr_stack+1650, r12vrr_stack+23522);

 /*--- compute (g0|g0)^4 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+7898, r12vrr_stack+1785, r12vrr_stack+17081, r12vrr_stack+216, r12vrr_stack+1695, r12vrr_stack+13419);

 /*--- compute (h0|g0)^3 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+26540, r12vrr_stack+14451, r12vrr_stack+7898, r12vrr_stack+26110, r12vrr_stack+1785, r12vrr_stack+16931);

 /*--- compute (i0|g0)^2 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+26855, r12vrr_stack+46191, r12vrr_stack+26540, r12vrr_stack+18594, r12vrr_stack+14451, r12vrr_stack+11949);

 /*--- compute (k0|g0)^1 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+69650, r12vrr_stack+46506, r12vrr_stack+26855, r12vrr_stack+29010, r12vrr_stack+46191, r12vrr_stack+26260);

 /*--- compute (l0|g0)^0 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+70190, r12vrr_stack+1935, r12vrr_stack+69650, r12vrr_stack+29325, r12vrr_stack+46506, r12vrr_stack+25702);

 /*--- compute (p0|h0)^7 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+29010, r12vrr_stack+5500, r12vrr_stack+5372, NULL, NULL, r12vrr_stack+5485);

 /*--- compute (d0|h0)^6 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+29073, r12vrr_stack+24978, r12vrr_stack+29010, r12vrr_stack+3230, r12vrr_stack+5500, r12vrr_stack+18364);

 /*--- compute (f0|h0)^5 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+18499, r12vrr_stack+10060, r12vrr_stack+29073, r12vrr_stack+867, r12vrr_stack+24978, r12vrr_stack+18409);

 /*--- compute (g0|h0)^4 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+70865, r12vrr_stack+3279, r12vrr_stack+18499, r12vrr_stack+930, r12vrr_stack+10060, r12vrr_stack+17081);

 /*--- compute (h0|h0)^3 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+71180, r12vrr_stack+46926, r12vrr_stack+70865, r12vrr_stack+29745, r12vrr_stack+3279, r12vrr_stack+7898);

 /*--- compute (i0|h0)^2 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+71621, r12vrr_stack+47241, r12vrr_stack+71180, r12vrr_stack+29955, r12vrr_stack+46926, r12vrr_stack+26540);

 /*--- compute (k0|h0)^1 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+72209, r12vrr_stack+47682, r12vrr_stack+71621, r12vrr_stack+30270, r12vrr_stack+47241, r12vrr_stack+26855);

 /*--- compute (l0|h0)^0 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+29745, r12vrr_stack+48270, r12vrr_stack+72209, r12vrr_stack+30711, r12vrr_stack+47682, r12vrr_stack+69650);
 tmp = r12vrr_stack + 29745;
 target_ptr = Libr12->gvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^7 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+867, r12vrr_stack+8934, r12vrr_stack+13142, NULL, NULL, r12vrr_stack+5372);

 /*--- compute (d0|i0)^6 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+8998, r12vrr_stack+3931, r12vrr_stack+867, r12vrr_stack+5521, r12vrr_stack+8934, r12vrr_stack+29010);

 /*--- compute (f0|i0)^5 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+72965, r12vrr_stack+4015, r12vrr_stack+8998, r12vrr_stack+1056, r12vrr_stack+3931, r12vrr_stack+29073);

 /*--- compute (g0|i0)^4 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+73245, r12vrr_stack+4183, r12vrr_stack+72965, r12vrr_stack+18819, r12vrr_stack+4015, r12vrr_stack+18499);

 /*--- compute (h0|i0)^3 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+73665, r12vrr_stack+49026, r12vrr_stack+73245, r12vrr_stack+2867, r12vrr_stack+4183, r12vrr_stack+70865);

 /*--- compute (i0|i0)^2 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+74253, r12vrr_stack+49446, r12vrr_stack+73665, r12vrr_stack+31299, r12vrr_stack+49026, r12vrr_stack+71180);

 /*--- compute (k0|i0)^1 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+75037, r12vrr_stack+50034, r12vrr_stack+74253, r12vrr_stack+31719, r12vrr_stack+49446, r12vrr_stack+71621);

 /*--- compute (l0|i0)^0 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+76045, r12vrr_stack+50818, r12vrr_stack+75037, r12vrr_stack+32307, r12vrr_stack+50034, r12vrr_stack+72209);
 tmp = r12vrr_stack + 76045;
 target_ptr = Libr12->gvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^7 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31299, r12vrr_stack+13170, r12vrr_stack+5430, NULL, NULL, r12vrr_stack+13142);

 /*--- compute (d0|k0)^6 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+951, r12vrr_stack+7214, r12vrr_stack+31299, r12vrr_stack+8962, r12vrr_stack+13170, r12vrr_stack+867);

 /*--- compute (f0|k0)^5 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31407, r12vrr_stack+7322, r12vrr_stack+951, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+8998);

 /*--- compute (g0|k0)^4 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31767, r12vrr_stack+7538, r12vrr_stack+31407, r12vrr_stack+6090, r12vrr_stack+7322, r12vrr_stack+72965);

 /*--- compute (h0|k0)^3 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+77305, r12vrr_stack+51826, r12vrr_stack+31767, r12vrr_stack+33091, r12vrr_stack+7538, r12vrr_stack+73245);

 /*--- compute (i0|k0)^2 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+78061, r12vrr_stack+52366, r12vrr_stack+77305, r12vrr_stack+33451, r12vrr_stack+51826, r12vrr_stack+73665);

 /*--- compute (k0|k0)^1 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+79069, r12vrr_stack+53122, r12vrr_stack+78061, r12vrr_stack+33991, r12vrr_stack+52366, r12vrr_stack+74253);

 /*--- compute (l0|k0)^0 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+33091, r12vrr_stack+54130, r12vrr_stack+79069, r12vrr_stack+34747, r12vrr_stack+53122, r12vrr_stack+75037);
 tmp = r12vrr_stack + 33091;
 target_ptr = Libr12->gvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^7 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+5982, r12vrr_stack+12966, r12vrr_stack+14676, NULL, NULL, r12vrr_stack+5430);

 /*--- compute (d0|l0)^6 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6117, r12vrr_stack+11094, r12vrr_stack+5982, r12vrr_stack+13206, r12vrr_stack+12966, r12vrr_stack+31299);

 /*--- compute (f0|l0)^5 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+80365, r12vrr_stack+11229, r12vrr_stack+6117, r12vrr_stack+341, r12vrr_stack+11094, r12vrr_stack+951);

 /*--- compute (g0|l0)^4 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+80815, r12vrr_stack+11499, r12vrr_stack+80365, r12vrr_stack+9510, r12vrr_stack+11229, r12vrr_stack+31407);

 /*--- compute (h0|l0)^3 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+81490, r12vrr_stack+55426, r12vrr_stack+80815, r12vrr_stack+35755, r12vrr_stack+11499, r12vrr_stack+31767);

 /*--- compute (i0|l0)^2 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+82435, r12vrr_stack+56101, r12vrr_stack+81490, r12vrr_stack+36205, r12vrr_stack+55426, r12vrr_stack+77305);

 /*--- compute (k0|l0)^1 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+83695, r12vrr_stack+57046, r12vrr_stack+82435, r12vrr_stack+36880, r12vrr_stack+56101, r12vrr_stack+78061);

 /*--- compute (l0|l0)^0 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+35755, r12vrr_stack+58306, r12vrr_stack+83695, r12vrr_stack+37825, r12vrr_stack+57046, r12vrr_stack+79069);
 tmp = r12vrr_stack + 35755;
 target_ptr = Libr12->gvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^16 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /*--- compute (00|d0)^15 ---*/
 _BUILD_00d0(Data,r12vrr_stack+37780, r12vrr_stack+15846, r12vrr_stack+21, Data->F+15, Data->F+16, NULL);

 /*--- compute (00|f0)^14 ---*/
 _BUILD_00f0(Data,r12vrr_stack+316, r12vrr_stack+15849, r12vrr_stack+37780, r12vrr_stack+0, r12vrr_stack+15846, NULL);

 /*--- compute (00|g0)^13 ---*/
 _BUILD_00g0(Data,r12vrr_stack+37786, r12vrr_stack+15855, r12vrr_stack+316, r12vrr_stack+8799, r12vrr_stack+15849, NULL);

 /*--- compute (00|h0)^12 ---*/
 _BUILD_00h0(Data,r12vrr_stack+30690, r12vrr_stack+326, r12vrr_stack+37786, r12vrr_stack+306, r12vrr_stack+15855, NULL);

 /*--- compute (00|i0)^11 ---*/
 _BUILD_00i0(Data,r12vrr_stack+9510, r12vrr_stack+15865, r12vrr_stack+30690, r12vrr_stack+8805, r12vrr_stack+326, NULL);

 /*--- compute (00|k0)^10 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+34711, r12vrr_stack+3251, r12vrr_stack+9510, r12vrr_stack+8820, r12vrr_stack+15865, NULL);

 /*--- compute (00|l0)^9 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13206, r12vrr_stack+476, r12vrr_stack+34711, r12vrr_stack+8841, r12vrr_stack+3251, NULL);

 /*--- compute (00|m0)^8 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9538, r12vrr_stack+14676, r12vrr_stack+13206, r12vrr_stack+5430, r12vrr_stack+476, NULL);

 /*--- compute (p0|m0)^7 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9593, r12vrr_stack+13066, r12vrr_stack+9538, NULL, NULL, r12vrr_stack+14676);

 /*--- compute (d0|m0)^6 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2867, r12vrr_stack+15886, r12vrr_stack+9593, r12vrr_stack+8869, r12vrr_stack+13066, r12vrr_stack+5982);

 /*--- compute (f0|m0)^5 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+85315, r12vrr_stack+16051, r12vrr_stack+2867, r12vrr_stack+13956, r12vrr_stack+15886, r12vrr_stack+6117);

 /*--- compute (g0|m0)^4 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+85865, r12vrr_stack+16381, r12vrr_stack+85315, r12vrr_stack+14121, r12vrr_stack+16051, r12vrr_stack+80365);

 /*--- compute (h0|m0)^3 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+86690, r12vrr_stack+59926, r12vrr_stack+85865, r12vrr_stack+39085, r12vrr_stack+16381, r12vrr_stack+80815);

 /*--- compute (i0|m0)^2 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+87845, r12vrr_stack+60751, r12vrr_stack+86690, r12vrr_stack+39635, r12vrr_stack+59926, r12vrr_stack+81490);

 /*--- compute (k0|m0)^1 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+89385, r12vrr_stack+61906, r12vrr_stack+87845, r12vrr_stack+40460, r12vrr_stack+60751, r12vrr_stack+82435);

 /*--- compute (l0|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+39085, r12vrr_stack+63446, r12vrr_stack+89385, r12vrr_stack+41615, r12vrr_stack+61906, r12vrr_stack+83695);
 tmp = r12vrr_stack + 39085;
 target_ptr = Libr12->gvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^7 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+13066, r12vrr_stack+9538, r12vrr_stack+12966, r12vrr_stack+14676, NULL);

 /*--- compute (p0|n0)^6 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+26062, r12vrr_stack+21926, r12vrr_stack+13956, NULL, NULL, r12vrr_stack+13066);

 /*--- compute (d0|n0)^5 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+21992, r12vrr_stack+26062, r12vrr_stack+19506, r12vrr_stack+21926, r12vrr_stack+15886);

 /*--- compute (f0|n0)^4 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+91365, r12vrr_stack+22190, r12vrr_stack+14022, r12vrr_stack+19572, r12vrr_stack+21992, r12vrr_stack+16051);

 /*--- compute (g0|n0)^3 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+92025, r12vrr_stack+22586, r12vrr_stack+91365, r12vrr_stack+19770, r12vrr_stack+22190, r12vrr_stack+16381);

 /*--- compute (h0|n0)^2 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+93015, r12vrr_stack+65426, r12vrr_stack+92025, r12vrr_stack+43155, r12vrr_stack+22586, r12vrr_stack+59926);

 /*--- compute (i0|n0)^1 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+94401, r12vrr_stack+66416, r12vrr_stack+93015, r12vrr_stack+43815, r12vrr_stack+65426, r12vrr_stack+60751);

 /*--- compute (k0|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+96249, r12vrr_stack+67802, r12vrr_stack+94401, r12vrr_stack+44805, r12vrr_stack+66416, r12vrr_stack+61906);
 tmp = r12vrr_stack + 96249;
 target_ptr = Libr12->gvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^8 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (d0|00)^7 ---*/
 _BUILD_d000(Data,r12vrr_stack+43155, r12vrr_stack+18186, r12vrr_stack+0, Data->F+7, Data->F+8, NULL);

 /*--- compute (f0|00)^6 ---*/
 _BUILD_f000(Data,r12vrr_stack+17231, r12vrr_stack+18189, r12vrr_stack+43155, r12vrr_stack+25314, r12vrr_stack+18186, NULL);

 /*--- compute (g0|00)^5 ---*/
 _BUILD_g000(Data,r12vrr_stack+43161, r12vrr_stack+18195, r12vrr_stack+17231, r12vrr_stack+25317, r12vrr_stack+18189, NULL);

 /*--- compute (h0|00)^4 ---*/
 _BUILD_h000(Data,r12vrr_stack+3230, r12vrr_stack+18205, r12vrr_stack+43161, r12vrr_stack+8924, r12vrr_stack+18195, NULL);

 /*--- compute (p0|p0)^8 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+5466, r12vrr_stack+3, r12vrr_stack+170, NULL, NULL, Data->F+9);

 /*--- compute (d0|p0)^7 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+18186, r12vrr_stack+512, r12vrr_stack+5466, r12vrr_stack+27, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (f0|p0)^6 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+27, r12vrr_stack+18220, r12vrr_stack+18186, r12vrr_stack+6, r12vrr_stack+512, r12vrr_stack+43155);

 /*--- compute (g0|p0)^5 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+57, r12vrr_stack+186, r12vrr_stack+27, r12vrr_stack+25323, r12vrr_stack+18220, r12vrr_stack+17231);

 /*--- compute (h0|p0)^4 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+102, r12vrr_stack+18238, r12vrr_stack+57, r12vrr_stack+25341, r12vrr_stack+186, r12vrr_stack+43161);

 /*--- compute (i0|p0)^3 ---*/
 _BUILD_i0p0(Data,r12vrr_stack+43155, r12vrr_stack+18283, r12vrr_stack+102, r12vrr_stack+25371, r12vrr_stack+18238, r12vrr_stack+3230);

 /*--- compute (p0|d0)^8 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+3230, r12vrr_stack+173, r12vrr_stack+3199, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|d0)^7 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+8962, r12vrr_stack+18346, r12vrr_stack+3230, r12vrr_stack+15, r12vrr_stack+173, r12vrr_stack+5466);

 /*--- compute (f0|d0)^6 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+43239, r12vrr_stack+24786, r12vrr_stack+8962, r12vrr_stack+1542, r12vrr_stack+18346, r12vrr_stack+18186);

 /*--- compute (g0|d0)^5 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+18186, r12vrr_stack+23246, r12vrr_stack+43239, r12vrr_stack+25416, r12vrr_stack+24786, r12vrr_stack+27);

 /*--- compute (h0|d0)^4 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+29199, r12vrr_stack+23306, r12vrr_stack+18186, r12vrr_stack+25452, r12vrr_stack+23246, r12vrr_stack+57);

 /*--- compute (i0|d0)^3 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+43299, r12vrr_stack+23396, r12vrr_stack+29199, r12vrr_stack+25512, r12vrr_stack+23306, r12vrr_stack+102);

 /*--- compute (k0|d0)^2 ---*/
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,r12vrr_stack+27, r12vrr_stack+13251, r12vrr_stack+43299, r12vrr_stack+24852, r12vrr_stack+23396, r12vrr_stack+43155);

 /*--- compute (p0|f0)^8 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+43155, r12vrr_stack+3205, r12vrr_stack+5475, NULL, NULL, r12vrr_stack+3199);

 /*--- compute (d0|f0)^7 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+24852, r12vrr_stack+24822, r12vrr_stack+43155, r12vrr_stack+542, r12vrr_stack+3205, r12vrr_stack+3230);

 /*--- compute (f0|f0)^6 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+542, r12vrr_stack+23522, r12vrr_stack+24852, r12vrr_stack+1560, r12vrr_stack+24822, r12vrr_stack+8962);

 /*--- compute (g0|f0)^5 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+13251, r12vrr_stack+13419, r12vrr_stack+542, r12vrr_stack+1590, r12vrr_stack+23522, r12vrr_stack+43239);

 /*--- compute (h0|f0)^4 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+23246, r12vrr_stack+16931, r12vrr_stack+13251, r12vrr_stack+25602, r12vrr_stack+13419, r12vrr_stack+18186);

 /*--- compute (i0|f0)^3 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+43467, r12vrr_stack+11949, r12vrr_stack+23246, r12vrr_stack+20166, r12vrr_stack+16931, r12vrr_stack+29199);

 /*--- compute (k0|f0)^2 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+43747, r12vrr_stack+26260, r12vrr_stack+43467, r12vrr_stack+20316, r12vrr_stack+11949, r12vrr_stack+43299);

 /*--- compute (l0|f0)^1 ---*/
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+44107, r12vrr_stack+25702, r12vrr_stack+43747, r12vrr_stack+9780, r12vrr_stack+26260, r12vrr_stack+27);

 /*--- compute (p0|g0)^8 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+27, r12vrr_stack+5485, r12vrr_stack+5357, NULL, NULL, r12vrr_stack+5475);

 /*--- compute (d0|g0)^7 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+72, r12vrr_stack+18364, r12vrr_stack+27, r12vrr_stack+3215, r12vrr_stack+5485, r12vrr_stack+43155);

 /*--- compute (f0|g0)^6 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+16931, r12vrr_stack+18409, r12vrr_stack+72, r12vrr_stack+1650, r12vrr_stack+18364, r12vrr_stack+24852);

 /*--- compute (g0|g0)^5 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+43155, r12vrr_stack+17081, r12vrr_stack+16931, r12vrr_stack+1695, r12vrr_stack+18409, r12vrr_stack+542);

 /*--- compute (h0|g0)^4 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+19506, r12vrr_stack+7898, r12vrr_stack+43155, r12vrr_stack+1785, r12vrr_stack+17081, r12vrr_stack+13251);

 /*--- compute (i0|g0)^3 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+19821, r12vrr_stack+26540, r12vrr_stack+19506, r12vrr_stack+14451, r12vrr_stack+7898, r12vrr_stack+23246);

 /*--- compute (k0|g0)^2 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+25041, r12vrr_stack+26855, r12vrr_stack+19821, r12vrr_stack+46191, r12vrr_stack+26540, r12vrr_stack+43467);

 /*--- compute (l0|g0)^1 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+69650, r12vrr_stack+25041, r12vrr_stack+46506, r12vrr_stack+26855, r12vrr_stack+43747);

 /*--- compute (m0|g0)^0 ---*/
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+26260, r12vrr_stack+70190, r12vrr_stack+98625, r12vrr_stack+1935, r12vrr_stack+69650, r12vrr_stack+44107);

 /*--- compute (p0|h0)^8 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+69650, r12vrr_stack+5372, r12vrr_stack+13121, NULL, NULL, r12vrr_stack+5357);

 /*--- compute (d0|h0)^7 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+29199, r12vrr_stack+29010, r12vrr_stack+69650, r12vrr_stack+5500, r12vrr_stack+5372, r12vrr_stack+27);

 /*--- compute (f0|h0)^6 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+69713, r12vrr_stack+29073, r12vrr_stack+29199, r12vrr_stack+24978, r12vrr_stack+29010, r12vrr_stack+72);

 /*--- compute (g0|h0)^5 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+46191, r12vrr_stack+18499, r12vrr_stack+69713, r12vrr_stack+10060, r12vrr_stack+29073, r12vrr_stack+16931);

 /*--- compute (h0|h0)^4 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+43380, r12vrr_stack+70865, r12vrr_stack+46191, r12vrr_stack+3279, r12vrr_stack+18499, r12vrr_stack+43155);

 /*--- compute (i0|h0)^3 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+43821, r12vrr_stack+71180, r12vrr_stack+43380, r12vrr_stack+46926, r12vrr_stack+70865, r12vrr_stack+19506);

 /*--- compute (k0|h0)^2 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+71621, r12vrr_stack+43821, r12vrr_stack+47241, r12vrr_stack+71180, r12vrr_stack+19821);

 /*--- compute (l0|h0)^1 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+72209, r12vrr_stack+18186, r12vrr_stack+47682, r12vrr_stack+71621, r12vrr_stack+25041);

 /*--- compute (m0|h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+70865, r12vrr_stack+29745, r12vrr_stack+19506, r12vrr_stack+48270, r12vrr_stack+72209, r12vrr_stack+98625);
 tmp = r12vrr_stack + 70865;
 target_ptr = Libr12->gvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^8 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+98625, r12vrr_stack+13142, r12vrr_stack+8841, NULL, NULL, r12vrr_stack+13121);

 /*--- compute (d0|i0)^7 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+98709, r12vrr_stack+867, r12vrr_stack+98625, r12vrr_stack+8934, r12vrr_stack+13142, r12vrr_stack+69650);

 /*--- compute (f0|i0)^6 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+98877, r12vrr_stack+8998, r12vrr_stack+98709, r12vrr_stack+3931, r12vrr_stack+867, r12vrr_stack+29199);

 /*--- compute (g0|i0)^5 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+72020, r12vrr_stack+72965, r12vrr_stack+98877, r12vrr_stack+4015, r12vrr_stack+8998, r12vrr_stack+69713);

 /*--- compute (h0|i0)^4 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+46506, r12vrr_stack+73245, r12vrr_stack+72020, r12vrr_stack+4183, r12vrr_stack+72965, r12vrr_stack+46191);

 /*--- compute (i0|i0)^3 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+72440, r12vrr_stack+73665, r12vrr_stack+46506, r12vrr_stack+49026, r12vrr_stack+73245, r12vrr_stack+43380);

 /*--- compute (k0|i0)^2 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+47094, r12vrr_stack+74253, r12vrr_stack+72440, r12vrr_stack+49446, r12vrr_stack+73665, r12vrr_stack+43821);

 /*--- compute (l0|i0)^1 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+43155, r12vrr_stack+75037, r12vrr_stack+47094, r12vrr_stack+50034, r12vrr_stack+74253, r12vrr_stack+18186);

 /*--- compute (m0|i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+49026, r12vrr_stack+76045, r12vrr_stack+43155, r12vrr_stack+50818, r12vrr_stack+75037, r12vrr_stack+19506);
 tmp = r12vrr_stack + 49026;
 target_ptr = Libr12->gvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^8 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+5430, r12vrr_stack+476, NULL, NULL, r12vrr_stack+8841);

 /*--- compute (d0|k0)^7 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19614, r12vrr_stack+31299, r12vrr_stack+19506, r12vrr_stack+13170, r12vrr_stack+5430, r12vrr_stack+98625);

 /*--- compute (f0|k0)^6 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19830, r12vrr_stack+951, r12vrr_stack+19614, r12vrr_stack+7214, r12vrr_stack+31299, r12vrr_stack+98709);

 /*--- compute (g0|k0)^5 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+69650, r12vrr_stack+31407, r12vrr_stack+19830, r12vrr_stack+7322, r12vrr_stack+951, r12vrr_stack+98877);

 /*--- compute (h0|k0)^4 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+31767, r12vrr_stack+69650, r12vrr_stack+7538, r12vrr_stack+31407, r12vrr_stack+72020);

 /*--- compute (i0|k0)^3 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+73224, r12vrr_stack+77305, r12vrr_stack+98625, r12vrr_stack+51826, r12vrr_stack+31767, r12vrr_stack+46506);

 /*--- compute (k0|k0)^2 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+74232, r12vrr_stack+78061, r12vrr_stack+73224, r12vrr_stack+52366, r12vrr_stack+77305, r12vrr_stack+72440);

 /*--- compute (l0|k0)^1 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+99381, r12vrr_stack+79069, r12vrr_stack+74232, r12vrr_stack+53122, r12vrr_stack+78061, r12vrr_stack+47094);

 /*--- compute (m0|k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+51826, r12vrr_stack+33091, r12vrr_stack+99381, r12vrr_stack+54130, r12vrr_stack+79069, r12vrr_stack+43155);
 tmp = r12vrr_stack + 51826;
 target_ptr = Libr12->gvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^8 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+341, r12vrr_stack+14676, r12vrr_stack+13206, NULL, NULL, r12vrr_stack+476);

 /*--- compute (d0|l0)^7 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+43155, r12vrr_stack+5982, r12vrr_stack+341, r12vrr_stack+12966, r12vrr_stack+14676, r12vrr_stack+19506);

 /*--- compute (f0|l0)^6 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+43425, r12vrr_stack+6117, r12vrr_stack+43155, r12vrr_stack+11094, r12vrr_stack+5982, r12vrr_stack+19614);

 /*--- compute (g0|l0)^5 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+43875, r12vrr_stack+80365, r12vrr_stack+43425, r12vrr_stack+11229, r12vrr_stack+6117, r12vrr_stack+19830);

 /*--- compute (h0|l0)^4 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+80815, r12vrr_stack+43875, r12vrr_stack+11499, r12vrr_stack+80365, r12vrr_stack+69650);

 /*--- compute (i0|l0)^3 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+77305, r12vrr_stack+81490, r12vrr_stack+19506, r12vrr_stack+55426, r12vrr_stack+80815, r12vrr_stack+98625);

 /*--- compute (k0|l0)^2 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+78565, r12vrr_stack+82435, r12vrr_stack+77305, r12vrr_stack+56101, r12vrr_stack+81490, r12vrr_stack+73224);

 /*--- compute (l0|l0)^1 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+80185, r12vrr_stack+83695, r12vrr_stack+78565, r12vrr_stack+57046, r12vrr_stack+82435, r12vrr_stack+74232);

 /*--- compute (m0|l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+55426, r12vrr_stack+35755, r12vrr_stack+80185, r12vrr_stack+58306, r12vrr_stack+83695, r12vrr_stack+99381);
 tmp = r12vrr_stack + 55426;
 target_ptr = Libr12->gvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^17 ---*/
 _BUILD_00p0(Data,r12vrr_stack+98625, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /*--- compute (00|d0)^16 ---*/
 _BUILD_00d0(Data,r12vrr_stack+98628, r12vrr_stack+21, r12vrr_stack+98625, Data->F+16, Data->F+17, NULL);

 /*--- compute (00|f0)^15 ---*/
 _BUILD_00f0(Data,r12vrr_stack+98634, r12vrr_stack+37780, r12vrr_stack+98628, r12vrr_stack+15846, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^14 ---*/
 _BUILD_00g0(Data,r12vrr_stack+98644, r12vrr_stack+316, r12vrr_stack+98634, r12vrr_stack+15849, r12vrr_stack+37780, NULL);

 /*--- compute (00|h0)^13 ---*/
 _BUILD_00h0(Data,r12vrr_stack+98659, r12vrr_stack+37786, r12vrr_stack+98644, r12vrr_stack+15855, r12vrr_stack+316, NULL);

 /*--- compute (00|i0)^12 ---*/
 _BUILD_00i0(Data,r12vrr_stack+98625, r12vrr_stack+30690, r12vrr_stack+98659, r12vrr_stack+326, r12vrr_stack+37786, NULL);

 /*--- compute (00|k0)^11 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+37780, r12vrr_stack+9510, r12vrr_stack+98625, r12vrr_stack+15865, r12vrr_stack+30690, NULL);

 /*--- compute (00|l0)^10 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+34711, r12vrr_stack+37780, r12vrr_stack+3251, r12vrr_stack+9510, NULL);

 /*--- compute (00|m0)^9 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+41560, r12vrr_stack+13206, r12vrr_stack+12966, r12vrr_stack+476, r12vrr_stack+34711, NULL);

 /*--- compute (p0|m0)^8 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+9538, r12vrr_stack+41560, NULL, NULL, r12vrr_stack+13206);

 /*--- compute (d0|m0)^7 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+98790, r12vrr_stack+9593, r12vrr_stack+98625, r12vrr_stack+13066, r12vrr_stack+9538, r12vrr_stack+341);

 /*--- compute (f0|m0)^6 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+99120, r12vrr_stack+2867, r12vrr_stack+98790, r12vrr_stack+15886, r12vrr_stack+9593, r12vrr_stack+43155);

 /*--- compute (g0|m0)^5 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+85315, r12vrr_stack+99120, r12vrr_stack+16051, r12vrr_stack+2867, r12vrr_stack+43425);

 /*--- compute (h0|m0)^4 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+85865, r12vrr_stack+18186, r12vrr_stack+16381, r12vrr_stack+85315, r12vrr_stack+43875);

 /*--- compute (i0|m0)^3 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+43155, r12vrr_stack+86690, r12vrr_stack+98625, r12vrr_stack+59926, r12vrr_stack+85865, r12vrr_stack+19506);

 /*--- compute (k0|m0)^2 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+87845, r12vrr_stack+43155, r12vrr_stack+60751, r12vrr_stack+86690, r12vrr_stack+77305);

 /*--- compute (l0|m0)^1 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+82210, r12vrr_stack+89385, r12vrr_stack+98625, r12vrr_stack+61906, r12vrr_stack+87845, r12vrr_stack+78565);

 /*--- compute (m0|m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+59926, r12vrr_stack+39085, r12vrr_stack+82210, r12vrr_stack+63446, r12vrr_stack+89385, r12vrr_stack+80185);

 /*--- compute (00|n0)^8 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+9538, r12vrr_stack+41560, r12vrr_stack+14676, r12vrr_stack+13206, NULL);

 /*--- compute (p0|n0)^7 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+98691, r12vrr_stack+13956, r12vrr_stack+98625, NULL, NULL, r12vrr_stack+9538);

 /*--- compute (d0|n0)^6 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+98889, r12vrr_stack+26062, r12vrr_stack+98691, r12vrr_stack+21926, r12vrr_stack+13956, r12vrr_stack+9593);

 /*--- compute (f0|n0)^5 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+99285, r12vrr_stack+14022, r12vrr_stack+98889, r12vrr_stack+21992, r12vrr_stack+26062, r12vrr_stack+2867);

 /*--- compute (g0|n0)^4 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+99945, r12vrr_stack+91365, r12vrr_stack+99285, r12vrr_stack+22190, r12vrr_stack+14022, r12vrr_stack+85315);

 /*--- compute (h0|n0)^3 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+77305, r12vrr_stack+92025, r12vrr_stack+99945, r12vrr_stack+22586, r12vrr_stack+91365, r12vrr_stack+85865);

 /*--- compute (i0|n0)^2 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+98625, r12vrr_stack+93015, r12vrr_stack+77305, r12vrr_stack+65426, r12vrr_stack+92025, r12vrr_stack+86690);

 /*--- compute (k0|n0)^1 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+77305, r12vrr_stack+94401, r12vrr_stack+98625, r12vrr_stack+66416, r12vrr_stack+93015, r12vrr_stack+87845);

 /*--- compute (l0|n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+79681, r12vrr_stack+96249, r12vrr_stack+77305, r12vrr_stack+67802, r12vrr_stack+94401, r12vrr_stack+89385);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+77305, &(Data->ss_r12_ss), NULL, r12vrr_stack+24, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+77308, r12vrr_stack+77305, &(Data->ss_r12_ss), r12vrr_stack+701, r12vrr_stack+24, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+77314, r12vrr_stack+77308, r12vrr_stack+77305, r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+24, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+77324, r12vrr_stack+77314, r12vrr_stack+77308, r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+701, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+30690, r12vrr_stack+77324, r12vrr_stack+77314, r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+707, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+77339, r12vrr_stack+30690, NULL, r12vrr_stack+3532, r12vrr_stack+521, NULL, r12vrr_stack+717);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+77402, r12vrr_stack+77339, r12vrr_stack+30690, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+732);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+77528, r12vrr_stack+77402, r12vrr_stack+77339, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+777);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+29010, r12vrr_stack+77528, r12vrr_stack+77402, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+1167);
 tmp = r12vrr_stack + 29010;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+732, r12vrr_stack+29010, r12vrr_stack+77528, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+1317);
 tmp = r12vrr_stack + 732;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+77339, r12vrr_stack+732, r12vrr_stack+29010, r12vrr_stack+30711, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+2524);
 tmp = r12vrr_stack + 77339;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||h0)^0 ---*/
 _R_BUILD_k0h0(Data,r12vrr_stack+77927, r12vrr_stack+77339, r12vrr_stack+732, r12vrr_stack+48270, r12vrr_stack+30711, r12vrr_stack+4897, r12vrr_stack+29325);
 tmp = r12vrr_stack + 77927;
 target_ptr = Libr12->rvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+732, r12vrr_stack+30690, r12vrr_stack+77324, r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+717, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+760, r12vrr_stack+732, NULL, r12vrr_stack+5730, r12vrr_stack+2839, NULL, r12vrr_stack+521);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+844, r12vrr_stack+760, r12vrr_stack+732, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+3532);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+1012, r12vrr_stack+844, r12vrr_stack+760, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+3595);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+78683, r12vrr_stack+1012, r12vrr_stack+844, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+3721);
 tmp = r12vrr_stack + 78683;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+98625, r12vrr_stack+78683, r12vrr_stack+1012, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+4582);
 tmp = r12vrr_stack + 98625;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+99213, r12vrr_stack+98625, r12vrr_stack+78683, r12vrr_stack+32307, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4897);
 tmp = r12vrr_stack + 99213;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||i0)^0 ---*/
 _R_BUILD_k0i0(Data,r12vrr_stack+31299, r12vrr_stack+99213, r12vrr_stack+98625, r12vrr_stack+50818, r12vrr_stack+32307, r12vrr_stack+8166, r12vrr_stack+30711);
 tmp = r12vrr_stack + 31299;
 target_ptr = Libr12->rvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+34711, r12vrr_stack+732, r12vrr_stack+30690, r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+521, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+98625, r12vrr_stack+34711, NULL, r12vrr_stack+9186, r12vrr_stack+5394, NULL, r12vrr_stack+2839);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+98733, r12vrr_stack+98625, r12vrr_stack+34711, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+5730);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+78683, r12vrr_stack+98733, r12vrr_stack+98625, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5814);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+69650, r12vrr_stack+78683, r12vrr_stack+98733, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+6514);
 tmp = r12vrr_stack + 69650;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+99997, r12vrr_stack+69650, r12vrr_stack+78683, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6794);
 tmp = r12vrr_stack + 99997;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+65426, r12vrr_stack+99997, r12vrr_stack+69650, r12vrr_stack+34747, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+8166);
 tmp = r12vrr_stack + 65426;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||k0)^0 ---*/
 _R_BUILD_k0k0(Data,r12vrr_stack+66434, r12vrr_stack+65426, r12vrr_stack+99997, r12vrr_stack+54130, r12vrr_stack+34747, r12vrr_stack+12210, r12vrr_stack+32307);
 tmp = r12vrr_stack + 66434;
 target_ptr = Libr12->rvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+12966, r12vrr_stack+34711, r12vrr_stack+732, r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+2839, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+2839, r12vrr_stack+12966, NULL, r12vrr_stack+13551, r12vrr_stack+8754, NULL, r12vrr_stack+5394);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+2974, r12vrr_stack+2839, r12vrr_stack+12966, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+9186);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+3244, r12vrr_stack+2974, r12vrr_stack+2839, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+9294);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+99997, r12vrr_stack+3244, r12vrr_stack+2974, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+10194);
 tmp = r12vrr_stack + 99997;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+78683, r12vrr_stack+99997, r12vrr_stack+3244, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10554);
 tmp = r12vrr_stack + 78683;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+82651, r12vrr_stack+78683, r12vrr_stack+99997, r12vrr_stack+37825, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+12210);
 tmp = r12vrr_stack + 82651;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||l0)^0 ---*/
 _R_BUILD_k0l0(Data,r12vrr_stack+83911, r12vrr_stack+82651, r12vrr_stack+78683, r12vrr_stack+58306, r12vrr_stack+37825, r12vrr_stack+17241, r12vrr_stack+34747);
 tmp = r12vrr_stack + 83911;
 target_ptr = Libr12->rvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+41560, r12vrr_stack+12966, r12vrr_stack+34711, r12vrr_stack+13011, r12vrr_stack+8754, r12vrr_stack+5394, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+78683, r12vrr_stack+41560, NULL, r12vrr_stack+19011, r12vrr_stack+13011, NULL, r12vrr_stack+8754);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+78683, r12vrr_stack+41560, r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+13011, r12vrr_stack+13551);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+9084, r12vrr_stack+8754, r12vrr_stack+78683, r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+13686);

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+78683, r12vrr_stack+9084, r12vrr_stack+8754, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+14721);
 tmp = r12vrr_stack + 78683;
 target_ptr = Libr12->rvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+78683, r12vrr_stack+9084, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+15171);
 tmp = r12vrr_stack + 12966;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+85531, r12vrr_stack+12966, r12vrr_stack+78683, r12vrr_stack+41615, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+17241);
 tmp = r12vrr_stack + 85531;
 target_ptr = Libr12->rvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+87071, r12vrr_stack+85531, r12vrr_stack+12966, r12vrr_stack+63446, r12vrr_stack+41615, r12vrr_stack+23631, r12vrr_stack+37825);
 tmp = r12vrr_stack + 87071;
 target_ptr = Libr12->rvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+29010, r12vrr_stack+4582, r12vrr_stack+6794, r12vrr_stack+4897, r12vrr_stack+2524, r12vrr_stack+1317);
 tmp = r12vrr_stack + 29010;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+12966, r12vrr_stack+6794, r12vrr_stack+10554, r12vrr_stack+8166, r12vrr_stack+4897, r12vrr_stack+4582);
 tmp = r12vrr_stack + 12966;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+69650, r12vrr_stack+10554, r12vrr_stack+15171, r12vrr_stack+12210, r12vrr_stack+8166, r12vrr_stack+6794);
 tmp = r12vrr_stack + 69650;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13386, r12vrr_stack+15171, r12vrr_stack+21101, r12vrr_stack+17241, r12vrr_stack+12210, r12vrr_stack+10554);
 tmp = r12vrr_stack + 13386;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+78683, r12vrr_stack+21101, r12vrr_stack+28020, r12vrr_stack+23631, r12vrr_stack+17241, r12vrr_stack+15171);
 tmp = r12vrr_stack + 78683;
 target_ptr = Libr12->t2vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14061, r12vrr_stack+4897, r12vrr_stack+8166, r12vrr_stack+30711, r12vrr_stack+29325, r12vrr_stack+2524);
 tmp = r12vrr_stack + 14061;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+98625, r12vrr_stack+8166, r12vrr_stack+12210, r12vrr_stack+32307, r12vrr_stack+30711, r12vrr_stack+4897);
 tmp = r12vrr_stack + 98625;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8754, r12vrr_stack+12210, r12vrr_stack+17241, r12vrr_stack+34747, r12vrr_stack+32307, r12vrr_stack+8166);
 tmp = r12vrr_stack + 8754;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+99997, r12vrr_stack+17241, r12vrr_stack+23631, r12vrr_stack+37825, r12vrr_stack+34747, r12vrr_stack+12210);
 tmp = r12vrr_stack + 99997;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+89051, r12vrr_stack+23631, r12vrr_stack+44805, r12vrr_stack+41615, r12vrr_stack+37825, r12vrr_stack+17241);
 tmp = r12vrr_stack + 89051;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9510, r12vrr_stack+30711, r12vrr_stack+32307, r12vrr_stack+48270, r12vrr_stack+1935, r12vrr_stack+29325);
 tmp = r12vrr_stack + 9510;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+90206, r12vrr_stack+32307, r12vrr_stack+34747, r12vrr_stack+50818, r12vrr_stack+48270, r12vrr_stack+30711);
 tmp = r12vrr_stack + 90206;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+90990, r12vrr_stack+34747, r12vrr_stack+37825, r12vrr_stack+54130, r12vrr_stack+50818, r12vrr_stack+32307);
 tmp = r12vrr_stack + 90990;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+91998, r12vrr_stack+37825, r12vrr_stack+41615, r12vrr_stack+58306, r12vrr_stack+54130, r12vrr_stack+34747);
 tmp = r12vrr_stack + 91998;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+93258, r12vrr_stack+41615, r12vrr_stack+67802, r12vrr_stack+63446, r12vrr_stack+58306, r12vrr_stack+37825);
 tmp = r12vrr_stack + 93258;
 target_ptr = Libr12->t2vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+94798, r12vrr_stack+48270, r12vrr_stack+50818, r12vrr_stack+29745, r12vrr_stack+70190, r12vrr_stack+1935);
 tmp = r12vrr_stack + 94798;
 target_ptr = Libr12->t2vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21926, r12vrr_stack+50818, r12vrr_stack+54130, r12vrr_stack+76045, r12vrr_stack+29745, r12vrr_stack+48270);
 tmp = r12vrr_stack + 21926;
 target_ptr = Libr12->t2vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+43155, r12vrr_stack+54130, r12vrr_stack+58306, r12vrr_stack+33091, r12vrr_stack+76045, r12vrr_stack+50818);
 tmp = r12vrr_stack + 43155;
 target_ptr = Libr12->t2vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+18186, r12vrr_stack+58306, r12vrr_stack+63446, r12vrr_stack+35755, r12vrr_stack+33091, r12vrr_stack+54130);
 tmp = r12vrr_stack + 18186;
 target_ptr = Libr12->t2vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+72020, r12vrr_stack+63446, r12vrr_stack+96249, r12vrr_stack+39085, r12vrr_stack+35755, r12vrr_stack+58306);
 tmp = r12vrr_stack + 72020;
 target_ptr = Libr12->t2vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15846, r12vrr_stack+29745, r12vrr_stack+76045, r12vrr_stack+70865, r12vrr_stack+26260, r12vrr_stack+70190);
 tmp = r12vrr_stack + 15846;
 target_ptr = Libr12->t2vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+74000, r12vrr_stack+76045, r12vrr_stack+33091, r12vrr_stack+49026, r12vrr_stack+70865, r12vrr_stack+29745);
 tmp = r12vrr_stack + 74000;
 target_ptr = Libr12->t2vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+46191, r12vrr_stack+33091, r12vrr_stack+35755, r12vrr_stack+51826, r12vrr_stack+49026, r12vrr_stack+76045);
 tmp = r12vrr_stack + 46191;
 target_ptr = Libr12->t2vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+24786, r12vrr_stack+35755, r12vrr_stack+39085, r12vrr_stack+55426, r12vrr_stack+51826, r12vrr_stack+33091);
 tmp = r12vrr_stack + 24786;
 target_ptr = Libr12->t2vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+100942, r12vrr_stack+39085, r12vrr_stack+79681, r12vrr_stack+59926, r12vrr_stack+55426, r12vrr_stack+35755);
 tmp = r12vrr_stack + 100942;
 target_ptr = Libr12->t2vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+70190, r12vrr_stack+4582, r12vrr_stack+4897, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+3721);
 tmp = r12vrr_stack + 70190;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+29325, r12vrr_stack+6794, r12vrr_stack+8166, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6514);
 tmp = r12vrr_stack + 29325;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+95554, r12vrr_stack+10554, r12vrr_stack+12210, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10194);
 tmp = r12vrr_stack + 95554;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+22934, r12vrr_stack+15171, r12vrr_stack+17241, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+14721);
 tmp = r12vrr_stack + 22934;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+11094, r12vrr_stack+21101, r12vrr_stack+23631, r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+20551);
 tmp = r12vrr_stack + 11094;
 target_ptr = Libr12->t1vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14502, r12vrr_stack+4897, r12vrr_stack+30711, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4582);
 tmp = r12vrr_stack + 14502;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19806, r12vrr_stack+8166, r12vrr_stack+32307, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+6794);
 tmp = r12vrr_stack + 19806;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+75260, r12vrr_stack+12210, r12vrr_stack+34747, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+10554);
 tmp = r12vrr_stack + 75260;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10098, r12vrr_stack+17241, r12vrr_stack+37825, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+15171);
 tmp = r12vrr_stack + 10098;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+26811, r12vrr_stack+23631, r12vrr_stack+41615, r12vrr_stack+44805, r12vrr_stack+28020, r12vrr_stack+21101);
 tmp = r12vrr_stack + 26811;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14943, r12vrr_stack+30711, r12vrr_stack+48270, r12vrr_stack+32307, r12vrr_stack+8166, r12vrr_stack+4897);
 tmp = r12vrr_stack + 14943;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20394, r12vrr_stack+32307, r12vrr_stack+50818, r12vrr_stack+34747, r12vrr_stack+12210, r12vrr_stack+8166);
 tmp = r12vrr_stack + 20394;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+27966, r12vrr_stack+34747, r12vrr_stack+54130, r12vrr_stack+37825, r12vrr_stack+17241, r12vrr_stack+12210);
 tmp = r12vrr_stack + 27966;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+37825, r12vrr_stack+58306, r12vrr_stack+41615, r12vrr_stack+23631, r12vrr_stack+17241);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+2475, r12vrr_stack+41615, r12vrr_stack+63446, r12vrr_stack+67802, r12vrr_stack+44805, r12vrr_stack+23631);
 tmp = r12vrr_stack + 2475;
 target_ptr = Libr12->t1vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23609, r12vrr_stack+48270, r12vrr_stack+29745, r12vrr_stack+50818, r12vrr_stack+32307, r12vrr_stack+30711);
 tmp = r12vrr_stack + 23609;
 target_ptr = Libr12->t1vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+44451, r12vrr_stack+50818, r12vrr_stack+76045, r12vrr_stack+54130, r12vrr_stack+34747, r12vrr_stack+32307);
 tmp = r12vrr_stack + 44451;
 target_ptr = Libr12->t1vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16791, r12vrr_stack+54130, r12vrr_stack+33091, r12vrr_stack+58306, r12vrr_stack+37825, r12vrr_stack+34747);
 tmp = r12vrr_stack + 16791;
 target_ptr = Libr12->t1vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4015, r12vrr_stack+58306, r12vrr_stack+35755, r12vrr_stack+63446, r12vrr_stack+41615, r12vrr_stack+37825);
 tmp = r12vrr_stack + 4015;
 target_ptr = Libr12->t1vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+5635, r12vrr_stack+63446, r12vrr_stack+39085, r12vrr_stack+96249, r12vrr_stack+67802, r12vrr_stack+41615);
 tmp = r12vrr_stack + 5635;
 target_ptr = Libr12->t1vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+67730, r12vrr_stack+29745, r12vrr_stack+70865, r12vrr_stack+76045, r12vrr_stack+50818, r12vrr_stack+48270);
 tmp = r12vrr_stack + 67730;
 target_ptr = Libr12->t1vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+70505, r12vrr_stack+76045, r12vrr_stack+49026, r12vrr_stack+33091, r12vrr_stack+54130, r12vrr_stack+50818);
 tmp = r12vrr_stack + 70505;
 target_ptr = Libr12->t1vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+49026, r12vrr_stack+33091, r12vrr_stack+51826, r12vrr_stack+35755, r12vrr_stack+58306, r12vrr_stack+54130);
 tmp = r12vrr_stack + 49026;
 target_ptr = Libr12->t1vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+51826, r12vrr_stack+35755, r12vrr_stack+55426, r12vrr_stack+39085, r12vrr_stack+63446, r12vrr_stack+58306);
 tmp = r12vrr_stack + 51826;
 target_ptr = Libr12->t1vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+55426, r12vrr_stack+39085, r12vrr_stack+59926, r12vrr_stack+79681, r12vrr_stack+96249, r12vrr_stack+63446);
 tmp = r12vrr_stack + 55426;
 target_ptr = Libr12->t1vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||h0)^0 ---*/
 _R_BUILD_l0h0(Data,r12vrr_stack+59926, r12vrr_stack+77927, r12vrr_stack+77339, r12vrr_stack+29745, r12vrr_stack+48270, r12vrr_stack+30711, r12vrr_stack+1935);
 tmp = r12vrr_stack + 59926;
 target_ptr = Libr12->rvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||i0)^0 ---*/
 _R_BUILD_l0i0(Data,r12vrr_stack+29745, r12vrr_stack+31299, r12vrr_stack+99213, r12vrr_stack+76045, r12vrr_stack+50818, r12vrr_stack+32307, r12vrr_stack+48270);
 tmp = r12vrr_stack + 29745;
 target_ptr = Libr12->rvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||k0)^0 ---*/
 _R_BUILD_l0k0(Data,r12vrr_stack+31005, r12vrr_stack+66434, r12vrr_stack+65426, r12vrr_stack+33091, r12vrr_stack+54130, r12vrr_stack+34747, r12vrr_stack+50818);
 tmp = r12vrr_stack + 31005;
 target_ptr = Libr12->rvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||l0)^0 ---*/
 _R_BUILD_l0l0(Data,r12vrr_stack+65426, r12vrr_stack+83911, r12vrr_stack+82651, r12vrr_stack+35755, r12vrr_stack+58306, r12vrr_stack+37825, r12vrr_stack+54130);
 tmp = r12vrr_stack + 65426;
 target_ptr = Libr12->rvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+32625, r12vrr_stack+87071, r12vrr_stack+85531, r12vrr_stack+39085, r12vrr_stack+63446, r12vrr_stack+41615, r12vrr_stack+58306);
 tmp = r12vrr_stack + 32625;
 target_ptr = Libr12->rvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];


}

